/*!
 * Bootstrap v3.3.5 (http://getbootstrap.com)
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under the MIT license
 */

/* ========================================================================
 * Bootstrap: transition.js v3.3.5
 * http://getbootstrap.com/javascript/#transitions
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */

/* ========================================================================
 * Bootstrap: alert.js v3.3.5
 * http://getbootstrap.com/javascript/#alerts
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */

/* ========================================================================
 * Bootstrap: button.js v3.3.5
 * http://getbootstrap.com/javascript/#buttons
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== *


+ function ($) {
	'use strict';

	// BUTTON PUBLIC CLASS DEFINITION
	// ==============================

	var Button = function (element, options) {
		this.$element = $(element)
		this.options = $.extend({}, Button.DEFAULTS, options)
		this.isLoading = false
	}

	Button.VERSION = '3.3.5'

	Button.DEFAULTS = {
		loadingText: 'loading...'
	}

	Button.prototype.setState = function (state) {
		var d = 'disabled'
		var $el = this.$element
		var val = $el.is('input') ? 'val' : 'html'
		var data = $el.data()

		state += 'Text'

		if (data.resetText == null) $el.data('resetText', $el[val]())

		// push to event loop to allow forms to submit
		setTimeout($.proxy(function () {
			$el[val](data[state] == null ? this.options[state] : data[state])

			if (state == 'loadingText') {
				this.isLoading = true
				$el.addClass(d).attr(d, d)
			} else if (this.isLoading) {
				this.isLoading = false
				$el.removeClass(d).removeAttr(d)
			}
		}, this), 0)
	}

	Button.prototype.toggle = function () {
		var changed = true
		var $parent = this.$element.closest('[data-toggle="buttons"]')

		if ($parent.length) {
			var $input = this.$element.find('input')
			if ($input.prop('type') == 'radio') {
				if ($input.prop('checked')) changed = false
				$parent.find('.active').removeClass('active')
				this.$element.addClass('active')
			} else if ($input.prop('type') == 'checkbox') {
				if (($input.prop('checked')) !== this.$element.hasClass('active')) changed = false
				this.$element.toggleClass('active')
			}
			$input.prop('checked', this.$element.hasClass('active'))
			if (changed) $input.trigger('change')
		} else {
			this.$element.attr('aria-pressed', !this.$element.hasClass('active'))
			this.$element.toggleClass('active')
		}
	}


	// BUTTON PLUGIN DEFINITION
	// ========================

	function Plugin(option) {
		return this.each(function () {
			var $this = $(this)
			var data = $this.data('bs.button')
			var options = typeof option == 'object' && option

			if (!data) $this.data('bs.button', (data = new Button(this, options)))

			if (option == 'toggle') data.toggle()
			else if (option) data.setState(option)
		})
	}

	var old = $.fn.button

	$.fn.button = Plugin
	$.fn.button.Constructor = Button


	// BUTTON NO CONFLICT
	// ==================

	$.fn.button.noConflict = function () {
		$.fn.button = old
		return this
	}


	// BUTTON DATA-API
	// ===============

	$(document)
		.on('click.bs.button.data-api', '[data-toggle^="button"]', function (e) {
			var $btn = $(e.target)
			if (!$btn.hasClass('btn')) $btn = $btn.closest('.btn')
			Plugin.call($btn, 'toggle')
			if (!($(e.target).is('input[type="radio"]') || $(e.target).is('input[type="checkbox"]'))) e.preventDefault()
		})
		.on('focus.bs.button.data-api blur.bs.button.data-api', '[data-toggle^="button"]', function (e) {
			$(e.target).closest('.btn').toggleClass('focus', /^focus(in)?$/.test(e.type))
		})

}(jQuery);

/* ========================================================================
 * Bootstrap: carousel.js v3.3.5
 * http://getbootstrap.com/javascript/#carousel
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== *


+ function ($) {
	'use strict';

	// CAROUSEL CLASS DEFINITION
	// =========================

	var Carousel = function (element, options) {
		this.$element = $(element)
		this.$indicators = this.$element.find('.carousel-indicators')
		this.options = options
		this.paused = null
		this.sliding = null
		this.interval = null
		this.$active = null
		this.$items = null

		this.options.keyboard && this.$element.on('keydown.bs.carousel', $.proxy(this.keydown, this))

		this.options.pause == 'hover' && !('ontouchstart' in document.documentElement) && this.$element
			.on('mouseenter.bs.carousel', $.proxy(this.pause, this))
			.on('mouseleave.bs.carousel', $.proxy(this.cycle, this))
	}

	Carousel.VERSION = '3.3.5'

	Carousel.TRANSITION_DURATION = 600

	Carousel.DEFAULTS = {
		interval: 5000,
		pause: 'hover',
		wrap: true,
		keyboard: true
	}

	Carousel.prototype.keydown = function (e) {
		if (/input|textarea/i.test(e.target.tagName)) return
		switch (e.which) {
		case 37:
			this.prev();
			break
		case 39:
			this.next();
			break
		default:
			return
		}

		e.preventDefault()
	}

	Carousel.prototype.cycle = function (e) {
		e || (this.paused = false)

		this.interval && clearInterval(this.interval)

		this.options.interval && !this.paused && (this.interval = setInterval($.proxy(this.next, this), this.options.interval))

		return this
	}

	Carousel.prototype.getItemIndex = function (item) {
		this.$items = item.parent().children('.item')
		return this.$items.index(item || this.$active)
	}

	Carousel.prototype.getItemForDirection = function (direction, active) {
		var activeIndex = this.getItemIndex(active)
		var willWrap = (direction == 'prev' && activeIndex === 0) || (direction == 'next' && activeIndex == (this.$items.length - 1))
		if (willWrap && !this.options.wrap) return active
		var delta = direction == 'prev' ? -1 : 1
		var itemIndex = (activeIndex + delta) % this.$items.length
		return this.$items.eq(itemIndex)
	}

	Carousel.prototype.to = function (pos) {
		var that = this
		var activeIndex = this.getItemIndex(this.$active = this.$element.find('.item.active'))

		if (pos > (this.$items.length - 1) || pos < 0) return

		if (this.sliding) return this.$element.one('slid.bs.carousel', function () {
				that.to(pos)
			}) // yes, "slid"
		if (activeIndex == pos) return this.pause().cycle()

		return this.slide(pos > activeIndex ? 'next' : 'prev', this.$items.eq(pos))
	}

	Carousel.prototype.pause = function (e) {
		e || (this.paused = true)

		if (this.$element.find('.next, .prev').length && $.support.transition) {
			this.$element.trigger($.support.transition.end)
			this.cycle(true)
		}

		this.interval = clearInterval(this.interval)

		return this
	}

	Carousel.prototype.next = function () {
		if (this.sliding) return
		return this.slide('next')
	}

	Carousel.prototype.prev = function () {
		if (this.sliding) return
		return this.slide('prev')
	}

	Carousel.prototype.slide = function (type, next) {
		var $active = this.$element.find('.item.active')
		var $next = next || this.getItemForDirection(type, $active)
		var isCycling = this.interval
		var direction = type == 'next' ? 'left' : 'right'
		var that = this

		if ($next.hasClass('active')) return (this.sliding = false)

		var relatedTarget = $next[0]
		var slideEvent = $.Event('slide.bs.carousel', {
			relatedTarget: relatedTarget,
			direction: direction
		})
		this.$element.trigger(slideEvent)
		if (slideEvent.isDefaultPrevented()) return

		this.sliding = true

		isCycling && this.pause()

		if (this.$indicators.length) {
			this.$indicators.find('.active').removeClass('active')
			var $nextIndicator = $(this.$indicators.children()[this.getItemIndex($next)])
			$nextIndicator && $nextIndicator.addClass('active')
		}

		var slidEvent = $.Event('slid.bs.carousel', {
				relatedTarget: relatedTarget,
				direction: direction
			}) // yes, "slid"
		if ($.support.transition && this.$element.hasClass('slide')) {
			$next.addClass(type)
			$next[0].offsetWidth // force reflow
			$active.addClass(direction)
			$next.addClass(direction)
			$active
				.one('bsTransitionEnd', function () {
					$next.removeClass([type, direction].join(' ')).addClass('active')
					$active.removeClass(['active', direction].join(' '))
					that.sliding = false
					setTimeout(function () {
						that.$element.trigger(slidEvent)
					}, 0)
				})
				.emulateTransitionEnd(Carousel.TRANSITION_DURATION)
		} else {
			$active.removeClass('active')
			$next.addClass('active')
			this.sliding = false
			this.$element.trigger(slidEvent)
		}

		isCycling && this.cycle()

		return this
	}


	// CAROUSEL PLUGIN DEFINITION
	// ==========================

	function Plugin(option) {
		return this.each(function () {
			var $this = $(this)
			var data = $this.data('bs.carousel')
			var options = $.extend({}, Carousel.DEFAULTS, $this.data(), typeof option == 'object' && option)
			var action = typeof option == 'string' ? option : options.slide

			if (!data) $this.data('bs.carousel', (data = new Carousel(this, options)))
			if (typeof option == 'number') data.to(option)
			else if (action) data[action]()
			else if (options.interval) data.pause().cycle()
		})
	}

	var old = $.fn.carousel

	$.fn.carousel = Plugin
	$.fn.carousel.Constructor = Carousel


	// CAROUSEL NO CONFLICT
	// ====================

	$.fn.carousel.noConflict = function () {
		$.fn.carousel = old
		return this
	}


	// CAROUSEL DATA-API
	// =================

	var clickHandler = function (e) {
		var href
		var $this = $(this)
		var $target = $($this.attr('data-target') || (href = $this.attr('href')) && href.replace(/.*(?=#[^\s]+$)/, '')) // strip for ie7
		if (!$target.hasClass('carousel')) return
		var options = $.extend({}, $target.data(), $this.data())
		var slideIndex = $this.attr('data-slide-to')
		if (slideIndex) options.interval = false

		Plugin.call($target, options)

		if (slideIndex) {
			$target.data('bs.carousel').to(slideIndex)
		}

		e.preventDefault()
	}

	$(document)
		.on('click.bs.carousel.data-api', '[data-slide]', clickHandler)
		.on('click.bs.carousel.data-api', '[data-slide-to]', clickHandler)

	$(window).on('load', function () {
		$('[data-ride="carousel"]').each(function () {
			var $carousel = $(this)
			Plugin.call($carousel, $carousel.data())
		})
	})

}(jQuery);

/* ========================================================================
 * Bootstrap: collapse.js v3.3.5
 * http://getbootstrap.com/javascript/#collapse
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */

/* ========================================================================
 * Bootstrap: dropdown.js v3.3.5
 * http://getbootstrap.com/javascript/#dropdowns
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */

/* ========================================================================
 * Bootstrap: modal.js v3.3.5
 * http://getbootstrap.com/javascript/#modals
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */

/* ========================================================================
 * Bootstrap: tooltip.js v3.3.5
 * http://getbootstrap.com/javascript/#tooltip
 * Inspired by the original jQuery.tipsy by Jason Frame
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */

/* ========================================================================
 * Bootstrap: popover.js v3.3.5
 * http://getbootstrap.com/javascript/#popovers
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */

/* ========================================================================
 * Bootstrap: scrollspy.js v3.3.5
 * http://getbootstrap.com/javascript/#scrollspy
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */

/* ========================================================================
 * Bootstrap: tab.js v3.3.5
 * http://getbootstrap.com/javascript/#tabs
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */

/* ========================================================================
 * Bootstrap: affix.js v3.3.5
 * http://getbootstrap.com/javascript/#affix
 * ========================================================================
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 * ======================================================================== */

if("undefined"===typeof jQuery)throw Error("Bootstrap's JavaScript requires jQuery");+function(c){c=c.fn.jquery.split(" ")[0].split(".");if(2>c[0]&&9>c[1]||1==c[0]&&9==c[1]&&1>c[2])throw Error("Bootstrap's JavaScript requires jQuery version 1.9.1 or higher");}(jQuery);
+function(c){c.fn.emulateTransitionEnd=function(d){var f=!1,b=this;c(this).one("bsTransitionEnd",function(){f=!0});setTimeout(function(){f||c(b).trigger(c.support.transition.end)},d);return this};c(function(){var d=c.support,f;a:{f=document.createElement("bootstrap");var b={WebkitTransition:"webkitTransitionEnd",MozTransition:"transitionend",OTransition:"oTransitionEnd otransitionend",transition:"transitionend"},a;for(a in b)if(void 0!==f.style[a]){f={end:b[a]};break a}f=!1}d.transition=f;c.support.transition&&
(c.event.special.bsTransitionEnd={bindType:c.support.transition.end,delegateType:c.support.transition.end,handle:function(a){if(c(a.target).is(this))return a.handleObj.handler.apply(this,arguments)}})})}(jQuery);
+function(c){var d=function(b){c(b).on("click",'[data-dismiss="alert"]',this.close)};d.VERSION="3.3.5";d.TRANSITION_DURATION=150;d.prototype.close=function(b){function a(){h.detach().trigger("closed.bs.alert").remove()}var g=c(this),e=g.attr("data-target");e||(e=(e=g.attr("href"))&&e.replace(/.*(?=#[^\s]*$)/,""));var h=c(e);b&&b.preventDefault();h.length||(h=g.closest(".alert"));h.trigger(b=c.Event("close.bs.alert"));b.isDefaultPrevented()||(h.removeClass("in"),c.support.transition&&h.hasClass("fade")?
h.one("bsTransitionEnd",a).emulateTransitionEnd(d.TRANSITION_DURATION):a())};var f=c.fn.alert;c.fn.alert=function(b){return this.each(function(){var a=c(this),g=a.data("bs.alert");g||a.data("bs.alert",g=new d(this));"string"==typeof b&&g[b].call(a)})};c.fn.alert.Constructor=d;c.fn.alert.noConflict=function(){c.fn.alert=f;return this};c(document).on("click.bs.alert.data-api",'[data-dismiss="alert"]',d.prototype.close)}(jQuery);
+function(c){function d(a){var b,a=a.attr("data-target")||(b=a.attr("href"))&&b.replace(/.*(?=#[^\s]+$)/,"");return c(a)}function f(a){return this.each(function(){var e=c(this),h=e.data("bs.collapse"),k=c.extend({},b.DEFAULTS,e.data(),"object"==typeof a&&a);!h&&(k.toggle&&/show|hide/.test(a))&&(k.toggle=!1);h||e.data("bs.collapse",h=new b(this,k));if("string"==typeof a)h[a]()})}var b=function(a,e){this.$element=c(a);this.options=c.extend({},b.DEFAULTS,e);this.$trigger=c('[data-toggle="collapse"][href="#'+
a.id+'"],[data-toggle="collapse"][data-target="#'+a.id+'"]');this.transitioning=null;this.options.parent?this.$parent=this.getParent():this.addAriaAndCollapsedClass(this.$element,this.$trigger);this.options.toggle&&this.toggle()};b.VERSION="3.3.5";b.TRANSITION_DURATION=350;b.DEFAULTS={toggle:!0};b.prototype.dimension=function(){return this.$element.hasClass("width")?"width":"height"};b.prototype.show=function(){if(!this.transitioning&&!this.$element.hasClass("in")){var a,e=this.$parent&&this.$parent.children(".panel").children(".in, .collapsing");
if(e&&e.length&&(a=e.data("bs.collapse"))&&a.transitioning)return;var h=c.Event("show.bs.collapse");this.$element.trigger(h);if(!h.isDefaultPrevented()){e&&e.length&&(f.call(e,"hide"),a||e.data("bs.collapse",null));var k=this.dimension();this.$element.removeClass("collapse").addClass("collapsing")[k](0).attr("aria-expanded",!0);this.$trigger.removeClass("collapsed").attr("aria-expanded",!0);this.transitioning=1;a=function(){this.$element.removeClass("collapsing").addClass("collapse in")[k]("");this.transitioning=
0;this.$element.trigger("shown.bs.collapse")};if(!c.support.transition)return a.call(this);e=c.camelCase(["scroll",k].join("-"));this.$element.one("bsTransitionEnd",c.proxy(a,this)).emulateTransitionEnd(b.TRANSITION_DURATION)[k](this.$element[0][e])}}};b.prototype.hide=function(){if(!this.transitioning&&this.$element.hasClass("in")){var a=c.Event("hide.bs.collapse");this.$element.trigger(a);if(!a.isDefaultPrevented()){a=this.dimension();this.$element[a](this.$element[a]())[0].offsetHeight;this.$element.addClass("collapsing").removeClass("collapse in").attr("aria-expanded",
!1);this.$trigger.addClass("collapsed").attr("aria-expanded",!1);this.transitioning=1;var e=function(){this.transitioning=0;this.$element.removeClass("collapsing").addClass("collapse").trigger("hidden.bs.collapse")};if(!c.support.transition)return e.call(this);this.$element[a](0).one("bsTransitionEnd",c.proxy(e,this)).emulateTransitionEnd(b.TRANSITION_DURATION)}}};b.prototype.toggle=function(){this[this.$element.hasClass("in")?"hide":"show"]()};b.prototype.getParent=function(){return c(this.options.parent).find('[data-toggle="collapse"][data-parent="'+
this.options.parent+'"]').each(c.proxy(function(a,b){var h=c(b);this.addAriaAndCollapsedClass(d(h),h)},this)).end()};b.prototype.addAriaAndCollapsedClass=function(a,c){var b=a.hasClass("in");a.attr("aria-expanded",b);c.toggleClass("collapsed",!b).attr("aria-expanded",b)};var a=c.fn.collapse;c.fn.collapse=f;c.fn.collapse.Constructor=b;c.fn.collapse.noConflict=function(){c.fn.collapse=a;return this};c(document).on("click.bs.collapse.data-api",'[data-toggle="collapse"]',function(a){var b=c(this);b.attr("data-target")||
a.preventDefault();a=d(b);b=a.data("bs.collapse")?"toggle":b.data();f.call(a,b)})}(jQuery);
+function(c){function d(a){var b=a.attr("data-target");b||(b=(b=a.attr("href"))&&/#[A-Za-z]/.test(b)&&b.replace(/.*(?=#[^\s]*$)/,""));return(b=b&&c(b))&&b.length?b:a.parent()}function f(g){g&&3===g.which||(c(b).remove(),c(a).each(function(){var a=c(this),b=d(a),e={relatedTarget:this};if(b.hasClass("open")&&(!g||!("click"==g.type&&/input|textarea/i.test(g.target.tagName)&&c.contains(b[0],g.target))))b.trigger(g=c.Event("hide.bs.dropdown",e)),g.isDefaultPrevented()||(a.attr("aria-expanded","false"),
b.removeClass("open").trigger("hidden.bs.dropdown",e))}))}var b=".dropdown-backdrop",a='[data-toggle="dropdown"]',g=function(a){c(a).on("click.bs.dropdown",this.toggle)};g.VERSION="3.3.5";g.prototype.toggle=function(a){var b=c(this);if(!b.is(".disabled, :disabled")){var g=d(b),a=g.hasClass("open");f();if(!a){if("ontouchstart"in document.documentElement&&!g.closest(".navbar-nav").length)c(document.createElement("div")).addClass("dropdown-backdrop").insertAfter(c(this)).on("click",f);var e={relatedTarget:this};
g.trigger(a=c.Event("show.bs.dropdown",e));if(a.isDefaultPrevented())return;b.trigger("focus").attr("aria-expanded","true");g.toggleClass("open").trigger("shown.bs.dropdown",e)}return!1}};g.prototype.keydown=function(b){if(/(38|40|27|32)/.test(b.which)&&!/input|textarea/i.test(b.target.tagName)){var g=c(this);b.preventDefault();b.stopPropagation();if(!g.is(".disabled, :disabled")){var e=d(g),f=e.hasClass("open");if(!f&&27!=b.which||f&&27==b.which)return 27==b.which&&e.find(a).trigger("focus"),g.trigger("click");
g=e.find(".dropdown-menu li:not(.disabled):visible a");g.length&&(e=g.index(b.target),38==b.which&&0<e&&e--,40==b.which&&e<g.length-1&&e++,~e||(e=0),g.eq(e).trigger("focus"))}}};var e=c.fn.dropdown;c.fn.dropdown=function(a){return this.each(function(){var b=c(this),e=b.data("bs.dropdown");e||b.data("bs.dropdown",e=new g(this));"string"==typeof a&&e[a].call(b)})};c.fn.dropdown.Constructor=g;c.fn.dropdown.noConflict=function(){c.fn.dropdown=e;return this};c(document).on("click.bs.dropdown.data-api",
f).on("click.bs.dropdown.data-api",".dropdown form",function(a){a.stopPropagation()}).on("click.bs.dropdown.data-api",a,g.prototype.toggle).on("keydown.bs.dropdown.data-api",a,g.prototype.keydown).on("keydown.bs.dropdown.data-api",".dropdown-menu",g.prototype.keydown)}(jQuery);
+function(c){function d(a,b){return this.each(function(){var e=c(this),h=e.data("bs.modal"),d=c.extend({},f.DEFAULTS,e.data(),"object"==typeof a&&a);h||e.data("bs.modal",h=new f(this,d));if("string"==typeof a)h[a](b);else d.show&&h.show(b)})}var f=function(a,b){this.options=b;this.$body=c(document.body);this.$element=c(a);this.$dialog=this.$element.find(".modal-dialog");this.originalBodyPad=this.isShown=this.$backdrop=null;this.scrollbarWidth=0;this.ignoreBackdropClick=!1;this.options.remote&&this.$element.find(".modal-content").load(this.options.remote,
c.proxy(function(){this.$element.trigger("loaded.bs.modal")},this))};f.VERSION="3.3.5";f.TRANSITION_DURATION=300;f.BACKDROP_TRANSITION_DURATION=150;f.DEFAULTS={backdrop:!0,keyboard:!0,show:!0};f.prototype.toggle=function(a){return this.isShown?this.hide():this.show(a)};f.prototype.show=function(a){var b=this,e=c.Event("show.bs.modal",{relatedTarget:a});this.$element.trigger(e);!this.isShown&&!e.isDefaultPrevented()&&(this.isShown=!0,this.checkScrollbar(),this.setScrollbar(),this.$body.addClass("modal-open"),
this.escape(),this.resize(),this.$element.on("click.dismiss.bs.modal",'[data-dismiss="modal"]',c.proxy(this.hide,this)),this.$dialog.on("mousedown.dismiss.bs.modal",function(){b.$element.one("mouseup.dismiss.bs.modal",function(a){c(a.target).is(b.$element)&&(b.ignoreBackdropClick=!0)})}),this.backdrop(function(){var e=c.support.transition&&b.$element.hasClass("fade");b.$element.parent().length||b.$element.appendTo(b.$body);b.$element.show().scrollTop(0);b.adjustDialog();e&&b.$element[0].offsetWidth;
b.$element.addClass("in");b.enforceFocus();var d=c.Event("shown.bs.modal",{relatedTarget:a});e?b.$dialog.one("bsTransitionEnd",function(){b.$element.trigger("focus").trigger(d)}).emulateTransitionEnd(f.TRANSITION_DURATION):b.$element.trigger("focus").trigger(d)}))};f.prototype.hide=function(a){a&&a.preventDefault();a=c.Event("hide.bs.modal");this.$element.trigger(a);this.isShown&&!a.isDefaultPrevented()&&(this.isShown=!1,this.escape(),this.resize(),c(document).off("focusin.bs.modal"),this.$element.removeClass("in").off("click.dismiss.bs.modal").off("mouseup.dismiss.bs.modal"),
this.$dialog.off("mousedown.dismiss.bs.modal"),c.support.transition&&this.$element.hasClass("fade")?this.$element.one("bsTransitionEnd",c.proxy(this.hideModal,this)).emulateTransitionEnd(f.TRANSITION_DURATION):this.hideModal())};f.prototype.enforceFocus=function(){c(document).off("focusin.bs.modal").on("focusin.bs.modal",c.proxy(function(a){this.$element[0]!==a.target&&!this.$element.has(a.target).length&&this.$element.trigger("focus")},this))};f.prototype.escape=function(){if(this.isShown&&this.options.keyboard)this.$element.on("keydown.dismiss.bs.modal",
c.proxy(function(a){27==a.which&&this.hide()},this));else this.isShown||this.$element.off("keydown.dismiss.bs.modal")};f.prototype.resize=function(){if(this.isShown)c(window).on("resize.bs.modal",c.proxy(this.handleUpdate,this));else c(window).off("resize.bs.modal")};f.prototype.hideModal=function(){var a=this;this.$element.hide();this.backdrop(function(){a.$body.removeClass("modal-open");a.resetAdjustments();a.resetScrollbar();a.$element.trigger("hidden.bs.modal")})};f.prototype.removeBackdrop=function(){this.$backdrop&&
this.$backdrop.remove();this.$backdrop=null};f.prototype.backdrop=function(a){var b=this,e=this.$element.hasClass("fade")?"fade":"";if(this.isShown&&this.options.backdrop){var h=c.support.transition&&e;this.$backdrop=c(document.createElement("div")).addClass("modal-backdrop "+e).appendTo(this.$body);this.$element.on("click.dismiss.bs.modal",c.proxy(function(a){this.ignoreBackdropClick?this.ignoreBackdropClick=!1:a.target===a.currentTarget&&("static"==this.options.backdrop?this.$element[0].focus():
this.hide())},this));h&&this.$backdrop[0].offsetWidth;this.$backdrop.addClass("in");a&&(h?this.$backdrop.one("bsTransitionEnd",a).emulateTransitionEnd(f.BACKDROP_TRANSITION_DURATION):a())}else!this.isShown&&this.$backdrop?(this.$backdrop.removeClass("in"),e=function(){b.removeBackdrop();a&&a()},c.support.transition&&this.$element.hasClass("fade")?this.$backdrop.one("bsTransitionEnd",e).emulateTransitionEnd(f.BACKDROP_TRANSITION_DURATION):e()):a&&a()};f.prototype.handleUpdate=function(){this.adjustDialog()};
f.prototype.adjustDialog=function(){var a=this.$element[0].scrollHeight>document.documentElement.clientHeight;this.$element.css({paddingLeft:!this.bodyIsOverflowing&&a?this.scrollbarWidth:"",paddingRight:this.bodyIsOverflowing&&!a?this.scrollbarWidth:""})};f.prototype.resetAdjustments=function(){this.$element.css({paddingLeft:"",paddingRight:""})};f.prototype.checkScrollbar=function(){var a=window.innerWidth;a||(a=document.documentElement.getBoundingClientRect(),a=a.right-Math.abs(a.left));this.bodyIsOverflowing=
document.body.clientWidth<a;this.scrollbarWidth=this.measureScrollbar()};f.prototype.setScrollbar=function(){var a=parseInt(this.$body.css("padding-right")||0,10);this.originalBodyPad=document.body.style.paddingRight||"";this.bodyIsOverflowing&&this.$body.css("padding-right",a+this.scrollbarWidth)};f.prototype.resetScrollbar=function(){this.$body.css("padding-right",this.originalBodyPad)};f.prototype.measureScrollbar=function(){var a=document.createElement("div");a.className="modal-scrollbar-measure";
this.$body.append(a);var b=a.offsetWidth-a.clientWidth;this.$body[0].removeChild(a);return b};var b=c.fn.modal;c.fn.modal=d;c.fn.modal.Constructor=f;c.fn.modal.noConflict=function(){c.fn.modal=b;return this};c(document).on("click.bs.modal.data-api",'[data-toggle="modal"]',function(a){var b=c(this),e=b.attr("href"),h=c(b.attr("data-target")||e&&e.replace(/.*(?=#[^\s]+$)/,"")),e=h.data("bs.modal")?"toggle":c.extend({remote:!/#/.test(e)&&e},h.data(),b.data());b.is("a")&&a.preventDefault();h.one("show.bs.modal",
function(a){if(!a.isDefaultPrevented())h.one("hidden.bs.modal",function(){b.is(":visible")&&b.trigger("focus")})});d.call(h,e,this)})}(jQuery);
+function(c){var d=function(b,a){this.inState=this.$element=this.hoverState=this.timeout=this.enabled=this.options=this.type=null;this.init("tooltip",b,a)};d.VERSION="3.3.5";d.TRANSITION_DURATION=150;d.DEFAULTS={animation:!0,placement:"top",selector:!1,template:'<div class="tooltip" role="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>',trigger:"hover focus",title:"",delay:0,html:!1,container:!1,viewport:{selector:"body",padding:0}};d.prototype.init=function(b,a,
g){this.enabled=!0;this.type=b;this.$element=c(a);this.options=this.getOptions(g);this.$viewport=this.options.viewport&&c(c.isFunction(this.options.viewport)?this.options.viewport.call(this,this.$element):this.options.viewport.selector||this.options.viewport);this.inState={click:!1,hover:!1,focus:!1};if(this.$element[0]instanceof document.constructor&&!this.options.selector)throw Error("`selector` option must be specified when initializing "+this.type+" on the window.document object!");b=this.options.trigger.split(" ");
for(a=b.length;a--;)if(g=b[a],"click"==g)this.$element.on("click."+this.type,this.options.selector,c.proxy(this.toggle,this));else if("manual"!=g){var e="hover"==g?"mouseleave":"focusout";this.$element.on(("hover"==g?"mouseenter":"focusin")+"."+this.type,this.options.selector,c.proxy(this.enter,this));this.$element.on(e+"."+this.type,this.options.selector,c.proxy(this.leave,this))}this.options.selector?this._options=c.extend({},this.options,{trigger:"manual",selector:""}):this.fixTitle()};d.prototype.getDefaults=
function(){return d.DEFAULTS};d.prototype.getOptions=function(b){b=c.extend({},this.getDefaults(),this.$element.data(),b);b.delay&&"number"==typeof b.delay&&(b.delay={show:b.delay,hide:b.delay});return b};d.prototype.getDelegateOptions=function(){var b={},a=this.getDefaults();this._options&&c.each(this._options,function(c,e){a[c]!=e&&(b[c]=e)});return b};d.prototype.enter=function(b){var a=b instanceof this.constructor?b:c(b.currentTarget).data("bs."+this.type);a||(a=new this.constructor(b.currentTarget,
this.getDelegateOptions()),c(b.currentTarget).data("bs."+this.type,a));b instanceof c.Event&&(a.inState["focusin"==b.type?"focus":"hover"]=!0);if(a.tip().hasClass("in")||"in"==a.hoverState)a.hoverState="in";else{clearTimeout(a.timeout);a.hoverState="in";if(!a.options.delay||!a.options.delay.show)return a.show();a.timeout=setTimeout(function(){"in"==a.hoverState&&a.show()},a.options.delay.show)}};d.prototype.isInStateTrue=function(){for(var b in this.inState)if(this.inState[b])return!0;return!1};d.prototype.leave=
function(b){var a=b instanceof this.constructor?b:c(b.currentTarget).data("bs."+this.type);a||(a=new this.constructor(b.currentTarget,this.getDelegateOptions()),c(b.currentTarget).data("bs."+this.type,a));b instanceof c.Event&&(a.inState["focusout"==b.type?"focus":"hover"]=!1);if(!a.isInStateTrue()){clearTimeout(a.timeout);a.hoverState="out";if(!a.options.delay||!a.options.delay.hide)return a.hide();a.timeout=setTimeout(function(){"out"==a.hoverState&&a.hide()},a.options.delay.hide)}};d.prototype.show=
function(){var b=c.Event("show.bs."+this.type);if(this.hasContent()&&this.enabled){this.$element.trigger(b);var a=c.contains(this.$element[0].ownerDocument.documentElement,this.$element[0]);if(!b.isDefaultPrevented()&&a){var g=this,b=this.tip(),a=this.getUID(this.type);this.setContent();b.attr("id",a);this.$element.attr("aria-describedby",a);this.options.animation&&b.addClass("fade");var a="function"==typeof this.options.placement?this.options.placement.call(this,b[0],this.$element[0]):this.options.placement,
e=/\s?auto?\s?/i,h=e.test(a);h&&(a=a.replace(e,"")||"top");b.detach().css({top:0,left:0,display:"block"}).addClass(a).data("bs."+this.type,this);this.options.container?b.appendTo(this.options.container):b.insertAfter(this.$element);this.$element.trigger("inserted.bs."+this.type);var e=this.getPosition(),f=b[0].offsetWidth,i=b[0].offsetHeight;if(h){var h=a,j=this.getPosition(this.$viewport),a="bottom"==a&&e.bottom+i>j.bottom?"top":"top"==a&&e.top-i<j.top?"bottom":"right"==a&&e.right+f>j.width?"left":
"left"==a&&e.left-f<j.left?"right":a;b.removeClass(h).addClass(a)}e=this.getCalculatedOffset(a,e,f,i);this.applyPlacement(e,a);a=function(){var a=g.hoverState;g.$element.trigger("shown.bs."+g.type);g.hoverState=null;"out"==a&&g.leave(g)};c.support.transition&&this.$tip.hasClass("fade")?b.one("bsTransitionEnd",a).emulateTransitionEnd(d.TRANSITION_DURATION):a()}}};d.prototype.applyPlacement=function(b,a){var g=this.tip(),e=g[0].offsetWidth,h=g[0].offsetHeight,d=parseInt(g.css("margin-top"),10),f=parseInt(g.css("margin-left"),
10);isNaN(d)&&(d=0);isNaN(f)&&(f=0);b.top+=d;b.left+=f;c.offset.setOffset(g[0],c.extend({using:function(a){g.css({top:Math.round(a.top),left:Math.round(a.left)})}},b),0);g.addClass("in");var f=g[0].offsetWidth,j=g[0].offsetHeight;"top"==a&&j!=h&&(b.top=b.top+h-j);var l=this.getViewportAdjustedDelta(a,b,f,j);l.left?b.left+=l.left:b.top+=l.top;e=(d=/top|bottom/.test(a))?2*l.left-e+f:2*l.top-h+j;h=d?"offsetWidth":"offsetHeight";g.offset(b);this.replaceArrow(e,g[0][h],d)};d.prototype.replaceArrow=function(b,
a,c){this.arrow().css(c?"left":"top",50*(1-b/a)+"%").css(c?"top":"left","")};d.prototype.setContent=function(){var b=this.tip(),a=this.getTitle();b.find(".tooltip-inner")[this.options.html?"html":"text"](a);b.removeClass("fade in top bottom left right")};d.prototype.hide=function(b){function a(){"in"!=g.hoverState&&e.detach();g.$element.removeAttr("aria-describedby").trigger("hidden.bs."+g.type);b&&b()}var g=this,e=c(this.$tip),h=c.Event("hide.bs."+this.type);this.$element.trigger(h);if(!h.isDefaultPrevented())return e.removeClass("in"),
c.support.transition&&e.hasClass("fade")?e.one("bsTransitionEnd",a).emulateTransitionEnd(d.TRANSITION_DURATION):a(),this.hoverState=null,this};d.prototype.fixTitle=function(){var b=this.$element;if(b.attr("title")||"string"!=typeof b.attr("data-original-title"))b.attr("data-original-title",b.attr("title")||"").attr("title","")};d.prototype.hasContent=function(){return this.getTitle()};d.prototype.getPosition=function(b){var b=b||this.$element,a=b[0],g="BODY"==a.tagName,a=a.getBoundingClientRect();
null==a.width&&(a=c.extend({},a,{width:a.right-a.left,height:a.bottom-a.top}));var e=g?{top:0,left:0}:b.offset(),b={scroll:g?document.documentElement.scrollTop||document.body.scrollTop:b.scrollTop()},g=g?{width:c(window).width(),height:c(window).height()}:null;return c.extend({},a,b,g,e)};d.prototype.getCalculatedOffset=function(b,a,c,e){return"bottom"==b?{top:a.top+a.height,left:a.left+a.width/2-c/2}:"top"==b?{top:a.top-e,left:a.left+a.width/2-c/2}:"left"==b?{top:a.top+a.height/2-e/2,left:a.left-
c}:{top:a.top+a.height/2-e/2,left:a.left+a.width}};d.prototype.getViewportAdjustedDelta=function(b,a,c,e){var d={top:0,left:0};if(!this.$viewport)return d;var f=this.options.viewport&&this.options.viewport.padding||0,i=this.getPosition(this.$viewport);/right|left/.test(b)?(c=a.top-f-i.scroll,a=a.top+f-i.scroll+e,c<i.top?d.top=i.top-c:a>i.top+i.height&&(d.top=i.top+i.height-a)):(e=a.left-f,a=a.left+f+c,e<i.left?d.left=i.left-e:a>i.right&&(d.left=i.left+i.width-a));return d};d.prototype.getTitle=function(){var b=
this.$element,a=this.options;return b.attr("data-original-title")||("function"==typeof a.title?a.title.call(b[0]):a.title)};d.prototype.getUID=function(b){do b+=~~(1E6*Math.random());while(document.getElementById(b));return b};d.prototype.tip=function(){if(!this.$tip&&(this.$tip=c(this.options.template),1!=this.$tip.length))throw Error(this.type+" `template` option must consist of exactly 1 top-level element!");return this.$tip};d.prototype.arrow=function(){return this.$arrow=this.$arrow||this.tip().find(".tooltip-arrow")};
d.prototype.enable=function(){this.enabled=!0};d.prototype.disable=function(){this.enabled=!1};d.prototype.toggleEnabled=function(){this.enabled=!this.enabled};d.prototype.toggle=function(b){var a=this;b&&(a=c(b.currentTarget).data("bs."+this.type),a||(a=new this.constructor(b.currentTarget,this.getDelegateOptions()),c(b.currentTarget).data("bs."+this.type,a)));b?(a.inState.click=!a.inState.click,a.isInStateTrue()?a.enter(a):a.leave(a)):a.tip().hasClass("in")?a.leave(a):a.enter(a)};d.prototype.destroy=
function(){var b=this;clearTimeout(this.timeout);this.hide(function(){b.$element.off("."+b.type).removeData("bs."+b.type);b.$tip&&b.$tip.detach();b.$tip=null;b.$arrow=null;b.$viewport=null})};var f=c.fn.tooltip;c.fn.tooltip=function(b){return this.each(function(){var a=c(this),g=a.data("bs.tooltip"),e="object"==typeof b&&b;if(g||!/destroy|hide/.test(b))if(g||a.data("bs.tooltip",g=new d(this,e)),"string"==typeof b)g[b]()})};c.fn.tooltip.Constructor=d;c.fn.tooltip.noConflict=function(){c.fn.tooltip=
f;return this}}(jQuery);
+function(c){var d=function(b,a){this.init("popover",b,a)};if(!c.fn.tooltip)throw Error("Popover requires tooltip.js");d.VERSION="3.3.5";d.DEFAULTS=c.extend({},c.fn.tooltip.Constructor.DEFAULTS,{placement:"right",trigger:"click",content:"",template:'<div class="popover" role="tooltip"><div class="arrow"></div><h3 class="popover-title"></h3><div class="popover-content"></div></div>'});d.prototype=c.extend({},c.fn.tooltip.Constructor.prototype);d.prototype.constructor=d;d.prototype.getDefaults=function(){return d.DEFAULTS};
d.prototype.setContent=function(){var b=this.tip(),a=this.getTitle(),c=this.getContent();b.find(".popover-title")[this.options.html?"html":"text"](a);b.find(".popover-content").children().detach().end()[this.options.html?"string"==typeof c?"html":"append":"text"](c);b.removeClass("fade top bottom left right in");b.find(".popover-title").html()||b.find(".popover-title").hide()};d.prototype.hasContent=function(){return this.getTitle()||this.getContent()};d.prototype.getContent=function(){var b=this.$element,
a=this.options;return b.attr("data-content")||("function"==typeof a.content?a.content.call(b[0]):a.content)};d.prototype.arrow=function(){return this.$arrow=this.$arrow||this.tip().find(".arrow")};var f=c.fn.popover;c.fn.popover=function(b){return this.each(function(){var a=c(this),g=a.data("bs.popover"),e="object"==typeof b&&b;if(g||!/destroy|hide/.test(b))if(g||a.data("bs.popover",g=new d(this,e)),"string"==typeof b)g[b]()})};c.fn.popover.Constructor=d;c.fn.popover.noConflict=function(){c.fn.popover=
f;return this}}(jQuery);
+function(c){function d(a,b){this.$body=c(document.body);this.$scrollElement=c(a).is(document.body)?c(window):c(a);this.options=c.extend({},d.DEFAULTS,b);this.selector=(this.options.target||"")+" .nav li > a";this.offsets=[];this.targets=[];this.activeTarget=null;this.scrollHeight=0;this.$scrollElement.on("scroll.bs.scrollspy",c.proxy(this.process,this));this.refresh();this.process()}function f(a){return this.each(function(){var b=c(this),e=b.data("bs.scrollspy"),f="object"==typeof a&&a;e||b.data("bs.scrollspy",
e=new d(this,f));if("string"==typeof a)e[a]()})}d.VERSION="3.3.5";d.DEFAULTS={offset:10};d.prototype.getScrollHeight=function(){return this.$scrollElement[0].scrollHeight||Math.max(this.$body[0].scrollHeight,document.documentElement.scrollHeight)};d.prototype.refresh=function(){var a=this,b="offset",e=0;this.offsets=[];this.targets=[];this.scrollHeight=this.getScrollHeight();c.isWindow(this.$scrollElement[0])||(b="position",e=this.$scrollElement.scrollTop());this.$body.find(this.selector).map(function(){var a=
c(this),a=a.data("target")||a.attr("href"),d=/^#./.test(a)&&c(a);return d&&d.length&&d.is(":visible")&&[[d[b]().top+e,a]]||null}).sort(function(a,b){return a[0]-b[0]}).each(function(){a.offsets.push(this[0]);a.targets.push(this[1])})};d.prototype.process=function(){var a=this.$scrollElement.scrollTop()+this.options.offset,b=this.getScrollHeight(),c=this.options.offset+b-this.$scrollElement.height(),d=this.offsets,f=this.targets,i=this.activeTarget,j;this.scrollHeight!=b&&this.refresh();if(a>=c)return i!=
(j=f[f.length-1])&&this.activate(j);if(i&&a<d[0])return this.activeTarget=null,this.clear();for(j=d.length;j--;)i!=f[j]&&a>=d[j]&&(void 0===d[j+1]||a<d[j+1])&&this.activate(f[j])};d.prototype.activate=function(a){this.activeTarget=a;this.clear();a=c(this.selector+'[data-target="'+a+'"],'+this.selector+'[href="'+a+'"]').parents("li").addClass("active");a.parent(".dropdown-menu").length&&(a=a.closest("li.dropdown").addClass("active"));a.trigger("activate.bs.scrollspy")};d.prototype.clear=function(){c(this.selector).parentsUntil(this.options.target,
".active").removeClass("active")};var b=c.fn.scrollspy;c.fn.scrollspy=f;c.fn.scrollspy.Constructor=d;c.fn.scrollspy.noConflict=function(){c.fn.scrollspy=b;return this};c(window).on("load.bs.scrollspy.data-api",function(){c('[data-spy="scroll"]').each(function(){var a=c(this);f.call(a,a.data())})})}(jQuery);
+function(c){function d(a){return this.each(function(){var b=c(this),d=b.data("bs.tab");d||b.data("bs.tab",d=new f(this));if("string"==typeof a)d[a]()})}var f=function(a){this.element=c(a)};f.VERSION="3.3.5";f.TRANSITION_DURATION=150;f.prototype.show=function(){var a=this.element,b=a.closest("ul:not(.dropdown-menu)"),d=a.data("target");d||(d=(d=a.attr("href"))&&d.replace(/.*(?=#[^\s]*$)/,""));if(!a.parent("li").hasClass("active")){var f=b.find(".active:last a"),i=c.Event("hide.bs.tab",{relatedTarget:a[0]}),
j=c.Event("show.bs.tab",{relatedTarget:f[0]});f.trigger(i);a.trigger(j);!j.isDefaultPrevented()&&!i.isDefaultPrevented()&&(d=c(d),this.activate(a.closest("li"),b),this.activate(d,d.parent(),function(){f.trigger({type:"hidden.bs.tab",relatedTarget:a[0]});a.trigger({type:"shown.bs.tab",relatedTarget:f[0]})}))}};f.prototype.activate=function(a,b,d){function k(){i.removeClass("active").find("> .dropdown-menu > .active").removeClass("active").end().find('[data-toggle="tab"]').attr("aria-expanded",!1);
a.addClass("active").find('[data-toggle="tab"]').attr("aria-expanded",!0);j?(a[0].offsetWidth,a.addClass("in")):a.removeClass("fade");a.parent(".dropdown-menu").length&&a.closest("li.dropdown").addClass("active").end().find('[data-toggle="tab"]').attr("aria-expanded",!0);d&&d()}var i=b.find("> .active"),j=d&&c.support.transition&&(i.length&&i.hasClass("fade")||!!b.find("> .fade").length);i.length&&j?i.one("bsTransitionEnd",k).emulateTransitionEnd(f.TRANSITION_DURATION):k();i.removeClass("in")};var b=
c.fn.tab;c.fn.tab=d;c.fn.tab.Constructor=f;c.fn.tab.noConflict=function(){c.fn.tab=b;return this};var a=function(a){a.preventDefault();d.call(c(this),"show")};c(document).on("click.bs.tab.data-api",'[data-toggle="tab"]',a).on("click.bs.tab.data-api",'[data-toggle="pill"]',a)}(jQuery);
+function(c){function d(a){return this.each(function(){var b=c(this),e=b.data("bs.affix"),d="object"==typeof a&&a;e||b.data("bs.affix",e=new f(this,d));if("string"==typeof a)e[a]()})}var f=function(a,b){this.options=c.extend({},f.DEFAULTS,b);this.$target=c(this.options.target).on("scroll.bs.affix.data-api",c.proxy(this.checkPosition,this)).on("click.bs.affix.data-api",c.proxy(this.checkPositionWithEventLoop,this));this.$element=c(a);this.pinnedOffset=this.unpin=this.affixed=null;this.checkPosition()};
f.VERSION="3.3.5";f.RESET="affix affix-top affix-bottom";f.DEFAULTS={offset:0,target:window};f.prototype.getState=function(a,b,c,d){var f=this.$target.scrollTop(),i=this.$element.offset(),j=this.$target.height();if(null!=c&&"top"==this.affixed)return f<c?"top":!1;if("bottom"==this.affixed)return null!=c?f+this.unpin<=i.top?!1:"bottom":f+j<=a-d?!1:"bottom";var l=null==this.affixed,i=l?f:i.top;return null!=c&&f<=c?"top":null!=d&&i+(l?j:b)>=a-d?"bottom":!1};f.prototype.getPinnedOffset=function(){if(this.pinnedOffset)return this.pinnedOffset;
this.$element.removeClass(f.RESET).addClass("affix");var a=this.$target.scrollTop();return this.pinnedOffset=this.$element.offset().top-a};f.prototype.checkPositionWithEventLoop=function(){setTimeout(c.proxy(this.checkPosition,this),1)};f.prototype.checkPosition=function(){if(this.$element.is(":visible")){var a=this.$element.height(),b=this.options.offset,d=b.top,h=b.bottom,k=Math.max(c(document).height(),c(document.body).height());"object"!=typeof b&&(h=d=b);"function"==typeof d&&(d=b.top(this.$element));
"function"==typeof h&&(h=b.bottom(this.$element));b=this.getState(k,a,d,h);if(this.affixed!=b){null!=this.unpin&&this.$element.css("top","");var d="affix"+(b?"-"+b:""),i=c.Event(d+".bs.affix");this.$element.trigger(i);if(i.isDefaultPrevented())return;this.affixed=b;this.unpin="bottom"==b?this.getPinnedOffset():null;this.$element.removeClass(f.RESET).addClass(d).trigger(d.replace("affix","affixed")+".bs.affix")}"bottom"==b&&this.$element.offset({top:k-a-h})}};var b=c.fn.affix;c.fn.affix=d;c.fn.affix.Constructor=
f;c.fn.affix.noConflict=function(){c.fn.affix=b;return this};c(window).on("load",function(){c('[data-spy="affix"]').each(function(){var a=c(this),b=a.data();b.offset=b.offset||{};null!=b.offsetBottom&&(b.offset.bottom=b.offsetBottom);null!=b.offsetTop&&(b.offset.top=b.offsetTop);d.call(a,b)})})}(jQuery);