define(['exports', 'react', 'react-dom'], function (exports, _react, _reactDom) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  var _react2 = _interopRequireDefault(_react);

  var _reactDom2 = _interopRequireDefault(_reactDom);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  var _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  const confirmable = Component => class extends _react2.default.Component {

    constructor(props) {
      super(props);

      this.dismiss = this.dismiss.bind(this);
      this.cancel = this.cancel.bind(this);
      this.proceed = this.proceed.bind(this);

      this.state = {
        show: true
      };
    }
    dismiss() {
      this.setState({
        show: false
      }, () => {
        this.props.dispose();
      });
    }
    cancel(value) {
      this.setState({
        show: false
      }, () => {
        this.props.reject(value);
      });
    }
    proceed(value) {
      this.setState({
        show: false
      }, () => {
        this.props.resolve(value);
      });
    }
    render() {
      return _react2.default.createElement(Component, _extends({ proceed: this.proceed, cancel: this.cancel, dismiss: this.dismiss, show: this.state.show }, this.props));
    }
  };

  const createConfirmation = Component => {
    return props => {
      const wrapper = document.body.appendChild(document.createElement('div'));

      const promise = new Promise((resolve, reject) => {
        try {
          _reactDom2.default.render(_react2.default.createElement(Component, _extends({
            reject: reject,
            resolve: resolve,
            dispose: dispose
          }, props)), wrapper);
        } catch (e) {
          console.error(e);
          throw e;
        }
      });

      function dispose() {
        setTimeout(() => {
          _reactDom2.default.unmountComponentAtNode(wrapper);
          setTimeout(() => wrapper.remove());
        }, 1000);
      }

      return promise.then(result => {
        dispose();
        return result;
      }, result => {
        dispose();
        return Promise.reject(result);
      });
    };
  };

  exports.default = {
    confirmable,
    createConfirmation
  };
});
//# sourceMappingURL=react-confirm.js.map
