import $ from "jquery";

import webI18n from "@esko/i18n/webi18n-loader?bundle=3DViewer!";
import "./3DViewerLauncher-style.css";
import loader from "./images/loaderTransparent.gif";

/**
 * 3DView View
 *
 * @author KADA
 */
var Viewer3DLauncherView = function(element) {
	// If not wrapped by jQuery, do it.
	if (!(element instanceof $)) {
		element = $(element);
	}
	this._wrapper = element;

	// Private variables
	this._showMessage = true;

	// HTML elements
	this._messageIndicator = $("<img src='" + loader + "' class='ViewerMessageBoxIndicator'/>");
	this._message = $("<span>");
	this._messageBox = $("<div class='ViewerMessageBox ViewerInfoMessage'></div>");
	this._viewerWrapper = $("<div class='viewerApp fullscreen' style='height:100%; width:100%;overflow: hidden;'></div>");
	this._messageBox.append(this._messageIndicator);
	this._messageBox.append(this._message);
	this._messageBox.hide();

	this._wrapper.append(this._messageBox);
	this._wrapper.append(this._viewerWrapper);
};

Viewer3DLauncherView.prototype.showAnyMessage = function() {
	this._showMessage = true;
	this._messageBox.show();
};

Viewer3DLauncherView.prototype.hideAnyMessage = function() {
	this._showMessage = false;
	this._messageBox.hide();
};

Viewer3DLauncherView.prototype.displayInfoMessage = function(msg) {
	this.clearMessage();

	this._message.append(msg);

	this._messageIndicator.attr("src", loader);
	this._messageBox.addClass("ViewerInfoMessage");
	this._messageBox.removeClass("ViewerErrorMessage");
	this.showAnyMessage();
};

Viewer3DLauncherView.prototype.displayLoadingMessage = function(progress) {
	this.clearMessage();
	if (progress) {
		this._message.text(webI18n.t("GENERATING_AND_RETRIEVING", progress));
	} else {
		this._message.text(webI18n.t("GENERATING_AND_RETRIEVING", "..."));
	}
	this._messageIndicator.attr("src", loader);
	this._messageBox.addClass("ViewerInfoMessage");
	this._messageBox.removeClass("ViewerErrorMessage");
	this.showAnyMessage();
};

Viewer3DLauncherView.prototype.displayErrorMessage = function(msg, onClickHandler) {
	this.clearMessage();
	this._message.text(msg);
	this._messageIndicator.attr("src", "./images/rejected.gif");
	this._messageBox.removeClass("ViewerInfoMessage");
	this._messageBox.addClass("ViewerErrorMessage");

	this.addOnClickHandler(onClickHandler);

	this.showAnyMessage();
};

Viewer3DLauncherView.prototype.displayErrorMessageLangTag = function(tag, onClickHandler) {
	this.clearMessage();
	this._message.text(webI18n.t(tag));
	this._messageIndicator.attr("src", "./images/rejected.gif");
	this._messageBox.removeClass("ViewerInfoMessage");
	this._messageBox.addClass("ViewerErrorMessage");

	this.addOnClickHandler(onClickHandler);

	this.showAnyMessage();
};

Viewer3DLauncherView.prototype.addOnClickHandler = function(onClickHandler) {
	if (onClickHandler) {
		this._messageBox.on("click", onClickHandler);
		this._messageBox.addClass("ViewerErrorMessageClickAction");
	}
};

Viewer3DLauncherView.prototype.clearMessage = function() {
	this._message.empty();
	this._messageBox.off("click");
	this._messageBox.removeClass("ViewerErrorMessageClickAction");
};

/**
 * Return the jQElement of the div of the actual viewer.
 *
 * @returns [JQuery] The jQuery wrapped element of the  div of the actual viewer.
 */
Viewer3DLauncherView.prototype.getViewerJQElement = function() {
	return this._viewerWrapper;
};

/**
 * Return the jQElement of the wrapping div of this view.
 *
 * @returns [JQuery] The jQuery wrapped element of the wrapping div.
 */
Viewer3DLauncherView.prototype.getJQElement = function() {
	return this._wrapper;
};

export default Viewer3DLauncherView;
