/**
 * @author DOGO
 * @module WebViewer3D
 * @copyright   2015 Esko Stonecube Ltd. All rights reserved.
 */

define([
    "underscore",
    "backbone",
    "@esko/3d-web-viewer/modules/OverrideRingBuffer"
], function (
    _,
    bb,
    OverrideRingBuffer
)
{

    "use strict";

    /**
     * @alias module:WebViewer3D
     * @class WV3DSystemChecker
     * Warning : this class is a singleton, any modification to one of its component will change for each reference to it.
     * Part of the code has been inspired from http://stackoverflow.com/questions/16432804/recording-fps-in-webgl
     */
    const WV3DFPSCounter = bb.Model.extend({

        initialize: function ()
        {
            this.set("_count", 0);
            this.set("_fps", 0);
            this.set("_minuteBuffer", new OverrideRingBuffer(2));//2 seconds window
        },

        Update: function ()
        {
            if (!this.get("_prevSecond"))
            {
                this.set("_prevSecond", (window.performance !== undefined && window.performance.now !== undefined) ? window.performance.now() : Date.now());
                this.set("_count", 1);
            }
            else
            {
                const currentTime = (window.performance !== undefined && window.performance.now !== undefined) ? window.performance.now() : Date.now();
                const difference = currentTime - this.get("_prevSecond");
                if (difference > 1000)
                {
                    this.set("_prevSecond", currentTime);
                    this.set("_fps", this.get("_count"));
                    this.get("_minuteBuffer").Push(this.get("_count"));
                    this.set("_count", 0);
                }
                else
                {
                    this.set("_count", this.get("_count") + 1);
                }
            }
        },

        GetCountPerMinute: function ()
        {
            return this.get("_minuteBuffer").GetAverage();
        },

        GetCountPerSecond: function ()
        {
            return this.get("_fps");
        }
    });

    return new WV3DFPSCounter;//New is what makes it a singleton, see usage in ViewerView.js

});
