/**
 * @author DOGO
 * @module WebViewer3D
 * @copyright   2014 Esko Stonecube Ltd. All rights reserved.
 */

define([
    "underscore",
    "backbone",
    "@esko/3d-web-viewer/modules/HttpRequestHandler",
    "@esko/3d-web-viewer/modules/LogMessage"
], function (
    _,
    bb,
    WV3DHttpRequestHandler,
    LogMessage
)
{

    "use strict";


    /**
     * @alias module:WebViewer3D
     * @class WV3DHttpRequestManager
     */
    return bb.Model.extend({

        initialize: function (__callback, __errorCallback, __urlPreprocessCallback)
        {
            LogMessage.Log("Creating WV3DHttpRequestManager Object");
            this.set("_callback", __callback);
            this.set("_errorCallback", __errorCallback);
            if (typeof __urlPreprocessCallback === "function")
                this.set("_urlPreprocessCallback", __urlPreprocessCallback);
            else
                this.set("_urlPreprocessCallback", function (__url, __queryCallback)
                {
                    __queryCallback(__url);
                });
        },

        /**
         * Return true if the given string is a URL, else false
         *
         * @param {String} __string URL to the scene data
         */
        IsURL: function (__string)
        {
            const regexprelative = /.\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?/;
            return (regexprelative.test(__string) || this.IsAbsoluteURL(__string));
        },

        /**
         * Return true if the given string is a URL, else false
         *
         *
         * @param {String} __string URL to the scene data
         */
        IsRelativeURL: function (__string)
        {
            return this.IsURL(__string) && !this.IsAbsoluteURL(__string);
        },

        /**
         * Return true if the given string is a URL, else false
         *
         * @param {String} __string URL to the scene data
         */
        IsAbsoluteURL: function (__string)
        {
            const regexpabsolute = /(ftp|http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?/;
            return regexpabsolute.test(__string);
        },

        /**
         * Return the file name + extension from the URL
         *
         * @param {String} __string URL to the file
         */
        GetFileName: function (__string)
        {
            const idx_hash = __string.lastIndexOf("#");
            let __realstring;
            if (idx_hash === -1)
            {
                __realstring = __string;
            }
            else
            {
                __realstring = __string.substring(0, __string.indexOf("#"));
            }
            return __realstring.substring(__realstring.lastIndexOf("/") + 1);
        },

        /**
         * Return the asset name + extension from the URL
         *
         * @param {String} __string URL to the asset
         */
        GetAssetName: function (__string)
        {
            const hash_pos = __string.lastIndexOf("#");
            if (hash_pos == -1)
            {
                return "";
            }
            else
            {
                return __string.substring(hash_pos + 1);
            }
        },

        /**
         * Retrieve the real URL of a file, removing the json file prefix
         *
         * @param {String} __sceneURL URL to the scene data
         * @param __parentSceneURL
         * @param __idx_hash
         */
        GetRealURL: function (__sceneURL, __parentSceneURL, __idx_hash)
        {
            //Remove everything that might be located after an eventual # symbol
            //since it is useless for html requests (unless the server itself can understand it)
            let idx_hash;
            if (__idx_hash === undefined)
            {
                idx_hash = __sceneURL.lastIndexOf("#");
            }
            else
            {
                idx_hash = __idx_hash;
            }
            let realSceneURL;
            if (idx_hash === -1)
            {
                realSceneURL = __sceneURL;
            }
            else
            {
                realSceneURL = __sceneURL.substring(0, __sceneURL.indexOf("#"));
            }

            //Get the real URL by removing the base path
            if (this.IsRelativeURL(realSceneURL) && __parentSceneURL)
            {
                const __parentScenePath = __parentSceneURL.substring(0, __parentSceneURL.lastIndexOf("/") + 1);
                return __parentScenePath.concat(realSceneURL);
            }
            else if (this.IsAbsoluteURL(__sceneURL))
            {
                return realSceneURL;
            }
            else
            {
                throw "Not a URL";
            }
        },

        /**
         * Retrieve the real URL of a file, removing the json file prefix
         *
         * @param {String} __sceneURL URL to the scene data
         * @param __parentSceneURL
         */
        GetRealURLWithAppendedRef: function (__sceneURL, __parentSceneURL)
        {
            //Remove everything that might be located after an ventual # symbol
            //since it is useless for html requests (unless the server itself can understand it)
            const idx_hash = __sceneURL.lastIndexOf("#");
            let appendedRef = "";
            if (idx_hash !== -1)
            {
                appendedRef = __sceneURL.substring(__sceneURL.indexOf("#"));
            }
            return this.GetRealURL(__sceneURL, __parentSceneURL, idx_hash) + appendedRef;
        },

        /**
         * Load a scene from a URL resource
         *
         * @param {String} __sceneURL URL to the scene data
         */
        LoadURL: function (__sceneURL)
        {
            //Create a proper http request handler that can have its own attributes
            //Give to that new request the callback parameters inherited
            new WV3DHttpRequestHandler(__sceneURL, this.get("_callback"), this.get("_errorCallback"), this.get("_urlPreprocessCallback"));
        }

    });
});
