/**
 * @author DOGO
 * @module WebViewer3D
 * @copyright   2014 Esko Stonecube Ltd. All rights reserved.
 */

define(["backbone", "@esko/3d-web-viewer/libs/stacktrace"], function(bb, Stacktrace) {
	"use strict";

	const GetStackTrace = function() {
		return Stacktrace.get();
	};

	/**
	 * @alias module:WebViewer3D
	 * @class LogMessage
	 * Warning : this class is a singleton, any modification to one of its component will change for each reference to it.
	 */
	const LogMessage = bb.Model.extend({
		initialize: function() {
			this.set("_warning_message_displayed", false);
			this.set("_warning_message_displayed_error", false);
			this.set("_output_stacktrace", false); //by default we do not output the stack trace. The user can still set his or her own callback using SetCallbackFunction
		},

		SetCallbackFunction: function(__clientLogMessageCallback) {
			if (__clientLogMessageCallback) {
				console.log("LogMessage: Callback function set (following messages will use callback function).");
				this.set("_warning_message_displayed", false);
				this.set("_clientLogMessageCallback", __clientLogMessageCallback);
			}
		},

		SetErrorCallbackFunction: function(__clientLogMessageCallback) {
			if (__clientLogMessageCallback) {
				console.log("LogMessage: Callback function set (following messages will use error callback function).");
				this.set("_warning_message_displayed_error", false);
				this.set("_clientErrorMessageCallback", __clientLogMessageCallback);
			}
		},

		/**
		 * @function
		 */
		Log: function(__string) {
			if (this.get("_clientLogMessageCallback") && typeof this.get("_clientLogMessageCallback") === "function") {
				this.get("_clientLogMessageCallback")(__string, GetStackTrace);
			} else {
				if (!this.get("_warning_message_displayed")) {
					console.log("LogMessage: No function callback set or callback set is not a function (default to console).");
					this.set("_warning_message_displayed", true);
				}
				if (this.get("_output_stacktrace")) console.log(__string, GetStackTrace());
				else console.log(__string);
			}
		},

		Error: function(__string) {
			if (this.get("_clientErrorMessageCallback") && typeof this.get("_clientErrorMessageCallback") === "function") {
				this.get("_clientErrorMessageCallback")(__string, GetStackTrace);
			} else {
				if (!this.get("_warning_message_displayed_error")) {
					console.log("ErrorMessage: No function callback set or callback set is not a function (default to console).");
					this.set("_warning_message_displayed_error", true);
				}
				if (this.get("_output_stacktrace")) console.error(__string, GetStackTrace());
				else console.error(__string);
			}
		}
	});

	return new LogMessage();
});
