/**
 * @author DOGO
 * @module WebViewer3D
 * @copyright 2017 Esko Software BVBA. All rights reserved.
 */

define([
    "underscore",
    "backbone",
    "@esko/3d-web-viewer/modules/LogMessage"
], function (
    _,
    bb,
    LogMessage
)
{

    "use strict";

    /**
     * @alias module:WebViewer3D
     * @class WV3DSceneManager
     */
    return bb.Model.extend({

        initialize: function (__model, __materialManager, __textureManager, __executionQueue, __clientUIAddElementCallback)
        {
            LogMessage.Log("Creating WV3DNotifier Object");
            this.set("_model", __model);
            this.set("_texturemanager", __textureManager);
            this.set("_exec_queue", __executionQueue);
            this.set("_clientUIAddElementCallback", __clientUIAddElementCallback);

            //This notifier listens to material manager triggers and notifies
            //the view if needed to trigger the post scene load actions
            this.listenTo(__materialManager, "check_post_scene_load_actions", this.CheckPostSceneLoadActions);
            this.listenTo(__materialManager, "resource_query_error", this.NotifyResourceQueryErrorCallback);
            this.listenTo(__textureManager, "check_post_scene_load_actions", this.CheckPostSceneLoadActions);
            this.listenTo(__textureManager, "resource_query_error", this.NotifyResourceQueryErrorCallback);

        },

        NotifySceneBuildProgress: function (__geometry_percent, __texture__percent, __error__code)
        {
            if (typeof this.get("_model").get("_clientCallback") === "function")
            {
                if (this.get("_model").get("_assetmanager").get("_textureCounter") === 0)//If no texture to load, then emit a default 100% conplete signal
                {
                    __texture__percent = 100;
                }
                if (__texture__percent === undefined)
                {
                    __texture__percent = this.get("_model").get("_assetmanager").get("_textureLoadedCounter") / this.get("_model").get("_assetmanager").get("_textureCounter") * 100;
                }
                if (__error__code === undefined)
                {
                    __error__code = 0;
                }
                this.get("_model").get("_clientCallback")(__error__code, __geometry_percent, __texture__percent,
                    this.get("_model").get("_assetmanager").get("_queriedassetnumber"),
                    this.get("_model").get("_assetmanager").get("_resolvedassetnumber"));
            }
            else
            {
                LogMessage.Log("ViewerView Warning: Client callback not a function");
            }
        },

        NotifyAddedResource: function ()
        {
            this.get("_exec_queue").whenFinished(function ()
            {
                this.CheckPostSceneLoadActions();
            }, this);
        },

        NotifyResourceQueryErrorCallback: function (__params)
        {
            this.get("_exec_queue").whenFinished(function ()
            {
                LogMessage.Log("ViewerView Warning: Problem loading " + __params.message);
                this.CheckPostSceneLoadActions({"errorCode": __params.errorCode});
            }, this);
        },

        CheckPostSceneLoadActions: function (__params)
        {
            const nb_qd_asset = this.get("_model").get("_assetmanager").get("_queriedassetnumber");
            const nb_res_asset = this.get("_model").get("_assetmanager").get("_resolvedassetnumber");
            const nb_qd_tex = this.get("_model").get("_assetmanager").get("_textureCounter");
            const nb_res_tex = this.get("_model").get("_assetmanager").get("_textureLoadedCounter");
            const percent_tex_loaded = nb_res_tex / nb_qd_tex * 100;
            if ((nb_qd_asset === nb_res_asset) && (nb_qd_tex === nb_res_tex))
            {
                this.trigger("post_scene_load_actions");
            }
            if (__params)
                this.NotifySceneBuildProgress(100, percent_tex_loaded, this.get("_texturemanager").get("_TextureSizeByPass") ? __params.errorCode : 1);
            else
                this.NotifySceneBuildProgress(100, percent_tex_loaded, this.get("_texturemanager").get("_TextureSizeByPass") ? 0 : 1);
        },

        /**
         * Add a ui element using client callback and forwarding all parameters
         */
        AddUIElement: function (arg)
        {
            if (typeof this.get("_clientUIAddElementCallback") === "function")
            {
                this.get("_clientUIAddElementCallback").apply(null, arguments);
            }
            else
            {
                LogMessage.Log("ViewerView Warning: Client callback not a function");
            }
        }
    });
});
