/**
 * @author DOGO
 * @module WebViewer3D
 * @copyright 2017 Esko Software BVBA. All rights reserved.
 */

define([
    "underscore",
    "backbone",
    "three",
    "@esko/3d-web-viewer/modules/TextSpriteMaker",
    "@esko/3d-web-viewer/modules/LogMessage",
    "@esko/3d-web-viewer/modules/Timers",
    "@esko/3d-web-viewer/modules/Utils"
], function (
    _,
    bb,
    THREE,
    WV3DTextSpriteMaker,
    LogMessage,
    WV3DTimers,
    WV3DUtils
)
{

    "use strict";

    //IMPROVEME: use const and let instead of var

    /* PRIVATE */

    /**
     * Parse an asset reference and
     * Precondition: __assetRef is a well formed URL
     * @param {String} __assetRef - asset reference url
     * @param {Obj} __rootnodes - the scene root nodes used to fetch the scene from the url
     * @returns {new_scene_id, refnode} if parsed succesfully using the expected type
     */
    const AssetRefParse = function (__assetRef, __rootnodes)
    {
        var refnode_n_new_scene_id = {};

        //Extract url to retrieve the scene
        var idx_hash = __assetRef.lastIndexOf("#");
        if (idx_hash == -1)
        {
            refnode_n_new_scene_id.new_scene_id = __assetRef;
            refnode_n_new_scene_id.refnode = __rootnodes[refnode_n_new_scene_id.new_scene_id];
        }
        else
        {
            refnode_n_new_scene_id.new_scene_id = __assetRef.substring(0, idx_hash);
            var scene_object = __rootnodes[refnode_n_new_scene_id.new_scene_id];
            if (scene_object)
            {
                var object_local_ref = __assetRef.substring(idx_hash + 1);
                var object_type;
                do
                {
                    var index = object_local_ref.indexOf("/");
                    if (index == -1)
                    {
                        object_type = object_local_ref;
                        object_local_ref = "";
                    }
                    else
                    {
                        object_type = object_local_ref.substring(0, index);
                    }
                    scene_object = scene_object[object_type];
                    object_local_ref = object_local_ref.substring(Math.min(object_local_ref.indexOf("/") + 1, object_local_ref.length));
                }
                while (object_local_ref.length > 0 && scene_object !== undefined);
                if (!scene_object) scene_object == null;
            }

            if (scene_object === null)
            {
                LogMessage.Log(refnode_n_new_scene_id.new_scene_id + " is null");
            }
            else if (scene_object == undefined)
            {
                LogMessage.Log(refnode_n_new_scene_id.new_scene_id + " not yet in cache or not existing");
            }

            refnode_n_new_scene_id.refnode = scene_object;

        }
        return refnode_n_new_scene_id;
    };

    /**
     * Private helper function (to reuse code) to copy a subset of label properties from one object to the other.
     * only copies text, orientation, preferred_loc_h, preferred_loc_v
     */
    const CopyRemainingLabelProperties = function (__toAsset, __fromAsset)
    {
        if (__fromAsset.hasOwnProperty("text") && __fromAsset.text)
            __toAsset["text"] = __fromAsset["text"];

        if (__fromAsset.hasOwnProperty("orientation") && __fromAsset.orientation)
            __toAsset["orientation"] = __fromAsset["orientation"];

        if (__fromAsset.hasOwnProperty("preferred_loc_h") && __fromAsset.preferred_loc_h)
            __toAsset["preferred_loc_h"] = __fromAsset["preferred_loc_h"];

        if (__fromAsset.hasOwnProperty("preferred_loc_v") && __fromAsset.preferred_loc_v)
            __toAsset["preferred_loc_v"] = __fromAsset["preferred_loc_v"];

        if (__fromAsset.hasOwnProperty("pixel_offset") && __fromAsset.pixel_offset)
            __toAsset["pixel_offset"] = __fromAsset["pixel_offset"];
    };

    //! Deduces edge_list type bounds for given bounding box type. Allowed values for bbox type: x, y, z, xyz
    const DeduceLabelEdgesFromBoundingBox = function (__bounding_box_type, __label_asset, __bbox)
    {
        if (__bounding_box_type == "x_axis" || __bounding_box_type == "xyz_axes")
        {
            //Four edges for x axis
            __label_asset["edge_list"][0] = {"v1": new THREE.Vector3(__bbox.min.x, __bbox.min.y, __bbox.min.z), "v2": new THREE.Vector3(__bbox.max.x, __bbox.min.y, __bbox.min.z)};
            __label_asset["edge_list"][1] = {"v1": new THREE.Vector3(__bbox.min.x, __bbox.min.y, __bbox.max.z), "v2": new THREE.Vector3(__bbox.max.x, __bbox.min.y, __bbox.max.z)};
            __label_asset["edge_list"][2] = {"v1": new THREE.Vector3(__bbox.min.x, __bbox.max.y, __bbox.max.z), "v2": new THREE.Vector3(__bbox.max.x, __bbox.max.y, __bbox.max.z)};
            __label_asset["edge_list"][3] = {"v1": new THREE.Vector3(__bbox.min.x, __bbox.max.y, __bbox.min.z), "v2": new THREE.Vector3(__bbox.max.x, __bbox.max.y, __bbox.min.z)};
        }

        if (__bounding_box_type == "y_axis" || __bounding_box_type == "xyz_axes")
        {
            var idx = 0;
            if (__bounding_box_type == "xyz_axes")
                idx = 4;
            //Four edges for y axis
            __label_asset["edge_list"][idx] = {"v1": new THREE.Vector3(__bbox.max.x, __bbox.min.y, __bbox.max.z), "v2": new THREE.Vector3(__bbox.max.x, __bbox.min.y, __bbox.min.z)};
            __label_asset["edge_list"][idx + 1] = {"v1": new THREE.Vector3(__bbox.max.x, __bbox.max.y, __bbox.max.z), "v2": new THREE.Vector3(__bbox.max.x, __bbox.max.y, __bbox.min.z)};
            __label_asset["edge_list"][idx + 2] = {"v1": new THREE.Vector3(__bbox.min.x, __bbox.max.y, __bbox.max.z), "v2": new THREE.Vector3(__bbox.min.x, __bbox.max.y, __bbox.min.z)};
            __label_asset["edge_list"][idx + 3] = {"v1": new THREE.Vector3(__bbox.min.x, __bbox.min.y, __bbox.max.z), "v2": new THREE.Vector3(__bbox.min.x, __bbox.min.y, __bbox.min.z)};
        }

        if (__bounding_box_type == "z_axis" || __bounding_box_type == "xyz_axes")
        {
            var idx = 0;
            if (__bounding_box_type == "xyz_axes")
                idx = 8;
            //Four edges for z axis
            __label_asset["edge_list"][idx] = {"v1": new THREE.Vector3(__bbox.min.x, __bbox.min.y, __bbox.max.z), "v2": new THREE.Vector3(__bbox.min.x, __bbox.max.y, __bbox.max.z)};
            __label_asset["edge_list"][idx + 1] = {"v1": new THREE.Vector3(__bbox.max.x, __bbox.min.y, __bbox.max.z), "v2": new THREE.Vector3(__bbox.max.x, __bbox.max.y, __bbox.max.z)};
            __label_asset["edge_list"][idx + 2] = {"v1": new THREE.Vector3(__bbox.max.x, __bbox.min.y, __bbox.min.z), "v2": new THREE.Vector3(__bbox.max.x, __bbox.max.y, __bbox.min.z)};
            __label_asset["edge_list"][idx + 3] = {"v1": new THREE.Vector3(__bbox.min.x, __bbox.min.y, __bbox.min.z), "v2": new THREE.Vector3(__bbox.min.x, __bbox.max.y, __bbox.min.z)};
        }
    };

    /**
     * @alias module:WebViewer3D
     * @class WV3DSceneBuilder
     * This class is responsible for building the threeJS scenes that are held in the scenemanager
     * This builder traverses recursively the json asset to create the corresponding 3JS Objects
     * using RegisterObjectNode.
     * Several different 3JS scenes are being built for each render pass to avoid rebuilding while rendering
     * for every pass: 1 for opaque non coincident, 1 for each opaque coincident group, 1 for transparent non
     * coincident, 1 for each transparent coincident group, 1 for depth, etc. (see scene manager reset scene)
     * 1 for labels, 1 for hard edges highlights.
     * When reaching a geometry node (when traversing the scene hierarchy), we create a new instance of that geometry
     * using _objectbuilder InstantiateGeometry.
     */
    return bb.Model.extend({

        /* PUBLIC */

        initialize: function (__rendererCache, __model, __sceneManager, __materialManager, __objectBuilder, __executionQueue)
        {
            LogMessage.Log("Creating WV3DSceneBuilder Object");
            //IMPROVEME: We could consider using singletons for some of these attributes
            this.set("_renderercache", __rendererCache);
            this.set("_model", __model);
            /* IMPROVEME: avoid keping a ref to the scenemanager by passing a ref to all the scenes in a single object */
            this.set("_scenemanager", __sceneManager);
            this.set("_materialmanager", __materialManager);
            this.set("_objectbuilder", __objectBuilder);
            this.set("_exec_queue", __executionQueue);
            this.set("_textSpriteMaker", new WV3DTextSpriteMaker());

            this.listenTo(__objectBuilder, "new_coincident_group_pass", this.CreateNewCoincidentGroupPass);
        },

        Reset: function ()
        {
            //Node and geometry counters
            this.set("_nodecounter", 0);
            this.set("_geometrycounter", 0);
            this.set("_parsedEntireSceneGraphOnce", false);
        },

        /**
         * Build the scene using data from the asset manager
         */
        SetUpScene: function ()
        {
            //Create 3JS Node hierarchy
            WV3DTimers.start("Scene Hierarchy Creation");
            this.CreateTHREEJSObjectHierarchy();
            WV3DTimers.stop("Scene Hierarchy Creation");
        },

        /*
         * TRIGGERED EVENT (object_builder::'new_coincident_group_pass'): Creates new coincident group pass if not already created
         * group passes. see CreateTHREEJSObjectHierarchy below that iterates through all build passes for more details
         */
        CreateNewCoincidentGroupPass: function (__params)
        {
            var __i = __params["coincidentgroup"];
            var __transparent = __params["transparent"];
            if (!__transparent)
            {
                if (!this.get("_scenemanager").get("_3JSsceneOpCoincidentGroupsIds").hasOwnProperty(__i))
                {
                    this.get("_scenemanager").get("_3JSsceneOpCoincidentGroupsIds")[__i] = {};
                    this.get("_scenemanager").get("_3JSsceneOpCoincidentGroupsPasses").push(__i);
                }
            }
            else
            {
                if (!this.get("_scenemanager").get("_3JSsceneTranspCoincidentGroupsIds").hasOwnProperty(__i))
                {
                    this.get("_scenemanager").get("_3JSsceneTranspCoincidentGroupsIds")[__i] = {};
                    this.get("_scenemanager").get("_3JSsceneTranspCoincidentGroupsPasses").push(__i);
                }
            }
        },

        /**
         * Creates the root node and start the recursive traversal
         * of the json structure to build the 3JS scene graph
         */
        CreateTHREEJSObjectHierarchy: function ()
        {
            this.get("_objectbuilder").set("_geometrycounter", 0);

            this.get("_exec_queue").run(function ()
            {
                LogMessage.Log("Building Surfaces...");
            }, this);
            this.get("_exec_queue").whenFinished(function ()
            {
                LogMessage.Log("Finished Building Surfaces.");
            }, this);

            //Build the initial opaque scenes
            this.get("_exec_queue").run(function ()
            {
                var cache = this.get("_model").get("_assetmanager").get("_cache");
                var root_node_unique_id = this.get("_model").get("SceneId");
                var root_node = cache["rootnodes"][root_node_unique_id];
                //BuildOpaqueScenes is calling this.CreateNewCoincidentGroupPass every time a coincident group is found
                this.BuildOpaqueScenes(root_node, root_node_unique_id);
            }, this);

            //Build an opaque scene for each coincident group, with its own shading passes
            this.get("_exec_queue").run(function ()
            {
                if (!this.get("_scenemanager").get("_emptyOpaqueScene"))
                {
                    var cache = this.get("_model").get("_assetmanager").get("_cache");
                    var root_node_unique_id = this.get("_model").get("SceneId");
                    var root_node = cache["rootnodes"][root_node_unique_id];
                    for (var cg = 0; cg < this.get('_scenemanager').get('_3JSsceneOpCoincidentGroupsPasses').length; ++cg)
                    {
                        var cg_id = this.get("_scenemanager").get("_3JSsceneOpCoincidentGroupsPasses")[cg];
                        this.BuildOpaqueScenes(root_node, root_node_unique_id, cg_id);
                    }
                }
            }, this);

            //Build the transparent scenes
            this.get("_exec_queue").run(function ()
            {
                if (!this.get("_scenemanager").get("_emptyTransparentScene"))
                {
                    var cache = this.get("_model").get("_assetmanager").get("_cache");
                    var root_node_unique_id = this.get("_model").get("SceneId");
                    var root_node = cache["rootnodes"][root_node_unique_id];

                    //Build transparent scene for each shading pass once
                    this.BuildTransparentScenes(root_node, root_node_unique_id);

                    //Build a transparent scene for each transparent coincident group, with its own shading passes
                    for (var cg = 0; cg < this.get('_scenemanager').get('_3JSsceneTranspCoincidentGroupsPasses').length; ++cg)
                    {
                        var cg_id = this.get("_scenemanager").get("_3JSsceneTranspCoincidentGroupsPasses")[cg];
                        this.BuildTransparentScenes(root_node, root_node_unique_id, cg_id);
                    }
                }
            }, this);

            this.get("_exec_queue").run(function ()
            {
                this.get("_scenemanager").NotifyUpdateLightingContrast();
            }, this);

            this.get("_exec_queue").run(function ()
            {
                var cache = this.get("_model").get("_assetmanager").get("_cache");
                var root_node_unique_id = this.get("_model").get("SceneId");
                var root_node = cache["rootnodes"][root_node_unique_id];

                //Build scene for hard edge highlights rendering
                var highlightchild = this.GetTHREEJSObjectHierarchy(root_node, "highlightnode", root_node_unique_id, root_node_unique_id);
                if (highlightchild.newlycreated)
                    this.get("_scenemanager").get("_3JSsceneHightlights").add(highlightchild.node);

                this.set("_geometrycounter", this.get("_geometrycounter") + this.get("_objectbuilder").get("_geometrycounter"));
                LogMessage.Log(this.get("_nodecounter") + " nodes have been created for this scene");
                LogMessage.Log(this.get("_geometrycounter") + " geometries have been created for this scene");
            }, this);
        },

        BuildOpaqueScenes: function (__root_node, __root_node_unique_id, __coincident_group_id)
        {
            // Build scene for opaque pass
            var pass_scene = this.GetTHREEJSObjectHierarchy(__root_node, "opaque_pass", __root_node_unique_id, __root_node_unique_id, __coincident_group_id);
            //If there is at least one opaque pass create an opaque diffuse pass and opaque coincident passes
            if (!this.get("_scenemanager").get("_emptyOpaqueScene"))
            {
                var opaque_diffuse_pass_scene = this.GetTHREEJSObjectHierarchy(__root_node, "opaque_diffuse_pass", __root_node_unique_id, __root_node_unique_id, __coincident_group_id);
                if (__coincident_group_id === undefined)
                {
                    if (pass_scene.newlycreated)
                    {
                        pass_scene.node.applyMatrix(this.get("_renderercache").get("view_settings")["model_xform"]);
                        this.get("_scenemanager").get("_3JSsceneOp").add(pass_scene.node);
                    }
                    if (opaque_diffuse_pass_scene.newlycreated)
                    {
                        opaque_diffuse_pass_scene.node.applyMatrix(this.get("_renderercache").get("view_settings")["model_xform"]);
                        this.get("_scenemanager").get("_3JSsceneOpaqueDiffuse").add(opaque_diffuse_pass_scene.node);
                    }
                }
                else //Create one scene hierarchy per coincident group
                {
                    this.get("_scenemanager").InitOpaqueCoincidentGroupScene(__coincident_group_id);
                    if (pass_scene.newlycreated)
                    {
                        pass_scene.node.applyMatrix(this.get("_renderercache").get("view_settings")["model_xform"]);
                        this.get("_scenemanager").get("_3JSsceneOpCoincidentGroups")[__coincident_group_id].add(pass_scene.node);
                    }
                    if (opaque_diffuse_pass_scene.newlycreated)
                    {
                        opaque_diffuse_pass_scene.node.applyMatrix(this.get("_renderercache").get("view_settings")["model_xform"]);
                        this.get("_scenemanager").get("_3JSsceneOpCoincidentGroupsDiffuse")[__coincident_group_id].add(opaque_diffuse_pass_scene.node);
                    }
                }
            }
        },

        BuildTransparentScenes: function (__root_node, __root_node_unique_id, __coincident_group_id)
        {
            // Build scene for each requested transparent pass
            var pass_scene = this.GetTHREEJSObjectHierarchy(__root_node, "transparent_pass", __root_node_unique_id, __root_node_unique_id, __coincident_group_id);
            // Create a transparent depth pass
            var transp_diffuse_pass_scene = this.GetTHREEJSObjectHierarchy(__root_node, "transp_diffuse_pass", __root_node_unique_id, __root_node_unique_id, __coincident_group_id);
            if (__coincident_group_id === undefined)
            {
                if (pass_scene.newlycreated)
                {
                    this.get("_scenemanager").get("_3JSsceneTransp").add(pass_scene.node);
                }
                if (transp_diffuse_pass_scene.newlycreated)
                {
                    this.get("_scenemanager").get("_3JSsceneTranspDiffuse").add(transp_diffuse_pass_scene.node);
                }
            }
            else //Create one scene hierarchy per coincident group
            {
                this.get("_scenemanager").InitTransparentCoincidentGroupScene(__coincident_group_id);
                if (pass_scene.newlycreated)
                {
                    this.get("_scenemanager").get("_3JSsceneTranspCoincidentGroups")[__coincident_group_id].add(pass_scene.node);
                }
                if (transp_diffuse_pass_scene.newlycreated)
                {
                    this.get("_scenemanager").get("_3JSsceneTranspCoincidentGroupsDiffuse")[__coincident_group_id].add(transp_diffuse_pass_scene.node);
                }
            }
        },

        /**
         * Register a node in the renderer cache if not already created and return the corresponding node object
         */
        RegisterObjectNode: function (__asset_absolute_path, __mode, __isleaf, __coincident_group_id, __add_ui_elem)
        {
            var __absolute_path = WV3DUtils.URLToKeyString(__asset_absolute_path);

            var nodeviewprops = this.get("_renderercache").get("nodeviewproperties");
            var created = false;
            if (!nodeviewprops.hasOwnProperty(__absolute_path))
            {
                //We store the path as an additional property of the node to make sure that
                //the THREE.Object3D() can know ist own URL, see 'view_prop_nodes' below,
                //but also the other nodes that were created for the other modes.
                //This is useful, for example, when picking an object to add the object URL
                //to the resulting intersection, so that the API user can also call the API
                //using the given url to act on the picked object (visibility, highlight, etc.)
                nodeviewprops[__absolute_path] = {"threejsnodes": {}, "nodeURL": __absolute_path};
            }
            if (!(nodeviewprops[__absolute_path].threejsnodes.hasOwnProperty(__mode)))
            {
                nodeviewprops[__absolute_path].threejsnodes[__mode] = {};
            }
            if (__coincident_group_id === undefined)
            {
                if (!(nodeviewprops[__absolute_path].threejsnodes[__mode].hasOwnProperty("default_cg")))
                {
                    this.set("_nodecounter", this.get("_nodecounter") + 1);
                    nodeviewprops[__absolute_path].threejsnodes[__mode]["default_cg"] = new THREE.Object3D();
                    nodeviewprops[__absolute_path].threejsnodes[__mode]["default_cg"]["view_prop_nodes"] = nodeviewprops[__absolute_path];
                    created = true;
                }
            }
            else
            {
                if (!(nodeviewprops[__absolute_path].threejsnodes[__mode].hasOwnProperty(__coincident_group_id)))
                {
                    this.set("_nodecounter", this.get("_nodecounter") + 1);
                    nodeviewprops[__absolute_path].threejsnodes[__mode][__coincident_group_id] = new THREE.Object3D();
                    nodeviewprops[__absolute_path].threejsnodes[__mode][__coincident_group_id]["view_prop_nodes"] = nodeviewprops[__absolute_path];
                    created = true;
                }
            }
            if (__mode == "highlightnode" && (__add_ui_elem === undefined || __add_ui_elem === true))
            {
                this.get("_scenemanager").NotifyAddUIElement(__absolute_path, __isleaf);
            }

            var returnnode = (__coincident_group_id !== undefined) ? nodeviewprops[__absolute_path].threejsnodes[__mode][__coincident_group_id] : nodeviewprops[__absolute_path].threejsnodes[__mode]["default_cg"];
            return {"node": returnnode, "newlycreated": created, "register": true};
        },

        IsAssetLabelAssetType: function (__assetRef, rootnodes, __current_scene_id)
        {
            var refnode;
            if (this.get("_model").get("_assetmanager").get("_assetloader").IsURL(__assetRef))
                refnode = AssetRefParse(__assetRef, rootnodes).refnode;
            else
                refnode = rootnodes[__current_scene_id]["Assets"][__assetRef];

            if (refnode)
                return (refnode.AssetType == "Label");
            else
                return false;
        },

        /**
         * Add an intermediate instance node to the scene and apply its instance properties
         */
        GetTHREEJSObjectHierarchyRec: function (__asset, __mode, __current_scene_id, __current_asset_prefix, __coincident_group_id, __asset_ref_unique_name, __parent_local_materials_refs, __parent_label_settings_map, __transmat, __forceSWInstPath, __parent_threejsnode)
        {
            //Retrieve local material references and lazy query materials from asset manager if needed
            var properties = __asset.AssetReferenceProperties;
            var local_materials_refs = {};//output: used for meshes materials since references are unique per instance, not in the whole scene
            if (__parent_local_materials_refs)
            {
                for (var i = 0, keys = Object.keys(__parent_local_materials_refs), l = keys.length; i < l; ++i)
                {
                    var mat = keys[i];
                    local_materials_refs[mat] = __parent_local_materials_refs[mat];
                }
            }
            if (properties)
            {
                var local_mats_refs = properties["materialmap"];//input
                if (local_mats_refs)
                {
                    for (var i = 0, keys = Object.keys(local_mats_refs), l = keys.length; i < l; ++i)
                    {
                        var mat = keys[i];
                        var materiallist = this.get("_renderercache").get("materials")["materiallist"];
                        //Fetch from asset manager
                        var rootnodes = this.get("_model").get("_assetmanager").get("_cache").rootnodes;

                        var material_key = local_mats_refs[mat][0] + ((local_mats_refs[mat][1]) ? ("/" + local_mats_refs[mat][1]) : "");

                        //The next lines have to be considered differently if a parent instance
                        //node has to have precedence on the material setup over its children
                        //in that case the caller should give its own local_mats_refs
                        //(named parent_local_materials_refs here), inherited from the parent
                        //and this part should check if mat is already present in it. If present,
                        //then put that reference in the current local_materials_refs
                        //i.e.
                        //if (__parent_local_materials_refs.hasOwnProperty(mat))
                        //  local_materials_refs[mat] = __parent_local_materials_refs[mat]
                        //else //create the ref as usual using next lines

                        //RETRIEVE THE FRONT AND BACK ASSETS IN THE CURRENT SCENE ASSET POOL
                        var assets = rootnodes[__current_scene_id]["Assets"];
                        var front_mat_struct = null;
                        var back_mat_struct = null;
                        var mat_structs;
                        if (!materiallist.hasOwnProperty(material_key))
                        {
                            var shared_material = false;
                            if (!assets.hasOwnProperty(local_mats_refs[mat][0]))
                            {
                                LogMessage.Log("ViewerView Warning: Front material " + local_mats_refs[mat][0] + " not found");
                            }
                            else
                            {
                                var mat_node_front = assets[local_mats_refs[mat][0]];
                                front_mat_struct = this.get("_materialmanager").LoadMaterial(local_mats_refs[mat][0], mat_node_front, assets, __current_scene_id, false);
                            }

                            var backfound = false;
                            if (local_mats_refs[mat][1])
                            {
                                if (!assets.hasOwnProperty(local_mats_refs[mat][1]))
                                {
                                    LogMessage.Log("ViewerView Warning: Back material " + local_mats_refs[mat][1] + " not found. Trying to assign front material.");
                                }
                                else
                                {
                                    var mat_node_back = assets[local_mats_refs[mat][1]];
                                    back_mat_struct = this.get("_materialmanager").LoadMaterial(local_mats_refs[mat][1], mat_node_back, assets, __current_scene_id, true);
                                    backfound = true;
                                }
                            }

                            if (!backfound && assets.hasOwnProperty(local_mats_refs[mat][0]))
                            {
                                var mat_node_back = assets[local_mats_refs[mat][0]];
                                back_mat_struct = this.get("_materialmanager").LoadMaterial(local_mats_refs[mat][0], mat_node_back, assets, __current_scene_id, false);
                                shared_material = true;
                            }

                            //Update local material list
                            mat_structs = {"material_name": material_key, "front": front_mat_struct, "back": back_mat_struct, "sharedmaterial": shared_material}; //Used here
                            materiallist[material_key] = mat_structs;
                        }
                        else
                        {
                            //Retrieve front mat from material list
                            mat_structs = materiallist[material_key];
                        }

                        local_materials_refs[mat] = mat_structs; //Used to link meshes in 3DObjectHandler
                    }
                }
            }

            //Depth first traversal to enable getting the bounding box of the leaf node if needed later

            var transmat = new THREE.Matrix4;

            if (!properties)
            {
                transmat.set(1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0);
            }
            else
            {
                //Retrieve local transformation

                var local_trans = new THREE.Vector3(parseFloat(properties.x), parseFloat(properties.y), parseFloat(properties.z));
                var offset = new THREE.Vector3(0, 0, 0);

                ////NODE ROTATION + TRANSLATION
                if (properties.hasOwnProperty("orientation_matrix"))
                {
                    transmat.set(properties["orientation_matrix"][0], properties["orientation_matrix"][1], properties["orientation_matrix"][2], local_trans.x,
                        properties["orientation_matrix"][3], properties["orientation_matrix"][4], properties["orientation_matrix"][5], local_trans.y,
                        properties["orientation_matrix"][6], properties["orientation_matrix"][7], properties["orientation_matrix"][8], local_trans.z,
                        0.0, 0.0, 0.0, 1.0);
                }
                else
                {
                    // for a full explanation of the Cape orientation constants see: https://wiki.esko.com/x/fhU_BQ
                    switch (properties.orientation)
                    {
                        case  "2":
                            transmat.set(0.0, -1.0, 0.0, local_trans.x, 1.0, 0.0, 0.0, local_trans.y, 0.0, 0.0, 1.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case  "3":
                            transmat.set(-1.0, 0.0, 0.0, local_trans.x, 0.0, -1.0, 0.0, local_trans.y, 0.0, 0.0, 1.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case  "4":
                            transmat.set(0.0, 1.0, 0.0, local_trans.x, -1.0, 0.0, 0.0, local_trans.y, 0.0, 0.0, 1.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case  "5":
                            transmat.set(1.0, 0.0, 0.0, local_trans.x, 0.0, 0.0, 1.0, local_trans.y, 0.0, -1.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case  "6":
                            transmat.set(0.0, 0.0, -1.0, local_trans.x, 1.0, 0.0, 0.0, local_trans.y, 0.0, -1.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case  "7":
                            transmat.set(-1.0, 0.0, 0.0, local_trans.x, 0.0, 0.0, -1.0, local_trans.y, 0.0, -1.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case  "8":
                            transmat.set(0.0, 0.0, 1.0, local_trans.x, -1.0, 0.0, 0.0, local_trans.y, 0.0, -1.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case  "9":
                            transmat.set(0.0, 0.0, -1.0, local_trans.x, 0.0, 1.0, 0.0, local_trans.y, 1.0, 0.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "10":
                            transmat.set(0.0, -1.0, 0.0, local_trans.x, 0.0, 0.0, -1.0, local_trans.y, 1.0, 0.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "11":
                            transmat.set(0.0, 0.0, 1.0, local_trans.x, 0.0, -1.0, 0.0, local_trans.y, 1.0, 0.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "12":
                            transmat.set(0.0, 1.0, 0.0, local_trans.x, 0.0, 0.0, 1.0, local_trans.y, 1.0, 0.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "13":
                            transmat.set(-1.0, 0.0, 0.0, local_trans.x, 0.0, 1.0, 0.0, local_trans.y, 0.0, 0.0, -1.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "14":
                            transmat.set(0.0, -1.0, 0.0, local_trans.x, -1.0, 0.0, 0.0, local_trans.y, 0.0, 0.0, -1.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "15":
                            transmat.set(1.0, 0.0, 0.0, local_trans.x, 0.0, -1.0, 0.0, local_trans.y, 0.0, 0.0, -1.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "16":
                            transmat.set(0.0, 1.0, 0.0, local_trans.x, 1.0, 0.0, 0.0, local_trans.y, 0.0, 0.0, -1.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "17":
                            transmat.set(-1.0, 0.0, 0.0, local_trans.x, 0.0, 0.0, 1.0, local_trans.y, 0.0, 1.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "18":
                            transmat.set(0.0, 0.0, -1.0, local_trans.x, -1.0, 0.0, 0.0, local_trans.y, 0.0, 1.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "19":
                            transmat.set(1.0, 0.0, 0.0, local_trans.x, 0.0, 0.0, -1.0, local_trans.y, 0.0, 1.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "20":
                            transmat.set(0.0, 0.0, 1.0, local_trans.x, 1.0, 0.0, 0.0, local_trans.y, 0.0, 1.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "21":
                            transmat.set(0.0, 0.0, 1.0, local_trans.x, 0.0, 1.0, 0.0, local_trans.y, -1.0, 0.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "22":
                            transmat.set(0.0, -1.0, 0.0, local_trans.x, 0.0, 0.0, 1.0, local_trans.y, -1.0, 0.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "23":
                            transmat.set(0.0, 0.0, -1.0, local_trans.x, 0.0, -1.0, 0.0, local_trans.y, -1.0, 0.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        case "24":
                            transmat.set(0.0, 1.0, 0.0, local_trans.x, 0.0, 0.0, -1.0, local_trans.y, -1.0, 0.0, 0.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                        //case  "1":
                        default:
                            transmat.set(1.0, 0.0, 0.0, local_trans.x, 0.0, 1.0, 0.0, local_trans.y, 0.0, 0.0, 1.0, local_trans.z, 0.0, 0.0, 0.0, 1.0);
                            break;
                    }
                }
            }

            if (__transmat instanceof THREE.Matrix4)
            {
                transmat.premultiply(__transmat);
            }

            var label_settings_map_merged = {};
            if (__parent_label_settings_map && !this.get("_parsedEntireSceneGraphOnce"))
            {
                for (var plsm = 0, plsm_keys = Object.keys(__parent_label_settings_map), n_plsmkeys = plsm_keys.length; plsm < n_plsmkeys; ++plsm)
                {
                    label_settings_map_merged[plsm_keys[plsm]] = __parent_label_settings_map[plsm_keys[plsm]];
                }
            }

            if (properties && !this.get("_parsedEntireSceneGraphOnce"))
            {
                var labelSettingsMap_local = properties["labelsettingsmap"];
                if (labelSettingsMap_local)
                {
                    for (var lsm = 0, lsm_keys = Object.keys(labelSettingsMap_local), n_lsmkeys = lsm_keys.length; lsm < n_lsmkeys; ++lsm)
                    {
                        label_settings_map_merged[lsm_keys[lsm]] = labelSettingsMap_local[lsm_keys[lsm]];
                    }
                }
            }

            //Transformation matrix is not used directly on the current node, but instead forwarded
            //recursively to GetTHREEJSObjectHierarchy and to addassettonode functions, to feed the instance array.
            // node.node.applyMatrix(transmat);

            return this.GetTHREEJSObjectHierarchy(__asset, __mode, __current_scene_id, __current_asset_prefix, __coincident_group_id, __asset_ref_unique_name, local_materials_refs, label_settings_map_merged, transmat, __forceSWInstPath, __parent_threejsnode);
        },

        /**
         * Add specific object to the scene
         */
        GetTHREEJSObjectHierarchy: function (__asset, __mode, __current_scene_id, __current_asset_prefix, __coincident_group_id, __asset_ref_unique_name, __local_materials_refs, __local_label_settings_map, __transmat, __forceSWInstPath, __parent_threejsnode)
        {

            var rootnodes = this.get("_model").get("_assetmanager").get("_cache").rootnodes;
            var threejsnode;

            if (__asset == undefined)
            {
                LogMessage.Log("ViewerView Warning: Reference to __asset '" + __current_asset_prefix + "' not yet loaded in cache. This node should be updated when asynchronuous data is loaded.");
                return {"node": null, "newlycreated": false, "register": false};
            }

            //Create a new threejs abstract node
            var isleaf = !((__asset.hasOwnProperty("Children") && __asset.Children) || (__asset.hasOwnProperty("AssetRef")));

            if (__asset.hasOwnProperty("Children") && __asset.Children)
            {
                //Before submiting the current node for registration as a separate branch
                //we have to know first if the children queried for being registered is
                //separate instances.
                //If at least one of the children requests it, we register the parent node
                //(this node) as a distinct node. As this operation is expensive for big scenes
                //with thousands of instances, it is preferable to use hardware instancing and,
                //therefore avoid registering thousands of items.

                var forceSoftwareInstance = false;
                if (__asset.hasOwnProperty("FlattenSubTree"))
                {
                    forceSoftwareInstance = !WV3DUtils.ToBool(__asset["FlattenSubTree"]);
                }

                var nodes_for_scene_graph = [];
                var has_label_nodes = false;
                //! Loop through all children except for Label type assets. We loop through Label assets after generating ThreeJSNode for current parent node
                for (var i = 0, keys = Object.keys(__asset.Children), l = keys.length; i < l; ++i)
                {
                    var id = keys[i];
                    if (this.IsAssetLabelAssetType(__asset.Children[id].AssetRef, rootnodes, __current_scene_id))
                    {
                        has_label_nodes = true;
                        continue;
                    }

                    var child_asset_name = __current_asset_prefix + "/" + id;
                    var child = this.GetTHREEJSObjectHierarchyRec(__asset.Children[id], __mode, __current_scene_id, child_asset_name, __coincident_group_id, __asset.AssetRef, __local_materials_refs, __local_label_settings_map, __transmat, forceSoftwareInstance ? child_asset_name : __forceSWInstPath, null);
                    // child{"node": node, "register": register, "trans_mat": transmat}
                    if (child.register && child.newlycreated)
                    {
                        nodes_for_scene_graph.push(child.node);
                    }
                }

                if (nodes_for_scene_graph.length > 0 || has_label_nodes)
                {
                    threejsnode = this.RegisterObjectNode(__current_asset_prefix, __mode, isleaf, __coincident_group_id);
                    //! Loop through newly created threejs nodes to add them to the parent threejsnode
                    for (var i = 0, keys = Object.keys(nodes_for_scene_graph), l = keys.length; i < l; ++i)
                    {
                        var node_to_add = keys[i];
                        threejsnode.node.add(nodes_for_scene_graph[node_to_add]);
                    }
                    //! Loop again through children of current node for Label type assets which need a threejs parent
                    for (var i = 0, keys = Object.keys(__asset.Children), l = keys.length; i < l; ++i)
                    {
                        var id = keys[i];
                        if (!this.IsAssetLabelAssetType(__asset.Children[id].AssetRef, rootnodes, __current_scene_id))
                            continue;

                        var child_asset_name = __current_asset_prefix + "/" + id;
                        var child = this.GetTHREEJSObjectHierarchyRec(__asset.Children[id], __mode, __current_scene_id, child_asset_name, __coincident_group_id, __asset.AssetRef, __local_materials_refs, __local_label_settings_map, __transmat, forceSoftwareInstance ? child_asset_name : __forceSWInstPath, threejsnode);
                    }
                }
                else
                {
                    if (__asset.AssetType == "Scene")
                    {
                        threejsnode = this.RegisterObjectNode(__current_asset_prefix, __mode, isleaf, __coincident_group_id);
                        threejsnode.newlycreated = true;
                    }
                    else
                        threejsnode = {"node": null, "newlycreated": false, "register": false};
                }
            }
            else if (__asset.hasOwnProperty("AssetRef"))
            {
                var refnode, new_scene_id, child_asset_name;
                if (this.get("_model").get("_assetmanager").get("_assetloader").IsURL(__asset.AssetRef))
                {
                    //RETRIEVE THE ASSET IN AN EXTERNAL SCENE ASSET POOL
                    var refnode_n_new_scene_id = AssetRefParse(__asset.AssetRef, rootnodes);
                    refnode = refnode_n_new_scene_id.refnode;
                    new_scene_id = refnode_n_new_scene_id.new_scene_id;
                    child_asset_name = __current_asset_prefix;

                }
                else
                {
                    //RETRIEVE THE ASSET IN THE CURRENT SCENE ASSET POOL
                    refnode = rootnodes[__current_scene_id]["Assets"][__asset.AssetRef];
                    new_scene_id = __current_scene_id;
                    child_asset_name = __current_asset_prefix;
                }
                threejsnode = this.GetTHREEJSObjectHierarchy(refnode, __mode, new_scene_id, child_asset_name, __coincident_group_id, __asset.AssetRef, __local_materials_refs, __local_label_settings_map, __transmat, __forceSWInstPath, __parent_threejsnode);
            }
            else
            {
                var register = false;
                if (__asset.hasOwnProperty("Properties") && __asset.Properties && (__asset.AssetType == "Cuboid" || __asset.AssetType == "Mesh"))
                {
                    //A NODE CONTAINING THE GEOMETRY
                    var geometry_type = __asset.AssetType;
                    var properties = __asset.Properties;
                    var geometries = this.get("_renderercache").get("geometries");
                    var materials = this.get("_renderercache").get("materials");
                    var coplanarity_epsilon = this.get("_renderercache").get("coplanarityepsilon");
                    var enable_boundary_hard_edges = this.get("_renderercache").get("boundaryhardedges");

                    var unique_geometry_id = __current_scene_id + __asset_ref_unique_name.substring(__asset_ref_unique_name.lastIndexOf("/"));

                    var register_objects = this.get("_objectbuilder").InstantiateGeometry(geometry_type, unique_geometry_id, __mode, properties, geometries, materials, __local_materials_refs, coplanarity_epsilon, enable_boundary_hard_edges, __coincident_group_id, __transmat, __forceSWInstPath);

                    if (register_objects.register)
                    {
                        register = true;
                        threejsnode = this.RegisterObjectNode(__current_asset_prefix, __mode, isleaf, __coincident_group_id);
                        for (var i = 0, keys = Object.keys(register_objects.objects), l = keys.length; i < l; ++i)
                        {
                            var registered_object = keys[i];
                            threejsnode.node.add(register_objects.objects[registered_object]);
                            if (register_objects.objects[registered_object].geometry.hasOwnProperty("useSoftwareInstancing")
                                && register_objects.objects[registered_object].geometry.useSoftwareInstancing)
                            {
                                register_objects.objects[registered_object].applyMatrix(__transmat);
                            }
                        }
                    }
                }
                else if (__asset.hasOwnProperty("Properties") && __asset.Properties && __asset.AssetType == "Label" && !this.get("_parsedEntireSceneGraphOnce"))
                {
                    //A label asset, which creation is deferred to the end of the scene construction
                    var labelCreationCallback = function ()
                    {
                        LogMessage.Log("Label: Current Scene Id: " + __current_scene_id);
                        LogMessage.Log("Label: root node: " + rootnodes[__current_scene_id]);
                        this.LoadLabel(rootnodes[__current_scene_id], __current_asset_prefix, __asset, __asset_ref_unique_name, __local_label_settings_map, __transmat, __parent_threejsnode);
                    };
                    this.get("_scenemanager").get("_labelCreationCallbackList").push(labelCreationCallback.bind(this));
                }

                if (!register)
                {
                    threejsnode = {"node": null, "newlycreated": false, "register": false};
                }
            }

            if (__asset.hasOwnProperty("AssetType") && __asset.AssetType == "Scene")
            {
                //We consider scene has been entirely parse only if this asset is the root node
                if (this.get("_model").get("SceneId") == __asset.AssetId) this.set("_parsedEntireSceneGraphOnce", true);
                //Post process traversal is triggered at the end of the whole recursive traversal process
                if (threejsnode.node)
                {
                    var setup_instanciation_array = function (obj)
                    {
                        if (obj instanceof THREE.Mesh)
                        {
                            if (obj.geometry instanceof THREE.InstancedBufferGeometry)
                            {
                                //Update instance count
                                if (obj.geometry.attributes["inst_translation"].jarray &&
                                    obj.geometry.attributes["inst_rotation"].jarray &&
                                    obj.geometry.attributes["inst_scale"].jarray &&
                                    obj.geometry.attributes["inst_translation"].jarray.length / 3 > 1)
                                {
                                    obj.geometry.maxInstancedCount = obj.geometry.attributes["inst_translation"].jarray.length / 3;
                                    obj.geometry.adjacentfacesedgeslines.maxInstancedCount = obj.geometry.maxInstancedCount;
                                    //Creating new bigger array using ALL instances
                                    var newoffsets = new Float32Array(obj.geometry.attributes["inst_translation"].jarray);
                                    var neworientations = new Float32Array(obj.geometry.attributes["inst_rotation"].jarray);
                                    var newscales = new Float32Array(obj.geometry.attributes["inst_scale"].jarray);
                                    obj.geometry.attributes["inst_translation"].array = newoffsets;
                                    obj.geometry.attributes["inst_rotation"].array = neworientations;
                                    obj.geometry.attributes["inst_scale"].array = newscales;
                                    obj.geometry.adjacentfacesedgeslines.attributes["inst_translation"].array = newoffsets;
                                    obj.geometry.adjacentfacesedgeslines.attributes["inst_rotation"].array = neworientations;
                                    obj.geometry.adjacentfacesedgeslines.attributes["inst_scale"].array = newscales;
                                }
                            }
                        }
                    };
                    threejsnode.node.traverse(setup_instanciation_array);
                }
            }
            //return the node to the scene
            return threejsnode;
        },

        /**
         * Load 'Label' assets from JSON
         */
        LoadLabel: function (__root_node, __node_path, __label_asset, __label_name, __label_settings_map, __transmat, __parent_threejsnode)
        {
            if (__label_asset.AssetType != "Label" || !__label_asset.hasOwnProperty("Properties") || __label_asset.Properties == null)
                return;

            var label_obj_props = __label_asset.Properties;

            var label_asset =
                {
                    "text": label_obj_props["text"],
                    "orientation": label_obj_props["orientation"],
                    "preferred_loc_h": label_obj_props["preferred_loc_h"],
                    "preferred_loc_v": label_obj_props["preferred_loc_v"],
                    "edge_list": [],
                    "point_list": [],
                    "ellipse":
                        {
                            "center": null,
                            "radius1_vec": null,
                            "radius2_vec": null
                        },
                    "bounds_type": null,
                    "threejs_sprite": null,    //This is set later in CreateSprites
                    "display_style": null,
                    "pixel_offset": null
                };

            if (label_obj_props.hasOwnProperty("display_style") && label_obj_props.display_style)
                label_asset["display_style"] = __root_node["Properties"].label_display_styles[label_obj_props["display_style"]];
            else if (__root_node["Properties"].hasOwnProperty("label_display_styles") && __root_node["Properties"].label_display_styles)
                label_asset["display_style"] = __root_node["Properties"].label_display_styles["default_style"];

            if (label_obj_props.hasOwnProperty("pixel_offset") && label_obj_props.pixel_offset)
                label_asset["pixel_offset"] = label_obj_props["pixel_offset"];
            else
                label_asset["pixel_offset"] = [0, 0];

            if (label_obj_props.hasOwnProperty("edge_list") && label_obj_props.edge_list)
            {
                label_asset["bounds_type"] = "edge_list";
                for (var ed = 0, ed_keys = Object.keys(label_obj_props.edge_list), n_eds = ed_keys.length; ed < n_eds; ++ed)
                {
                    var p = JSON.parse(JSON.stringify(label_obj_props.edge_list[ed_keys[ed]]));
                    var v1 = new THREE.Vector3(p[0], p[1], p[2]);
                    var v2 = new THREE.Vector3(p[3], p[4], p[5]);
                    v1.applyMatrix4(__transmat);
                    v2.applyMatrix4(__transmat);
                    label_asset["edge_list"][ed] = {"v1": v1, "v2": v2};
                }
            }
            else if (label_obj_props.hasOwnProperty("point_list") && label_obj_props.point_list)
            {
                label_asset["bounds_type"] = "point_list";
                for (var pt = 0, pt_keys = Object.keys(label_obj_props.point_list), n_pts = pt_keys.length; pt < n_pts; ++pt)
                {
                    var v = new THREE.Vector3();
                    v.fromArray(JSON.parse(JSON.stringify(label_obj_props.point_list[pt_keys[pt]])));
                    v.applyMatrix4(__transmat);
                    label_asset["point_list"][pt] = v;
                }
            }
            else if (label_obj_props.hasOwnProperty("ellipse") && label_obj_props.ellipse)
            {
                label_asset["bounds_type"] = "ellipse";
                // Clone (deep copy) the coordinates array. Below is the simplest method of all when not using complex objects
                label_asset["ellipse"]["center"] = new THREE.Vector3;
                label_asset["ellipse"]["center"].fromArray(JSON.parse(JSON.stringify(label_obj_props.ellipse.center)));
                label_asset["ellipse"]["center"].applyMatrix4(__transmat);

                label_asset["ellipse"]["radius1_vec"] = new THREE.Vector3();
                label_asset["ellipse"]["radius1_vec"].fromArray(JSON.parse(JSON.stringify(label_obj_props.ellipse.radius1_vec)));
                label_asset["ellipse"]["radius2_vec"] = new THREE.Vector3();
                label_asset["ellipse"]["radius2_vec"].fromArray(JSON.parse(JSON.stringify(label_obj_props.ellipse.radius2_vec)));

                var transmat3 = new THREE.Matrix3();
                transmat3.setFromMatrix4(__transmat);
                label_asset["ellipse"]["radius1_vec"].applyMatrix3(transmat3);
                label_asset["ellipse"]["radius2_vec"].applyMatrix3(transmat3);
            }
            else if (label_obj_props.hasOwnProperty("bounding_box") && label_obj_props.bounding_box)
            {
                //! We convert bounding_box into a set of edges
                // This process is being defered due to lack of information from the scene
                // Bounding box is processed after the entire geometry has been parsed.
                label_asset["bounds_type"] = "edge_list";
                var bounding_box = new THREE.Box3();
                bounding_box.setFromObject(__parent_threejsnode.node);
                DeduceLabelEdgesFromBoundingBox(label_obj_props["bounding_box"], label_asset, bounding_box);
            }
            else
            {
                LogMessage.Log("Invalid bounds specification in Label asset: " + __label_name);
                return;
            }

            if (__label_settings_map instanceof Object && Object.keys(__label_settings_map).length != 0 && __label_settings_map.hasOwnProperty(__label_name))
            {
                var asset_override_props = __label_settings_map[__label_name];
                if (!asset_override_props)
                    return; // Visibility turned off for this label at a particular node. Do not add this into [labels][list]

                if (asset_override_props.hasOwnProperty("display_style") && asset_override_props.display_style)
                    label_asset["display_style"] = __root_node["Properties"].label_display_styles[asset_override_props["display_style"]];

                CopyRemainingLabelProperties(label_asset, asset_override_props);
            }

            var node_path = WV3DUtils.URLToKeyString(__node_path);
            this.get("_renderercache").get("labels")["list"][node_path] = label_asset;
            //Trigger application callback with label nodel url
            this.get("_scenemanager").NotifyAddUIElement(node_path, true);

            LogMessage.Log("Built Label asset: " + __label_name);
        },


        /**
         * Text sprite creation
         */
        CreateSprites: function ()
        {
            for (var labelIndex = 0, labels_list = Object.keys(this.get("_renderercache").get("labels")["list"]), n_labels = labels_list.length; labelIndex < n_labels; ++labelIndex)
            {
                var label_asset = this.get("_renderercache").get("labels")["list"][labels_list[labelIndex]];
                var sprite = this.get("_textSpriteMaker").MakeTextSprite(label_asset["text"], label_asset["display_style"],
                    new THREE.Vector3(0, 0, 0), false, false, false, false, false, false, label_asset["orientation"]);

                // add to renderlayer
                this.get("_scenemanager").get("_3JSsceneLabels").add(sprite);
                // add backreference for easy position updates
                label_asset["threejs_sprite"] = sprite;
            }
        },

        /**
         * Text sprite update
         */
        SetLabelProperties: function (__label_asset, __properties)
        {
            if (__properties.hasOwnProperty("display_style") && __properties.display_style)
            {
                var displayStyleProps = __properties["display_style"];

                if (displayStyleProps.hasOwnProperty("fontface") && displayStyleProps.fontface)
                    __label_asset["display_style"].fontface = displayStyleProps.fontface;

                if (displayStyleProps.hasOwnProperty("fontsize") && displayStyleProps.fontsize)
                    __label_asset["display_style"].fontsize = displayStyleProps.fontsize;

                if (displayStyleProps.hasOwnProperty("borderThickness") && displayStyleProps.borderThickness)
                    __label_asset["display_style"].borderThickness = displayStyleProps.borderThickness;

                if (displayStyleProps.hasOwnProperty("borderColor") && displayStyleProps.borderColor)
                    __label_asset["display_style"].borderColor = displayStyleProps.borderColor;

                if (displayStyleProps.hasOwnProperty("backgroundColor") && displayStyleProps.backgroundColor)
                    __label_asset["display_style"].backgroundColor = displayStyleProps.backgroundColor;

                if (displayStyleProps.hasOwnProperty("color") && displayStyleProps.color)
                    __label_asset["display_style"].color = displayStyleProps.color;
            }

            CopyRemainingLabelProperties(__label_asset, __properties);

            var prevVisibility = __label_asset["threejs_sprite"].visible;

            this.get("_scenemanager").get("_3JSsceneLabels").remove(__label_asset["threejs_sprite"]);

            var sprite = this.get("_textSpriteMaker").MakeTextSprite(__label_asset["text"], __label_asset["display_style"],
                new THREE.Vector3(0, 0, 0), false, false, false, false, false, false, __label_asset["orientation"]);

            this.get("_scenemanager").get("_3JSsceneLabels").add(sprite);

            __label_asset["threejs_sprite"] = sprite;

            if (__properties.hasOwnProperty("visible"))
                __label_asset["threejs_sprite"].visible = WV3DUtils.ToBool(__properties.visible);
            else
                __label_asset["threejs_sprite"].visible = prevVisibility;
        }


    });

});
