/**
 * @author DOGO
 * @module WebViewer3D
 * @copyright   2015 Esko Stonecube Ltd. All rights reserved.
 */

define([
    "backbone",
    "@esko/3d-web-viewer/modules/LogMessage"
], function (bb,
             LogMessage)
{

    "use strict";

    /**
     * @alias module:WebViewer3D
     * @class Utility gathering timer that can be accessed from any other class
     * Warning : this class is a singleton, any modification to one of its component will change for each reference to it.
     */

    const Timers = bb.Model.extend({

        initialize: function ()
        {
            this.set("_timers", {});
        },

        reset: function (_name, __verbose)
        {
            if (this.get("_timers").hasOwnProperty(_name))
            {
                this.get("_timers")[_name]["accumulated"] = 0;
            }
            this.start(_name, __verbose);
        },

        start: function (_name, __verbose)
        {
            var start_time = (window.performance !== undefined && window.performance.now !== undefined) ? window.performance.now() : Date.now();
            if (this.get("_timers").hasOwnProperty(_name))
            {
                if (!this.get("_timers")[_name]["started"])
                {
                    this.get("_timers")[_name]["start"] = start_time;
                    if (__verbose === undefined || __verbose === true) LogMessage.Log("Timer " + _name + " started");
                    this.get("_timers")[_name]["started"] = true;
                }
                else
                {
                    if (__verbose === undefined || __verbose === true) LogMessage.Log("Timer " + _name + " is already started");
                    this.now(_name);
                }
            }
            else
            {
                this.get("_timers")[_name] = {start: start_time, accumulated: 0, started: true};
                if (__verbose === undefined || __verbose === true) LogMessage.Log("Timer " + _name + " started");
            }
        },

        isRunning: function (_name)
        {
            if (!this.get("_timers").hasOwnProperty(_name))
            {
                return false;
            }
            else
            {
                return this.get("_timers")[_name]["started"];
            }
        },

        now: function (_name, __verbose)
        {
            var now_time = (window.performance !== undefined && window.performance.now !== undefined) ? window.performance.now() : Date.now();
            var elapsed = this.get("_timers")[_name]["accumulated"] + now_time - this.get("_timers")[_name]["start"];
            if (__verbose === undefined || __verbose === true) LogMessage.Log("Timer " + _name + " is now: " + elapsed);
            return elapsed;
        },

        stop: function (_name, __verbose)
        {
            var stop_time = (window.performance !== undefined && window.performance.now !== undefined) ? window.performance.now() : Date.now();
            var elapsed = this.get("_timers")[_name]["accumulated"] + stop_time - this.get("_timers")[_name]["start"];
            this.get("_timers")[_name]["accumulated"] = elapsed;
            this.get("_timers")[_name]["started"] = false;
            if (__verbose === undefined || __verbose === true) LogMessage.Log("Timer " + _name + " is stopped at: " + elapsed);
            return elapsed;
        }


    });

    return new Timers;//New is what makes it a singleton, see usage in ViewerView.js
});
