/**
 * @author DOGO
 * @module WebViewer3D
 * @copyright   2015 Esko Stonecube Ltd. All rights reserved.
 */

define([
    'backbone'
], function( bb ) {

    'use strict';

    /**
     * @alias module:WebViewer3D
     * @class Utils gather utility functions that can be reused in other classes
     * Warning : this class is a singleton, any modification to one of its component will change for each reference to it.
     */

    const Utils = bb.Model.extend({

        /* Converts any object to a boolean */
        /* return true if __var == "TRUE", "true", "TRue",..., and true */
        /* otherwise returns false*/
        ToBool: function(__var)
        {
            if (typeof (__var.toLowerCase) === 'function')
            {
                return (__var.toLowerCase() === "true");
            }
            else
            {
                return __var ? true : false;//return explicitely a boolean in case __var is null or undefined
            }
        },

        /* Returns size (in Bytes) of an object: This process might take a long time to end but should not have
         * any crash issue */
        SizeOf: function( __object )
        {
            const objectList = [];
            const stack = [__object];
            let bytes = 0;
            while(stack.length)
            {
                const value = stack.pop();

                if ( typeof value === 'boolean' ) {
                    bytes += 4;
                }
                else if ( typeof value === 'string' ) {
                    bytes += value.length * 2;
                }
                else if ( typeof value === 'number' ) {
                    bytes += 8;
                }
                else if ( typeof value === 'object' && value !== null && value !== undefined && objectList.indexOf( value ) === -1)
                {
                    objectList.push( value );
                    for(const i in value )
                    {
                        if(value.hasOwnProperty(i))
                        {
                            bytes += i.length * 2;
                            bytes += 8; // an assumed existence overhead
                            stack.push( value[ i ] );
                        }
                    }
                }
            }
            return bytes;
        },

        /**
         * Function to convert an URL to a string that can be used as a key in a map
         * Replaces # with / and chops off http, https and ftp
         */
        URLToKeyString: function(URL)
        {
            let keyStr = URL.replace("#", "/");
            keyStr = keyStr.replace(/(ftp|http|https):\/\/?/, "");
            return keyStr;
        }
    });

    return new Utils;//New is what makes it a singleton
});
