/**
 * @author DOGO
 * @module WebViewer3D
 * @copyright   2016 Esko Stonecube Ltd. All rights reserved.
 */

define([
    "backbone",
    "hammerjs"
], function (bb,
             Hammer)
{

    "use strict";

    /**
     * @alias module:WebViewer3D
     * @class HammerEXT extension to allow right click
     */

    const HammerEXT = bb.Model.extend({

        initialize: function ()
        {
            //Taken from
            //http://stackoverflow.com/questions/27609969/how-to-enable-right-click-and-middle-click-of-mouse-in-hammer-js
            //apparently not working for IE11, therefore we also provide ctrl + left click as an alternative to rotate environment
            //even second solution provided on stackoverflow does not seem to be working
            //input mouse map is not a public property of Hammer, so copy it here
            const MOUSE_INPUT_MAP = {
                mousedown: Hammer.INPUT_START,
                mousemove: Hammer.INPUT_MOVE,
                mouseup: Hammer.INPUT_END
            };
            //override
            Hammer.inherit(Hammer.MouseInput, Hammer.Input, {
                /**
                 * handle mouse events
                 * @param {Object} ev
                 */
                handler: function MEhandler(ev)
                {
                    let eventType = MOUSE_INPUT_MAP[ev.type];

                    //modified to handle all buttons
                    //left=0, middle=1, right=2
                    if (eventType & Hammer.INPUT_START)
                    {
                        //firefox sends button 0 for mousemove, so store it here
                        if (this.pressed === false) this.button = ev.button;
                        this.pressed = true;
                    }

                    if (eventType & Hammer.INPUT_MOVE && ev.which === 0)
                    {
                        eventType = Hammer.INPUT_END;
                    }
                    // mouse must be down, and mouse events are allowed (see the TouchMouse input)
                    if (!this.pressed || !this.allow)
                    {
                        return;
                    }

                    if (eventType & Hammer.INPUT_END)
                    {
                        this.pressed = false;
                        this.button = false;
                    }

                    this.callback(this.manager, eventType, {
                        button: this.button,
                        pointers: [ev],
                        changedPointers: [ev],
                        pointerType: "mouse",
                        srcEvent: ev
                    });
                }
            });
        }

    });

    new HammerEXT();

    return Hammer;
});
