import Block from "../core/Block";
import HTMLParameter from "../core/parameters/HTMLParameter";
import $ from "jquery";

/**
 * Basic implementation of an HTML Block
 * This block can display a customizable chunk of HTML
 *
 * @class
 * @constructor
 * @augments Block
 * @param {String} id - ID
 * @param {Context} [context]
 */
var HTMLBlock = function(id, context) {
	Block.call(this, id, context);
};

HTMLBlock.prototype = Object.create(Block.prototype);
HTMLBlock.prototype.constructor = HTMLBlock;

/**
 * @Override
 */
HTMLBlock.prototype.getType = function() {
	return "dashboard/blocks/HTMLBlock";
};

/**
 * Configure the default parameters of the block
 * @override
 */
HTMLBlock.prototype._initializeDefaultParameters = function() {
	return this._context.getLanguageBundle("DashboardHTMLBlock").then(
		function(bundle) {
			var parameter = new HTMLParameter("HTMLContent", this._context, "Content"); // FUTURE i18n, this block is nowhere used, just as an example;

			var sample = $("<p>", {
				text: bundle.t("DEFAULT_TEXT")
			});
			parameter.setValue(sample.html());

			this._addParameter(parameter);
		}.bind(this)
	);
};

/**
 * @Override
 */
HTMLBlock.prototype._doInit = function(config) {
	this._observeParam("HTMLContent", this._render);
	this._element.addClass("dshBlockPadding");
	this._render();
};

/**
 * @Override
 */
HTMLBlock.prototype._doRender = function() {
	this._element.html(this._parameters.getValue("HTMLContent"));
};

export default HTMLBlock;
