import Block from "../core/Block";
import $ from "jquery";
import _ from "underscore";
/**
 * Configurator for a Dashboard
 * @augments Block
 */
var DashboardBuilder = function(id, context) {
	Block.call(this, id, context);

	this._options = _.extend(
		{
			calculateDimensions: false // if this is a function,the function is triggered on window resize with the element as an argument
		},
		context.getOption("builder")
	);
	this._layout = null;
	this._isActive = false;

	if (this._options.calculateDimensions) {
		this._listener = _.throttle(this._onResize.bind(this), 42);
	}
};

DashboardBuilder.prototype = Object.create(Block.prototype);
DashboardBuilder.prototype.constructor = DashboardBuilder;

/**
 * @Override
 */
DashboardBuilder.prototype.getType = function() {
	return "dashboard/builder/DashboardBuilder";
};

/**
 * @Override
 */
DashboardBuilder.prototype.isPersistent = function() {
	return false;
};

/**
 * @Override
 * @protected
 */
DashboardBuilder.prototype._doConfigure = function(config) {
	this._dashboard = config.dashboard;
	this._dashboardLayout = config.layout;
};

/**
 * @Override
 */
DashboardBuilder.prototype._doInit = function() {
	var self = this;

	this._element.addClass("dshBuilder");

	this._galleryID = this._context.registerBlock({
		type: "dashboard/builder/gallery/Gallery",
		config: {}
	});

	this._layout = this._context.registerAndLoadBlock({
		type: "dashboard/layout/flex/FlexLayout",
		config: {
			items: [],
			parameters: [
				{
					name: "FlexColumnParameter",
					type: "dashboard/layout/flex/FlexColumnParameter",
					config: {
						value: {
							columns: [
								{
									grow: 1,
									shrink: 1,
									lockedColumn: true,
									className: "dshBuilderLayout"
								},
								{
									grow: 0,
									shrink: 0,
									width: "15%",
									maxWidth: "300px",
									minWidth: "210px",
									lockedColumn: true,
									className: "dshBuilderGallery"
								}
							],
							flexDirection: "row"
						}
					}
				}
			]
		}
	});

	return this._layout.then(function(layout) {
		self._registerChild(layout);
		layout.replaceColumnWithBlock(1, self._galleryID);
		self._element.append(layout.getElement());
		return layout;
	});
};

/**
 * Activate the builder
 * Move in the layout element if needed
 * @param {Boolean} active
 */
DashboardBuilder.prototype.activate = function(active) {
	if (this._isActive != active) {
		if (active) {
			Promise.all([this._layout, this._dashboardLayout]).then(
				function(values) {
					if (active) {
						var builderLayout = values[0];
						var dashboardLayout = values[1];

						builderLayout.replaceColumnWithBlock(0, dashboardLayout.getID());

						if (this._options.calculateDimensions) {
							$(window).on("resize", this._listener);
							this._onResize();
						}
					}
				}.bind(this)
			);
		} else if (this._options.calculateDimensions) {
			$(window).off("resize", this._listener);
		}
		this._isActive = active;
	}
};

DashboardBuilder.prototype._onResize = function() {
	this._element.addClass("dshBuilderConstrainedHeight");
	this._options.calculateDimensions(this._element);
};

export default DashboardBuilder;
