import $ from "jquery";
import _ from "underscore";
import Observer from "@esko/observer";

/**
 * A Configuration panel is used to configure a Block or Parameter
 * @class
 */
var ConfigurationPanel = function() {
	Observer.mixin(this);
	this._element = $("<div>");

	/**
	 * @member {Array.<ConfigurationPanel>}
	 * @private
	 */

	this._subpanels = [];
};

/**
 * Generate configuration panels for all the parameters in an array
 * @private
 * @returns {JQueryObj} div with configuration panels for the parameters of the block
 */
ConfigurationPanel.prototype._getParameterConfiguration = function(listOfParameters) {
	var wrapper = $("<div>"); // placeholder for parameters which will be added in the promise

	Promise.all(
		_.map(
			listOfParameters,
			function(parameter) {
				if (parameter.isConfigurableByUser()) {
					return parameter.getConfigurationPanel();
				} else {
					return null;
				}
			},
			this
		)
	).then(
		function(parameterPanels) {
			_.each(
				parameterPanels,
				function(panel) {
					if (panel) {
						wrapper.append(panel.getElement());
						this.registerSubpanel(panel);
					}
				},
				this
			);
		}.bind(this)
	);

	return wrapper;
};
/**
 * Get the element for the configuration panel
 * @returns {JQueryObj}
 */
ConfigurationPanel.prototype.getElement = function() {
	return this._element;
};

/**
 * Register a subpanel to the configuration panel.
 */
ConfigurationPanel.prototype.registerSubpanel = function(panel) {
	this._subpanels.push(panel);
};

/**
 * Called when configurationpanel is destroyed
 */
ConfigurationPanel.prototype.destroy = function() {
	for (var i = 0; i < this._subpanels.length; i++) {
		this._subpanels[i].destroy();
	}
};

export default ConfigurationPanel;
