import ConfigurationPanel from "./ConfigurationPanel";
import $ from "jquery";
import _ from "underscore";
/**
 * @augments ConfigurationPanel
 * @param {[[Type]]} parameter [[Description]]
 */
var ParameterConfigurationPanel = function(parameter) {
	ConfigurationPanel.call(this);

	/**
	 * @member {Parameter}
	 */
	this._parameter = parameter;

	this._init();

	this._observeParam(this._updateVisibility);
	this._updateVisibility();
};

ParameterConfigurationPanel.prototype = Object.create(ConfigurationPanel.prototype);
ParameterConfigurationPanel.prototype.constructor = ParameterConfigurationPanel;

/**
 * By default a parameter is shown as a form-group with a label and an input field
 * @private
 */
ParameterConfigurationPanel.prototype._init = function() {
	this._element.addClass("form-group");

	this._$label = $("<label>", {
		text: this._parameter.getUserFriendlyName()
	});

	if (!this._parameter.getRestrictedSet()) {
		this._$input = $("<input>", {
			type: "text",
			class: "form-control",
			value: this._parameter.getValue()
		});
	} else {
		this._$input = $("<select>", {
			class: "form-control"
		});

		_.each(
			this._parameter.getRestrictedSet(),
			function(text, value) {
				this._$input.append(
					$("<option>", {
						value: value,
						text: text
					})
				);
			},
			this
		);
		if (this._parameter.getValue()) {
			this._$input.val(this._parameter.getValue());
		}
	}

	this._$input.attr("data-param-name", this._parameter.getName());

	this._$input.on(
		"change",
		function(event) {
			this._parameter.undoableSetValue(this._$input.val());
		}.bind(this)
	);

	this._observeParam(
		function() {
			this._$input.val(this._parameter.getValue());
		}.bind(this)
	);

	this._element.append(this._$label).append(
		$("<div>", {
			class: "form-entry"
		}).append(this._$input)
	);
};

/**
 * Get the custom config part for the parameter
 * @private
 * @returns {object} [[Description]]
 */
ParameterConfigurationPanel.prototype._getCustomConfiguration = function() {
	return {
		value: this._$input.val()
	};
};

/**
 * Observe the parameter attached to this panel
 * @private
 * @param {function} handler - executed when something is changed to the parameter
 */
ParameterConfigurationPanel.prototype._observeParam = function(handler) {
	this._observe(this._parameter, "changed", handler);
};

/**
 * Called when configurationpanel is closed
 */
ParameterConfigurationPanel.prototype.destroy = function() {
	ConfigurationPanel.prototype.destroy.call(this);
	this._stopObserveAll();
};

ParameterConfigurationPanel.prototype._updateVisibility = function() {
	this._element.toggleClass("hidden", !this._parameter.isVisible());
};

export default ParameterConfigurationPanel;
