import ParameterConfigurationPanel from "../ParameterConfigurationPanel";
import $ from "jquery";
import _ from "underscore";
/**
 * Configuration panel for a Boolean parameter
 * @augments ParameterConfigurationPanel
 * @param {[[Type]]} parameter [[Description]]
 */
var BooleanParameterConfigurationPanel = function(parameter) {
	ParameterConfigurationPanel.call(this, parameter);
};

BooleanParameterConfigurationPanel.prototype = Object.create(ParameterConfigurationPanel.prototype);
BooleanParameterConfigurationPanel.prototype.constructor = BooleanParameterConfigurationPanel;

/**
 * By default a parameter is shown as a form-group with a label and an input field
 * @private
 */
BooleanParameterConfigurationPanel.prototype._init = function() {
	this._element.addClass("form-group");

	this._$label = $("<label>", {
		text: this._parameter.getUserFriendlyName()
	});

	this._$input = $("<input>", {
		type: "checkbox"
	});

	this._$input.attr("data-param-name", this._parameter.getName());
	this._$label.prepend(this._$input);

	this._element.append('<label class="offset-label"></label>').append(
		$("<div>", {
			class: "form-entry"
		}).append(
			$("<div>", {
				class: "checkbox"
			}).append(this._$label)
		)
	);

	this._$input.prop("checked", this._parameter.getValue());

	this._$input.on(
		"change",
		function() {
			this._parameter.undoableSetValue(this._$input.is(":checked"));
		}.bind(this)
	);
	this._observeParam(
		function() {
			this._$input.prop("checked", this._parameter.getValue());
		}.bind(this)
	);
};

/**
 * @override
 * @private
 * @returns {object} [[Description]]
 */
BooleanParameterConfigurationPanel.prototype._getCustomConfiguration = function() {
	return {
		value: this._$input.is(":checked")
	};
};

export default BooleanParameterConfigurationPanel;
