import ParameterConfigurationPanel from "../ParameterConfigurationPanel";
import ColorPickerInput from "@esko/colorpickerinput/ColorPickerInput";
import $ from "jquery";
import _ from "underscore";
/**
 * Configuration panel for a HTML parameter
 * @augments ParameterConfigurationPanel
 * @param {[[Type]]} parameter [[Description]]
 */
var ColorPickerConfigurationPanel = function(parameter) {
	ParameterConfigurationPanel.call(this, parameter);
};

ColorPickerConfigurationPanel.prototype = Object.create(ParameterConfigurationPanel.prototype);
ColorPickerConfigurationPanel.prototype.constructor = ColorPickerConfigurationPanel;

/**
 * By default a parameter is shown as a form-group with a label and an input field
 * @private
 */
ColorPickerConfigurationPanel.prototype._init = function() {
	// we don't display a label currently :)
	this._element.addClass("form-group");

	this._$label = $("<label>", {
		text: this._parameter.getUserFriendlyName()
	});

	this._colorPicker = new ColorPickerInput({ allowEmpty: false });
	this._colorPicker.setValue(this._parameter.getValue());

	this._colorPicker.on(
		"changed",
		function(color) {
			this._parameter.undoableSetValue(color);
		}.bind(this)
	);

	this._observeParam(
		function() {
			this._colorPicker.setValue(this._parameter.getValue());
		}.bind(this)
	);

	this._element.append(this._$label).append(
		$("<div>", {
			class: "form-entry"
		}).append(this._colorPicker.getElement())
	);
};

/**
 * @override
 * @private
 * @returns {object} [[Description]]
 */
ColorPickerConfigurationPanel.prototype._getCustomConfiguration = function() {
	return {
		value: this._colorPicker.getValue()
	};
};

export default ColorPickerConfigurationPanel;
