import ParameterConfigurationPanel from "../ParameterConfigurationPanel";
import $ from "jquery";
import _ from "underscore";
/**
 * Configuration panel for a Dropdown parameter
 * @augments ParameterConfigurationPanel
 * @param {Parameter} parameter
 * @param {object} data
 */
var DropdownParameterConfigurationPanel = function(parameter, data) {
	this._optionsData = data;

	ParameterConfigurationPanel.call(this, parameter);
};

DropdownParameterConfigurationPanel.prototype = Object.create(ParameterConfigurationPanel.prototype);
DropdownParameterConfigurationPanel.prototype.constructor = DropdownParameterConfigurationPanel;

/**
 * By default a parameter is shown as a form-group with a label and an input field
 * @private
 */
DropdownParameterConfigurationPanel.prototype._init = function() {
	this._element.addClass("form-group");

	this._$label = $("<label>", {
		text: this._parameter.getUserFriendlyName()
	});
	this._$select = $("<select>", {
		class: "form-control"
	});

	_.each(
		this._optionsData,
		_.bind(function(option, index) {
			this._$select.append(
				$("<option>", {
					value: option.value
				}).text(option.text)
			);
		}, this)
	);

	this._$select.on(
		"change",
		function() {
			this._parameter.undoableSetValue(this._$select.val());
		}.bind(this)
	);

	this._element.append(this._$label).append(
		$("<div>", {
			class: "form-entry"
		}).append(this._$select)
	);
};

/**
 * Re-init the dropdown with new options
 * @param {object} data optionsData
 */
DropdownParameterConfigurationPanel.prototype.setOptions = function(data) {
	this._optionsData = data;
	this._element.empty();
	this._init();
};

/**
 * Set the selected option
 * @param {string} value - value of the value attribute
 */
DropdownParameterConfigurationPanel.prototype.setSelected = function(value) {
	this._$select.val(value);
};

/**
 * @override
 * @private
 * @returns {object} [[Description]]
 */
DropdownParameterConfigurationPanel.prototype._getCustomConfiguration = function() {
	return {
		value: this._$select.val()
	};
};

/**
 * Get the selected value from the dropdown
 * @returns {string}
 */
DropdownParameterConfigurationPanel.prototype.getSelectedValue = function() {
	return this._getCustomConfiguration().value;
};

/**
 * Get the selected value's label from the dropdown
 * @returns {string}
 */
DropdownParameterConfigurationPanel.prototype.getSelectedValueLabel = function() {
	var label = $("option[value='" + this.getSelectedValue() + "']", this._$select).text();
	return label;
};

export default DropdownParameterConfigurationPanel;
