import Block from "../../core/Block";
import XDropPanel from "@esko/xdrop/panel/XDropPanel";
import LabelRenderer from "@esko/xdrop/renderers/LabelRenderer";
import GalleryItemRenderer from "./GalleryItemRenderer";
import GalleryDataProvider from "./GalleryDataProvider";
import $ from "jquery";
import _ from "underscore";
import "./Gallery.css";
import "jqueryUI";
/**
 * A Gallery block is used to display a (searchable) list of available items
 * @augments Block
 * @class
 * @constructor
 * @param {String} id
 * @param {Context} context
 */
var Gallery = function(id, context) {
	Block.call(this, id, context);

	this._element.addClass("dshBlockGallery");
};

Gallery.prototype = Object.create(Block.prototype);
Gallery.prototype.constructor = Gallery;

/**
 * @Override
 */
Gallery.prototype.getType = function() {
	return "dashboard/builder/gallery/Gallery";
};

/**
 * @Override
 */
Gallery.prototype._doInit = function() {
	var self = this;
	return Promise.resolve()
		.then(function() {
			return self._context.getLanguageBundle("DashboardGallery");
		})
		.then(function(bundle) {
			self._i18n = bundle;

			self.$filtericon = $("<i>", {
				class: "icon icon-WCR_Search"
			});

			self._galleryProvider = new GalleryDataProvider(self._context, {
				filter: function(datasource, filter) {
					return datasource.filterBlocks(self.$category.val(), filter);
				}
			});

			// prevent drag&drop while we are reloading the gallery data
			self._galleryProvider.on("loading", function(isLoading) {
				var draggables = $(".ui-draggable", self._element);
				draggables.draggable("option", "disabled", isLoading);
			});

			self._xdropPanel = new XDropPanel(
				self._galleryProvider,
				{
					galeryItem: GalleryItemRenderer.factory(self._context),
					label: LabelRenderer
				},
				{}
			);

			self.$category = $("<select>", {
				class: "form-control"
			})
				.addClass("hiddenElement")
				.on("change", function() {
					self._xdropPanel.setQuery("");
					self._galleryProvider.updateResultSet();
				});

			self._context.getBlockDefinitionDataSource().then(function(datasource) {
				self._observe(datasource, "changed.blockDefinitions", function() {
					self._updateCategoryDropdown();
				});
				self._updateCategoryDropdown();
			});

			self._element.append($("<div>").append(self.$category)).append(self._xdropPanel.getElement());
			self._xdropPanel.getElement().addClass("limitedHeight");
		});
};

/**
 * Update the dropdown with category information
 */
Gallery.prototype._updateCategoryDropdown = function() {
	// update the categories dropdown
	this._context
		.getBlockDefinitionDataSource()
		.then(function(datasource) {
			return datasource.getCategories();
		})
		.then(
			function(categories) {
				this.$category.toggleClass("hiddenElement", categories.length <= 1);
				var currentValue = this.$category.val();

				this.$category.empty();
				this.$category.append(
					$("<option>", {
						value: "",
						text: this._i18n.t("GALLERY_ALL_CATEGORIES")
					})
				);

				_.each(
					_.sortBy(
						_.map(
							categories,
							function(category) {
								return {
									id: category,
									label: this._i18n.tFallback("CATEGORY_" + category, category)
								};
							},
							this
						),
						"label"
					),
					function(category) {
						this.$category.append(
							$("<option>", {
								value: category.id,
								text: category.label
							})
						);
					},
					this
				);
				this.$category.val(currentValue);
			}.bind(this)
		);
};

export default Gallery;
