import Renderer from "@esko/xdrop/renderers/Renderer";
import $ from "jquery";
/**
 * @class LabelRenderer
 *
 * @class
 * @augments Renderer
 * @param {JQueryObj}   div
 * @param {ResultEntry} resultEntry
 * @param {Object}      api        -  render API
 */
var GalleryItemRenderer = function(div, resultEntry, api, dashboardContext) {
	Renderer.call(this, div, resultEntry, api);

	this._context = dashboardContext;

	/* this._element is used to render in the XDrop panel, it is returned by renderer.getElement() */
	var data = this._resultEntry.getData();
	var h4 = $("<h4>", {
		text: data.getDisplayName()
	}).appendTo(this._element);

	this._handle = null;
	if ($("body.mobile").length > 0) {
		this._handle = ".dsh-drag-handle";
		h4.prepend(
			$("<i>", {
				class: "icon icon-WCR_DragHandler dsh-drag-handle"
			})
		);
	}
	$("<span>", {
		text: data.getDescription()
	}).appendTo(this._element);

	this.render();
};

GalleryItemRenderer.prototype = Object.create(Renderer.prototype);
GalleryItemRenderer.prototype.constructor = GalleryItemRenderer;

/**
 * @Override
 * @private
 */
GalleryItemRenderer.prototype.render = function() {
	var self = this;
	Promise.resolve()
		.then(function() {
			if (self._draggable) {
				// if there where draggables, make sure to destroy the draggable behavior
				return self._context.getDragDropHandler().then(function(dragDropHandler) {
					dragDropHandler.toggleDragging(false, null, null, null, self._draggable);
					self._draggable = null;
				});
			}
		})
		.then(function() {
			// render the template

			if (self._context.isEditModeActive()) {
				// we need to enable drag/drop
				//var list = self._filteredItems.slice(0);

				// we want to create only one block definition
				var newBlockDefinition = null;
				var getBlockDefinition = function(element) {
					if (!newBlockDefinition) {
						var definition = self._resultEntry.getData();
						var newID = self._context.registerBlockFromDefinition(definition);
						newBlockDefinition = self._context.getBlockDefinition(newID);
					}
					return newBlockDefinition;
				};

				self._context.getDragDropHandler().then(function(dragDropHandler) {
					self._draggable = self._element;
					dragDropHandler.toggleDragging(
						self._context.isEditModeActive(),
						self._context,
						function(element) {
							return getBlockDefinition(element);
						},
						null,
						self._draggable,
						self._handle,
						function(event, ui) {
							self._api.pauseRender(true);
							// block rendering, so that the dragging can be completed without any problems

							// on start of drag, make the sure to inject the correct block definition in the ui.helper
							var blockDef = getBlockDefinition(this);
							ui.helper.text(blockDef.getDisplayName());
							ui.helper.data("BlockDefinition", blockDef);
						},
						function(event, ui) {
							// if the draggable was dropped on an invalid location, remove the definition from the context
							if (!ui.helper.data("isValidDrop")) {
								// we need to remove the definition from the context
								self._context.removeBlockDefinition(ui.helper.data("BlockDefinition"));
							}

							// make sure we don't reuse this block definition anymore
							newBlockDefinition = null;

							// the widget can be rendered again, trigger a render
							self._api.pauseRender(false);
						}
					);
				});
			}
		});
};

export default {
	make: function(div, resultEntry, api) {
		return new GalleryItemRenderer(div, resultEntry, api);
	},

	factory: function(dashboardContext) {
		return {
			make: function(div, resultEntry, api) {
				return new GalleryItemRenderer(div, resultEntry, api, dashboardContext);
			}
		};
	}
};
