import _ from "underscore";
/**
 * A simple datastructure used by the Context to store information on Blocks
 * @param {String} id
 * @param {String} type - type of the Block
 * @param {Object} config - configuration of the block
 */
var BlockDefinition = function(id, type, config) {
	/**
	 * @member {Promise.<Block>} promise for the block
	 */
	this.promise = null;

	this._id = id;
	this.type = type;
	this.config = config;
	this._description = null;
};

/**
 * Get the ID of the blockdefintion
 * @returns {String}
 */
BlockDefinition.prototype.getID = function() {
	return this._id;
};

/**
 * Get the type of the blockdefinition
 * @returns {String} [[Description]]
 */
BlockDefinition.prototype.getType = function() {
	return this.type;
};

/**
 * Get the display name of the block
 * @returns {String}
 */
BlockDefinition.prototype.getDisplayName = function() {
	return this.config.displayName || this.getID() || "";
};

/**
 * Get the description of the block
 * @returns {String}
 */
BlockDefinition.prototype.getDescription = function() {
	return this._description;
};

/**
 * Set the description of the block
 */
BlockDefinition.prototype.setDescription = function(description) {
	this._description = description;
};

/**
 * Get the category of the block
 * @returns {String}
 */
BlockDefinition.prototype.getCategory = function() {
	return this.config.category || "";
};

/**
 * Are multiple instances of the blockdefinition allowed in the context?
 * @returns {[[Type]]} [[Description]]
 */
BlockDefinition.prototype.allowMultipleInContext = function() {
	return !this.config.onePerContext;
};

/**
 * Create clone of the block definition
 * This only works for JSONable configurations (so references to objects will be lost!)
 * @param   {String}          id - new ID for the clone
 * @returns {BlockDefinition}
 */
BlockDefinition.prototype.clone = function(id) {
	return new BlockDefinition(id, this.type, JSON.parse(JSON.stringify(this.config)));
};
export default BlockDefinition;
