import defaultMapping from "./default.mapping.js";

class Factory {
	constructor() {
		this.mapping = { ...defaultMapping };
	}

	/**
	 *Add new entires to the mapping
	 *
	 * @param {*} newMapping
	 * @memberof Factory
	 */
	remap(newMapping) {
		this.mapping = { ...this.mapping, ...newMapping };
	}

	/**
	 * Load a module of a certain type
	 *
	 * @param {*} type
	 * @returns
	 * @memberof Factory
	 */
	import(type) {
		if (this.mapping[type]) {
			return this.mapping[type]().then(mod => mod.default);
		} else {
			let error = `Could not load definition for ${type}`;
			console.error(error);
			return Promise.reject(error);
		}
	}

	/**
	 * Initialize a block of a certain type
	 * @param {String} id - ID of the block
	 * @param {Context} context - context in which the block is being initialized
	 * @param {String} type - type definition of the block
	 * @param {Object} config - configuration object of the block
	 */
	initBlock(id, context, type, config) {
		return this.import(type).then(Block => new Block(id, context));
	}
}

export default Factory;
