var IDMap = function(masterMap) {
	this._masterMap = masterMap;

	this._mapping = {};
};

/**
 * Get the real ID given a original ID
 * @param   {String} originalID
 * @returns {String} real id
 */
IDMap.prototype.mapID = function(originalID) {
	if (this._mapping[originalID]) {
		// the ID is mapped to another ID
		return this._mapping[originalID];
	} else if (this._masterMap) {
		// check if it is mapped in a parent Map
		return this._masterMap.mapID(originalID);
	} else {
		// ID is not mapped yet
		return originalID;
	}
};

/**
 * Add a new mapping
 * @param   {String} originalID - the id that needs to be mapped
 * @param   {String} newID      - new id for the originalID
 * @returns {String} newID
 */
IDMap.prototype.addMapping = function(originalID, newID) {
	this._mapping[originalID] = newID;
};

/**
 * Create a nested instance of the IDMap
 * @returns {IDMap} an IDMap that has the current map as a master
 */
IDMap.prototype.createInstance = function() {
	return new IDMap(this);
};

export default IDMap;
