import Parameter from "./Parameter";
import Promisify from "@esko/promisify";
/**
 * Number Parameter
 * @augments Parameter
 * @param {String} name             - name of the parameter
 * @param {String} userFriendlyName - user friendly representation of the parameter
 * @param {number} defaultNumber	- default value for when the constraints are not met
 * @param {object} constraints      - { type: "int"/"float", [min: <number>, max: <number>] }
 */
var NumberParameter = function(name, context, userFriendlyName, defaultNumber, constraints, units, helpText, extraInfoText) {
	Parameter.call(this, name, context, this.getType(), userFriendlyName, helpText, extraInfoText);

	this._defaultNumber = defaultNumber;
	this._constraints = constraints;
	this._units = units || [];
};

NumberParameter.prototype = Object.create(Parameter.prototype);
NumberParameter.prototype.constructor = NumberParameter;

NumberParameter.prototype.getType = function() {
	"dashboard/core/parameters/NumberParameter";
};

/**
 * Get the default number
 * @returns {number}
 */
NumberParameter.prototype.getDefaultNumber = function() {
	return this._defaultNumber;
};

/**
 * Get the constraints
 * @returns {object} - { type: "int"/"float", [min: <number>, max: <number>] }
 */
NumberParameter.prototype.getConstraints = function() {
	return this._constraints;
};

/**
 *
 */
NumberParameter.prototype.getUnits = function() {
	return this._units;
};

/**
 * Get the configuration element for the parameter
 * @returns {Promise.<ConfigurationPanel>}
 */
NumberParameter.prototype.getConfigurationPanel = function() {
	return import("../../builder/configuration/parameters/NumberParameterConfigurationPanel").then(
		({ default: ParameterConfigurationPanel }) => new ParameterConfigurationPanel(this)
	);
};

export default NumberParameter;
