var LanguageBundle = function() {};

/**
 * Get the translation for a certain key
 * (no subtitutions should occur)
 * @param {String} key
 * @returns {String}
 */
LanguageBundle.prototype.getValueForKey = function(key) {
	return; // return undefined
};

/**
 * The main translation function
 * If called with extra parameters, this will replace {0}, {1}, ... {n} in the translated string
 * If the language string is not found, the key will be returned
 * @param {String} key - key of the language string
 * @param {Any} replacements... -
 * @returns {String}
 */
LanguageBundle.prototype.t = function(key) {
	var value = this.getValueForKey(key);

	if (typeof value === "undefined") {
		value = key;
	}

	return this.substitute(value, Array.prototype.slice.call(arguments, 1));
};

/**
 * This translation function kan have a custom value as fallback
 * If called with extra parameters after defaultValue, this will replace {0}, {1}, ... {n} in the translated string
 * @param {String} key - key of the language string
 * @param {String} defaultValue - default value, used when the translation for "key" is not found
 * @param {Any} replacements... -
 * @returns {String}
 */
LanguageBundle.prototype.tFallback = function(key, defaultValue) {
	var value = this.getValueForKey(key);

	if (typeof value === "undefined") {
		value = defaultValue;
	}

	return this.substitute(value, Array.prototype.slice.call(arguments, 2));
};

/**
 * Replacement logic for language strings
 * Replaces all occurences of {0} ... {n} with the subtitutes provided in substitutes
 * @param {String} value
 * @param {Array.<String>} substitues
 * @returns {String}
 */
LanguageBundle.prototype.substitute = function(value, substitutes) {
	for (var i = 0; i < substitutes.length; i++) {
		value = value.replace("{" + i + "}", substitutes[i]);
	}
	return value;
};

export default LanguageBundle;
