import FlexLayout from "./FlexLayout";
import $ from "jquery";
import _ from "underscore";
/**
 * This file extends the Flexlayout prototype, to include the drag and drop functionality
 */

/**
 * Fills in FlexItem column with a placeholder and handlers
 * @private
 * @param {FlexItem} column
 */
FlexLayout.prototype._initializePlaceholder = function(column) {
	if (!column.getBlockID()) {
		//double div because margin is not a dropzone otherwise
		var ghost = $("<div>")
			.css("display", "flex")
			.append(
				$("<div>", {
					style: "padding: 10px; margin: 5px;flex: 1 1 auto;",
					class: "dshFlexDragDropGhost"
				})
			);
		column.makePlaceholder(ghost);

		var self = this;
		this._context.getDragDropHandler().then(function(dragDropHandler) {
			if (!column.getBlockID()) {
				dragDropHandler.registerDropzone(
					self,
					ghost,
					{
						over: _.partial(self._ddOver, column),
						out: _.partial(self._ddOut, column),
						drop: _.partial(self._ddDrop, column)
					},
					self
				);
			}
		});
	}
};

/**
 * Handle over event of the droppable
 * @private
 * @param {Event}  event - event
 * @param {Object} ui    - JQueryUI extra info
 */
FlexLayout.prototype._ddOver = function(column, event, ui) {
	column
		.getElement()
		.find(".dshFlexDragDropGhost")
		.css("border", "1px dotted #ccc");
};

/**
 * Handle out event of the droppable
 * @private
 * @param {Event}  event - event
 * @param {Object} ui    - JQueryUI extra info
 */
FlexLayout.prototype._ddOut = function(column, event, ui) {
	column
		.getElement()
		.find(".dshFlexDragDropGhost")
		.css("border", "");
};

/**
 * Handle over event of the droppable
 * @private
 * @param {Event}  event - event
 * @param {Object} ui    - JQueryUI extra info
 */
FlexLayout.prototype._ddDrop = function(column, event, ui) {
	var blockDefinition = ui.helper.data("BlockDefinition");
	var affectedBlocks = [this];
	if (ui.helper.data("CurrentParent")) {
		affectedBlocks.push(ui.helper.data("CurrentParent"));
	}

	if (ui.helper.data("FlexLayoutFlexItem") === column) {
		// we didn't move the item, restore its position and make sure not to add an undoable action
		column.setItem(blockDefinition.getID());
		return true;
	}

	var columnID = column.getID();
	// return a promise, so the draggable is only shown once it is moved
	return this._context.getLanguageBundle("Dashboard").then(
		function(i18n) {
			// we now have the languagebundle
			return this._context.undoableAction(
				affectedBlocks,
				function() {
					this.replaceColumnWithBlock(columnID, blockDefinition.getID());
				}.bind(this),
				i18n.t("MOVE_BLOCK_UNDOREDOMESSAGE", blockDefinition.getDisplayName())
			);
		}.bind(this)
	);
};
