import Tooltip from "@esko/tooltip";
import $ from "jquery";
import i18n from "@esko/i18n/webi18n-loader?bundle=HelpBalloon!";
/**
 * This function returns an object {
 * 		{String} url: the URL to the help pages
 * 		{Function} onClick: the click handler that opens the help page in a new tab/window
 * }
 * @param {String} topic      - the topic for which the help should be shown
 * @param {String} [language] - the user language key (if not defined, it will be fetched from webcenterConfig)
 */
var getHelpURL = function(topic, language) {
	if (!language) {
		language = window.webcenterConfig.userLang;
	}

	var URLval = window.webcenterConfig.jspBaseUrl + "help.jsp?topic=" + topic + "&lang=" + language;
	var onclickString =
		"window.open('" +
		URLval +
		"','help' ,'scrollbars=1, width=800 ,height=500, toolbar=yes, location=yes, menu=yes').focus(); return false;";
	var onClickFunction = function() {
		window.open(URLval, "help", "scrollbars = 1, width = 800, height = 500, toolbar = yes, location = yes, menu = yes").focus();
		return false;
	};

	return {
		url: URLval,
		onClickString: onclickString,
		onClickFunction: onClickFunction
	};
};

/**
 * Get the HTML code for an inline help balloon to a topic
 * @param {String} topic - the topic for which the help should be shown
 * @param {String} [language] - the user language key (if not defined, it will be fetched from webcenterConfig)
 */
var getInlineHelpTopicHTML = function(topic, language) {
	var help = getHelpURL(topic, language);

	var htmlcode = '<a href="' + help.url + '" class="inline_help btn" onclick="' + help.onClickString + '" target="_blank">';
	htmlcode += '<i class="icon icon-WCR_Info-Balloon icon-normal"></i>';
	htmlcode += "</a>";

	return htmlcode;
};

/**
 * Gets the JQueryObject for an inline help balloon with a tooltip
 * if the options parameter is defined, a reference to the tooltip will be added to it with the "tooltipReference" key
 * @param {String} topic - the topic for which the help should be shown
 * @param {String} [language] - the user language key (if not defined, it will be fetched from webcenterConfig)
 * @param {Boolean} [options] - {
                                    [isMobile = false]: <Boolean>,
                                    [tooltipText = i18n.t("HelpPages"): <String>,
                                    [context = $(".w")]: <the context of the tooltip>, 
                                    [restrict = $(".w")]: <the restriction of the tooltip>
                                [cssClass = "inline_help_tooltip"]: <css class to add to the tooltip>]
                                }
 * @returns {JQueryObject}
 */
var getInlineHelpTopicJQuery = function(topic, language, options) {
	options = options || {};

	var html = getInlineHelpTopicHTML(topic, language);
	var helpBalloon = $(html);
	var tooltip = new Tooltip(
		options.i18n || i18n,
		helpBalloon,
		options.context || $(".w"),
		options.restrict || $(".w"),
		options.isMobile,
		options.tooltipText || i18n.t("HelpPages"),
		undefined,
		undefined,
		{
			cssClass: options.cssClass || "tooltip inline_help_tooltip"
		}
	);
	options.tooltipReference = tooltip;
	return helpBalloon;
};

export default {
	getHelpURL: getHelpURL,
	getInlineHelpTopicHTML: getInlineHelpTopicHTML,
	getInlineHelpTopicJQuery: getInlineHelpTopicJQuery
};
