import Observable from "@esko/observable";
import _ from "underscore";
/**
 * NEVER include this file directly, but use dependency component/message/MessageComponent instead
 *
 * This is the message model for a message widget.
 * It holds messages to show to a user in a queue.
 * @exports MessageModel
 * @constructor
 */
var MessageModel = function() {
	Observable.mixin(this, "message");

	/**
	 * @member {Array.<Message>} Array of messages to be shown
	 */
	this._messageQueue = [];
};

/**
 * Add to Message Queue
 * @param {Message} message - Message to add to the queue
 */
MessageModel.prototype.addToMessageQueue = function(message) {
	this._messageQueue.push(message);
	this._emit("added", message);
};

/**
 * Get the next message of the message queue.
 * @returns {Message} Next message of the message queue or undefined if queue was empty.
 */
MessageModel.prototype.getNextMessage = function() {
	return this._messageQueue.shift();
};

/**
 * Mark all messages with "tag" as tag, obsolete
 * @param {String} tag
 */
MessageModel.prototype.markObsolete = function(tag) {
	this._messageQueue = _.filter(this._messageQueue, function(msg) {
		return !msg.getTag() || msg.getTag() !== tag;
	});
	this._emit("obsolete", tag);
};

/**
 * Get the number of messages in the model
 * @returns {Number}
 */
MessageModel.prototype.getMessageCount = function() {
	return this._messageQueue.length;
};

export default MessageModel;
