import $ from "jquery";
import SliderConstants from "./SliderConstants";

/**
 * Responsible for displaying a slider with a single customizable indicator
 *
 * @param {Slider} slider
 */
var SliderSingle = function(slider) {
	this._slider = slider;

	this._sliderTrack = $("<div/>", {
		class: "esko-slider-track"
	});
	this._sliderIndicator = $("<div/>", {
		class: "esko-slider-indicator"
	});

	// Hook get/set to slider object
	slider.getValue = function() {
		return this._value;
	}.bind(this);

	slider.setValue = function(value) {
		if (this._value !== value) {
			this._value = value;
			this._adjustPositions();
		}
	}.bind(this);
};

/**
 * Called when this mode is activated
 *
 * @param {Object} options
 */
SliderSingle.prototype.onStart = function(options) {
	this._slider.element.addClass("esko-slider-single");
	this._slider._getLayer(SliderConstants.Layer.TRACK).append(this._sliderTrack);
	this._slider._getLayer(SliderConstants.Layer.INDICATOR).append(this._sliderIndicator);
	this._value = options.value;
	this._adjustPositions();
};

/**
 * Called when this mode is de-activated
 *
 */
SliderSingle.prototype.onStop = function() {
	this._slider.element.removeClass("esko-slider-single");
	this._sliderTrack.detach();
	this._sliderIndicator.detach();
};

/**
 * Called when the user starts dragging somewhere on the slider
 *
 * @param {Number} value
 */
SliderSingle.prototype.onDragStart = function(value) {
	this._sliderIndicator.addClass("esko-slider-indicator-focus");
	this.onDrag(value);
};

/**
 * Called when the user is dragging somewhere on the slider
 *
 * @param {Number} value
 */
SliderSingle.prototype.onDrag = function(value) {
	this._slider.setValue(value);
	this._slider.emit("value.change", value);
};

/**
 * Called when the user stops dragging
 *
 */
SliderSingle.prototype.onDragEnd = function() {
	this._sliderIndicator.removeClass("esko-slider-indicator-focus");
};

/**
 * Re-positions the track and indicator based on the current value
 *
 */
SliderSingle.prototype._adjustPositions = function() {
	window.requestAnimationFrame(
		function() {
			var percentage = this._slider._valueToPercentage(this._value);
			this._sliderTrack.css("width", percentage + "%");
			this._sliderIndicator.css("left", percentage + "%");
			this._sliderIndicator.attr("data-slider-tooltip", this._slider._options.tooltip(SliderConstants.Mode.SINGLE, this._value));
		}.bind(this)
	);
};

export default SliderSingle;
