import createInterval from "./Interval";
import $ from "jquery";
/**
 * This function will send an ajax request to url every ms milliseconds.
 * If the observable and itrs parameters are specified, the ajax request will only be sent on activity of @param{observable}.
 * If no activity is monitored, the keep session alive wil keep on sending for @param{itrs} times
 * @param {String} url
 * @param {Integer} ms
 * @param {Observable} observable
 * @param {Integer} itrs
 * @returns {Promise} promise that will fail on an ajax error
 */
var HTTPKeepAlive = function(url, ms, observable, itrs) {
	itrs = itrs || 10;
	ms = ms || 30000;

	var keepAlive = $.ajax.bind($, url, {
		beforeSend: function() {},
		complete: function() {}
	});

	return new Promise(function(resolve, reject) {
		if (observable) {
			var resetItrs = createInterval(
				ms,
				function() {
					// each ms seconds we want to send a keep alive, if it fails, stop the observable and reject the promise.
					keepAlive().fail(function() {
						resetItrs(0);
						observable.off("**", boundResetItrs);
						reject();
					});
				},
				itrs
			);
			var boundResetItrs = resetItrs.bind(undefined, itrs);
			observable.on("**", boundResetItrs);
		} else {
			setInterval(function() {
				keepAlive().fail(reject);
			}, ms);
		}
	});
};

export default HTTPKeepAlive;
