import createInterval from "./Interval";
/**
 * This function will send an ajax request to url every ms milliseconds.
 * If the observable and itrs parameters are specified, the ajax request will only be sent on activity of @param{observable}.
 * If no activity is monitored, the keep session alive wil keep on sending for @param{itrs} times
 * @param {String} url
 * @param {Integer} ms
 * @param {Observable} observable
 * @param {Integer} itrs
 * @returns {Promise} promise that will fail on an ajax error
 */
var WebSocketKeepAlive = function(ws, message, ms, observable, itrs) {
	if (ws == undefined) {
		throw "1st argument should be a websocket";
	}
	itrs = itrs || 10;
	ms = ms || 30000;
	message = message || "Keep Alive";
	var keepAlive = ws.send.bind(ws, message);

	return new Promise(function(resolve, reject) {
		var startSending = function() {
			var onError = function(e) {
				if (observable) {
					observable.off("**", boundResetItrs);
				}
				resetItrs(0);
				reject(e);
			};
			ws.addEventListener("error", onError);
			if (observable) {
				var resetItrs = createInterval(
					ms,
					function() {
						// each ms seconds we want to send a keep alive, if it fails, stop the observable and reject the promise.
						if (ws.readyState === 1) {
							keepAlive();
						} else {
							onError("WebSocket Closed");
						}
					},
					itrs
				);
				var boundResetItrs = resetItrs.bind(undefined, itrs);
				observable.on("**", boundResetItrs);
			} else {
				var interval = setInterval(function() {
					keepAlive();
				}, ms);

				ws.addEventListener("close", function() {
					clearInterval(interval);
				});
			}
		};

		if (ws.readyState === 1) {
			startSending();
		} else {
			ws.addEventListener("open", startSending);
		}
	});
};

WebSocketKeepAlive.builder = function(ws) {
	var interval, message, itrs, observable;
	var builder = {
		setInterval: function(x) {
			interval = x;
			return builder;
		},
		setMessage: function(x) {
			message = x;
			return builder;
		},
		setIterations: function(x) {
			itrs = x;
			return builder;
		},
		setObservable: function(x) {
			observable = x;
			return builder;
		},
		start: function() {
			return WebSocketKeepAlive(ws, message, interval, observable, itrs);
		}
	};
	return builder;
};

export default WebSocketKeepAlive;
