import ButtonGroup from "./ButtonGroup";
import Observable from "@esko/observable";
import $ from "jquery";
import _ from "underscore";
var ToolbarComponent = function ToolbarComponent(name) {
	Observable.mixin(this, ["toolbarComponent", name]);

	this.name = name;
	this.element = $("<div />")
		.attr("name", name)
		.addClass("btn-toolbar");
	this._elements = [];

	this._isVisible = true;

	/**
	 * Add custom object to the toolbar component, needs to have element-property.
	 *
	 * @param {Object} object
	 * @param {Integer} index
	 */
	this.addObject = function(object, index) {
		if (index !== undefined && index !== null && index > -1) {
			this._elements[index] = object;
			var prevIndex = index - 1; // try to find an already added object
			var previousBtnGroup = this._elements[prevIndex];
			while (--prevIndex >= 0 && !previousBtnGroup) {
				previousBtnGroup = this._elements[prevIndex];
			}
			if (previousBtnGroup) {
				//a previous object was found
				previousBtnGroup.element.after(object.element);
			} else {
				//if not found add the new button group to the front
				this.element.prepend(object.element);
			}
		} else {
			this._elements.push(object);
			this.element.append(object.element);
		}
	};

	/**
	 * Add a button group (in the end of the component)
	 *
	 * @param buttonGroup {ButtonGroup} the button group to add
	 * @param index {Integer} the index where the button group should be added
	 */
	this.addButtonGroup = function(buttonGroup, index) {
		this.addObject(buttonGroup, index);
	};

	/**
	 * Add a button group (in the beginning of the component)
	 *
	 * @param buttonGroup {ButtonGroup} the button group to add
	 */
	this.prependButtonGroup = function(buttonGroup) {
		this._elements.unshift(buttonGroup);
		this.element.prepend(buttonGroup.element);
	};

	/**
	 * Detach a button group from the DOM
	 */
	this.detachButtonGroup = function(buttonGroup) {
		this._elements = _.without(this._elements, buttonGroup);
		buttonGroup.element.detach();
	};

	/**
	 * Called when the toolbar component is moved
	 */
	this.moved = function() {
		_.each(this._elements, function(buttonGroup) {
			if (buttonGroup && buttonGroup.moved) {
				buttonGroup.moved();
			}
		});
	};

	this.show = function() {
		this.element.toggleClass("displayNone", false);
		var changed = !this._isVisible;
		this._isVisible = true;
		if (changed) {
			this._emit("changed.visibility");
		}
	};

	this.hide = function() {
		this.element.toggleClass("displayNone", true);
		var changed = this._isVisible;
		this._isVisible = false;
		if (changed) {
			this._emit("changed.visibility");
		}
	};
};

/**
 * Returns the name of the toolbarcomponent
 * @returns {String}
 */
ToolbarComponent.prototype.getName = function() {
	return this.name;
};

/**
 * Check if the toolbarcomponent is visible.
 * @returns {Boolean}
 */
ToolbarComponent.prototype.isVisible = function() {
	return this._isVisible;
};

export default ToolbarComponent;
