import _ from "underscore";

export default {
	mixin: function(object) {
		var didRequestAnimationFrame = null;

		var renderPromise = new Promise(function() {});
		var callbacks = [];

		/**
		 * Trigger a render on the object
		 * @private
		 * @param   {Function} [callback] - called when render operation is finished
		 * @returns {Promise}  resolved when render is finished
		 */
		object._render = function(callback) {
			renderPromise = new Promise(function(resolve, reject) {
				if (callback) {
					callbacks.push(callback);
				}
				callbacks.push(resolve);

				if (!didRequestAnimationFrame) {
					didRequestAnimationFrame = window.requestAnimationFrame(function() {
						didRequestAnimationFrame = null;
						object._doRender();
						_.each(callbacks, function(callback) {
							callback();
						});
						callbacks = [];
					});
				}
			});
			return renderPromise;
		};

		/**
		 * Have promise for when component is rendered
		 * @returns {Promise} resolved when render is finished
		 */
		object.whenRendered = function() {
			return renderPromise;
		};
	}
};
