var FilterUtils = {
	/**
	 * Preprocess a pattern
	 *
	 * if empty, it will become the wildcard * pattern if it doesn't
	 * contain a ? or *, wildcards will be added at beginning and end
	 *
	 * @param textPattern
	 */
	preprocessPattern: function(textPattern) {
		if (textPattern.length === 0) {
			textPattern = "*";
		} else if (textPattern.indexOf("?") === -1 && textPattern.indexOf("*") === -1) {
			// add * at beginning and end
			textPattern = "*" + textPattern + "*";
		}

		return textPattern;
	},

	/**
	 * Generate a regular expression of a preprocessed Text Pattern
	 *
	 * @param textPattern
	 */
	generateRegex: function(textPattern, preprocess) {
		var preprocessedTextPattern;
		if (preprocess) {
			preprocessedTextPattern = this.preprocessPattern(textPattern);
		} else {
			preprocessedTextPattern = textPattern;
		}

		// add ^ beginning and $ delimiters
		preprocessedTextPattern = "^" + this.escapeRegexSpecials(preprocessedTextPattern) + "$";
		// replace wildcards by their regex counterparts, and create a
		// case insensitive RegEx object
		return new RegExp(preprocessedTextPattern.replace(/\?/g, ".").replace(/\*/g, ".*"), "i");
	},

	/**
	 * Escape special RegEx characters (except * and ?)
	 *
	 * @param text
	 * @returns
	 */
	escapeRegexSpecials: function(text) {
		var specials = ["/", ".", "+", "|", "(", ")", "[", "]", "{", "}", "\\", "^", "$"];
		var regexp = new RegExp("(\\" + specials.join("|\\") + ")", "g");
		return text.replace(regexp, "\\$1");
	}
};
export default FilterUtils;
