import _ from "underscore";
import ConvertUtils from "@esko/convertutils";
var HTTPUtils = {
	/**
	 * Construct an url (with urlencoded arguments)
	 * @param servlet {String} the servlet to call
	 * @param args {Object} parameters for url (key-value pairs)
	 * @param base {String} url (optional)
	 * @returns {String}
	 */
	constructURL: function(servlet, args, base) {
		var url = "";
		if (base) {
			url += base;
		}
		url += servlet;

		var pre = "?";
		for (var key in args) {
			if (args.hasOwnProperty(key)) {
				if (_.isArray(args[key])) {
					for (var i = 0; i < args[key].length; i++) {
						url += pre + encodeURIComponent(key) + "=" + encodeURIComponent(ConvertUtils.decodeHtmlEntities(args[key][i]));
						pre = "&";
					}
				} else {
					url += pre + encodeURIComponent(key) + "=" + encodeURIComponent(ConvertUtils.decodeHtmlEntities(args[key]));
				}
			}
			pre = "&";
		}

		return url;
	},
	/**
	 * Get the value of a specific query string parameter
	 * (note: it doesn't work multiple entries with the same name)
	 * @param   {String} name - name of the parameter
	 * @returns {String} value of the parameter
	 */
	getQueryStringParam: function(name) {
		name = name.replace(/[\[\]]/g, "\\$&");
		var regex = new RegExp("[?&]" + name + "(=([^&#]*)|&|#|$)"),
			results = regex.exec("?" + location.search);
		if (!results) {
			return null;
		} else if (!results[2]) {
			return "";
		} else {
			return decodeURIComponent(results[2].replace(/\+/g, " "));
		}
	},
	/**
	 * Get a map of all query string parameters
	 * (note: it doesn't support multiple entries with the same name (but it will not crash)
	 * @returns {object}
	 */
	getQueryStringParams: function() {
		return (function(a) {
			var b = {};
			for (var i = 0; i < a.length; ++i) {
				if (a[i] !== "") {
					var p = a[i].split("=", 2);
					if (p.length == 1) {
						b[p[0]] = "";
					} else {
						b[p[0]] = decodeURIComponent(p[1].replace(/\+/g, " "));
					}
				}
			}
			return b;
		})(window.location.search.substr(1).split("&"));
	},

	/**
	 * Update a single parameter in a url
	 * @param   {String}   uri   - url that needs to be adapted
	 * @param   {String}   key   - key of the parameter that needsto be changed
	 * @param   {String}   value - new value for the parameter. If undefined the parameter is removed
	 * @returns {String} new url
	 */
	updateQueryStringParameter: function(uri, key, value) {
		var re = new RegExp("([?&])" + key + "=.*?(&|#|$)", "i");
		if (value === undefined) {
			if (uri.match(re)) {
				return uri.replace(re, "$1$2");
			} else {
				return uri;
			}
		} else {
			if (uri.match(re)) {
				return uri.replace(re, "$1" + key + "=" + encodeURIComponent(value) + "$2");
			} else {
				var hash = "";
				if (uri.indexOf("#") !== -1) {
					hash = uri.replace(/.*#/, "#");
					uri = uri.replace(/#.*/, "");
				}
				var separator = uri.indexOf("?") !== -1 ? "&" : "?";
				return uri + separator + key + "=" + encodeURIComponent(value) + hash;
			}
		}
	}
};

export default HTTPUtils;
