import _ from "underscore";
/**
 * Handle mousewheel events
 */
var Mousewheel = new function() {
	var listeners = [];

	this.enabled = true;

	var handleScrollEvent = _.bind(function(event) {
		if (this.enabled) {
			var delta = Math.max(-1, Math.min(1, event.wheelDelta || -event.detail));
			/**
			 * If delta is nonzero, handle it. Basically, delta is now
			 * positive if wheel was scrolled up, and negative, if wheel
			 * was scrolled down.
			 */
			if (delta) {
				_.each(listeners, function(callback) {
					callback(event, delta);
				});
			}
		}
	}, this);

	if (window.addEventListener && /Firefox/i.test(navigator.userAgent)) {
		/** DOMMouseScroll is for mozilla. */
		window.addEventListener("DOMMouseScroll", handleScrollEvent, false);
	} else {
		/** IE/chrome */
		document.onmousewheel = handleScrollEvent;
	}

	this.addListener = function(callback) {
		if (_.indexOf(listeners, callback) < 0) {
			listeners.push(callback);
		}
	};

	this.removeListener = function(callback) {
		listeners = _.without(listeners, callback);
	};
}();

export default Mousewheel;
