var XMLUtils = null;
XMLUtils = {
	attributeValue: function(xml, attribute) {
		var att = xml.attributes.getNamedItem(attribute);
		if (att) {
			return att.nodeValue;
		} else {
			return null;
		}
	},
	nodeTextContent: function(parent, nodename) {
		var child = parent.getElementsByTagName(nodename)[0];
		if (child) {
			return XMLUtils.textContent(child);
		} else {
			return null;
		}
	},
	textContent: function(node) {
		var content = node.textContent;
		if (content === undefined) content = node.nodeTypedValue; //ie7/8
		return content;
	},
	/**
	 * This is a utility function for converting an xml to an object for fast traversal.
	 * If a node has attributes they are available via obj.attributes[xxx], otherwise .attributes is an empty object, but
	 * KNOWN LIMITATIONS:
	 * - attributes object will not be added for leaf nodes: the leaf node will just be the text value
	 * - a node cannot have a node called "attributes"
	 * @param {DOMNode} node - The node you want to convert to an object
	 * @param {Number} [_nrOfChildren] - Don't define this parameter. It is used by this function in recursion for optimization
	 * @returns {Object}
	 */
	xml2obj: function(node, _nrOfChildren) {
		var obj = new Object();
		var nodes = node.childNodes;

		for (var i = 0; i < nodes.length; i++) {
			var childnode = nodes[i];
			var name = childnode.nodeName;
			if (name == "#text") continue;

			var nrOfChildren = this.numberOfChildren(childnode);
			var value = undefined;
			if (nrOfChildren > 0) {
				value = this.xml2obj(childnode, nrOfChildren);
			} else {
				value = this.textContent(childnode);
			}

			if (obj[name] !== undefined) {
				if (Object.prototype.toString.call(obj[name]) !== "[object Array]") {
					var o = obj[name];
					obj[name] = [];
					obj[name].push(o);
				}

				obj[name].push(value);
			} else {
				obj[name] = value;
			}
		}

		// read the attributes (for nodes with children or if the root node has children) and attributes is defined (not the case if you pass #document)
		if ((_nrOfChildren !== undefined || this.numberOfChildren(node) > 0) && node.attributes) {
			obj.attributes = {};
			for (var a = 0; a < node.attributes.length; a++) {
				obj.attributes[node.attributes[a].name] = node.attributes[a].value;
			}
		}

		return obj;
	},
	numberOfChildren: function(node) {
		var number = 0;
		if (node.childNodes && node.childNodes.length > 0) {
			for (var i = 0; i < node.childNodes.length; i++) {
				if (node.childNodes[i].nodeType == 1) {
					number++;
				}
			}
			return number;
		} else {
			return number;
		}
	},
	/**
	 * Get the first child element by tag name
	 * @param   {Node}   node - XML element to search
	 * @param   {String}   tagName - The tag name to search
	 * @returns {Node} The element of the first element matching the tag name or undefined if not found
	 */
	getFirstChildElementByTagName: function(node, tagName) {
		for (var child = node.firstChild; child; child = child.nextSibling) {
			if (child.nodeType == 1 && child.tagName.toLowerCase() === tagName) {
				return child;
			}
		}
		return undefined;
	}
};

export default XMLUtils;
