import Core from "./core/Core";


/**
 * The ViewerApp class is an instance of the web viewer.
 * To launch an instance of the web viewer, a new instance of this function should be created
 *
 *  new ViewerApp(......)
 *
 *  @param context                {HTMLObject}          a reference to the div in which the viewer should be created
 *  @param documentInformation    {any}                 String or JSON object containing information on which document to load
 *  @param config                 {Core.AbstractConfig} configuration object
 *
 */
var ViewerApp = function (context, documentInformation, config) {
	// we create a new instance of the viewer core facade
	this._f = new Core(context, config);

	// open the document(s)
	this._f.openDocuments(documentInformation);
};

/**
 * Inject state of modules into the viewerApp.
 * @param {Object} state - module name is mapped on the state object for that specific module
 */
ViewerApp.prototype.injectState = function (state) {
	this._f.injectState(state);
};

export default ViewerApp;

