import ViewerUtils from "@esko/web-viewer/utils/ViewerUtils";
import Tooltip from "@esko/tooltip/Tooltip";
import ConvertUtils from "@esko/convertutils";
import $ from "jquery";
import _ from "underscore";
/**
 * @exports AnnotationCharLineCount
 * @memberof AnnotationModule
 * Constructs a new AnnotationCharLineCount element
 * @class
 * Annotation Char Line Count is an element that shows the character/line count of an annotation, including tooltips.
 * It can be shown/hidden and the text can be updated.
 * @constructor
 * @param {Core.ViewerFacade} f - Viewer facade
 */
var AnnotationCharLineCount = function(f) {
	this.element = $("<div />").addClass("charLineCount");
	this.showing = false;
	this.f = f;
	this.tooltip = null;
};

/**
 * Update the character line count with the newest count for the given rawHTMLString
 * @param {String} rawHTMLString - HTML string to count the characters/lines from
 */
AnnotationCharLineCount.prototype.update = function(rawHTMLString) {
	if (this.showing) {
		// Update the count
		var charLineCount = ConvertUtils.getCharacterLineCount(rawHTMLString);
		this.element.text(charLineCount.charCount + "/" + charLineCount.lineCount);
		// Update the tooltip
		if (this.tooltip) {
			this.tooltip.setTooltipContent("viewer", "charLineCount", [charLineCount.charCount, charLineCount.lineCount]);
		} else {
			this.tooltip = new Tooltip(
				this.f.i18n,
				this.element,
				this.f.getContext(),
				this.f.getContext(),
				this.f.isMobile(),
				"viewer",
				"charLineCount",
				[charLineCount.charCount, charLineCount.lineCount]
			);
		}
	}
};

/**
 * Show the character line count element
 */
AnnotationCharLineCount.prototype.show = function() {
	this.element.show();
	this.showing = true;
};

/**
 * Hide the character line count
 */
AnnotationCharLineCount.prototype.hide = function() {
	this.element.hide();
	this.showing = false;
};

export default AnnotationCharLineCount;
