import $ from "jquery";
import _ from "underscore";
import TimeInput from "./TimeInput";
import Timestamp from "@esko/web-viewer/video/Timestamp";
/**
 * @exports AnnotationTimeRow
 * @memberof AnnotationModule
 * @class A row displaying start time and end time for an annotation
 * @constructor
 * @param {Core.ViewerFacade} f - Viewerfacade
 * @param {Annotation} annotation - Annotation to which the times apply
 * @param {AnnotationModel} annotationModel
 * @param {boolean} editable - are the times editable or not?
 */
var AnnotationTimeRow = function(f, annotation, annotationModel, editable) {
	this.f = f;
	this._annotation = annotation;
	this.editable = editable;
	this.annotationModel = annotationModel;

	this.element = $("<div>");

	this.startInput = new TimeInput(this._annotation.startTime || 0).onChange(
		function(time) {
			this._annotation.setStartEndTime(time, this._annotation.endTime);
		}.bind(this)
	);

	this.endInput = new TimeInput(this._annotation.endTime || this._annotation.startTime).onChange(
		function(time) {
			this._annotation.setStartEndTime(this._annotation.startTime, time);
		}.bind(this)
	);

	this.render();

	annotation.on("modified.startEndTime", this.render.bind(this));

	/**
	 * When annotations are saved, update time
	 */
	this.annotationModel.on(
		"save.finished",
		_.bind(function() {
			this.render();
		}, this)
	);
};

/**
 * render the row
 */
AnnotationTimeRow.prototype.render = function() {
	this.startInput.element.detach();
	this.endInput.element.detach();
	this.element.empty();

	var startLabel = $("<td />").addClass("AnnTimeRowLabel");
	var endLabel = $("<td />").addClass("AnnTimeRowLabel");
	if (this.editable) {
		this.startInput.setTime(this._annotation.startTime || 0);
		this.endInput.setTime(this._annotation.endTime || this._annotation.startTime);
		var table = $("<table>", {
			class: "AnnTimeRowEditable"
		});
		var start = $("<tr>")
			.append(startLabel)
			.append($("<td>").append(this.startInput.element));
		var end = $("<tr>")
			.append(endLabel)
			.append($("<td>").append(this.endInput.element));
		table.append(start).append(end);
		this.element.append(table);
	} else {
		var startValue = $("<span>").append(new Timestamp(this._annotation.startTime || 0).toString());
		var endValue = $("<span>").append(new Timestamp(this._annotation.endTime || this._annotation.startTime).toString());

		var div = $("<div>", {
			class: "AnnTimeRow"
		})
			.append(startValue)
			.append("&nbsp;-&nbsp;")
			.append(endValue);
		this.element.append(div);
	}

	// Set texts
	this.f.i18n.loadBundle(
		"viewer",
		_.bind(function() {
			startLabel.append(this.f.i18n.t("AnnStartTime") + ":");
			endLabel.append(this.f.i18n.t("AnnEndTime") + ":");
		}, this)
	);
};

/**
 * Checks if the row should show all the option-buttons
 * @returns {Boolean}
 */
AnnotationTimeRow.prototype.getElement = function(editable) {
	return this.element;
};

AnnotationTimeRow.prototype.hide = function(editable) {
	this.element.addClass("displayNone");
};

AnnotationTimeRow.prototype.show = function(editable) {
	this.element.removeClass("displayNone");
};

export default AnnotationTimeRow;
