import ToolbarComponent from "@esko/toolbar/ToolbarComponent";
import ButtonGroup from "@esko/toolbar/ButtonGroup";
import ViewerToolbarButton from "@esko/web-viewer/layout/component/ViewerToolbarButton";
import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";

/**
 * @exports AnnotationTouchToolbarComponent
 * @memberof AnnotationModule
 * @constructor
 * @param {Core.ViewerFacade} f - Viewer facade
 * @param {AnnotationModel} annotationsModel - Annotation model
 * @param {AnnotationTouchDrawTool} drawTool - The annotation draw tool
 */
var AnnotationTouchToolbarComponent = function(f, annotationsModel, drawTool) {
	ToolbarComponent.call(this, LayoutConstants.ToolbarComponent.ANNOTATION, f);
	this.f = f;
	this.annotationModel = annotationsModel;
	/**
	 * Group: annotate
	 */
	var annotateGroup = new ButtonGroup("AnnotateGroup");
	annotateGroup.setTitle(f.i18n, "viewer", "AnnBtnGroupTitle");
	this.addButtonGroup(annotateGroup);

	// Annotate ViewerToolbarButton
	var annotateButton = new ViewerToolbarButton(f, "AnnotateButton", "icon-WCR_Add", true, function() {
		//make sure annotations are visible
		annotationsModel.toggleVisibility(true);
	});
	annotateButton.listenToTool(drawTool, true);
	annotateGroup.addButton(annotateButton);

	/**
	 * Disable/Enable the buttons depending on:
	 * 	1. If the user can't change the annotations (e.g. document is approved and annotationmode is set to "readonly when approved"
	 *  2. If "hideAllAnnotations" is true
	 */
	var updateAnnotationButtonsUsability = function() {
		if (!annotationsModel.canChangeAnnotations(true)) {
			var reason = "";
			if (annotationsModel.getDisabledReason().length > 0) {
				reason = annotationsModel.getDisabledReason();
			}

			// set the tooltip for when the button is disabled
			annotateButton.setDisabledTooltip(reason);

			// disable buttons
			if (drawTool.isActive()) {
				drawTool.requestDeactivation();
			}

			annotateButton.setEnabled(false);
		} else {
			// the buttons should be enabled
			annotateButton.setEnabled(true);
		}
	};
	updateAnnotationButtonsUsability();

	annotationsModel.on("readWriteChanged", updateAnnotationButtonsUsability);
	annotationsModel.on("temporarilyDisableChanged", updateAnnotationButtonsUsability);
	annotationsModel.on("disabledReasonChanged", updateAnnotationButtonsUsability);
};

AnnotationTouchToolbarComponent.prototype = Object.create(ToolbarComponent.prototype);
AnnotationTouchToolbarComponent.prototype.constructor = AnnotationTouchToolbarComponent;
AnnotationTouchToolbarComponent.toolbarName = LayoutConstants.ToolbarComponent.ANNOTATION;

export default AnnotationTouchToolbarComponent;
