import Timestamp from "@esko/web-viewer/video/Timestamp";
import $ from "jquery";

/**
 * This elements renders a div filled wiht inputs in order to specify a time HH:MM:SS,mmm
 *
 * @param {Number} time in seconds
 * @param {Number} [max] max value allowed to enter
 */
var TimeInput = function(time, max) {
	this.time = time || 0;
	this.max = max || Number.MAX_VALUE;
	this.element = $("<div>", {
		class: "timeinput"
	});

	this._minute = $('<input class="timeinput-minute" min="0" max="60" type="number" />').on("change", this._onChange.bind(this));
	this._second = $('<input class="timeinput-second" min="0" max="60" type="number" />').on("change", this._onChange.bind(this));
	this._millisecond = $('<input class="timeinput-millisecond" min="0" max="1000" type="number" />').on("change", this._onChange.bind(this));

	this.element
		.append(this._minute)
		.append("<span>:</span>")
		.append(this._second)
		.append("<span>,</span>")
		.append(this._millisecond);
	this._changeInputs();
};

/**
 * Triggered whenever one of the inputs changes value
 *
 */
TimeInput.prototype._onChange = function() {
	var seconds = (parseInt(this._minute.val(), 10) || 0) * 60;
	seconds += parseInt(this._second.val(), 10) || 0;
	seconds += (parseInt(this._millisecond.val(), 10) || 0) / 1000;
	if (seconds < 0) {
		seconds = 0;
	} else if (seconds > this.max) {
		seconds = this.max;
	}
	this.time = seconds;
	this._changeInputs();
	if (this._callback) {
		this._callback(this.time);
	}
};

/**
 * Re-calculates the value of the inputs based on the given time
 *
 */
TimeInput.prototype._changeInputs = function() {
	var data = new Timestamp(this.time).format();

	this._minute.val(data.min);
	this._second.val(data.sec);
	this._millisecond.val(data.ms);
};

/**
 * Add a callback that is fired whenever the time changes
 *
 * @param {Function} callback
 * @returns
 */
TimeInput.prototype.onChange = function(callback) {
	this._callback = callback;
	return this;
};

/**
 * Changes the current time
 *
 * @param {Number} time  in seconds
 */
TimeInput.prototype.setTime = function(time) {
	this.time = time;
	this._changeInputs();
};

export default TimeInput;
