import AbstractDocumentPage from "@esko/web-viewer/data/AbstractDocumentPage";
import ViewerUtils from "@esko/web-viewer/utils/ViewerUtils";
import _ from "underscore";
import ShapeUtils from "@esko/shapeutils";
var CadDataExtensions = _.once(function(f) {
	/**
	 * Returns the origin of the CAD-file, only if the CAD-origin is above and/or left of the graphics' (0,0)-point
	 * if this is not the case it returns (0,0) If only the original origin is requested it will return positive origins.
	 *
	 * @param {Boolean} getOriginalOrigin - returns the original origin even if it's positive
	 *
	 * @returns {ShapeUtils.Point}
	 */
	AbstractDocumentPage.prototype.getOrigin = function(getOriginalOrigin) {
		var originX = 0;
		var originY = 0;
		if (this._parameters) {
			if (this.hasCad() && getOriginalOrigin) {
				if (this.isCadAvailable && this.isCadAvailable()) {
					return this.getCad().getOriginalOrigin();
				} else {
					return null;
				}
			}
		}
		return new ShapeUtils.Point(originX, -originY);
	};

	/**
	 * Get CAD offset
	 * @returns {ShapeUtils.Size} the cad offset
	 */
	AbstractDocumentPage.prototype.getCadOffset = function() {
		if (this._data.offsetx !== undefined || this._data.offsety !== undefined) {
			var offsetx = 0;
			if (this._data.offsetx !== undefined) {
				offsetx = ViewerUtils.parseFloat(this._data.offsetx);
			}

			var offsety = 0;
			if (this._data.offsety !== undefined) {
				offsety = ViewerUtils.parseFloat(this._data.offsety);
			}

			return new ShapeUtils.Size(offsetx, offsety);
		} else {
			return null;
		}
	};

	AbstractDocumentPage.prototype.requestCad = function(onCadAvailable) {
		throw "Not Implemented: requestCad";
	};

	/**
	 * Parse the raw cad data and style and store it in the page
	 * @returns {Boolean} true if successful
	 */
	AbstractDocumentPage.prototype.initializeCadFile = function() {
		throw "Not Implemented: initializeCadFile";
	};

	/**
	 * Get the cad file
	 * @returns {CadFile} Cad File
	 */
	AbstractDocumentPage.prototype.getCad = function() {
		throw "Not Implemented: getCad";
	};

	AbstractDocumentPage.prototype.isCadAvailable = function() {
		throw "Not Implemented: isCadAvailable";
	};
});
export default CadDataExtensions;
