import _ from "underscore";
import CadLayerModel from "@esko/web-viewer/cad/CadLayerModel";
import ShapeUtils from "@esko/shapeutils";
/**
 * @exports ViewserverCADLayerModel
 * @class Extends the CadLayerModel, only used for the CAD overlay, in combination with Graphics layer
 * @augments Viewport.CadLayerModel
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {String} ID
 * @param {CadModel} cadModel
 * @param {Boolean} isForReferencePage - is this layer showing the reference document page or not
 */
var CadOverlayLayerModel = function(f, ID, cadModel, isForReferencePage) {
	CadLayerModel.call(this, f, ID, cadModel, isForReferencePage);
};

// inherit
CadOverlayLayerModel.prototype = Object.create(CadLayerModel.prototype);
// correct the constructor pointer
CadOverlayLayerModel.prototype.constructor = CadOverlayLayerModel;

/**
 * Override the _calculateTransformation of the CadLayerModel, this is specific for CAD overlay
 */
CadOverlayLayerModel.prototype._calculateTransformation = function() {
	if (this.f.getModule("viewport")) {
		var worldBounds = this.f.getModule("viewport").getWorldBounds();

		this.resetTransformation();

		var page = this.cadModel.getPage();
		var graphicsPage = this.f.getDocumentController().getActivePage();
		//get the Size of the Active (Graphics) document page, this is the page the CAD overlay is linked to
		var graphicsSize = graphicsPage.getPageSize();
		page.getCad().setLocation(null); //reset the location

		this._offsetX = 0;
		this._offsetY = -this.cadModel.getCad().getSize().height; //cad is always seen from bottom left corner

		var offset = new ShapeUtils.Size(this._offsetX, this._offsetY);
		var compareOffset = new ShapeUtils.Point();
		if (page.hasStateParam("compareOffset")) {
			compareOffset = page.getStateParam("compareOffset").copy();
			offset.width -= compareOffset.x;
			offset.height += compareOffset.y;
		}

		offset.width += graphicsPage.getDocumentPageOrigin().x;
		offset.height += graphicsPage.getDocumentPageOrigin().y;

		var rotation = this.cadModel.getPage().getRotation();
		if (rotation % 360 === 90) {
			offset.height -= graphicsSize.width;
		} else if (rotation % 360 === 180) {
			offset.width -= graphicsSize.width;
			offset.height -= graphicsSize.height;
		} else if (rotation % 360 === 270) {
			offset.width -= graphicsSize.height;
		}

		var isFlipped = this.cadModel.getPage().isFlipped();

		if (isFlipped && rotation % 360 === 0) {
			offset.width -= graphicsSize.width;
		} else if (isFlipped && rotation % 360 === 90) {
			offset.width -= graphicsSize.height;
		} else if (isFlipped && rotation % 360 === 180) {
			offset.width += graphicsSize.width;
		} else if (isFlipped && rotation % 360 === 270) {
			offset.width += graphicsSize.height;
		}

		this.calculateTransformation(worldBounds, page.getPageSize(), offset, 0, false, rotation, isFlipped);

		var origin = page.getCad().getOrigin();
		var pageSize = page.getPageSize();
		origin.y = -origin.y;
		var rect = new ShapeUtils.Rect(origin, pageSize);
		var newRect = this.getTransform().transformedRect(rect);

		page.getCad().setLocation(newRect);

		this.modelChanged();
	}
};

export default CadOverlayLayerModel;
