import LineworkWrapper from "@esko/web-viewer/utils/LineworkWrapper";
import ShapeUtils from "@esko/shapeutils";
import XMLUtils from "@esko/xmlutils";
import ViewerUtils from "@esko/web-viewer/utils/ViewerUtils";
/**
 * @exports CadText
 * @memberof CadModule
 * @class CadText is a LineworkWrapper object that is used to display a text within a CadFile
 * @augments Utils.LineworkWrapper
 * @constructor
 * @param {XMLElement} node - xml to construct the CadText
 * @param {Object} styles - plotting styles to use to construct the CadFile (colors/width/...)
 * @param {Number} tspanIndex - index of the tspan node
 * @param {Number} height - height of the cad file to calculate the point on normal axis
 */
var CadText = function(node, styles, tspanIndex, height) {
	LineworkWrapper.call(this);

	this.type = -21;
	//		this.staticsize = true;
	this.textoptions["rotation"] = 0;

	for (var i = 0; i < node.attributes.length; i++) {
		var attrib = node.attributes[i];
		this.textoptions[attrib.nodeName] = attrib.nodeValue;
	}
	if (this.textoptions.rotate == null) {
		this.textoptions.rotate = 0;
	} else {
		this.textoptions.rotate = ViewerUtils.parseFloat(this.textoptions.rotate);
	}

	var tspannode = node.getElementsByTagName("Tspan")[tspanIndex];
	this.textoptions["text"] = tspannode.firstChild.nodeValue;
	var x = XMLUtils.attributeValue(tspannode, "x");
	var y = XMLUtils.attributeValue(tspannode, "y");
	if (this.textoptions.rotate !== 0) {
		var rotate = (-this.textoptions.rotate / 180) * Math.PI;

		// SVG store text position pre-rotate, we prefer post-rotate
		var newX = x * Math.cos(rotate) - y * Math.sin(rotate);
		var newY = x * Math.sin(rotate) + y * Math.cos(rotate);
		x = newX;
		y = newY;
	}

	this.rect = new ShapeUtils.Rect(new ShapeUtils.Point(0, 0), new ShapeUtils.Size(0, 0));
	this.rect.origin.x = x;
	this.rect.origin.y = height - y;

	var pstyle = styles[this.textoptions.filltype];
	if (pstyle) {
		this.c = pstyle.color;
		this.color = "#" + ViewerUtils.rgbToHex(this.c.r, this.c.g, this.c.b);
	}

	if (this.textoptions["fill"] !== undefined) {
		this.color = this.textoptions["fill"];
	}
};

// inherit
CadText.prototype = Object.create(LineworkWrapper.prototype);
// correct the constructor pointer
CadText.prototype.constructor = CadText;

export default CadText;
