import _ from "underscore";
import CompareMode from "@esko/web-viewer/compare/CompareMode";
import CompareConst from "@esko/web-viewer/compare/CompareConstants";
import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import ViewportConstants from "@esko/web-viewer/viewport/ViewportConstants";
import ListenerUtil from "@esko/web-viewer/utils/ListenerUtil";
/**
 * @memberof CompareModule
 * @exports Compare3DBlinking
 * @class This mode shows a blinking view of the 3D views of the current and reference document.
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {CompareModule.CompareModel} compareModel - model for compare
 */
var Compare3DBlinking = function(f, compareModel) {
	CompareMode.call(this, f, CompareConst.mode.BLINKING3D, compareModel, true, "DiffShow3DSideBySide");
	ListenerUtil.mixin(this, f);
	/**
	 * @private the interval for the switch between documents
	 */
	this._blinkInterval = CompareConst.blinkingSpeed;

	/**
	 * @private is the difference visible?
	 */
	this._differenceVisible = false;

	/**
	 * internal function used to execute the blinking mode
	 */
	this._toggleDifference = _.bind(function() {
		this._differenceVisible = !this._differenceVisible;
		// instruct the graphics module
		this._updateCompareModel();

		if (this.isEnabled()) {
			this._timer = setTimeout(this._toggleDifference, this._blinkInterval);
		}
	}, this);
};

Compare3DBlinking.prototype = Object.create(CompareMode.prototype);
Compare3DBlinking.prototype.constructor = Compare3DBlinking;

/**
 * Start/stop blinking mode
 * @param {Boolean} [toggle] - should the mode be blinking or not, if undefined the mode will go to the other state than it is in
 */
Compare3DBlinking.prototype.toggle = function(toggle) {
	CompareMode.prototype.toggle.call(this, toggle);

	if (toggle) {
		this.f.whenModuleAvailable(
			"view3D",
			function(view3D) {
				view3D.set3DDifferenceEnabled(toggle);
				this._toggleDifference();
			}.bind(this)
		);
	} else {
		if (this._timer) {
			clearTimeout(this._timer);
		}
		this._differenceVisible = false;

		this._updateCompareModel();
	}
};

/**
 * Update the state of the compare model
 */
Compare3DBlinking.prototype._updateCompareModel = function() {
	var newDiffMode = this.isDifferenceVisible() ? CompareConst.diffMode.SHOWDIFFERENCE3D : CompareConst.diffMode.SHOWCURRENT3D;
	this._compareModel.setDiffMode(newDiffMode);
};

/**
 * Is the difference visible
 * @returns {Boolean}
 */
Compare3DBlinking.prototype.isDifferenceVisible = function() {
	return this._differenceVisible;
};

/**
 * Is the current visible
 * @returns
 */
Compare3DBlinking.prototype.isCurrentVisible = function() {
	return !this._differenceVisible;
};

Compare3DBlinking.prototype.getLayoutMode = function() {
	return LayoutConstants.LayoutMode.COMPARE_3D;
};

export default Compare3DBlinking;
