import _ from "underscore";
import CompareMode from "@esko/web-viewer/compare/CompareMode";
import CompareConst from "@esko/web-viewer/compare/CompareConstants";
import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import ViewportConstants from "@esko/web-viewer/viewport/ViewportConstants";
import ListenerUtil from "@esko/web-viewer/utils/ListenerUtil";
/**
 * @memberof CompareModule
 * @exports Compare3DSideBySideMode
 * @class This mode shows a side by side view of the current and reference document. It enables the user to show a difference panel too (therefor it relies on compareShowDifferenceMode)
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {CompareModule.CompareModel} compareModel - model for compare
 */
var Compare3DSideBySideMode = function(f, compareModel) {
	CompareMode.call(this, f, CompareConst.mode.SIDEBYSIDE3D, compareModel, true, "DiffShow3DSideBySide");
	ListenerUtil.mixin(this, f);
};

Compare3DSideBySideMode.prototype = Object.create(CompareMode.prototype);
Compare3DSideBySideMode.prototype.constructor = Compare3DSideBySideMode;

/**
 * Start/stop show compare mode
 * @param {Boolean} toggle
 * @override
 */
Compare3DSideBySideMode.prototype.toggle = function(toggle, diffMode) {
	CompareMode.prototype.toggle.call(this, toggle, diffMode);
	this._compareModel.setDiffMode(toggle ? CompareConst.diffMode.SHOW3DSIDEBYSIDE : CompareConst.diffMode.UNDEFINED);
	if (toggle) {
		this.f.whenModuleAvailable("view3D", function(view3D) {
			view3D.set3DDifferenceEnabled(toggle);
		});
	}
};

Compare3DSideBySideMode.prototype.getLayoutMode = function() {
	return LayoutConstants.LayoutMode.COMPARE_3D;
};

export default Compare3DSideBySideMode;
