import _ from "underscore";
import crosshairImage from "@esko/web-viewer/layout/img/crosshair.png";
import crosshairActiveImage from "@esko/web-viewer/layout/img/crosshair_active.png";
/**
 * @memberof CompareModule
 * @exports CompareConstants
 */

var modes = [
	{
		SHOW_CURRENT: "showCurrent",
		CURRENT3D: "current3D",
		twoD: "SHOW_CURRENT",
		threeD: "CURRENT3D"
	},
	{
		SHOW_DIFFERENCE: "showDifference",
		REFERENCE3D: "reference3D",
		twoD: "SHOW_DIFFERENCE",
		threeD: "REFERENCE3D"
	},
	{
		BLINKING: "blinking",
		BLINKING3D: "blinking3D",
		twoD: "BLINKING",
		threeD: "BLINKING3D"
	},
	{
		SIDEBYSIDE: "sidebyside",
		SIDEBYSIDE3D: "sidebyside3D",
		twoD: "SIDEBYSIDE",
		threeD: "SIDEBYSIDE3D"
	},
	{
		DIFFERENCE: "difference",
		twoD: "DIFFERENCE"
	},
	{
		READERSPREAD: "readerspread",
		twoD: "READERSPREAD"
	},
	{
		ALIGNMENT: "alignment",
		twoD: "ALIGNMENT"
	},
	{
		SHOWBOTHONTOP: "showBothOnTop",
		twoD: "SHOWBOTHONTOP"
	}
];

var modes2D = _.chain(modes)
	.filter(function(mode) {
		return mode.twoD;
	})
	.map(function(mode) {
		return [mode.twoD, mode[mode.twoD]];
	})
	.object()
	.value();
var modes3D = _.chain(modes)
	.filter(function(mode) {
		return mode.threeD;
	})
	.map(function(mode) {
		return [mode.threeD, mode[mode.threeD]];
	})
	.object()
	.value();

var map2Dto3D = _.chain(modes)
	.filter(function(mode) {
		return mode.twoD && mode.threeD;
	})
	.map(function(mode) {
		return [mode[mode.twoD], mode[mode.threeD]];
	})
	.object()
	.value();
var map3Dto2D = _.chain(modes)
	.filter(function(mode) {
		return mode.twoD && mode.threeD;
	})
	.map(function(mode) {
		return [mode[mode.threeD], mode[mode.twoD]];
	})
	.object()
	.value();

export default {
	diffMode: {
		// undefined diff display mode (-1)
		UNDEFINED: -1,
		// show current version only (0)
		CURRENTVERSION: 0,
		// show previous version only (1)
		DIFFVERSION: 1,
		// show both with changes (2)
		SHOWBOTHCHANGES: 2,
		// show both with changes - dim common parts (3)
		SHOWBOTHCHANGESHIGHLIGHT: 3,
		// show both with changes - hide common parts (4)
		SHOWBOTHCHANGESONLY: 4,
		// show both - side by side(5)
		SHOWBOTHSIDEBYSIDE: 5,
		// show recto-verso - flip horizontally (6)
		RECTOVERSOATSIDE: 6, // not used currently in HTML5 Viewer
		// show both - one on top of the other (7)
		SHOWBOTHONTOP: 7,
		// show recto-verso - flip vertically (8)
		RECTOVERSOATTOP: 8, // not used currently in HTML5 Viewer
		// show in reader-spread (9)
		READERSPREAD: 9,
		// show in blinking mode - current (10)
		BLINKING_CURRENT: 10,
		// show side by side with highlight, not in java viewer
		SHOWBOTHSIDEBYSIDEHIGHLIGHT: 11,
		// show side by side with changes only, not in java viewer
		SHOWBOTHSIDEBYSIDECHANGESONLY: 12,

		SHOW3DSIDEBYSIDE: 13,
		SHOW3DBLINKING: 14,
		SHOWCURRENT3D: 15,
		SHOWDIFFERENCE3D: 16
	},
	blinkingSpeed: 1000,
	modes2D: _.invert(modes2D),
	modes3D: _.invert(modes3D),
	map2Dto3D: map2Dto3D,
	map3Dto2D: map3Dto2D,
	mode: _.extend({}, modes2D, modes3D),
	modeNameToLanguageKey: {
		showCurrent: "DiffCurrentTT",
		showDifference: "DiffPrevTT",
		blinking: "DiffBothBlinkingTT",
		difference: "compareDifferenceMode",
		sidebyside: "DiffBothSplitTT",
		showBothOnTop: "DiffShowBothOnTopTT",
		alignment: "AnchorAlignWizardTitle",
		readerspread: "ReaderSpreadModeTitle"
	},
	sideBySideToDiffMode: {
		//map side by side difference modes to the correct difference compare mode
		5: 2,
		11: 3,
		12: 4
	},
	colorSpace: {
		DEFAULT: 0,
		CHANNELS: 1,
		HSV: 2,
		AUTOMATIC: 3
	},
	channelsMode: {
		AUTO: 0
	},
	showDifferenceMode: {
		SHOW: 2,
		HIGHLIGHT: 3,
		ONLY: 4
	},
	diffModeToMode: {
		UNDEFINED: "SHOW_CURRENT",
		CURRENTVERSION: "SHOW_CURRENT",
		DIFFVERSION: "SHOW_DIFFERENCE",
		SHOWBOTHCHANGES: "DIFFERENCE",
		SHOWBOTHCHANGESHIGHLIGHT: "DIFFERENCE",
		SHOWBOTHCHANGESONLY: "DIFFERENCE",
		SHOWBOTHSIDEBYSIDE: "SIDEBYSIDE",
		RECTOVERSOATSIDE: null,
		SHOWBOTHONTOP: "SHOWBOTHONTOP",
		RECTOVERSOATTOP: null,
		READERSPREAD: "READERSPREAD",
		BLINKING_CURRENT: "BLINKING",
		SHOWBOTHSIDEBYSIDEHIGHLIGHT: "SIDEBYSIDE",
		SHOWBOTHSIDEBYSIDECHANGESONLY: "SIDEBYSIDE",
		SHOW3DSIDEBYSIDE: "SIDEBYSIDE3D",
		SHOWCURRENT3D: "CURRENT3D",
		SHOWDIFFERENCE3D: "DIFFERENCE3D"
	},
	cornerAutoAlign: {
		TOPLEFT: 0,
		TOPCENTER: 1,
		TOPRIGHT: 2,
		CENTERLEFT: 3,
		CENTERED: 4,
		CENTERRIGHT: 5,
		BOTTOMLEFT: 6,
		BOTTOMCENTER: 7,
		BOTTOMRIGHT: 8
	},
	cornerAlignIcons: {
		0: "icon-WCR_Align-TopLeft",
		1: "icon-WCR_Align-TopCenter",
		2: "icon-WCR_Align-TopRight",
		3: "icon-WCR_Align-MiddleLeft",
		4: "icon-WCR_Align-MiddleCenter",
		5: "icon-WCR_Align-MiddleRight",
		6: "icon-WCR_Align-BottomLeft",
		7: "icon-WCR_Align-BottomCenter",
		8: "icon-WCR_Align-BottomRight"
	},
	referenceRotation: {
		NOTROTATED: 0,
		ROTATED90: 90,
		ROTATED180: 180,
		ROTATED270: 270
	},
	pagelistCompareRange: {
		CURRENT: 0,
		CURRENTANDFOLLOWING: 1,
		ALL: 2
	},
	pagelistSide: {
		LEFTPAGE: 1,
		RIGHTPAGE: 2
	},
	anchorAlignment: {
		DEFAULT: crosshairImage,
		ACTIVE: crosshairActiveImage,
		SIZE: {
			width: 14,
			height: 14
		},
		OFFSET: {
			width: 7,
			height: 7
		}
	}
};
