import CompareDifferenceSubToolbarComponent from "@esko/web-viewer/compare/CompareDifferenceSubToolbarComponent";
import ButtonGroup from "@esko/toolbar/ButtonGroup";
import SubtoolbarButton from "@esko/web-viewer/layout/component/SubtoolbarButton";
import DropdownSubtoolbarButton from "@esko/web-viewer/layout/component/DropdownSubtoolbarButton";
import ViewportConstants from "@esko/web-viewer/viewport/ViewportConstants";
import CompareConstants from "@esko/web-viewer/compare/CompareConstants";
import $ from "jquery";
import _ from "underscore";
/**
 * @memberof CompareModule
 * @exports CompareSideBySideSubToolbarComponent
 * @class A subtoolbare component for the side by side compare
 * @augments CompareModule.CompareDifferenceSubToolbarComponent
 * @constructor
 * @param {Core.ViewerFacade}
 * @param {CompareModule.CompareDifferenceMode} compareDiffMode - compare difference mode
 * @param {CompareModule.CompareSideBySideMode} compareSideBySideMode - compare side by side mode
 * @param {Layout.ToolbarComponent} parent - parent toolbar component
 *
 */
var CompareSideBySideSubToolbarComponent = function(f, compareDiffMode, compareSideBySideMode, parent) {
	this._sideBySideMode = compareSideBySideMode;
	CompareDifferenceSubToolbarComponent.call(this, f, compareDiffMode, parent);

	// panel tiling options
	this._tileIcons = ["icon-WCR_Tiling-Auto", "icon-WCR_Tiling-Vertical", "icon-WCR_Tiling-Horizontal"];
	this._tileButton = new DropdownSubtoolbarButton(this.f, "sideBySideMode", this.getTileIcon(), true);
	this._tileButton.setTooltip("viewer", "diffChangeSideBySideTilingMode");

	// options
	this.f.i18n.loadBundle(
		"viewer",
		function() {
			this._tileButton.addAction({
				name: "automaticTiling",
				icon: "icon-WCR_Tiling-Auto",
				content: this.f.i18n.t("DiffSplitTileAuto"),
				enabled: true,
				action: _.bind(function() {
					this._sideBySideMode.setPanelsLayoutMode(ViewportConstants.PanelsLayoutMode.AUTOMATIC);
				}, this)
			});

			this._tileButton.addAction({
				name: "verticalTiling",
				icon: "icon-WCR_Tiling-Vertical",
				content: this.f.i18n.t("DiffSplitTileVer"),
				enabled: true,
				action: _.bind(function() {
					this._sideBySideMode.setPanelsLayoutMode(ViewportConstants.PanelsLayoutMode.VERTICAL);
				}, this)
			});

			this._tileButton.addAction({
				name: "horizontalTiling",
				icon: "icon-WCR_Tiling-Horizontal",
				content: this.f.i18n.t("DiffSplitTileHor"),
				enabled: true,
				action: _.bind(function() {
					this._sideBySideMode.setPanelsLayoutMode(ViewportConstants.PanelsLayoutMode.HORIZONTAL);
				}, this)
			});
		},
		this
	);

	if (!this.f.isMobile()) {
		this._tilingModeButtonGroup = new ButtonGroup("tilingmode", [this._tileButton]);
		this.prependButtonGroup(this._tilingModeButtonGroup);
	}

	// add hide difference panel button
	this.toggleDifferenceSidePanelButton = new SubtoolbarButton(
		this.f,
		"toggleDifferencePanel",
		"icon-WCR_Compare-HideDiff",
		false,
		_.bind(this.toggleDifferencePanel, this)
	);

	this.toggleDifferenceSidePanelButton.setTooltip("viewer", "compareDisableDifferenceView");
	// tool tips
	this.f.i18n.loadBundle(
		"viewer",
		function() {
			var showDiff = this.f.i18n.t("DiffBothSplitShowDiff") + ": <br />\r\n";
			this.showModeButtons[0].setTooltip(showDiff + this.f.i18n.t("DiffBothTT"));
			this.showModeButtons[1].setTooltip(showDiff + this.f.i18n.t("DiffBothHighlightTT"));
			this.showModeButtons[2].setTooltip(showDiff + this.f.i18n.t("DiffBothShowTT"));
		},
		this
	);

	this.differenceShowModeGroup.prependButton(this.toggleDifferenceSidePanelButton);

	// when side by side mode has changed, update the controls
	this._sideBySideMode.on(
		"changed.*",
		_.bind(function() {
			this.updateControls();
		}, this)
	);

	this.updateControls();
};

CompareSideBySideSubToolbarComponent.prototype = Object.create(CompareDifferenceSubToolbarComponent.prototype);
CompareSideBySideSubToolbarComponent.prototype.constructor = CompareSideBySideSubToolbarComponent;

/**
 * @override
 */
CompareSideBySideSubToolbarComponent.prototype.updateParentIcon = function() {
	// do not update the parent icon for this mode...
};

/**
 * Update the controls for the toolbar component
 *
 * If difference compare mode is not shown, hide the controls for this mode
 */
CompareSideBySideSubToolbarComponent.prototype.updateControls = function() {
	this.differenceShowModeGroup.show();

	if (!this._sideBySideMode.isShowingDifference()) {
		// disabled difference controls
		this.colorspaceGroup.hide();
		this.slider.element.addClass("displayNone");
		if (this.diffColorChangeGroup) {
			this.diffColorChangeGroup.hide();
		}
	} else {
		//diff panel is visible
		if (this.diffColorChangeGroup) {
			this.diffColorChangeGroup.show();
		}
		var page = this.f.getDocumentController().getActivePage();
		if (page && !page.hasCad()) {
			this.colorspaceGroup.show();
			this.slider.element.removeClass("displayNone");
		}
	}

	if (this._tileButton) {
		this._tileButton.setIcon(this.getTileIcon());
	}

	this.updateDifferenceModeButtons();
	this.element.trigger("contentResized");
};

/**
 * When the difference mode is changed, interfere and disable show difference compare mode if the mode being set is the same as the current one
 * @override
 * @param {CompareConstants.showDifferenceMode} mode
 */
CompareSideBySideSubToolbarComponent.prototype.setDifferenceMode = function(mode) {
	this._sideBySideMode.setShowingDifference(true);

	// old behavior of setDifferenceMode
	CompareDifferenceSubToolbarComponent.prototype.setDifferenceMode.call(this, mode);
};

/**
 * When the acitve page changes, we also want to update the controls...
 * @override
 * @param oldPage
 * @param newPage
 */
CompareSideBySideSubToolbarComponent.prototype._whenActivePageChanged = function(oldPage, newPage) {
	CompareDifferenceSubToolbarComponent.prototype._whenActivePageChanged.call(this, oldPage, newPage);
	this.updateControls();
};

/**
 * Update the difference compare buttons
 * (set all buttons unactive if there is no compare difference shown)
 * @override
 */
CompareSideBySideSubToolbarComponent.prototype.updateDifferenceModeButtons = function() {
	var canUseDifferenceMode = this.compareDiffMode.isAvailable();

	if (!canUseDifferenceMode) {
		if (this.differenceShowModeGroup) {
			this.differenceShowModeGroup.hide();
		}
		// Difference mode not supported.
		_.each(this.showModeButtons, function(button, index) {
			button.element.addClass("displayNone");
		});
	} else {
		if (this._sideBySideMode.isShowingDifference()) {
			CompareDifferenceSubToolbarComponent.prototype.updateDifferenceModeButtons.call(
				this,
				undefined,
				this.compareDiffMode.getDifferenceMode()
			);
		} else {
			_.each(this.showModeButtons, function(button, index) {
				button.setActive(false);
			});
		}

		if (this.differenceShowModeGroup) {
			this.differenceShowModeGroup.show();
		}
		if (this.toggleDifferenceSidePanelButton) {
			this.toggleDifferenceSidePanelButton.setActive(!this._sideBySideMode.isShowingDifference());
		}

		// hide the difference mode buttons for non cad files
		var page = this.f.getDocumentController().getActivePage();
		if (page && page.hasCad()) {
			// CAD
			_.each(this.showModeButtons, function(el, index) {
				if (index > 0) {
					el.element.addClass("displayNone");
				} else {
					el.element.addClass("endRoundedCorner");
				}
			});
		} else if (page) {
			// graphics
			_.each(this.showModeButtons, function(el) {
				el.element.removeClass("displayNone");
				el.element.removeClass("endRoundedCorner");
			});
		}
	}
};

/**
 * Get the icon name for the currently active layout mode
 * @returns {String}
 */
CompareSideBySideSubToolbarComponent.prototype.getTileIcon = function() {
	return this._tileIcons[this._sideBySideMode.getPanelsLayoutMode()];
};

/**
 * The toggle button for the difference side by side panel is clicked
 */
CompareSideBySideSubToolbarComponent.prototype.toggleDifferencePanel = function() {
	if (this._sideBySideMode.isShowingDifference()) {
		this._sideBySideMode.setShowingDifference(false);
	}
};

export default CompareSideBySideSubToolbarComponent;
