import _ from "underscore";
import $ from "jquery";

/**
 * This strategy has a default jQuery ajax configuration and
 * sends out events before/after requests.
 *
 * @param {any} f
 */
var HttpConnectionStrategy = function(f) {
	this.f = f;

	this._defaultOptions = {
		dataType: "xml",
		success: function() {},
		error: function() {},
		cache: false,
		processData: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		type: "GET",
		data: "",
		noAjaxParam: false
	};

	// configure Ajax so it has a timeout, and emits loading events
	$.ajaxSetup({
		beforeSend: function(jqXHR, settings) {
			jqXHR["_viewerLoadKey"] = settings.url;
			this.f.emit("loading.start", settings.url);
		}.bind(this),
		complete: function(jqXHR) {
			var url = jqXHR["_viewerLoadKey"];
			this.f.emit("loading.stop", url);
		}.bind(this),
		timeout: 60000 // 1 min
	});
};

/**
 * Sends ajax call to the requested url with the given ajax options
 *
 * @param {String} url
 * @param {Object} options
 * @returns
 */
HttpConnectionStrategy.prototype.fetch = function(url, options) {
	// merge the options & execute ajax call
	return $.ajax(url, _.extend(_.clone(this._defaultOptions), options));
};

export default HttpConnectionStrategy;
