/**
 * Create a new debugger
 *
 * @exports AbstractDebug
 * @memberof Core
 * @class AbstractDebug Debug utility used for logging inside the viewer
 * @param {EventEmitter2} eventBus - the event bus
 */
var AbstractDebug = function(eventBus) {
	// Basic debug log information in production
	eventBus.on("error.SEVERE", function() {
		if (typeof console != "undefined") {
			if (!console.error) {
				if (console.log && console.log.apply) {
					console.log.apply(console, arguments);
				} else if (console.log) {
					console.log("ERROR", arguments);
				}
			} else if (console.error.apply) {
				console.error.apply(console, arguments);
			} else {
				console.error("ERROR", arguments);
			}
		}
	});
};

/**
 * Same behavior as console.log
 */
AbstractDebug.prototype.log = function() {};

/**
 * Same behavior as console.warn
 */
AbstractDebug.prototype.warn = function() {};

/**
 * Same behavior as console.error
 */
AbstractDebug.prototype.error = function() {};

/**
 * Same behavior as console.debug
 */
AbstractDebug.prototype.debug = function() {};

export default AbstractDebug;
