var Extendable = {
	/**
	 * Install the Extendable mixin to obj
	 * @static
	 * @param {Object} obj - The object that should become extendable
	 */
	installTo: function(obj) {
		/**
		 * Override an existing method
		 *
		 * @alias Extendable~_override
		 * @param {String} method - name of the method to override
		 * @param {Function} override - the new implementation for method. Previous implementation is still available through this._super
		 */
		obj._override = function(method, override) {
			var superMethod = this[method];
			if (superMethod === undefined) {
				superMethod = function() {};
			}
			this[method] = function() {
				var old_super = this._super;
				this._super = superMethod;
				var result = override.apply(this, arguments);
				this._super = old_super;
				return result;
			};
		};
	}
};

export default Extendable;
