var ImportLoadingStrategy = function(f, ebus, path) {
	this.f = f;
	this.ebus = ebus;
};

/**
 * Load a source in to memory and instantiate it
 *
 * @param {String} path - Full path to the source file (e.g. menus/SimpleControl)
 * @param {Function} [callback] - This callback is called when the source is loaded. The loaded object is given as first argument, or null if failed
 */
ImportLoadingStrategy.prototype.loadSourceFile = function(path, callback) {
	//load the widget with require
	var loadingID = "loadSourceFile_" + path;
	this.ebus.emit("loading.start", loadingID);

	path()
		.then(
			function(Class) {
				//call callback function if available
				callback(Class.__esModule ? Class.default : Class);
				this.ebus.emit("loading.stop", loadingID);
			}.bind(this)
		)
		.catch(
			function(err) {
				//loading of source file failed...
				if (callback) {
					callback(null, err);
				}
				this.ebus.emit("loading.stop", loadingID);
			}.bind(this)
		);
};

/**
 * load the module based on the file structre
 */
ImportLoadingStrategy.prototype.load = function(module, callback) {
	this.loadSourceFile(module.path, callback);
};

export default ImportLoadingStrategy;
