import PrivateChannel from "@esko/web-viewer/core/PrivateChannel";
import _ from "underscore";

/**
 * @class ViewerModeManager - The ViewerModeManager is responsible for which ViewerMode is active. it enforces that only 1 ViewerMode can be active at a certain point in time
 * @exports ViewerModeManager
 * @memberof {Core}
 * @params {Core.ViewerFacade} f
 */
var ViewerModeManager = function(f) {
	this.f = f;

	PrivateChannel.installTo(this, f, "viewerModeManager");

	this._activeMode = null;
};

/**
 * Start a ViewerMode, if another mode is active, it will be stopped
 *
 * @param {Core.ViewerMode} viewerMode - the mode to start
 */
ViewerModeManager.prototype.startMode = function(viewerMode) {
	if (viewerMode != this._activeMode) {
		this.stopActiveMode();

		this._activeMode = viewerMode;
		this._activeMode.toggle(true);

		this._emit("start", viewerMode);
	}
};

/**
 * Stop a mode, if it is the active mode
 *
 * @param {Core.ViewerMode} viewerMode - the mode which should be stoped
 */
ViewerModeManager.prototype.stopMode = function(viewerMode) {
	if (this._activeMode === viewerMode) {
		this.stopActiveMode();
	} else {
		this.f.debug.warn("Stopping a mode which isn't the active mode");
	}
};

/**
 * Stop the acitve mode
 */
ViewerModeManager.prototype.stopActiveMode = function() {
	if (this._activeMode) {
		var oldActiveMode = this._activeMode;
		this._activeMode.toggle(false);
		this._activeMode = null;

		this._emit("stop", oldActiveMode);
	}
};

/**
 * Get a reference to the currently active mode
 * @returns {Core.ViewerMode}
 */
ViewerModeManager.prototype.getActiveMode = function() {
	return this._activeMode;
};

export default ViewerModeManager;
