import AbstractWidget from "@esko/web-viewer/layout/AbstractWidget";
import Template from "@esko/template";
import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import tpl from "@esko/web-viewer/documentInfo/DebugWidget.tpl.html";
import ListenerUtil from "@esko/web-viewer/utils/ListenerUtil";
import $ from "jquery";
import _ from "underscore";

/**
 * @exports DebugWidget
 * @augments Layout.AbstractWidget
 * @class The DebugWidget shows some debug information on the viewport
 * @constructor
 * @mixes {Utils.ListenerUtilMixin}
 * @param {Core.ViewerFacade} f
 */
var DebugWidget = function DebugWidget(f) {
	AbstractWidget.call(this, f, LayoutConstants.Widget.DEBUG);
	ListenerUtil.mixin(this, f);

	this.setTitle("Debug Info");

	// initialize template
	this.t = new Template(f.i18n, tpl);

	var viewportModule = this.f.getModule("viewport");
	this.t.d.world = viewportModule.world;
	this.t.d.getZoom = _.bind(function() {
		var activePage = this.f.getActivePage();
		var docRes = activePage.getParam("resolutionx");
		var sceneRes = viewportModule.world.getZoom();

		if (docRes > sceneRes) {
			// zoomed out
			return (docRes / sceneRes).toFixed(3) + " : 1";
		} else {
			// zoomed in
			return "1 : " + (sceneRes / docRes).toFixed(3);
		}
	}, this);
	this._registerListener("transform.**", this.render, this);
	this.f.getDocumentController().whenActiveOrDifferencePageChangedAndParametersAvailable(this.render, this);
};

DebugWidget.prototype = Object.create(AbstractWidget.prototype);
DebugWidget.prototype.constructor = DebugWidget;
DebugWidget.widgetName = LayoutConstants.Widget.DEBUG;

/**
 * @override
 */
DebugWidget.prototype.setContext = function(context) {
	AbstractWidget.prototype.setContext.call(this, context);

	this.context.addClass("enableTextSelection");
	this.t.setContext(this.context);
	this.render();
};

/**
 * Render the widget
 */
DebugWidget.prototype.render = function() {
	var activePage = this.f.getActivePage();
	this.t.d.documentSize = activePage.getPageSize();
	this.t.d.resolution = activePage.getParam("resolutionx");
	this.t.d.targetViewport = this.t.d.world.getTargetViewPort();
	this.t.render();
};
export default DebugWidget;
