import _ from "underscore";
import AbstractModel from "@esko/web-viewer/core/AbstractModel";
/**
 * @exports DocumentInfoModel
 * @memberof DocumentInfoModule
 * @augments AbstractModel
 * @class This class gives the needed info for the info widget
 * @constructor
 *
 * @param {Core.ViewerFacade} f - Viewer facade
 * @param {String} ID - the ID of the model
 */
var DocumentInfoModel = function(f, ID) {
	AbstractModel.call(this, f, ID);

	/**
	 * {ShapeUtils.Point}
	 * previous position of the mouse
	 */
	this._previousMousePosition = null;

	/**
	 * {ShapeUtils.Point}
	 * current position of the mouse
	 */
	this._mousePosition = null;

	/**
	 * {ShapeUtils.Point}
	 * current selection
	 */
	this._selection = null;

	/**
	 * {ShapeUtils.Point}
	 * previous selection
	 */
	this._previousSelection = null;
};
// inherit
DocumentInfoModel.prototype = Object.create(AbstractModel.prototype);
DocumentInfoModel.prototype.constructor = DocumentInfoModel;

/**
 * Set the position of the mouse in the model
 * @param {ShapeUtils.Point} mousePoint - mouse position
 */
DocumentInfoModel.prototype.setMousePosition = function(mousePoint) {
	this._mousePosition = mousePoint;
	this._throttledFireChangeForPosition();
};

/**
 * Sends out an event that mouse position has changed. This is based on the state, so it can be throttled.
 */
DocumentInfoModel.prototype._throttledFireChangeForPosition = _.throttle(function() {
	this._fireChange(false, ["mouselocation"], this._previousMousePosition, this._mousePosition);
	this._previousMousePosition = this._mousePosition;
}, 50);

/**
 * Get mouse position.
 * @returns {ShapeUtils.Point} - position of the mouse
 */
DocumentInfoModel.prototype.getMousePosition = function() {
	return this._mousePosition;
};

/**
 * Sends out an event that selection has changed. This is based on the state, so it can be throttled.
 */
DocumentInfoModel.prototype._throttledFireChangeForSelection = _.throttle(function() {
	this._fireChange(false, ["selection"], this._previousSelection, this._selection);
	this._previousSelection = this._selection;
}, 50);

/**
 * Set the selection in the model
 * @param {Object} selection - new selection
 * Selection Object can contain following information
 * 		{
 * 			a: angle in degrees
 * 			d: distance in mm
 * 			x: x coordinate in mm
 * 			y: y coordinate in mm
 * 			w: width in mm
 * 			h: height in mm
 * 		}
 */
DocumentInfoModel.prototype.setSelection = function(selection) {
	this._selection = selection;
	this._throttledFireChangeForSelection();
};

/**
 * Get mouse position.
 * @returns {ShapeUtils.Point} - position of the mouse.
 */
DocumentInfoModel.prototype.getSelection = function() {
	return this._selection;
};

export default DocumentInfoModel;
