import _ from "underscore";
import AbstractTool from "@esko/web-viewer/viewport/tools/AbstractTool";
import CoreConstants from "@esko/web-viewer/core/CoreConstants";
/**
 * @exports MouseLocatorTool
 * @memberof DocumentInfoModule
 * @augments Viewport.AbstractTool
 *
 * @class
 * The MouseLocatorTool will send out events for the mouse position within the viewport
 *
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {DocumentInfo.DocumentInfoModel} documentInfoModel
 */
var MouseLocatorTool = function MouseLocator(f, documentInfoModel) {
	AbstractTool.call(this, f, CoreConstants.TOOLS.MOUSE_LOCATOR);

	/**
	 * {DocumentInfo.DocumentInfoModel}
	 */
	this._model = documentInfoModel;

	/**
	 * The default state will update the mouse position in the model. When leaving the viewport, reset position.
	 */
	this.registerState("default", {
		mousemove: _.bind(function(e) {
			this._model.setMousePosition(this.getWorldPoint(e));
		}, this),
		mouseleave: _.bind(function(e) {
			this._model.setMousePosition(null);
		}, this)
	});

	this._override("initialize", function(widget, toolManager) {
		this._super(widget, toolManager);
		this.registerPassiveEvents(["mousemove", "mouseleave"]);
		this.changeState("default");
	});
};

// extend from the AbstractTool
MouseLocatorTool.prototype = Object.create(AbstractTool.prototype);
MouseLocatorTool.prototype.constructor = MouseLocatorTool;

/**
 * @override
 */
MouseLocatorTool.prototype.getIconOffset = function() {
	var offset = null;
	var activeTool = this._toolManager.getActiveTool();
	if (activeTool) {
		offset = activeTool.getIconOffset();
	}
	return offset;
};

export default MouseLocatorTool;
