import AbstractModule from "@esko/web-viewer/core/AbstractModule";
import Modernizr from "./modernizr";

/**
 * The FeatureDetector module detects which features are available on a device
 * @exports FeatureDetectorModule
 * @memberof FeatureDetectorModule
 * @class FeatureDetectorModule A Module to detect features of the browser
 * @augments Core.AbstractModule
 * @param {Core.ViewerFacade} f
 * @param {Boolean} silenced
 */
var FeatureDetectorModule = function(f, silenced) {
	AbstractModule.call(this, f, silenced, "featureDetector");
};

FeatureDetectorModule.prototype = Object.create(AbstractModule.prototype);
FeatureDetectorModule.prototype.constructor = FeatureDetectorModule;

/**
 * Check if the device is a mobile device
 * @returns {Boolean}
 */
FeatureDetectorModule.prototype.isMobile = function() {
	return this.f.getProperty("isMobile") === true;
};

/**
 * Check if the currently used device is an iOS device
 * @returns
 */
FeatureDetectorModule.prototype.isIOS = function() {
	return /(iPad|iPhone|iPod)/i.test(navigator.userAgent);
};

/**
 * Check if device has touch
 * @returns {Boolean}
 */
FeatureDetectorModule.prototype.hasTouch = function() {
	// the last check is to detect Metro IE (IE on touch devices)... The surface2 isn't detected as "Modernizr.touch"
	return Modernizr.touchevents || (navigator.userAgent.indexOf("Trident") >= 0 && navigator.userAgent.indexOf("Touch") >= 0);
};

/**
 * Check if the device supports canvas
 * @returns {Boolean}
 */
FeatureDetectorModule.prototype.hasCanvas = function() {
	return Modernizr.canvas;
};

export default FeatureDetectorModule;
