import AbstractDocumentPage from "@esko/web-viewer/data/AbstractDocumentPage";
import Channel from "@esko/web-viewer/graphics/Channel";
import _ from "underscore";
/**
 * @exports GraphicsDataExtensions
 * @memberof Graphics
 * @class Inject graphics functionality in the data model
 * The AbstractDocumentPage prototype gets extended with methods for fetching graphics
 * @constructor
 *
 * @param {Core.ViewerFacade} f - Viewer facade
 */
var GraphicsDataExtensions = _.once(function(f) {
	/**
	 * Initialize the page with needed data object, so the graphics module can work correctly
	 * @private
	 */
	AbstractDocumentPage.prototype._initGraphicsModule = function() {
		if (this.hasGraphics() && this.isParametersAvailable()) {
			/**
			 * Channels
			 * @private
			 */
			this._channels = [];

			if (!_.isArray(this._parameters.channel)) {
				this._parseChannelData(this._parameters.channel);
			} else {
				for (var i = 0; i < this._parameters.channel.length; i++) {
					this._parseChannelData(this._parameters.channel[i]);
				}
			}
		}
	};

	/**
	 * Get channels
	 * @param {Boolean} forceUpdate - if true channel data is parsed
	 * @returns {Array.<Channel>} Array of all the channels.
	 */
	AbstractDocumentPage.prototype.getChannels = function(forceUpdate) {
		if (!this._channels || forceUpdate) {
			this._initGraphicsModule();
		}
		return _.clone(this._channels);
	};

	/**
	 * Get the Channel which has a certain file defined. (used for finding matched channels
	 * @param {String} file - the file the channel should have
	 * @returns {Graphics.Channel} the matched channel or null
	 */
	AbstractDocumentPage.prototype.getChannelForFile = function(file) {
		if (this._channels) {
			for (var i = 0; i < this._channels.length; i++) {
				if (this._channels[i].getFile() == file) {
					return this._channels[i];
				}
			}
		}

		return null;
	};

	/**
	 * Get the image url for the view server
	 * @param {Object} params - Key,Value pairs as parameters
	 * @returns {String} URL for image data for the given parameters
	 */
	AbstractDocumentPage.prototype.getImageURL = function(params) {
		throw "Not implemented: AbstractDocumentPage.getImageURL (GraphicsDataExtensions)";
	};

	/**
	 * Intercep fragment url generation and add the correct url parameters
	 * @returns {Object} c - context
	 */
	AbstractDocumentPage.prototype.interceptFragmentURL = function(c) {
		throw "Not implemented: AbstractDocumentPage.interceptFragmentURL (GraphicsDataExtensions)";
	};

	/**
	 * Parse to a channel from raw channel data and add it to the channels array.
	 * @param {Object} channelData - Raw channel data of one channel
	 */
	AbstractDocumentPage.prototype._parseChannelData = function(channelData) {
		throw "Not implemented: AbstractDocumentPage._parseChannelData (GraphicsDataExtensions)";
	};

	/**
	 * Does the page have deep zoom?
	 * @returns {Boolean}
	 */
	AbstractDocumentPage.prototype.hasDeepZoom = function() {
		return false;
	};
});

export default GraphicsDataExtensions;
