/**
 * @namespace HelpModule
 */
/**
 * @namespace HelpModule
 */
import AbstractModule from "@esko/web-viewer/core/AbstractModule";

import HelpWidget from "@esko/web-viewer/help/HelpWidget";
import ShortcutsPopup from "@esko/web-viewer/help/ShortcutsPopup";
import Mousetrap from "@esko/mousetrap";
import _ from "underscore";
/**
 * This module is responsible for displaying a help widget
 *
 * @exports HelpModule
 * @constructor
 * @augments Core.AbstractModule
 * @param {Core.ViewerFacade} f
 * @param {Boolean} silenced
 */
var HelpModule = function(f, silenced) {
	AbstractModule.call(this, f, silenced, "help");

	// publish the help widget
	this._publishWidget(HelpWidget.widgetName, this.createHelpWidget.bind(this));

	if ("onhelp" in window) {
		// IE doesn't allow to block f1 (opens windows help)
		window.onhelp = _.bind(function(e) {
			this.openHelpPages();

			e.preventDefault();
			e.stopPropagation();

			return false;
		}, this);
	} else {
		Mousetrap.bind(
			"f1",
			_.bind(function(e) {
				this.openHelpPages();

				e.preventDefault();
				e.stopPropagation();
			}, this),
			"keydown"
		);
	}

	Mousetrap.bind(
		"?",
		_.bind(function(e) {
			this.openShortcutsPopup();

			e.preventDefault();
			e.stopPropagation();
		}, this)
	);
};

// inherit
HelpModule.prototype = Object.create(AbstractModule.prototype);
// correct the constructor pointer
HelpModule.prototype.constructor = HelpModule;

HelpModule.prototype.openHelpPages = function() {
	throw "Not implemented: openHelpPages";
};

/**
 * Open the popup that shows all the shortcuts
 */
HelpModule.prototype.openShortcutsPopup = function() {
	if (!this._shortcutsPopup) {
		this._shortcutsPopup = new ShortcutsPopup(this.f);
	}

	this._shortcutsPopup.show();
};

/**
 * Creates a new HelpWidget. Can be overridden by child classes that want to inject their own HelpWidget.
 *
 * @returns
 */
HelpModule.prototype.createHelpWidget = function() {
	return new HelpWidget(this.f);
};

export default HelpModule;
