import AbstractWidget from "@esko/web-viewer/layout/AbstractWidget";
import Template from "@esko/template";
import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import tpl from "@esko/web-viewer/help/HelpWidget.tpl.html";
import ListenerUtil from "@esko/web-viewer/utils/ListenerUtil";
import $ from "jquery";
import _ from "underscore";

/**
 * @constant {Number} the speed to render the widget
 */
var RENDER_SPEED = 1000;

/**
 * @exports HelpWidget
 * @memberof HelpModule
 * @augments Layout.AbstractWidget
 * @class The HelpWidget shows some first aid to the user
 * @constructor
 * @mixes {Utils.ListenerUtilMixin}
 * @param {Core.ViewerFacade} f
 */
var HelpWidget = function HelpWidget(f) {
	AbstractWidget.call(this, f, LayoutConstants.Widget.HELP);

	this.t = new Template(f.i18n, tpl);
	this.render = _.throttle(_.bind(this._render, this), RENDER_SPEED);

	// need more help? link to KB89438893
	this.t.d.iHaveAProblemLink = "https://wiki.esko.com/pages/viewpage.action?pageId=90505429";

	this.setIcon("icon icon-WCR_Menu-Help");

	// bind some events
	this.t.bind("keydown", ".searchBox", this._searchEnter, this);
	this.t.bind("click", ".searchWrapper", this._searchClick, this);

	this.f.loadBundle(
		"viewer",
		function() {
			this.setTitle(this.f.t("helpWidgetTitle"));
			this._render();
		},
		this
	);
};

//inherit
HelpWidget.prototype = Object.create(AbstractWidget.prototype);
HelpWidget.prototype.constructor = HelpWidget;
HelpWidget.widgetName = LayoutConstants.Widget.HELP;

/**
 * @override
 */
HelpWidget.prototype.setContext = function(context) {
	AbstractWidget.prototype.setContext.call(this, context);

	this.context.addClass("enableTextSelection helpWidget");

	this.t.setContext(this.context);
	this.render();
};

/**
 * Render the widget
 */
HelpWidget.prototype._render = function() {
	this.t.render();
	this._fireResized();
};

/**
 * Execute the search on the KB
 * @param text
 */
HelpWidget.prototype._executeSearch = function(text) {
	throw "Not implemented: _executeSearch";
};

/**
 * Keydown event on the searchbox, detect enter and execute search
 * @param {JQueryObj} el - the jquery element on which the event occurred
 * @param {EventObject} event - the keydown event
 */
HelpWidget.prototype._searchEnter = function(el, event) {
	var keycode = event.keyCode ? event.keyCode : event.which;
	if (keycode == "13") {
		this._executeSearch($(el).val());
	}
};

/**
 * Click on the searchwrapper
 * @param {JQueryObj} el - the jquery object on which the click occured
 * @param {EventObject} event - the click event
 */
HelpWidget.prototype._searchClick = function(el, event) {
	var searchBox = $(el).find(".searchBox");

	if (event.pageX > $(el).offset().left + ($(el).width() || null) + 3 && searchBox.val().length > 0) {
		// the user clicked on the icon and there is a search keyword entered, execute a search
		this._executeSearch(searchBox.val());
	} else if (event.target != searchBox) {
		// the user clicked somewhere on the wrapper, (but not on the icon, or there was no search keyword)
		// focus the input field
		searchBox.trigger("focus");
	}
};

export default HelpWidget;
