import PrivateChannel from "@esko/web-viewer/core/PrivateChannel";
import ModalPopup from "@esko/web-viewer/layout/component/ModalPopup";
import Template from "@esko/template";
import tpl from "@esko/web-viewer/help/ShortcutsPopup.tpl.html";
import $ from "jquery";
import _ from "underscore";
/**
 * @exports ShortcutsPopup
 * @memberof HelpModule
 * @augments layout.component.ModelPopup
 * @class Popup which shows an overview of all the keyboard shortcuts available in the Viewer.
 *
 * @param {Core.ViewerFacade} f - Viewer facade
 */
var ShortcutsPopup = function(f) {
	ModalPopup.call(this, f, "shortcuts", f.getContext(), true, 750);

	f.i18n.loadBundle(
		"viewer",
		_.bind(function() {
			this.setHeader(
				$("<span/>")
					.addClass("popupTitle")
					.html(f.i18n.t("ShortCutsPopupTitle"))
			);
		}, this)
	);

	//Don't show any buttons in the popup
	this.toggleButtons(false);

	this.element.addClass("shortcutsPopup");

	/**
	 * @member {Template} template for the popup
	 */
	this.t = new Template(this.f.i18n, tpl);
	this.t.setContext(this._popupContent);
	this._popupContent.addClass("shortcuts-popup-content");

	/**
	 * @private
	 * @member {Object} All the shortcuts as they will be rendered by the template
	 */
	this._shortcuts = {
		navigationShortcuts: {
			zoomToolShortcut: "z",
			panToolShortcut: "h",
			panSingleActionShortcut: "F7",
			zoomSingleActionShortcut: "F8",
			cancelZoomActionShortcut: "Esc",
			panWithSpaceShortcut: "Space",
			zoomInActionShortcut: {
				keyword: "orKeyword",
				shortcuts: [["Ctrl", "+"], ["Ctrl", "="], ["F5"]]
			},
			zoomOutActionShortcut: {
				keyword: "orKeyword",
				shortcuts: [["Ctrl", "-"], ["F6"]]
			},
			panQuarterUpShortcut: {
				keyword: "orKeyword",
				shortcuts: [["Ctrl", "&uarr;"], ["&#8984;", "&uarr;"]]
			},
			panQuarterRightShortcut: {
				keyword: "orKeyword",
				shortcuts: [["Ctrl", "&rarr;"], ["&#8984;", "&rarr;"]]
			},
			panQuarterDownShortcut: {
				keyword: "orKeyword",
				shortcuts: [["Ctrl", "&darr;"], ["&#8984;", "&darr;"]]
			},
			panQuarterLeftShortcut: {
				keyword: "orKeyword",
				shortcuts: [["Ctrl", "&larr;"], ["&#8984;", "&larr;"]]
			}
		},
		compareShortcuts: {
			selectLastDocumentShortcut: "End",
			selectFirstDocumentShortcut: "Home",
			selectNextDocumentShortcut: "Page Down",
			selectPreviousDocumentShortcut: "Page Up",
			autoAlignShortcut: ["Ctrl", "l"],
			toggleCurrentPreviousViewShortcut: ["Ctrl", "s"],
			activateAnchorToolShortcut: "a",
			moveAnchorShortcuts: {
				keyword: ", ",
				shortcuts: [["&uarr;"], ["&rarr;"], ["&darr;"], ["&larr;"]]
			}
		},
		channelShortcuts: {
			showAllChannelsShortcut: ["Alt", "a"],
			ShowFirstTenChannels: {
				keyword: "toKeyword",
				shortcuts: [["Alt", "1"], ["Alt", "9"]]
			},
			showSecondTenChannels: {
				keyword: "toKeyword",
				shortcuts: [["Ctrl", "Alt", "1"], ["Ctrl", "Alt", "9"]]
			},
			enableNextChannel: ["Alt", "n"]
		},
		orientationShortcuts: {
			rotateCWShortcut: ["Ctrl", "Alt", "+"],
			rotateCCWShortcut: ["Ctrl", "Alt", "-"],
			mirrorViewShortcut: ["Ctrl", "m"]
		},
		otherShortcuts: {
			deleteSelectedAnnotShortcut: "Delete",
			createLinkedAnnotShortcut: ["Shift", "Left Mouse"],
			toggleSizeUnitsShortcut: ["Ctrl", "u"],
			toggleResolutionShortcut: ["Ctrl", "Shift", "u"],
			showHelpPopupShortcut: ["?"]
		}
	};
};

ShortcutsPopup.prototype = Object.create(ModalPopup.prototype);
ShortcutsPopup.prototype.constructor = ShortcutsPopup;

/**
 * Renders the popup
 */
ShortcutsPopup.prototype.render = function() {
	this.f.emit(
		"toolManager.shortcuts",
		function(shortcuts) {
			this.t.d.shortcuts = _.defaults(_.clone(this._shortcuts), shortcuts);
			this.t.render();
		}.bind(this)
	);
};

/**
 * Shows the popup.
 */
ShortcutsPopup.prototype.show = function() {
	this.render();

	ModalPopup.prototype.show.call(this);
};

export default ShortcutsPopup;
