import Tooltip from "@esko/tooltip/Tooltip";
import format from "date-fns/format";
import $ from "jquery";

var AutoTimeLabel = function(f, date) {
	this.f = f;
	this.editOnTop = true;
	this.element = $("<span>");
	this.date = date;
	this.tooltip = new Tooltip(f.i18n, this.element, f.getContext(), f.getContext(), f.isMobile(), "");

	this.updateText();
};

AutoTimeLabel.prototype.updateText = function(isCreationDate) {
	this.f.i18n.loadBundle(
		"viewer",
		function() {
			this.element.text(this._userFriendlyDate(this.date));
			var dateString = "";
			if (isCreationDate) {
				dateString = this.f.i18n.t("createdOn");
			} else {
				dateString = this.f.i18n.t("modifiedOn");
			}

			this.tooltip.setTooltipContent(dateString + format(this.date, "MMMM	D, YYYY h:mm A"));
		}.bind(this)
	);
};

AutoTimeLabel.prototype._userFriendlyDate = function(date) {
	var seconds = Math.floor((new Date().getTime() - date.getTime()) / 1000);

	var days = Math.floor(seconds / (3600 * 24));
	seconds -= days * 3600 * 24;

	var hours = Math.floor(seconds / 3600);
	seconds -= hours * 3600;

	var minutes = Math.floor(seconds / 60);
	seconds -= minutes * 60;

	var ago;
	var text = null;
	if (days > 0) {
		if (days == 1) {
			text = this.f.i18n.t("dateYesterday");
		} else if (days < 5) {
			ago = days + this.f.i18n.t("daysAbbreviation");
		} else {
			text = format(this.date, "MMMM	D, YYYY");
		}
	} else if (hours > 0) {
		ago = hours + this.f.i18n.t("hoursAbbreviation");
	} else if (minutes > 0) {
		ago = minutes + this.f.i18n.t("minutesAbbreviation");
	} else {
		ago = seconds + this.f.i18n.t("secondsAbbreviation");
		ago = "< 1" + this.f.i18n.t("minutesAbbreviation");
	}

	return text ? text : this.f.i18n.t("timeAgo", ago);
};

export default AutoTimeLabel;
