import _ from "underscore";
import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";

var alwaysAvailableWidgets = [{
	name: LayoutConstants.Widget.VIEWPORT,
	position: "west"
}];

// this fallback implementation is the default CustomFormExtension.js implementation
var defaultConfiguration = {
	layout: {
		north: [
			LayoutConstants.ToolbarComponent.PAGELIST,
			LayoutConstants.ToolbarComponent.NAVIGATE,
			LayoutConstants.ToolbarComponent.MEASURE,
			LayoutConstants.ToolbarComponent.TEXTSELECTION,
			LayoutConstants.ToolbarComponent.COMPARE,
			LayoutConstants.ToolbarComponent.ANNOTATION,
			LayoutConstants.ToolbarComponent.VIEW3D,
			LayoutConstants.ToolbarComponent.APPROVAL,
			LayoutConstants.ToolbarComponent.DYNCONTENT
		],
		east: [
			LayoutConstants.Widget.NAVIGATOR,
			LayoutConstants.Widget.VIEW3D,
			LayoutConstants.Widget.VIEWCONTROLS,
			LayoutConstants.Widget.CHANNELS,
			LayoutConstants.Widget.CAD,
			LayoutConstants.Widget.DEBUG,
			LayoutConstants.Widget.APPROVAL,
			LayoutConstants.Widget.INFO,
			LayoutConstants.Widget.HELP,
			LayoutConstants.Widget.VIDEO_KEYFRAME
		],
		west: [
			LayoutConstants.Widget.COMPARE,
			LayoutConstants.Widget.ATTRIBUTE_CATEGORY,
			LayoutConstants.Widget.ANNOTATION,
			LayoutConstants.Widget.DISCUSSION,
			LayoutConstants.Widget.PAGELIST,
			LayoutConstants.Widget.TEXTCONTENT,
			LayoutConstants.Widget.VIEWPORT
		],
		below: [LayoutConstants.ToolbarComponent.VIDEO]
	},
	west: {
		iconified: true
	},
	east: {
		iconified: true
	},
	disabledItems: []
};

export default new Promise(resolve => {
	fetch("custom/viewer/restricted.json", {
			credentials: "same-origin"
		})
		.then(function (response) {
			if(response.status >= 400) {
				throw "No Custom Configuration";
			}
			return response.json();

		})
		.then(function (layoutConfiguration) {
			_.each(alwaysAvailableWidgets, function (widget) {
				// Check if the custom layout defines the always available widget. If not, add it to its position
				if (
					!_.chain(layoutConfiguration.layout)
					.values()
					.flatten()
					.find(function (name) {
						return name === widget.name;
					})
					.value()
				) {
					layoutConfiguration.layout[widget.position].push(widget.name);
				}
			});
			resolve(layoutConfiguration);
		})
		.catch(function () {
			resolve(defaultConfiguration);
		});
});
