import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";

/**
 * @class LayoutItem A Layout item is a representation of a layout item
 * @memberof Layout
 *
 * @constructor
 * @param {String} name - the name of the layout item
 * @param {LayoutConstants.LayoutItemType} type - type of the layout item
 * @param {Function} factory - factory function which instantiates the layout item (this function gets a parameter: LayoutType)
 */
var LayoutItem = function(name, type, factory) {
	this.name = name;
	this.type = type;

	this._factory = factory;
	this._item = null;
	this._itemLayoutType = null;
};

/**
 * Get the item
 * @param layoutType
 * @returns {AbstractWidget|AbstractToolbarComponent} initialized item
 */
LayoutItem.prototype.getItem = function(layoutType) {
	if (this._item === null || this._itemLayoutType != layoutType) {
		// we might to some try catching in the future here? :)
		this._item = this._factory(layoutType);
		this._itemLayoutType = layoutType;
	}

	return this._item;
};

/**
 * Is the layout item a widget
 * @returns {Boolean}
 */
LayoutItem.prototype.isWidget = function() {
	return this.type === LayoutConstants.LayoutItemType.WIDGET;
};

/**
 * Is the layout item a toolbar component
 * @returns {Boolean}
 */
LayoutItem.prototype.isToolbarComponent = function() {
	return this.type === LayoutConstants.LayoutItemType.TOOLBARCOMPONENT;
};

export default LayoutItem;
