import $ from "jquery";

/**
 * @class This component is an element that consists of two color blocks that are glued together.
 * @exports DoubleColorBlock
 * @constructor
 * @param {String} [initialLeftColor] - Initial color of the left block (in hex with # format)
 * @param {String} [initialRightColor] - Initial color of the right block (in hex with # format)
 */
var DoubleColorBlock = function(initialLeftColor, initialRightColor) {
	this.element = $("<div />").addClass("doubleColorBlock");

	this._leftBlock = $("<div />").addClass("part");
	this._rightBlock = $("<div />").addClass("part");

	if (initialLeftColor !== undefined) {
		this.setLeftColor(initialLeftColor);
	}

	if (initialRightColor !== undefined) {
		this.setRightColor(initialRightColor);
	}

	this.element.append(this._leftBlock);
	this.element.append(this._rightBlock);
};

/**
 * Set the color of the left color block.
 * @param {String} leftColor - Color for the left block (in hex with # format)
 */
DoubleColorBlock.prototype.setLeftColor = function(leftColor) {
	this._leftBlock.css("background-color", leftColor);
};

/**
 * Set the color of the right color block.
 * @param {String} rightColor - Color for the right block (in hex with # format)
 */
DoubleColorBlock.prototype.setRightColor = function(rightColor) {
	this._rightBlock.css("background-color", rightColor);
};

export default DoubleColorBlock;
