import SubtoolbarButton from "@esko/web-viewer/layout/component/SubtoolbarButton";
import DropdownMenu from "@esko/dropdownmenu/DropdownMenu";
import $ from "jquery";
import _ from "underscore";
/**
 *
 * @class A DropdownSubtoolbarButton is a subtoolbar button that when left clicked shows a dropdownmenu (toggled).
 *
 * @exports Layout.Component.DropdownSubtoolbarButton
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {String} name - the name of the button
 * @param {String | JQueryObj } icon - The class which is used for displaying the icon, or your own jQuery element
 * @param {Boolean} forMobile - is the button needed for mobile usage?
 */
var DropdownSubtoolbarButton = function(f, name, icon, forMobile) {
	SubtoolbarButton.call(this, f, name, icon, forMobile, this.toggle);
	this.dropdown = new DropdownMenu(this.f.i18n, this.f.getContext(), this.f.isMobile(), "bottom", "wcr-dropdown");
};

DropdownSubtoolbarButton.prototype = Object.create(SubtoolbarButton.prototype);
DropdownSubtoolbarButton.prototype.constructor = DropdownSubtoolbarButton;

/**
 * Toggle the button
 */
DropdownSubtoolbarButton.prototype.toggle = function() {
	if (!this.isOpen()) {
		this.show();
	} else {
		this.hide();
	}
};

/**
 * Check whether the dropdown is open
 * @returns {Boolean} True if it is open, false otherwise
 */
DropdownSubtoolbarButton.prototype.isOpen = function() {
	return this.dropdown.isActive();
};

/**
 * Show the dropdownmenu
 */
DropdownSubtoolbarButton.prototype.show = function() {
	this.dropdown.show(this.element);
};

/**
 * Hide the dropdownmenu
 */
DropdownSubtoolbarButton.prototype.hide = function() {
	this.dropdown.hide();
};

/**
 * Set the text of a specific button by name
 * @param {String} name - Name of the button
 * @param {String} text - Text of the button
 */
DropdownSubtoolbarButton.prototype.setActionText = function(name, text) {
	this.dropdown.setActionText(name, text);
};

/**
 * Toggle an option
 * @param {String} name - Name of the option
 * @param {Boolean} toggle - True if should be 'checked', false otherwise
 */
DropdownSubtoolbarButton.prototype.toggleOption = function(name, toggle) {
	this.dropdown.toggleOption(name, toggle);
};

/**
 * Get the value of an option
 * @param {String} name - Name of the option
 * @returns {Boolean} Value of the option
 */
DropdownSubtoolbarButton.prototype.getOptionValue = function(name) {
	return this.dropdown.getOptionValue(name);
};

/**
 * Set whether the action is enabled or not
 * @param {String} name - Name of the action
 * @param {Boolean} enabled - True if it should be enabled, false otherwise
 */
DropdownSubtoolbarButton.prototype.setActionEnabled = function(name, enabled) {
	this.dropdown.setActionEnabled(name, enabled);
};

/**
 * Check whether the action is enabled or not
 * @param {String} name - Name of hte action
 * @returns {Boolean} True if it is enabled, false otherwise
 */
DropdownSubtoolbarButton.prototype.isActionEnabled = function(name) {
	return this.dropdown.isActionEnabled(name);
};

/**
 * Add an action
 * @param {Object} action - Description of the action
 * @example
 * {
 * 	name: 'nameOfButton',
 * 	content: Text|JQueryObj,
 * 	icon: undefined|''|'nameOfIcon',
 * 	action: function{},
 *  enabled: Boolean,
 * 	[optional: doNotHideOnClick]
 * }
 */
DropdownSubtoolbarButton.prototype.addAction = function(action) {
	this.dropdown.addAction(action);
};

/**
 * Add an option
 * @param {Object} option - Description of the option
 * @example
 * {
 * 	name,
 * 	content,
 *  enabled,
 * 	selected,
 * 	onchange,
 * 	[doNotHideOnClick]
 *}
 */
DropdownSubtoolbarButton.prototype.addOption = function(option) {
	this.dropdown.addOption(option);
};

/**
 * Add a divider line
 */
DropdownSubtoolbarButton.prototype.addDivider = function() {
	this.dropdown.addDivider();
};

export default DropdownSubtoolbarButton;
