import ModalPopup from "@esko/web-viewer/layout/component/ModalPopup";
import ShapeUtils from "@esko/shapeutils";
import _ from "underscore";
import $ from "jquery";
/**
 * A FullScreen modal popup is covering the complete viewer, its size depends on the screen size of the user
 * @exports FullscreenModalPopup
 * @class A FullScreen modal popup is covering the complete viewer, its size depends on the screen size of the user
 * @constructor
 * @param {Core.ViewerFacade} f - Viewer facade
 * @param {String} id - Id of the popup. It is used in its private channel.
 * @param {Boolean} [noCancelButton=false] - do no show a cancel button
 * @param {Number} [size=.95] - percentage of the screen the popup should cover
 */
var FullscreenModalPopup = function(f, id, noCancelButton, size, options) {
	ModalPopup.call(this, f, id, f.getContext(), noCancelButton, undefined, options);

	this.element.addClass("fullscreenModalPopup");

	if (!size) {
		size = 0.95;
	}

	this._size = size;

	this._debouncedRecalculateSize = _.debounce(
		_.bind(function(e) {
			// http://bugs.jqueryui.com/ticket/7514: resize of popups bubbles to window
			if (e.target === window) {
				this.recalculateSize();
			}
		}, this),
		300
	);

	this.content.append(this._actionBtns);
};

FullscreenModalPopup.prototype = Object.create(ModalPopup.prototype);
FullscreenModalPopup.prototype.constructor = FullscreenModalPopup;

/**
 * Override default recalculate size behavior
 * @Override
 */
FullscreenModalPopup.prototype.recalculateSize = function() {
	var width = Math.ceil((this.containment.innerWidth() || null) * this._size);
	var height = Math.ceil((this.containment.innerHeight() || null) * this._size);

	var x = (this.containment.innerWidth() || null) / 2 - width / 2;
	var y = (this.containment.innerHeight() || null) / 2 - height / 2;

	this.content.css("overflow", "hidden"); //fix for Chrome: dont show unnecessary scrollbar
	this.setRect(new ShapeUtils.Rect(new ShapeUtils.Point(x, y), new ShapeUtils.Size(width, height)));
	this.content.css("overflow", "auto");
};

/**
 * make sure the height of the content and action buttons is correctly set
 * @override
 */
FullscreenModalPopup.prototype._onResized = function() {
	ModalPopup.prototype._onResized.call(this);

	this._popupContentContainer.css({
		height: (this.content.innerHeight() || null) - (this._actionBtns.outerHeight(true) || null)
	});
};

/**
 * Add window resized listener when popup is shown
 * @Override
 */
FullscreenModalPopup.prototype.show = function() {
	ModalPopup.prototype.show.apply(this, arguments);

	$(window).on("resize", this._debouncedRecalculateSize);
};

/**
 * Remove window resized listener when popup is hidden
 * @Override
 */
FullscreenModalPopup.prototype.hide = function() {
	ModalPopup.prototype.hide.apply(this, arguments);
	$(window).off("resize", this._debouncedRecalculateSize);
};

export default FullscreenModalPopup;
