import Button from "@esko/button/Button";
import $ from "jquery";
/**
 * Mini Button is used in widget headers.
 *
 * A mini button can have a badge which shows some extra information
 *
 * @exports Layout.Component.MiniButton
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {String} name - the name of the button
 * @param {String} icon - the icon of the button (css class for 16px * 16px icon)
 * @param {Boolean} forMobile - is the button neede for mobile usage?
 * @param {Function} [action] - action executed when clicking on the button
 * @param {String} [disabledIcon] - icon shown when disabled
 * @param {String} [badgeText] - text to be shown in badge
 */
var MiniButton = function(f, name, icon, forMobile, action, disabledIcon, badgeText) {
	this.f = f;
	Button.call(this, this.f.i18n, this.f.getContext(), this.f.isMobile(), name, "", forMobile, action);
	this.element.addClass("mini-btn");
	this.defaultIcon = icon;
	this.disabledIcon = disabledIcon || icon;
	this.icon = $("<i />").addClass(icon);
	this.badge = $("<span />")
		.addClass("badge")
		.hide();
	this.icon.append(this.badge);
	this.badgeText = badgeText || "";

	this.element.append(this.icon);
};

MiniButton.prototype = Object.create(Button.prototype);
MiniButton.prototype.constructor = MiniButton;

/**
 * Set the badge text of the button
 *
 * @param {String} text - if undefined no badge will be shown
 */
MiniButton.prototype.setBadge = function(text) {
	this.badgeText = text;

	this._updateIcon();
};

/**
 * Set the default icon of the button
 * @param {String} icon
 * @param newIcon
 */
MiniButton.prototype.setIcon = function(newIcon) {
	this.defaultIcon = newIcon;
	this._updateIcon();
};

/**
 * Set the disabled icon of the button
 * @param {String} disabledIcon
 */
MiniButton.prototype.setDisabledIcon = function(disabledIcon) {
	this.disabledIcon = disabledIcon;
	this._updateIcon();
};

/**
 * Update the representation of the button
 * @private
 */
MiniButton.prototype._updateIcon = function() {
	if (!this.isEnabled()) {
		this.badge.hide();
	} else {
		if (this.badgeText) {
			this.badge.text(this.badgeText);
			this.badge.show();
		} else {
			this.badge.hide();
		}
	}
	this.icon.removeClass();
	this.icon.addClass(this.isEnabled() ? this.defaultIcon : this.disabledIcon);
	this.element.toggleClass("disabled", !this.isEnabled());
};

/**
 * Add a class to the element of the button
 * @param {String} buttonClass
 */
MiniButton.prototype.addButtonClass = function(buttonClass) {
	this.element.addClass(buttonClass);
};

export default MiniButton;
