import RichTextEditor from "@esko/web-viewer/layout/component/RichTextEditor";
import ViewerUtils from "@esko/web-viewer/utils/ViewerUtils";
import ConvertUtils from "@esko/convertutils";
import $ from "jquery";
import _ from "underscore";
/**
 * Create a new rich text editor. The richtext editor is not shown by default, it will be initialized by calling .init()
 * @class
 * A rich text editor has a title, a rich text area and an action bar with some buttons.
 * This class hangs on the DOM element in the property "richTextObj"
 * @exports RichTextEditorTextarea
 */
var RichTextEditorTextarea = function(f) {
	RichTextEditor.call(this, f);
};

RichTextEditorTextarea.prototype = Object.create(RichTextEditor.prototype);
RichTextEditorTextarea.prototype.constructor = RichTextEditorTextarea;

/**
 * Set content
 * @param {String} content - Content to set in the text area
 * @override
 */
RichTextEditorTextarea.prototype.setContent = function(content) {
	this.textArea.val(ConvertUtils.convertHTMLStringToRaw(content));
};

/**
 * Get content as HTML
 * @returns {String} Content as HTML if the editor was initialized, otherwise ""
 * @override
 */
RichTextEditorTextarea.prototype.getContent = function() {
	if (this.isInitialized()) {
		return "<html><body>" + ConvertUtils.convertRawStringToHTML(this.textArea.val()) + "</body></html>";
	} else {
		return "";
	}
};

/**
 * Init the rich text editor
 * Should be called after the element is added to the DOM
 * @param {Function} [callback] - Callback when the editor is initialized (also fired when it was already initialized). From then on, you can safely use methods like getContent().
 * @override
 */
RichTextEditorTextarea.prototype.init = function(callback) {
	if (!this.initialized) {
		this.initialized = true;
		this.textArea.on("keyup change", _.bind(this._fireTextChanged, this));
		this.textArea.trigger("focus");
		if (callback) {
			callback();
		}
	} else {
		if (callback) {
			callback();
		}
		this.textArea.trigger("focus");
	}
};

/**
 * Destroy the rich text editor.
 * @override
 */
RichTextEditorTextarea.prototype.destroy = function() {
	this.textArea.off("keyup change");
	this.initialized = false;
};

export default RichTextEditorTextarea;
