import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import LayoutMode from "@esko/web-viewer/layout/LayoutMode";
/**
 * @exports BasicMode
 * @memberof Layout
 * @class
 * Basic mode of the desktoplayout. Will allow all the layout items to be added and the state is persisted.
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {Layout} layout
 */
var BasicMode = function(f, layout) {
	LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.VIEW2D);

	this._blockedLayoutItems = [
		LayoutConstants.ToolbarComponent.DOCUMENTSELECTOR,
		LayoutConstants.Widget.VIDEO_KEYFRAME,
		LayoutConstants.Widget.VIEW3D_COMPARE
	];
};

BasicMode.prototype = new LayoutMode();
BasicMode.prototype.constructor = BasicMode;

/**
 * Turns On/Off the layoutMode
 * @param {Boolean} toggle
 */
BasicMode.prototype.toggle = function(toggle) {
	if (toggle === undefined) {
		toggle = !this._isActive;
	}
	this._isActive = toggle;
	if (this._isActive) {
		this.f.emit("viewport.zoomToFit");
	}
};

/**
 * Checks if the item is allowed for this layout mode.
 *
 * @param {String} itemname
 * @returns {Boolean}
 */
BasicMode.prototype.isItemAllowed = function(itemname) {
	if (this._blockedLayoutItems.indexOf(itemname) !== -1) {
		return false;
	}
	return true;
};

/**
 * Checks if the state of the layout should be persisted.
 * @return {Boolean}
 */
BasicMode.prototype.isPersisted = function() {
	return true;
};

export default BasicMode;
