import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import LayoutMode from "@esko/web-viewer/layout/LayoutMode";
/**
 * @exports Desktop2D3DMode
 * @memberof Layout
 * @class
 * Basic mode of the desktoplayout. Will allow all the layout items to be added and the state is persisted.
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {Layout} layout
 */
var Desktop2D3DMode = function(f, layout) {
	LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.DESKTOP_2D3D);

	this._blockedLayoutItems = [
		LayoutConstants.ToolbarComponent.DOCUMENTSELECTOR,
		LayoutConstants.Widget.VIDEO_KEYFRAME,
		LayoutConstants.Widget.VIEW3D_COMPARE
	];
};

Desktop2D3DMode.prototype = new LayoutMode();
Desktop2D3DMode.prototype.constructor = Desktop2D3DMode;

/**
 * Turns On/Off the layoutMode
 * @param {Boolean} toggle
 */
Desktop2D3DMode.prototype.toggle = function(toggle) {
	if (toggle === undefined) {
		toggle = !this._isActive;
	}
	this._isActive = toggle;
};

/**
 * Checks if the item is allowed for this layout mode.
 *
 * @param {String} itemname
 * @returns {Boolean}
 */
Desktop2D3DMode.prototype.isItemAllowed = function(itemname) {
	if (this._blockedLayoutItems.indexOf(itemname) !== -1) {
		return false;
	}
	return true;
};

/**
 * Checks if the state of the layout should be persisted.
 * @return {Boolean}
 */
Desktop2D3DMode.prototype.isPersisted = function() {
	return true;
};

Desktop2D3DMode.prototype.getMainPanelContent = function() {
	return [LayoutConstants.Widget.VIEWPORT, LayoutConstants.Widget.VIEW3D];
};

export default Desktop2D3DMode;
