import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import LayoutMode from "@esko/web-viewer/layout/LayoutMode";
/**
 * @exports Desktop3DMode
 * @memberof Layout
 * @class
 * Mode for mobile layout, shows the annotation widget
 * @constructor
 * @augments LayoutMode
 * @param {Core.ViewerFacade} f
 * @param {Layout} layout
 */
var Desktop3DMode = function(f, layout) {
	LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.DESKTOP_3D);
};

Desktop3DMode.prototype = new LayoutMode();
Desktop3DMode.prototype.constructor = Desktop3DMode;

/**
 * Turns On/Off the layoutMode
 * @param {Boolean} toggle
 */
Desktop3DMode.prototype.toggle = function(toggle) {
	if (toggle === undefined) {
		toggle = !this._isActive;
	}
	this._isActive = toggle;
	this.f.emit("viewport.zoomToFit");
};

Desktop3DMode.prototype.isPersisted = function() {
	return true;
};

/**
 * Checks if the item is allowed for this layout mode. Prevents channels and CAD widget from loading.
 *
 * @param {String} itemname
 * @returns {Boolean}
 */
Desktop3DMode.prototype.isItemAllowed = function(itemname) {
	return (
		itemname === LayoutConstants.Widget.COMPARE ||
		itemname === LayoutConstants.ToolbarComponent.APPROVAL ||
		itemname === LayoutConstants.Widget.APPROVAL ||
		itemname === LayoutConstants.Widget.MESSAGE ||
		itemname === LayoutConstants.Widget.VIEW3D ||
		itemname === LayoutConstants.Widget.VIEWPORT ||
		itemname === LayoutConstants.ToolbarComponent.VIEW3D ||
		itemname === LayoutConstants.ToolbarComponent.COMPARE ||
		itemname === LayoutConstants.Widget.ATTRIBUTE_CATEGORY
	);
};

/**
 * We want the 3D widget as Main Content
 * @override
 */
Desktop3DMode.prototype.getMainPanelContent = function() {
	return [LayoutConstants.Widget.VIEW3D];
};

export default Desktop3DMode;
