import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import LayoutMode from "@esko/web-viewer/layout/LayoutMode";
import FullscreenUtil from "@esko/web-viewer/utils/FullscreenUtil";
import CoreConstants from "@esko/web-viewer/core/CoreConstants";
/**
 * @exports DesktopVideoMode
 * @memberof Layout
 * @class
 * Mode for mobile layout, shows the annotation widget
 * @constructor
 * @augments LayoutMode
 * @param {Core.ViewerFacade} f
 * @param {Layout} layout
 */
var DesktopVideoMode = function(f, layout) {
	LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.VIDEO);

	FullscreenUtil.addEventListener(
		"fullscreenchange",
		function() {
			if (this._isActive) {
				this.f.emit("zoomTool.zoomOnScroll", !FullscreenUtil.fullscreenElement);
				this.f.emit("viewport.zoomToFit");
			}
		}.bind(this)
	);
};

DesktopVideoMode.prototype = new LayoutMode();
DesktopVideoMode.prototype.constructor = DesktopVideoMode;

/**
 * Turns On/Off the layoutMode
 * @param {Boolean} toggle
 */
DesktopVideoMode.prototype.toggle = function(toggle) {
	if (toggle === undefined) {
		toggle = !this._isActive;
	}

	this._isActive = toggle;
};

DesktopVideoMode.prototype.isPersisted = function() {
	return true;
};

/**
 * Checks if the item is allowed for this layout mode. Prevents channels and CAD widget from loading.
 *
 * @param {String} itemname
 * @returns {Boolean}
 */
DesktopVideoMode.prototype.isItemAllowed = function(itemname) {
	return (
		itemname === LayoutConstants.ToolbarComponent.VIDEO ||
		itemname === LayoutConstants.Widget.VIEWPORT ||
		itemname === LayoutConstants.ToolbarComponent.APPROVAL ||
		itemname === LayoutConstants.Widget.APPROVAL ||
		itemname === LayoutConstants.Widget.MESSAGE ||
		itemname === LayoutConstants.Widget.VIDEO_VIEWPORT ||
		itemname === LayoutConstants.Widget.COMPARE ||
		itemname === LayoutConstants.Widget.INFO ||
		itemname === LayoutConstants.Widget.HELP ||
		itemname === LayoutConstants.ToolbarComponent.NAVIGATE ||
		itemname === LayoutConstants.ToolbarComponent.ANNOTATION ||
		itemname === LayoutConstants.Widget.ANNOTATION ||
		itemname === LayoutConstants.Widget.DISCUSSION ||
		itemname === LayoutConstants.ToolbarComponent.MEASURE ||
		itemname === LayoutConstants.Widget.VIDEO_KEYFRAME ||
		itemname === LayoutConstants.Widget.ATTRIBUTE_CATEGORY
	);
};

/**
 * We want the 3D widget as Main Content
 * @override
 */
DesktopVideoMode.prototype.getMainPanelContent = function() {
	return [LayoutConstants.Widget.VIEWPORT];
};

DesktopVideoMode.prototype.getDefaultTool = function() {
	return CoreConstants.TOOLS.VIDEOTOOL;
};

export default DesktopVideoMode;
