import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import LayoutMode from "@esko/web-viewer/layout/LayoutMode";
/**
 * @exports RestrictedMode
 * @memberof Layout
 * @class
 * Restricted mode of the desktoplayout. Will not allow Channels or CAD widgets to be added and the state is persisted.
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {Layout} layout
 */
var RestrictedMode = function(f, layout) {
	LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.RESTRICTED);
};

RestrictedMode.prototype = new LayoutMode();
RestrictedMode.prototype.constructor = RestrictedMode;

/**
 * Turns On/Off the layoutMode
 * @param {Boolean} toggle
 */
RestrictedMode.prototype.toggle = function(toggle) {
	if (toggle === undefined) {
		toggle = !this._isActive;
	}
	this._isActive = toggle;
};

/**
 * Checks if the item is allowed for this layout mode.
 *
 * @param {String} itemname
 * @returns {Boolean}
 */
RestrictedMode.prototype.isItemAllowed = function(itemname) {
	// prevents channels widget, cad widget, viewcontrols widget, documentselector toolbarcomponent
	if (
		itemname === LayoutConstants.Widget.CHANNELS ||
		itemname === LayoutConstants.Widget.CAD ||
		itemname === LayoutConstants.Widget.VIEWCONTROLS ||
		itemname === LayoutConstants.ToolbarComponent.DOCUMENTSELECTOR
	) {
		return false;
	} else {
		return true;
	}
};

/**
 * Checks if the state of the layout should be persisted.
 * @return {Boolean}
 */
RestrictedMode.prototype.isPersisted = function() {
	return true;
};

export default RestrictedMode;
