import DraggableWidgets from "@esko/web-viewer/layout/DraggableWidgets";
import _ from "underscore";
import $ from "jquery";
import "jquery-ui/ui/widgets/draggable";
/**
 * Dragging for FlexLayout
 * @constructor
 * @class
 * @augments DraggableWidgets
 * @param {JQueryObj} container - container for all dragging/dropping
 */
var FlexDrag = function(container) {
	DraggableWidgets.call(this, container);

	this._acceptSelector = ".widgetWrapper, .tile";
	this._siblingSelector = ".widgetWrapper, .tile:not(.tileGhost)";
};

FlexDrag.prototype = Object.create(DraggableWidgets.prototype);
FlexDrag.prototype.constructor = FlexDrag;

/**
 * This method is similar to DraggableWidgets.enableDragging, but uses a tile as a dragging ghost
 * instead of the widgetwrapper clone and doesn't need to to extra sizing "paperwork"
 * @Override
 */
FlexDrag.prototype.enableDragging = function(wrapper) {
	var flexGhost = null;
	var sideBar = null;
	wrapper.element.add(wrapper.getTileElement()).draggable({
		distance: 20,
		scroll: false,
		revert: "invalid",
		helper: function() {
			flexGhost = wrapper
				.getTileElement()
				.clone()
				.addClass("tileGhost active");
			return flexGhost.clone();
		},
		appendTo: this.container,
		containment: this.contaner,
		start: _.bind(function(e, ui) {
			$(e.target).addClass("hiddenWhileDragging");
			sideBar = wrapper.getSidebar();
			wrapper.setSidebar(null);
		}, this),
		drag: _.bind(function(e, ui) {
			if (this.hoveredSortableDropzone) {
				this.insertAt(this.hoveredSortableDropzone, flexGhost, ui.offset.top - this.hoveredSortableDropzone.offset().top);
			} else {
				flexGhost.detach();
			}
		}, this),
		cursorAt: { top: 15, left: 30 },
		stop: _.bind(function(e, ui) {
			flexGhost.remove();
			$(e.target).removeClass("hiddenWhileDragging");

			if (wrapper.widget) {
				wrapper.widget.dragged(ui.offset.top, ui.offset.left);
			}
			if (!wrapper.getSidebar()) {
				wrapper.setSidebar(sideBar);
			}
		}, this)
	});

	wrapper.element.draggable("option", "handle", ".header");
};

/**
 * Define a FlexSidebar dropzone
 * @param panel
 */
FlexDrag.prototype.addFlexSidebarDropzone = function(sidebar, section, workspace) {
	var onIconfiedChanged = _.bind(function(oldValue, isIconified) {
		if (isIconified) {
			this.addSortableWidgetDropzone(sidebar.getTilebarContext(), section, workspace);
			sidebar.getWidgetbarContainer().droppable("destroy");
		} else {
			this.addSortableWidgetDropzone(sidebar.getWidgetbarContainer(), section, workspace);
			sidebar.getTilebarContext().droppable("destroy");
		}
	}, this);

	if (sidebar.isIconified()) {
		this.addSortableWidgetDropzone(sidebar.getTilebarContext(), section, workspace);
	} else {
		this.addSortableWidgetDropzone(sidebar.getWidgetbarContainer(), section, workspace);
	}
	sidebar.on("changed.iconified", onIconfiedChanged);
};

export default FlexDrag;
