import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import LayoutMode from "@esko/web-viewer/layout/LayoutMode";
import _ from "underscore";
/**
 * @exports MobileReaderSpreadMode
 * @memberof Layout
 * @class
 * ReaderSpread mode of the mobile layout
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {Layout} layout
 */
var MobileReaderSpreadMode = function(f, layout) {
	LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.MOBILE_READERSPREAD);

	// show/hide based on whether or not active page is multipage
	this.f.getDocumentController().whenActivePageChanged(function(oldPage, page) {
		this.f.emit("layout.modeAvailabilityChanged", this, page.getDocumentVersion().isMultiPage(), {
			icon: "icon-WCR_ReaderSpread",
			title: "ReaderSpreadModeTitle"
		});
	}, this);
};

MobileReaderSpreadMode.prototype = new LayoutMode();
MobileReaderSpreadMode.prototype.constructor = MobileReaderSpreadMode;

/**
 * Turns On/Off the layoutMode
 * @param {Boolean} toggle
 */
MobileReaderSpreadMode.prototype.toggle = function(toggle) {
	if (toggle === undefined) {
		toggle = !this._isActive;
	}
	this._isActive = toggle;
	this.f.requestModule(
		"pagelist",
		_.bind(function(pageListModule) {
			pageListModule.toggleReaderspread(this._isActive);
		}, this)
	);
};

/**
 * Checks if the item is allowed for this layout mode. Prevents channels and CAD widget from loading.
 *
 * @param {String} itemname
 * @returns {Boolean}
 */
MobileReaderSpreadMode.prototype.isItemAllowed = function(itemname) {
	// only allow viewport widget and page selection toolbar
	return (
		itemname === LayoutConstants.Widget.VIEWPORT ||
		itemname === LayoutConstants.Widget.PAGELIST ||
		itemname === LayoutConstants.Widget.MESSAGE ||
		itemname === LayoutConstants.ToolbarComponent.PAGESELECTION ||
		itemname === LayoutConstants.ToolbarComponent.APPROVAL
	);
};

/**
 * Checks if the state of the layout should be persisted.
 * @return {Boolean}
 */
MobileReaderSpreadMode.prototype.isPersisted = function() {
	return true;
};

/**
 * Decide whether or not to show the mode panel
 */
MobileReaderSpreadMode.prototype.isModePanelEnabled = function() {
	return true;
};

/**
 * @override
 */
MobileReaderSpreadMode.prototype.getModePanelContent = function() {
	return [LayoutConstants.Widget.PAGELIST];
};

export default MobileReaderSpreadMode;
