import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import LayoutMode from "@esko/web-viewer/layout/LayoutMode";
import FullscreenUtil from "@esko/web-viewer/utils/FullscreenUtil";
import CoreConstants from "@esko/web-viewer/core/CoreConstants";
/**
 * @exports MobileVideoMode
 * @memberof Layout
 * @class
 * Mode for mobile layout, shows the annotation widget
 * @constructor
 * @augments LayoutMode
 * @param {Core.ViewerFacade} f
 * @param {Layout} layout
 */
var MobileVideoMode = function(f, layout) {
	LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.VIDEO);

	this.setIsmodePanelExpanded(false);

	this._updateModeAvailability();
	this.f.getDocumentController().whenActivePageChangedAndParametersAvailable(this._updateModeAvailability, this);
};

MobileVideoMode.prototype = new LayoutMode();
MobileVideoMode.prototype.constructor = MobileVideoMode;

MobileVideoMode.prototype._updateModeAvailability = function() {
	var page = this.f.getDocumentController().getActivePage();
	this.f.emit("layout.modeAvailabilityChanged", this, page && page.hasVideo(), {
		icon: "icon-WCR_View",
		title: "ViewControlsTitle"
	});
};

/**
 * Turns On/Off the layoutMode
 * @param {Boolean} toggle
 */
MobileVideoMode.prototype.toggle = function(toggle) {
	if (toggle === undefined) {
		toggle = !this._isActive;
	}

	this._isActive = toggle;
};

MobileVideoMode.prototype.isPersisted = function() {
	return true;
};

/**
 * Checks if the item is allowed for this layout mode. Prevents channels and CAD widget from loading.
 *
 * @param {String} itemname
 * @returns {Boolean}
 */
MobileVideoMode.prototype.isItemAllowed = function(itemname) {
	return (
		itemname === LayoutConstants.Widget.VIEWPORT ||
		itemname === LayoutConstants.ToolbarComponent.DOCUMENTSELECTOR ||
		itemname === LayoutConstants.ToolbarComponent.APPROVAL ||
		itemname === LayoutConstants.Widget.MESSAGE ||
		itemname === LayoutConstants.Widget.DISCUSSION ||
		itemname === LayoutConstants.Widget.VIDEO_KEYFRAME
	);
};

/**
 * We want the 3D widget as Main Content
 * @override
 */
MobileVideoMode.prototype.getMainPanelContent = function() {
	return [LayoutConstants.Widget.VIEWPORT];
};

MobileVideoMode.prototype.isModePanelEnabled = function() {
	return true;
};

MobileVideoMode.prototype.getModePanelContent = function() {
	return [LayoutConstants.Widget.VIDEO_KEYFRAME];
};

export default MobileVideoMode;
