import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import LayoutMode from "@esko/web-viewer/layout/LayoutMode";
/**
 * @exports MobileViewMode
 * @memberof Layout
 * @class
 * Default mode of the mobile layout
 * @constructor
 * @param {Core.ViewerFacade} f
 * @param {Layout} layout
 */
var MobileViewMode = function(f, layout) {
	LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.VIEW2D);

	// by default the modepanel is collapsed for the mobile view mode
	this.setIsmodePanelExpanded(false);

	this._updateModeAvailability();
	this.f.getDocumentController().whenActivePageChangedAndParametersAvailable(this._updateModeAvailability, this);
};

MobileViewMode.prototype = new LayoutMode();
MobileViewMode.prototype.constructor = MobileViewMode;

/**
 * Turns On/Off the layoutMode
 * @param {Boolean} toggle
 */
MobileViewMode.prototype.toggle = function(toggle) {
	if (toggle === undefined) {
		toggle = !this._isActive;
	}
	this._isActive = toggle;
};

MobileViewMode.prototype._updateModeAvailability = function() {
	var page = this.f.getDocumentController().getActivePage();
	this.f.emit("layout.modeAvailabilityChanged", this, page && !page.is3D() && !page.hasVideo(), {
		icon: "icon-WCR_View",
		title: "ViewControlsTitle"
	});
};

/**
 * Checks if the item is allowed for this layout mode.
 * Allow viewport, documentselector, approval toolbar and message widget
 * @param {String} itemname - the name of the item
 * @returns {Boolean}
 */
MobileViewMode.prototype.isItemAllowed = function(itemname) {
	return (
		itemname === LayoutConstants.Widget.VIEWPORT ||
		itemname === LayoutConstants.ToolbarComponent.DOCUMENTSELECTOR ||
		itemname === LayoutConstants.ToolbarComponent.APPROVAL ||
		itemname === LayoutConstants.Widget.MESSAGE ||
		/* Channels and CAD should not be shown restricted mode */
		((itemname === LayoutConstants.Widget.CHANNELS || itemname === LayoutConstants.Widget.CAD) &&
			this.f.getProperty("viewerStyle") != LayoutConstants.ViewerStyle.RESTRICTED)
	);
};

/**
 * Checks if the state of the layout should be persisted.
 * @return {Boolean}
 */
MobileViewMode.prototype.isPersisted = function() {
	return true;
};

/**
 * The modepanel is enabled in the view mode
 * @returns {Boolean}
 * @override
 */
MobileViewMode.prototype.isModePanelEnabled = function() {
	return this.f.getProperty("viewerStyle") != LayoutConstants.ViewerStyle.RESTRICTED;
};

/**
 * Display the cad and channels widget
 * @override
 */
MobileViewMode.prototype.getModePanelContent = function() {
	return [LayoutConstants.Widget.CAD, LayoutConstants.Widget.CHANNELS];
};

export default MobileViewMode;
