import _ from "underscore";
import $ from "jquery";
import AbstractMeasureTool from "@esko/web-viewer/measure/AbstractMeasureTool";
import MeasureConstants from "@esko/web-viewer/measure/MeasureConstants";
import MeasurePopoverModel from "@esko/web-viewer/measure/MeasurePopoverModel";
import ViewerUtils from "@esko/web-viewer/utils/ViewerUtils";
import CoreConstants from "@esko/web-viewer/core/CoreConstants";
/**
 * Barcode measure tool,  You can see the barcode readout of your selected area
 *
 * @exports BarcodeMeasureTool
 * @memberof MeasureModule
 * @class BarcodeMeasureTool
 * @augments Measure.AbstractMeasureTool
 *
 * @param {Core.ViewerFacade} f
 * @param {MeasureModule} measureModule
 */
var BarcodeMeasureTool = function(f, measureModule) {
	AbstractMeasureTool.call(this, f, CoreConstants.TOOLS.MEASURE_BARCODE);

	this.f = f;
	this.measureModule = measureModule;
	this.model.setRulerType(MeasureConstants.MeasureType.Barcode);
};

// extend from the AbstractTool
BarcodeMeasureTool.prototype = Object.create(AbstractMeasureTool.prototype);
BarcodeMeasureTool.prototype.constructor = BarcodeMeasureTool;

/**
 * @override
 *
 * Gets the information from the to object converted xml and creates a MeasurePopoverModel that shows the information and tells the AbstractModel to add the popover
 *
 * @param {Object} object
 */
BarcodeMeasureTool.prototype.showInfo = function(object) {
	var info = [];
	if (object) {
		if (object.status.info) {
			if (!_.isArray(object.status.info.barcodegv)) {
				object.status.info.barcodegv = [object.status.info.barcodegv];
			}
			this.f.i18n.loadBundle(
				"viewer",
				_.bind(function() {
					_.each(
						object.status.info.barcodegv,
						_.bind(function(barcodesWrapper) {
							var barcodes = barcodesWrapper.xml.Barcodes;
							var barcodesArray = barcodes.Barcode;
							if (!_.isArray(barcodesArray)) {
								barcodesArray = [barcodesArray];
							}
							info[barcodesWrapper.color] = "";
							_.each(
								barcodesArray,
								_.bind(function(barcode, i) {
									// multiple barcodes
									if (i > 0) {
										info[barcodesWrapper.color] += " | ";
									}
									info[barcodesWrapper.color] += barcode.attributes.Type + ": " + barcode.Decoded;
									if (barcode["Decoded_reverse_dir"]) {
										info[barcodesWrapper.color] += " (-->) " + barcode["Decoded_reverse_dir"] + " (<--)";
									}
									if (
										barcode.Magnification !== undefined &&
										parseInt(barcode.Magnification, 10) !== 100 &&
										parseInt(barcode.Magnification, 10) !== 999
									) {
										info[barcodesWrapper.color] += " " + barcode.Magnification + "%";
									}
									var BWR = ViewerUtils.parseFloat(barcode.BWR);
									if (BWR < 999 && BWR !== 0) {
										info[barcodesWrapper.color] += " [" + BWR + " " + this.f.i18n.t("Unitmm") + "] ";
									}
								}, this)
							);
						}, this)
					);
				}, this)
			);
		}
		this.f.emit("channels.informationAdded", info);
	}

	this.showPopover(info);
};

/**
 * @override
 *
 * Removes the popover from the AbstractModel
 */
BarcodeMeasureTool.prototype.removePopover = function() {
	if (this.popover) {
		this.model.removePopoverModel(this.popover.getID());
	}
};

/**
 * @override
 *
 * Sets the required options for the call to the viewserver
 */
BarcodeMeasureTool.prototype.calculate = function() {
	this.getInfo({});
};

/**
 * Can the tool be used on the currently active page
 * @Override
 * @returns {Boolean}
 */
BarcodeMeasureTool.prototype.canBeUsedOnActivePage = function() {
	var page = this.f.getActivePage();
	return page && page.hasGraphics();
};

BarcodeMeasureTool.prototype.createPopoverModel = function(channelInfo, area) {
	return new MeasurePopoverModel(
		this.f,
		area,
		"Channels",
		$("<i>").addClass("icon icon-normal icon-WCR_Measure-Barcode"),
		channelInfo,
		this._needsTotalCount()
	);
};

export default BarcodeMeasureTool;
