import ShapeUtils from "@esko/shapeutils";
import _ from "underscore";
/**
 * @exports CaliperGap
 * @memberof MeasureModule
 * @class A caliper gap is used to hold information about a gap of the caliper tool. e.g. the angle and gap size (represented by a vector)
 * @constructor
 * @param {String} id - Style
 * @param {MeasureConstants.CaliperStyle} style - Style of the gap (e.g. freeform)
 * @param {ShapeUtils.Vector} vector - The vector representing the gap (angle and gap size)
 */
var CaliperGap = function(id, style, vector) {
	/**
	 * {String} Id of the gap
	 */
	this._id = id;
	/**
	 * {MeasureConstants.CaliperStyle} Style of the gap
	 */
	this._style = style;

	/**
	 * {ShapeUtils.Vector} Vector representing the angle and size of the gap
	 */
	this._vector = vector;
};

/**
 * Get the id of the gap
 * @returns {String}
 */
CaliperGap.prototype.getId = function() {
	return this._id;
};

/**
 * Get the style of the gap
 * @returns {MeasureConstants.CaliperStyle}
 */
CaliperGap.prototype.getStyle = function() {
	return this._style;
};

/**
 * Get the vector of the gap
 * It always returns a copy!
 * @returns {ShapeUtils.Vector}
 */
CaliperGap.prototype.getVector = function() {
	return this._vector.copy();
};

/**
 * Set a new vector for the gap
 * @param {ShapeUtils.Vector} vector - The new vector for this gap
 */
CaliperGap.prototype.setVector = function(vector) {
	this._vector = vector;
};

/**
 * Check whether the given gap is similar to this gap.
 * Similar means the same gap and orientation, so the same vector.
 * @param {CaliperGap} similarGap - The gap to check with this gap
 * @returns {Boolean} Returns true if the given similarGap is similar to this gap, false otherwise
 */
CaliperGap.prototype.isSimilarTo = function(similarGap) {
	return this._vector.equals(similarGap.getVector());
};

export default CaliperGap;
