import MeasurePopoverModel from "@esko/web-viewer/measure/MeasurePopoverModel";
import EyeDropperUnitSelector from "@esko/web-viewer/measure/EyeDropperUnitSelector";
import _ from "underscore";
import $ from "jquery";
/**
 * MeasurePopoverModel specific for the eye dropper.
 *
 * @exports EyeDropperPopoverModel
 * @memberof MeasureModule
 * @class EyeDropperPopoverModel
 * @augments MeasurePopoverModel
 * @constructor
 *
 * @param {Core.ViewerFacade} f
 * @param {LineworkWrapper} area
 * @param {String} name
 * @param {String | JQuery.Element} title - Title to be shown in the header
 * @param {Array<Number> | Array<String>} channels
 * @param {Boolean} [makeTotalCount] Defines if a total of the different channel values needs to be calculated, only possible if the
 * 										values of the channels array are numbers
 * @param {String | JQuery.Element} headerExtra - A jQuery component or string that is displayed in upper-right corner of this popver
 */
var EyeDropperPopoverModel = function(f, area, name, title, channels, makeTotalCount, headerExtra) {
	MeasurePopoverModel.call(this, f, area, name, title, channels, makeTotalCount, headerExtra);

	this._eyeDropperUnitSelector = null;

	this.f.getDocumentController().whenActivePageChangedAndParametersAvailable(this._updateEyeDropperUnitSelectorButton, this);
};

// inherit
EyeDropperPopoverModel.prototype = Object.create(MeasurePopoverModel.prototype);
// correct the constructor pointer
EyeDropperPopoverModel.prototype.constructor = EyeDropperPopoverModel;

/**
 * Called when the active page is changed to either show it or not for digital film
 */
EyeDropperPopoverModel.prototype._updateEyeDropperUnitSelectorButton = function() {
	if (this.f.getActivePage().isDigitalFilmPage()) {
		if (this._eyeDropperUnitSelector === null) {
			this._eyeDropperUnitSelector = new EyeDropperUnitSelector(this.f);
			this._headerExtra.append(this._eyeDropperUnitSelector.getButtonElement());
		} else {
			this._eyeDropperUnitSelector.getButtonElement().show();
		}
	} else {
		if (this._eyeDropperUnitSelector !== null) {
			this._eyeDropperUnitSelector.getButtonElement().hide();
		}
	}
};

export default EyeDropperPopoverModel;
