import DropdownMiniButton from "@esko/web-viewer/layout/component/DropdownMiniButton";
import CoreConstants from "@esko/web-viewer/core/CoreConstants";
import _ from "underscore";
/**
 * @exports EyeDropperUnitSelector
 * @class The EyeDropperUnitSelector has a button that allows setting the unit of the eye dropper
 * @constructor
 * @param {Core.ViewerFacade} f
 */
var EyeDropperUnitSelector = function(f) {
	this.f = f;

	/**
	 * Make the options dropdown
	 */
	this._optionButton = new DropdownMiniButton(this.f, "eyeDropperUnitSettings", "icon-WCR_Settings-submenu");
	this._optionButton.setTooltip("viewer", "UnitSettings");

	this.f.i18n.loadBundle(
		"viewer",
		function() {
			this._optionButton.addOption({
				name: "eyeDropperUnitPixels",
				content: this.f.i18n.t(CoreConstants.EyeDropperUnitsLocNames[CoreConstants.EyeDropperUnits.PIXELS]),
				onchange: _.bind(this._toggleEyeDropperUnit, this, CoreConstants.EyeDropperUnits.PIXELS),
				userCannotUncheck: true
			});

			this._optionButton.addOption({
				name: "eyeDropperUnitSQMM",
				content: this.f.i18n.t(CoreConstants.EyeDropperUnitsLocNames[CoreConstants.EyeDropperUnits.SQMM]),
				onchange: _.bind(this._toggleEyeDropperUnit, this, CoreConstants.EyeDropperUnits.SQMM),
				userCannotUncheck: true
			});

			this._optionButton.addOption({
				name: "eyeDropperUnitSQCM",
				content: this.f.i18n.t(CoreConstants.EyeDropperUnitsLocNames[CoreConstants.EyeDropperUnits.SQCM]),
				onchange: _.bind(this._toggleEyeDropperUnit, this, CoreConstants.EyeDropperUnits.SQCM),
				userCannotUncheck: true
			});

			this._optionButton.addOption({
				name: "eyeDropperUnitSQINCH",
				content: this.f.i18n.t(CoreConstants.EyeDropperUnitsLocNames[CoreConstants.EyeDropperUnits.SQINCH]),
				onchange: _.bind(this._toggleEyeDropperUnit, this, CoreConstants.EyeDropperUnits.SQINCH),
				userCannotUncheck: true
			});

			this._optionButton.addOption({
				name: "eyeDropperUnitPercent",
				content: this.f.i18n.t(CoreConstants.EyeDropperUnitsLocNames[CoreConstants.EyeDropperUnits.PERCENT]),
				onchange: _.bind(this._toggleEyeDropperUnit, this, CoreConstants.EyeDropperUnits.PERCENT),
				userCannotUncheck: true
			});

			// intial rendering
			this._updateOptions();

			// listen to changes
			this.f.getCurrentUser().on("options.changed.PREFERENCES_UNIT_EYEDROPPER", _.bind(this._updateOptions, this));
		},
		this
	);
};

/**
 * Get the button element
 * @returns {JQueryObj} element of the button
 */
EyeDropperUnitSelector.prototype.getButtonElement = function() {
	return this._optionButton.element;
};

/**
 * Toggle the eye dropper unit
 * @param {CoreConstants.EyeDropperUnits} mode - the new mode
 * @param {Boolean} toggle - true or false
 */
EyeDropperUnitSelector.prototype._toggleEyeDropperUnit = function(mode, toggle) {
	if (toggle) {
		this.f.setOption("PREFERENCES_UNIT_EYEDROPPER", mode, true);

		// link with unit size
		if (mode !== CoreConstants.EyeDropperUnits.PERCENT) {
			this.f.setOption("PREFERENCES_UNIT_SIZE", mode, true);
		}
	}
};

/**
 * Update the options in the menu (re-render)
 */
EyeDropperUnitSelector.prototype._updateOptions = function() {
	var currentEyeDropperUnit = this.f.getOption("PREFERENCES_UNIT_EYEDROPPER");
	this._optionButton.toggleOption("eyeDropperUnitPixels", currentEyeDropperUnit === CoreConstants.EyeDropperUnits.PIXELS);
	this._optionButton.toggleOption("eyeDropperUnitSQMM", currentEyeDropperUnit === CoreConstants.EyeDropperUnits.SQMM);
	this._optionButton.toggleOption("eyeDropperUnitSQCM", currentEyeDropperUnit === CoreConstants.EyeDropperUnits.SQCM);
	this._optionButton.toggleOption("eyeDropperUnitSQINCH", currentEyeDropperUnit === CoreConstants.EyeDropperUnits.SQINCH);
	this._optionButton.toggleOption("eyeDropperUnitPercent", currentEyeDropperUnit === CoreConstants.EyeDropperUnits.PERCENT);
};

export default EyeDropperUnitSelector;
