/**
 * @namespace MeasureModule
 */
/**
 * @namespace MeasureModule
 */
import _ from "underscore";

import AbstractModule from "@esko/web-viewer/core/AbstractModule";
import CoreConstants from "@esko/web-viewer/core/CoreConstants";
import MeasureConstants from "@esko/web-viewer/measure/MeasureConstants";
import ListenerUtil from "@esko/web-viewer/utils/ListenerUtil";
import $ from "jquery";
/**
 * Create the MeasureModule
 *
 * @exports MeasureModule
 * @memberof MeasureModule
 * @class
 * Responsible for publishing the correct tools and toolbarcomponents enabling navigation
 * @augments Core.AbstractModule
 * @mixes Utils.ListenerUtilMixin
 * @param {Core.ViewerFacade} f
 * @param {Boolean} silenced
 */
var MeasureModule = function(f, silenced) {
	AbstractModule.call(this, f, silenced, "measure");
	ListenerUtil.mixin(this, f);

	this._registerListener("module.graphics.model.changed.**", _.debounce(_.partial(this.updateMeasureTools, false), 10), this);
	this._registerListener("module.compare.referenceOffset.changed", _.partial(this.updateMeasureTools, true), this);
};

// inherit
MeasureModule.prototype = Object.create(AbstractModule.prototype);
// correct the constructor pointer
MeasureModule.prototype.constructor = MeasureModule;

/**
 * Updates the data displayed in the measure tool
 * @param {Boolean} forceUpdate - forces the update of the data in the measure tool
 */
MeasureModule.prototype.updateMeasureTools = function(forceUpdate) {
	_.each(this.tools, function(tool) {
		if (tool.isActive()) {
			tool.updateIfNeeded(forceUpdate);
		}
	});
};

/**
 * Get the state of all the measure tools
 * @returns {Object}
 */
MeasureModule.prototype.getState = function() {
	var measureState = {
		sizeUnitState: this.f.getOption("PREFERENCES_UNIT_SIZE")
	};
	_.each(this.tools, function(tool) {
		measureState[tool.getIID()] = tool.getToolState();
	});

	return measureState;
};

/**
 * Set the state of the measure tools
 * @param {Object} state
 */
MeasureModule.prototype.setState = function(state) {
	_.each(state, function(state, iid) {
		var tool = _.find(this.tools, function(tool) {
			return tool.getIID() === iid;
		});
		if (tool) {
			tool.setState(state);
		}
	});

	var ruler = _.find(this.tools, function(tool) {
		return tool.getIID() === CoreConstants.TOOLS.MEASURE_RULER;
	});

	if (state.ruler !== undefined && ruler) {
		if (state.ruler.isActive) {
			this.f.emit("toolManager.activateTool", ruler);
		}
		this.f.emit("toolManager.interruptTools", true);
	}
};

export default MeasureModule;
