import ToolbarComponent from "@esko/toolbar/ToolbarComponent";
import ButtonGroup from "@esko/toolbar/ButtonGroup";
import ViewerToolbarButton from "@esko/web-viewer/layout/component/ViewerToolbarButton";
import SubtoolbarButton from "@esko/web-viewer/layout/component/SubtoolbarButton";
import Button from "@esko/button/Button";
import ColorPicker from "@esko/web-viewer/layout/component/ColorPicker";
import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import MeasureConstants from "@esko/web-viewer/measure/MeasureConstants";
import CaliperSubtoolbarComponent from "@esko/web-viewer/measure/CaliperSubtoolbarComponent";
import OrderedObject from "@esko/orderedobject";
import _ from "underscore";
import $ from "jquery";
/**
 * @exports MeasureToolbarComponent
 * @memberof MeasureModule
 * @class This is the toolbar for all measure tools
 * @augments ToolbarComponent
 * @constructor
 * @param {Core.ViewerFacade} f - Viewer facade
 * @param {Measure.RulerTool} [rulerTool]
 * @param {Measure.EyeDropperMeasureTool} [eyedropperTool]
 * @param {Measure.BarcodeMeasureTool} [barcodeTool]
 * @param {Measure.BrailleMeasureTool} [brailleTool]
 * @param {Measure.CaliperTool} [caliperTool]
 * @param {Measure.ScreenRulingMeasureTool} [screenRulingTool]
 */
var MeasureToolbarComponent = function(f, rulerTool, eyedropperTool, barcodeTool, brailleTool, caliperTool, screenRulingTool) {
	ToolbarComponent.call(this, LayoutConstants.ToolbarComponent.MEASURE, f);
	this.f = f;

	this.rulerTool = rulerTool;
	this.eyedropperTool = eyedropperTool;
	this.barcodeTool = barcodeTool;
	this.brailleTool = brailleTool;
	this.caliperTool = caliperTool;
	this.screenRulingTool = screenRulingTool;

	this.rulerButton = null;
	this.eyeDropperButton = null;
	this.barcodeButton = null;
	this.brailleButton = null;
	this.caliperButton = null;
	this.screenRulingButton = null;

	/**
	 * Group: measure tools
	 */
	this.measureGroup = new ButtonGroup("MeasureGroup");
	this.measureGroup.setTitle(f.i18n, "viewer", "MeasurementToolsTitle");
	this.addButtonGroup(this.measureGroup);

	this.f.getDocumentController().whenActivePageChangedAndParametersAvailable(
		_.bind(function() {
			this.updateTools();
		}, this)
	);
};

MeasureToolbarComponent.prototype = Object.create(ToolbarComponent.prototype);
MeasureToolbarComponent.prototype.constructor = MeasureToolbarComponent;
MeasureToolbarComponent.toolbarName = LayoutConstants.ToolbarComponent.MEASURE;
/**
 * Initialize button for ruler tool
 * @param {Measure.RulerTool} tool
 */
MeasureToolbarComponent.prototype.initializeRulerButton = function(tool) {
	if (!this.rulerButton) {
		// Ruler button
		this.rulerButton = new ViewerToolbarButton(this.f, "RulerButton", "icon icon-WCR_Measure-Ruler", true);
		this.rulerButton.listenToTool(tool, true);

		this.rulerButton.setTooltip("viewer", "RulerTT");

		/**
		 * Subtoolbar Component:
		 */
		var rulerSubtoolbar = new ToolbarComponent("RulerSubtoolbar", this.f);
		this.rulerButton.addSubtoolbarComponent(rulerSubtoolbar);
		/**
		 * Group:
		 */
		var rulerSubGroup = new ButtonGroup("RulerSubGroup");
		rulerSubtoolbar.addButtonGroup(rulerSubGroup);

		// Distance and angle
		var daButton = new SubtoolbarButton(
			this.f,
			"DAButton",
			"icon-WCR_Measure-Ruler-DA-cont",
			true,
			_.partial(function(f) {
				f.setOption("PREFERENCES_RULER_DISPLAY_MODE_DA", f.getOption("PREFERENCES_RULER_DISPLAY_MODE_DA") ? 0 : 1);
				f.setOption("PREFERENCES_RULER_DISPLAY_MODE", f.getOption("PREFERENCES_RULER_DISPLAY_MODE") >= 1 ? 0 : 1);
			}, this.f)
		);
		daButton.setIcon("icon-WCR_Measure-Ruler-DA-cont", ["icon-WCR_Measure-Ruler-DA-sub icon-red"]);
		daButton.setTooltip("viewer", "RulerDATT");
		rulerSubGroup.addButton(daButton);
		//daButton.setActive(true);

		// X and Y
		var xyButton = new SubtoolbarButton(
			this.f,
			"XYButton",
			"icon-WCR_Measure-Ruler-XY-cont",
			true,
			_.partial(function(f) {
				f.setOption("PREFERENCES_RULER_DISPLAY_MODE_XY", f.getOption("PREFERENCES_RULER_DISPLAY_MODE_XY") ? 0 : 1);
				f.setOption("PREFERENCES_RULER_DISPLAY_MODE", f.getOption("PREFERENCES_RULER_DISPLAY_MODE") >= 2 ? 1 : 2);
			}, this.f)
		);
		xyButton.setIcon("icon-WCR_Measure-Ruler-XY-cont", ["icon-WCR_Measure-Ruler-XY-sub icon-red"]);
		xyButton.setTooltip("viewer", "RulerXYTT");
		rulerSubGroup.addButton(xyButton);

		// W and H
		var whButton = new SubtoolbarButton(
			this.f,
			"WHButton",
			"icon-WCR_Measure-Ruler-WH-cont",
			true,
			_.partial(function(f) {
				f.setOption("PREFERENCES_RULER_DISPLAY_MODE_WH", f.getOption("PREFERENCES_RULER_DISPLAY_MODE_WH") ? 0 : 1);
				f.setOption("PREFERENCES_RULER_DISPLAY_MODE", f.getOption("PREFERENCES_RULER_DISPLAY_MODE") >= 3 ? 2 : 3);
			}, this.f)
		);
		whButton.setIcon("icon-WCR_Measure-Ruler-WH-cont", ["icon-WCR_Measure-Ruler-WH-sub icon-red"]);
		whButton.setTooltip("viewer", "RulerWHTT");
		rulerSubGroup.addButton(whButton);

		var setRulerButtonsActive = _.partial(function(f) {
			daButton.setActive(f.getOption("PREFERENCES_RULER_DISPLAY_MODE_DA") === 1);
			xyButton.setActive(f.getOption("PREFERENCES_RULER_DISPLAY_MODE_XY") === 1);
			whButton.setActive(f.getOption("PREFERENCES_RULER_DISPLAY_MODE_WH") === 1);
		}, this.f);

		this.f.getCurrentUser().on("options.changed.PREFERENCES_RULER_DISPLAY_MODE", function(oldValue, newValue) {
			setRulerButtonsActive();
		});

		setRulerButtonsActive();

		var colorPicker = new ColorPicker(
			this.f,
			_.partial(function(f, newColor) {
				f.getCurrentUser().setColor("PREFERENCES_RULER_DISPLAY_COLOR", newColor);
			}, this.f)
		);

		this.f.getCurrentUser().on(
			"options.changed.PREFERENCES_RULER_DISPLAY_COLOR",
			_.partial(function(f, oldValue, newValue) {
				colorPicker.setColor(f.getCurrentUser().getColor("PREFERENCES_RULER_DISPLAY_COLOR"));
			}, this.f)
		);
		colorPicker.setColor(this.f.getCurrentUser().getColor("PREFERENCES_RULER_DISPLAY_COLOR"));

		var colorSelectorButton = new SubtoolbarButton(this.f, "ColorSelector", colorPicker.element, true);
		colorSelectorButton.setTooltip("viewer", "RulerDisplayColorChange");

		var colorResetButton = new SubtoolbarButton(
			this.f,
			"ColorReset",
			"icon-WCR_Revert",
			true,
			_.partial(function(f) {
				f.resetOption("PREFERENCES_RULER_DISPLAY_COLOR");
			}, this.f)
		);
		colorResetButton.setTooltip("viewer", "RulerDisplayColorReset");

		var angleButton = new SubtoolbarButton(
			this.f,
			"angleButton",
			this.f.getOption("PREFERENCES_RULER_ANGLE_MODE") ? "measureCCW" : "measureCW",
			true,
			_.partial(function(f) {
				f.setOption("PREFERENCES_RULER_ANGLE_MODE", f.getOption("PREFERENCES_RULER_ANGLE_MODE") ? 0 : 1);
				if (f.getOption("PREFERENCES_RULER_ANGLE_MODE")) {
					this.setTooltip("viewer", "RulerAngleToCW");
					this.setIcon("icon-WCR_Measure-Ruler-CCW-cont", ["icon-WCR_Measure-Ruler-CCW-sub icon-red"]);
				} else {
					this.setTooltip("viewer", "RulerAngleToCCW");
					this.setIcon("icon-WCR_Measure-Ruler-CW-cont", ["icon-WCR_Measure-Ruler-CW-sub icon-red"]);
				}
			}, this.f)
		);
		if (this.f.getOption("PREFERENCES_RULER_ANGLE_MODE")) {
			angleButton.setTooltip("viewer", "RulerAngleToCW");
			angleButton.setIcon("icon-WCR_Measure-Ruler-CCW-cont", ["icon-WCR_Measure-Ruler-CCW-sub icon-red"]);
		} else {
			angleButton.setTooltip("viewer", "RulerAngleToCCW");
			angleButton.setIcon("icon-WCR_Measure-Ruler-CW-cont", ["icon-WCR_Measure-Ruler-CW-sub icon-red"]);
		}

		var rulerSubGroupOptions = new ButtonGroup("RulerSubGroupOptions");
		rulerSubtoolbar.addButtonGroup(rulerSubGroupOptions);

		rulerSubGroupOptions.addButton(angleButton);

		rulerSubGroupOptions.addButton(colorSelectorButton);
		rulerSubGroupOptions.addButton(colorResetButton);
	}
};

/**
 * Initialize button for eyedropper tool
 * @param {Measure.EyeDropperMeasureTool} tool
 */
MeasureToolbarComponent.prototype.initializeEyeDropperButton = function(tool) {
	if (!this.eyeDropperButton) {
		// Eye dropper button
		this.eyeDropperButton = new ViewerToolbarButton(this.f, "EyeDropperButton", "icon icon-WCR_Measure-Colorpicker", false);
		this.eyeDropperButton.listenToTool(tool, true);
		this.eyeDropperButton.setTooltip("viewer", "ToolPercentageTT");
	}
};

/**
 * Initialize button for barcode tool
 * @param {Measure.BarcodeMeasureTool} tool
 */
MeasureToolbarComponent.prototype.initializeBarCodeButton = function(tool) {
	if (!this.barcodeButton) {
		// Barcode button
		this.barcodeButton = new ViewerToolbarButton(this.f, "BarcodeButton", "icon icon-WCR_Measure-Barcode", false);
		this.barcodeButton.listenToTool(tool, true);
		this.barcodeButton.setTooltip("viewer", "ToolBarcodeTT");
	}
};

/**
 * Initialize button for braille tool
 * @param {Measure.BrailleMeasureTool} tool
 */
MeasureToolbarComponent.prototype.initializeBrailleButton = function(tool) {
	if (!this.brailleButton) {
		// Braille button
		this.brailleButton = new ViewerToolbarButton(this.f, "BrailleButton", "icon icon-WCR_Measure-Braille", false);
		this.brailleButton.listenToTool(tool, true);
		this.brailleButton.setTooltip("viewer", "ToolBrailleTT");

		// translate the strings and sort alphabetically
		var langListTranslated = new OrderedObject();
		_.each(
			MeasureConstants.BrailleLanguage,
			function(lang, key) {
				if (key !== MeasureConstants.LanguageAutomatic) {
					langListTranslated.addItem(this.f.i18n.t(MeasureConstants.LanguageTranslationPrefix + lang.lang), key);
				}
			},
			this
		);
		langListTranslated.setOrder(_.sortBy(langListTranslated.getKeys()));
		// Add Option for Automatic as well, but only after sorting, as it should always be the first option
		langListTranslated.addItemAtIndex(
			this.f.i18n.t(MeasureConstants.LanguageTranslationPrefix + MeasureConstants.BrailleLanguage[MeasureConstants.LanguageAutomatic].lang),
			MeasureConstants.LanguageAutomatic
		);

		// Braille language selector
		var brailleSubtoolbar = new ToolbarComponent("BrailleSubToolbar", this.f);
		this.brailleButton.addSubtoolbarComponent(brailleSubtoolbar);
		var langPicker = $("<div/>").addClass("brailleLanguages");
		var currentLang = $("<span/>")
			.addClass("currentlang")
			.append(langListTranslated.getKeyByValue(this.f.getOption("PREFERENCES_BRAILLE_LANGUAGE").toString()));
		var languageList = $("<ul/>")
			.addClass("languagelist")
			.hide();

		var language = new Button(this.f.i18n, this.f.getContext(), this.f.isMobile(), "language", currentLang, false, function() {
			languageList.toggle();
		});

		// add language strings to dropdown
		_.each(
			langListTranslated.getKeys(),
			function(lang, key) {
				var langButton = new Button(
					this.f.i18n,
					this.f.getContext(),
					this.f.isMobile(),
					"brailleLang" + langListTranslated.getItemByKey(lang),
					lang,
					false,
					_.partial(function(f) {
						var langOptionID = parseInt(langListTranslated.getItemByKey(lang), 10);
						if (isNaN(langOptionID)) {
							langOptionID = 0;
						}
						f.setOption("PREFERENCES_BRAILLE_LANGUAGE", langOptionID);
						languageList.hide();
					}, this.f)
				);
				languageList.append($("<li/>").append(langButton.element));
			},
			this
		);

		language.element.append($("<b/>").addClass("caret"));
		langPicker.append(language.element);
		langPicker.append(languageList);
		brailleSubtoolbar.element.append(langPicker);

		//Change the contents of the brailleSubtoolbar to the current language
		this.f.getCurrentUser().on("options.changed.PREFERENCES_BRAILLE_LANGUAGE", function(oldValue, newValue) {
			currentLang.html(langListTranslated.getKeyByValue(newValue + ""));
		});
	}
};

/**
 * Initialize button for caliper tool
 * @param {Measure.CaliperTool} caliperTool
 */
MeasureToolbarComponent.prototype.initializeCaliperButton = function(caliperTool) {
	if (!this.caliperButton) {
		// Caliper button
		this.caliperButton = new ViewerToolbarButton(this.f, "CaliperButton", "icon-WCR_Measure-Caliper2-cont", false);
		this.caliperButton.listenToTool(caliperTool, true);
		this.caliperButton.setIcon("icon-WCR_Measure-Caliper2-cont", ["icon-WCR_Measure-Caliper2-sub icon-red"]);
		this.caliperButton.setTooltip("viewer", "CaliperTT");

		this.caliperButton.addSubtoolbarComponent(new CaliperSubtoolbarComponent(this.f, caliperTool.getCaliperModel()));
	}
};

/**
 * Initialize button for screen ruling tool
 * @param {Measure.ScreenRulingMeasureTool} screenRulingTool
 */
MeasureToolbarComponent.prototype.initializeScreenRulingButton = function(screenRulingTool) {
	if (!this.screenRulingButton) {
		// Screen Ruling button
		this.screenRulingButton = new ViewerToolbarButton(this.f, "ScreenRulingButton", "icon icon-WCR_Measure-Screen", false);
		this.screenRulingButton.listenToTool(screenRulingTool, true);
		this.screenRulingButton.setTooltip("viewer", "ToolScreenTT");
	}
};

/**
 * Check which buttons need to be shown and update button group + deactivate tool if needed
 */
MeasureToolbarComponent.prototype.updateTools = function() {
	// Tools
	this.f.emit(
		"toolManager.activeTool",
		_.bind(function(activeTool) {
			// one of our tools if canBeUsedOnActivePage is defined?
			if (activeTool && activeTool.canBeUsedOnActivePage && !activeTool.canBeUsedOnActivePage()) {
				this.f.emit("toolManager.deactivateTool", activeTool);
			}
		}, this)
	);

	// Buttons
	this.measureGroup.clearButtons();

	if (this.rulerTool && this.rulerTool.canBeUsedOnActivePage()) {
		this.initializeRulerButton(this.rulerTool);
		this.measureGroup.addButton(this.rulerButton);
	}

	if (this.eyedropperTool && this.eyedropperTool.canBeUsedOnActivePage()) {
		this.initializeEyeDropperButton(this.eyedropperTool);
		this.measureGroup.addButton(this.eyeDropperButton);
	}

	if (this.screenRulingTool && this.screenRulingTool.canBeUsedOnActivePage()) {
		this.initializeScreenRulingButton(this.screenRulingTool);
		this.measureGroup.addButton(this.screenRulingButton);
	}

	if (this.barcodeTool && this.barcodeTool.canBeUsedOnActivePage()) {
		this.initializeBarCodeButton(this.barcodeTool);
		this.measureGroup.addButton(this.barcodeButton);
	}

	if (this.brailleTool && this.brailleTool.canBeUsedOnActivePage()) {
		this.initializeBrailleButton(this.brailleTool);
		this.measureGroup.addButton(this.brailleButton);
	}

	if (this.caliperTool && this.caliperTool.canBeUsedOnActivePage()) {
		this.initializeCaliperButton(this.caliperTool);
		this.measureGroup.addButton(this.caliperButton);
	}

	this._emit("changed.content");
};

export default MeasureToolbarComponent;
