import _ from "underscore";
import $ from "jquery";
import ViewerUtils from "@esko/web-viewer/utils/ViewerUtils";
import ViewportPopoverModel from "@esko/web-viewer/viewport/model/ViewportPopoverModel";
import ShapeUtils from "@esko/shapeutils";
import Template from "@esko/template";
import tpl from "@esko/web-viewer/measure/RulerPopoverTemplate.tpl.html";
import CoreConstants from "@esko/web-viewer/core/CoreConstants";
/**
 * @exports RulerSnapIndicatorPopoverModel
 * @memberof MeasureModule
 * @class Model for the popover rulersnapindicator
 * @constructor
 */
var RulerSnapIndicatorPopoverModel = function(f, name, snapIndicator, cssClass) {
	ViewportPopoverModel.call(this, f, name);

	var div = $("<div/>");

	this.fix = 3;
	this.f = f;
	this.snapIndicator = snapIndicator;

	// initialize template
	this.t = new Template(f.i18n, tpl);

	// load language if needed
	f.i18n.loadBundle(
		"viewer",
		_.bind(function() {
			this.t.render();
		}, this)
	);

	this.t.setContext(div);
	this.t.render();

	this.getFrame = function() {
		if (this.snapIndicator) {
			return this.snapIndicator.rect;
		} else {
			return new ShapeUtils.Rect();
		}
	};

	/**
	 * @override
	 */
	this.getContent = function() {
		return div;
	};

	/**
	 * @override
	 */
	this.getRestrictBorder = function() {
		return 0;
	};

	/**
	 * Get the class for the popover
	 */
	this.getClass = function() {
		return cssClass;
	};

	/**
	 * Get the context for the popover
	 */
	this.getContext = _.bind(function() {
		return this.f.getContext().find(".viewport");
	}, this);
};

// inherit
RulerSnapIndicatorPopoverModel.prototype = Object.create(ViewportPopoverModel.prototype);
// correct the constructor pointer
RulerSnapIndicatorPopoverModel.prototype.constructor = RulerSnapIndicatorPopoverModel;

RulerSnapIndicatorPopoverModel.prototype.setPoint = function(point) {
	this.point = point;
	this.render();
};

RulerSnapIndicatorPopoverModel.prototype.render = function() {
	if (!this.snapIndicator) {
		return;
	}

	var center = this.snapIndicator.rect.center();
	var resx = null,
		resy = null;
	if (this.f.getUnits() === CoreConstants.SizeUnits.PIXELS) {
		var page = this.f.getActivePage();
		resx = page.getParam("resolutionx");
		resy = page.getParam("resolutiony");
	}

	/**
	 * Show values
	 */
	this.t.d.showXY = true;
	this.t.d.unitsloc = this.f.getUnitsLocName();

	// convert to correct coordinate system
	var centerPoint = new ShapeUtils.Point(center.x, center.y);
	var transformedCenterPoint = this._coordinates.getTransformedPoint(centerPoint);

	this.t.d.x = ViewerUtils.convertFromMmValue(
		transformedCenterPoint.x,
		this.f.getUnits(),
		this.f.getUnitsFix(),
		ViewerUtils.parseFloat(resx)
	);
	this.t.d.y = ViewerUtils.convertFromMmValue(
		transformedCenterPoint.y,
		this.f.getUnits(),
		this.f.getUnitsFix(),
		ViewerUtils.parseFloat(resy)
	);

	this.t.render();
};

export default RulerSnapIndicatorPopoverModel;
