import MeasurePopoverModel from "@esko/web-viewer/measure/MeasurePopoverModel";
import ScreenRulingUnitSelector from "@esko/web-viewer/measure/ScreenRulingUnitSelector";
import _ from "underscore";
import $ from "jquery";
/**
 * MeasurePopoverModel specific for the screen ruling tool.
 *
 * @exports ScreenRulingPopoverModel
 * @memberof MeasureModule
 * @class ScreenRulingPopoverModel
 * @augments MeasurePopoverModel
 * @constructor
 *
 * @param {Core.ViewerFacade} f
 * @param {LineworkWrapper} area
 * @param {String} name
 * @param {String | JQuery.Element} title - Title to be shown in the header
 * @param {Array<Number> | Array<String>} channels
 * @param {Boolean} [makeTotalCount] Defines if a total of the different channel values needs to be calculated, only possible if the
 * 										values of the channels array are numbers
 * @param {String | JQuery.Element} headerExtra - A jQuery component or string that is displayed in upper-right corner of this popver
 */
var ScreenRulingPopoverModel = function(f, area, name, title, channels, makeTotalCount, headerExtra) {
	MeasurePopoverModel.call(this, f, area, name, title, channels, makeTotalCount, headerExtra);

	this._screenRulingUnitSelector = null;

	this.f.getDocumentController().whenActivePageChangedAndParametersAvailable(this._updateScreenRulingUnitSelectorButton, this);
};

// inherit
ScreenRulingPopoverModel.prototype = Object.create(MeasurePopoverModel.prototype);
// correct the constructor pointer
ScreenRulingPopoverModel.prototype.constructor = ScreenRulingPopoverModel;

/**
 * Called when the active page is changed to either show it or not for digital film
 */
ScreenRulingPopoverModel.prototype._updateScreenRulingUnitSelectorButton = function() {
	if (this.f.getActivePage().isDigitalFilmPage()) {
		if (this._screenRulingUnitSelector === null) {
			this._screenRulingUnitSelector = new ScreenRulingUnitSelector(this.f);
			this._headerExtra.append(this._screenRulingUnitSelector.getButtonElement());
		} else {
			this._screenRulingUnitSelector.getButtonElement().show();
		}
	} else {
		if (this._screenRulingUnitSelector !== null) {
			this._screenRulingUnitSelector.getButtonElement().hide();
		}
	}
};

export default ScreenRulingPopoverModel;
