import AbstractWidget from "@esko/web-viewer/layout/AbstractWidget";
import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import MessageComponent from "@esko/web-viewer/message/MessageComponent";
import $ from "jquery";
import _ from "underscore";
/**
 * MessageWidget a wrapper around the message widget component specifically for the viewer to conform to the AbstractWidget interface.
 * @exports MessageWidgetWrapper
 * @memberof MessageModule
 * @constructor
 * @augments Layout.AbstractWidget
 * @param {Core.ViewerFacade} f
 * @param {MessageModel} messageModel - The message model where the widget should listen to
 */
var MessageWidgetWrapper = function(f, messageModel) {
	AbstractWidget.call(this, f, LayoutConstants.Widget.MESSAGE);

	/**
	 * @member {MessageModel} The message model
	 */
	this._messageModel = messageModel;

	/**
	 * @member {MessageWidget} The message widget
	 */
	this._messageWidget = null;

	this.f = f;
};

MessageWidgetWrapper.prototype = Object.create(AbstractWidget.prototype);
MessageWidgetWrapper.prototype.constructor = MessageWidgetWrapper;
MessageWidgetWrapper.widgetName = LayoutConstants.Widget.MESSAGE;

/**
 * @override
 * Get the widget type
 * @returns {String} "messagebar"
 */
MessageWidgetWrapper.prototype.getWidgetType = function() {
	return "messagebar";
};

/**
 * @override
 * Set the context of the widget
 * @alias AbstractWidget~setContext
 */
MessageWidgetWrapper.prototype.setContext = function(context) {
	AbstractWidget.prototype.setContext.call(this, context);
	if (this._messageWidget == null) {
		this._messageWidget = new MessageComponent.MessageWidget(this._messageModel, context, this.f.i18n);
	}
	// we want to allow selection of the message
	this.context.addClass("enableTextSelection");
};

export default MessageWidgetWrapper;
