import ModalPopup from "@esko/web-viewer/layout/component/ModalPopup";
import Template from "@esko/template";
import ViewerUtils from "@esko/web-viewer/utils/ViewerUtils";
import CoreConstants from "@esko/web-viewer/core/CoreConstants";
import tpl from "@esko/web-viewer/navigation/AdjustMonitorResolutionPopup.tpl.html";
import $ from "jquery";
import _ from "underscore";
/**
 * @exports AdjustMonitorResolutionPopup
 * @memberof NavigationModule
 * @augments layout.component.ModelPopup
 * @class Popup for adjusting monitor resolution
 * @constructor
 *
 * @param {Core.ViewerFacade} f - Viewer facade
 * @param {String} id - Id of the popup. It is used in its private channel.
 * @param {NavigationModule} navigationModule - The navigation module
 */
var AdjustMonitorResolutionPopup = function(f, id, navigationModule) {
	ModalPopup.call(this, f, id, f.getContext());

	this._navigationModule = navigationModule;

	this.f.i18n.loadBundle(
		"viewer",
		_.bind(function() {
			this.setHeader(
				$("<span/>")
					.addClass("popupTitle")
					.html(this.f.i18n.t("ZoomOneToOneAdjustResTitle"))
			);

			this.setOkBtnText(this.f.i18n.t("OkButton"));
			this.setOkAction(
				_.bind(function() {
					this._navigationModule.okMonitorResolution();
				}, this)
			);
			this.setCancelAction(
				_.bind(function() {
					this._navigationModule.cancelMonitorResolution();
				}, this)
			);
		}, this)
	);

	this.element.addClass("adjustMonitorResolutionPopup");

	/**
	 * @member {Template} template for the popup
	 */
	this.t = new Template(this.f.i18n, tpl);
	this.t.setContext(this._popupContent.addClass("adjustMonitorResolutionPopupContent"));

	// KB article for more info
	this.t.d.moreInfoLink =
		"https://wiki.esko.com/display/KBA/KB134185394:+WebCenter+-+How+to+determine+the+Monitor+Resolution+for+Zoom+to+Actual+Size+in+the+HTML5+Viewer";

	//action for the input field for the resolution
	this.t.bind(
		"focusout",
		"[name=monitorResolution]",
		_.bind(function(source, event) {
			var v = source.value;
			var parts = source.value.split("/");
			if (parts.length == 2) {
				v = ViewerUtils.parseFloat(parts[0]) / ViewerUtils.parseFloat(parts[1]);
			}
			v = ViewerUtils.parseFloat(v);
			if (isNaN(v)) {
				// if nothing is filled in or only letter(s), keep old valid value (in same unit as at it should be entered)
				v = ViewerUtils.parseFloat(
					ViewerUtils.convertResolutionFromPpmmValue(this._navigationModule.getMonitorResolution(), this.f.getResolutionUnits())
				);
			}

			// convert to ppmm
			var newMonitorResolution = ViewerUtils.parseFloat(ViewerUtils.convertResolutionToPpmmValue(v, this.f.getResolutionUnits()));

			// Put the values back (in right unit)
			source.value = ViewerUtils.convertResolutionFromPpmmValue(
				newMonitorResolution,
				this.f.getResolutionUnits(),
				this.f.getResolutionUnitsFix()
			);

			// set the option
			this._navigationModule.setMonitorResolution(newMonitorResolution);
		}, this)
	);

	// Listen to resolution changes
	this.f.getCurrentUser().on(
		"options.changed.PREFERENCES_UNIT_RESOLUTION",
		_.bind(function() {
			if (this.isVisible()) {
				this.render();
			}
		}, this)
	);
};

AdjustMonitorResolutionPopup.prototype = Object.create(ModalPopup.prototype);
AdjustMonitorResolutionPopup.prototype.constructor = AdjustMonitorResolutionPopup;

/**
 * Renders the popup for channel matching, it's a throttled function
 */
AdjustMonitorResolutionPopup.prototype.render = _.throttle(function() {
	this.t.d.monitorResolution = ViewerUtils.convertResolutionFromPpmmValue(
		this._navigationModule.getMonitorResolution(),
		this.f.getResolutionUnits(),
		this.f.getResolutionUnitsFix()
	);
	this.t.d.resolutionUnitsLangKey = this.f.getResolutionUnitsLocName();

	this.t.render();
	if (this._isInitialized) {
		this.recalculateSize(500);
	}
}, 40);

/**
 * Show the modal popup
 */
AdjustMonitorResolutionPopup.prototype.show = function() {
	this.render();
	ModalPopup.prototype.show.call(this);
	this.recalculateSize(500);
};

export default AdjustMonitorResolutionPopup;
