import _ from "underscore";
import AbstractTool from "@esko/web-viewer/viewport/tools/AbstractTool";
import TouchUtil from "@esko/web-viewer/utils/TouchUtil";
import CoreConstants from "@esko/web-viewer/core/CoreConstants";
/**
 * @exports TouchPreventTool
 * @memberof NavigationModule
 * @augments Viewport.AbstractTool
 *
 * @class
 * The touch preventer tool prevents users to use touch. This will disable browser zooming etc.
 * @constructor
 * @param {Core.ViewerFacade} f
 */
var TouchPreventTool = function Touch(f) {
	AbstractTool.call(this, f, CoreConstants.TOOLS.NOTOUCH);
	// create touch util within viewport context
	this._touchUtil = null;
};

// extend from the AbstractTool
TouchPreventTool.prototype = Object.create(AbstractTool.prototype);
TouchPreventTool.prototype.constructor = TouchPreventTool;

/**
 * override the passivation process, so all listeners are removed
 * @override
 */
TouchPreventTool.prototype.doPassivation = function() {
	AbstractTool.prototype.doPassivation.call(this);

	// unregister events
	this._touchUtil.removeAllListeners();
};

/**
 * Initialize the touch preventer tool
 * @param {AbstractWidget} widget - the widget on which the tool is activated
 */
TouchPreventTool.prototype.initialize = function(widget, toolManager) {
	AbstractTool.prototype.initialize.apply(this, arguments);
	// note this only works on the viewportwidget
	this._touchUtil = new TouchUtil(widget.getElement()[0]);
};

/**
 * Override the activation process, so all listeners are added.
 * Listen to everything to prevent the events from doing something.
 * @override
 */
TouchPreventTool.prototype.doActivation = function() {
	AbstractTool.prototype.doActivation.call(this);

	var preventDefault = _.bind(function(e) {
		this._touchUtil.preventDefault(e);
	}, this);

	// register events
	this._touchUtil.addPinchStartListener(_.bind(preventDefault, this));
	this._touchUtil.addPinchMoveListener(_.bind(preventDefault, this));
	this._touchUtil.addPinchEndListener(_.bind(preventDefault, this));

	this._touchUtil.addDoubleTapListener(_.bind(preventDefault, this));

	this._touchUtil.addPanStartListener(_.bind(preventDefault, this));
	this._touchUtil.addPanMoveListener(_.bind(preventDefault, this));
	this._touchUtil.addPanEndListener(_.bind(preventDefault, this));
};

export default TouchPreventTool;
