import LogSlider from "@esko/web-viewer/layout/component/LogSlider";
import ListenerUtil from "@esko/web-viewer/utils/ListenerUtil";
import MiniButton from "@esko/web-viewer/layout/component/MiniButton";
import $ from "jquery";
import _ from "underscore";

/**
 * @exports ZoomBar
 * @memberof NavigationModule
 * @class The ZoomBar shows the zoom bar of the navigator widget
 * @constructor
 * @param {Core.ViewerFacade} f
 */
var ZoomBar = function ZoomBar(f) {
	this.f = f;
	ListenerUtil.mixin(this, this.f);

	// the root element
	this.element = $("<div />").addClass("zoomBar clearfix");

	// min button
	this._minButton = new MiniButton(this.f, "minZoom", "icon-WCR_Minus", true, _.bind(this._minZoom, this));
	this.element.append(this._minButton.element.addClass("minZoom"));

	// zoom percentage
	this._zoomPercentage = $("<span />").addClass("zoomPercentage");
	this.element.append(this._zoomPercentage);

	// plus button
	this._plusButton = new MiniButton(this.f, "plusZoom", "icon-WCR_Plus", true, _.bind(this._plusZoom, this));
	this.element.append(this._plusButton.element.addClass("plusZoom"));

	// slider
	var viewportModule = this.f.getModule("viewport");
	if (viewportModule) {
		this._slider = new LogSlider(this.f, {
			onSliderChanged: _.bind(this._sliderChanged, this),
			minp: 1,
			maxp: viewportModule.getNumberOfZoomLevels() // this stays stable
		});
		this._updateMinMax(); // this can change
		this.element.append(this._slider.element);
	}

	this._registerListener("transform.viewportWidget.minMaxZoomChanged", this._updateMinMax, this);
	this._registerListener("transform.viewportWidget.transformChanged", this._updateZoom, this);
};

/**
 * Called when the slider is changed
 * @param {Number} sliderValue - The (new) slider value
 */
ZoomBar.prototype._sliderChanged = function(sliderValue) {
	var viewportModule = this.f.getModule("viewport");
	if (viewportModule) {
		viewportModule.transform({
			fixedzoom: sliderValue,
			animated: true
		});
	}
};

/**
 * Called when the zoom percentage/slider should be updated
 */
ZoomBar.prototype._updateZoom = function() {
	var viewportModule = this.f.getModule("viewport");
	if (viewportModule) {
		// update the percentage
		var zoomPercentage = viewportModule.getZoomPercentage();
		this._zoomPercentage.text(zoomPercentage.toFixed(2) + "%");

		// update the slider
		var zoom = viewportModule.getZoom();
		this._slider.setValue(zoom);
	}
};

/**
 * Update the max value of the slider
 */
ZoomBar.prototype._updateMinMax = function() {
	var viewportModule = this.f.getModule("viewport");
	if (viewportModule) {
		var minZoom = viewportModule.getMinZoom();
		var maxZoom = viewportModule.getMaxZoom();
		this._slider.setOptions({
			minv: minZoom,
			maxv: maxZoom
		});
	}
};

/**
 * Called when the min zoom button is clicked
 */
ZoomBar.prototype._minZoom = function() {
	var viewportModule = this.f.getModule("viewport");
	if (viewportModule) {
		viewportModule.transform({
			zoom: -1,
			animated: true
		});
	}
};

/**
 * Called when the plus zoom button is clicked
 */
ZoomBar.prototype._plusZoom = function() {
	var viewportModule = this.f.getModule("viewport");
	if (viewportModule) {
		viewportModule.transform({
			zoom: 1,
			animated: true
		});
	}
};

export default ZoomBar;
