import AbstractDocumentPage from "@esko/web-viewer/data/AbstractDocumentPage";
import _ from "underscore";

/**
 * Inject pagelist functionality in the data model
 *
 * @exports PagelistDataExtensions
 * @memberof PagelistModule
 */
var PagelistDataExtensions = _.once(function() {
	//---------------- AbstractDocumentPage extensions -------------------------------------------------------------

	/**
	 * Is this page marked
	 * @returns {Boolean} True if marked, false otherwise
	 */
	AbstractDocumentPage.prototype.isPagelistMarked = function() {
		return this._pagelistMarked !== undefined && this._pagelistMarked === true;
	};

	/**
	 * Set the page marked
	 * @param {Boolean} pagelistMarked - True to set it marked, false to set it not marked
	 */
	AbstractDocumentPage.prototype.setPagelistMarked = function(pagelistMarked) {
		if (this._pagelistMarked !== pagelistMarked) {
			this._pagelistMarked = pagelistMarked;
			this._emit("pagelistMarked.changed", this);
		}
	};

	/**
	 * Get the page name
	 * @returns {String} The page name or empty string if not defined
	 */
	AbstractDocumentPage.prototype.getPageName = function() {
		return this.getPagenum() + "" || "";
	};
});

export default PagelistDataExtensions;
