import DropdownMenu from "@esko/dropdownmenu/DropdownMenu";
import ShapeUtils from "@esko/shapeutils";
import $ from "jquery";
import _ from "underscore";
/**
 * @class This class is a wrapper around a dropdown menu to show a custom context menu of a page in the pagelist widget (only for pagelists). It allows to do mark/clear mark oparations.
 * @exports PagelistWidgetPageContextMenu
 * @memberof PagelistModule
 * @param {Core.ViewerFacade} f - The viewer facade
 * @param {PagelistModule} - The page list module
 */
var PagelistWidgetPageContextMenu = function(f, pagelistModule) {
	this.f = f;

	this._page = null; // page where the context menu is opened off

	this._anchorDiv = $("<div />").addClass("pagelistWidgetPageContextMenuAnchor"); // the context menu is attached to this element
	this.f.getContext().append(this._anchorDiv);

	this._pagelistModule = pagelistModule;
	this._dropdown = new DropdownMenu(this.f.i18n, this.f.getContext(), this.f.isMobile(), "right", "wcr-dropdown");

	// Mark option
	this._dropdown.addAction({
		name: "markOne",
		content: this.f.i18n.t("MarkedOn"),
		enabled: true,
		action: _.bind(function() {
			var page = this._page;
			if (page !== null) {
				this._pagelistModule.togglePageMarked(page);
			}
		}, this)
	});

	// Mark all pages
	this._dropdown.addAction({
		name: "markAll",
		content: this.f.i18n.t("MarkedOnAll"),
		enabled: true,
		action: _.bind(function() {
			this._pagelistModule.markAllPages();
		}, this)
	});

	// Clear marks of all pages
	this._dropdown.addAction({
		name: "markClearAll",
		content: this.f.i18n.t("MarkedOffAll"),
		enabled: true,
		action: _.bind(function() {
			this._pagelistModule.clearAllMarkedPages();
		}, this)
	});
};

/**
 * Show the context menu
 * @param {AbstractDocumentPage} page - Page where the context menu is opened off
 * @param {ShapeUtils.Point} location - Location of the context menu
 */
PagelistWidgetPageContextMenu.prototype.show = function(page, location) {
	if (!page || !location) {
		return;
	}

	this._page = page;
	this._anchorDiv.css({
		left: location.x,
		top: location.y
	});

	if (page.isPagelistMarked()) {
		this._dropdown.setActionText("markOne", this.f.i18n.t("MarkedOff"));
	} else {
		this._dropdown.setActionText("markOne", this.f.i18n.t("MarkedOn"));
	}

	this._dropdown.show(this._anchorDiv);
};

export default PagelistWidgetPageContextMenu;
