import ConversionConstants from "@esko/web-viewer/utils/ConversionConstants";
import ShapeUtils from "@esko/shapeutils";
import CompareConstants from "@esko/web-viewer/compare/CompareConstants";
import $ from "jquery";

export default {
	mixin: function(object) {
		object.hasSvg = function() {
			return true;
		};

		object.getPageSize = function() {
			var size = this.getSVGSize();
			if (size) {
				return size;
			} else {
				return new ShapeUtils.Size();
			}
		};

		/**
		 * returns the size of the svg
		 * @return {ShapeUtils.Size}
		 */
		object.getSVGSize = function() {
			/*
             * The svg needs a width and height attribute to display correctly
             * We first look at the attributes, if not present, use the viewbox to determine the width and height
             */
			if (this.get("svgSize")) {
				return this.get("svgSize");
			} else if (this.getSVGElement()) {
				var svgElement = this.getSVGElement();
				var width = $(svgElement).attr("width");
				if (width && width.indexOf("pt") > -1) {
					// Width of the SVG defined in pt, convert to mm
					width = parseFloat(width) / ConversionConstants.MM_TO_POINT_RATIO;
				} else if (width) {
					width = parseFloat(width) / ConversionConstants.MM_TO_PX_RATIO;
				} else if (svgElement.viewBox) {
					width = svgElement.viewBox.baseVal.width / ConversionConstants.MM_TO_PX_RATIO;
					svgElement.setAttribute("width", svgElement.viewBox.baseVal.width + "px");
				}
				var height = $(svgElement).attr("height");
				if (height && height.indexOf("pt") > -1) {
					// height of the SVG defined in pt, convert to mm
					height = parseFloat(height) / ConversionConstants.MM_TO_POINT_RATIO;
				} else if (height) {
					height = parseFloat(height) / ConversionConstants.MM_TO_PX_RATIO;
				} else if (svgElement.viewBox) {
					height = svgElement.viewBox.baseVal.height / ConversionConstants.MM_TO_PX_RATIO;
					svgElement.setAttribute("height", svgElement.viewBox.baseVal.height + "px");
				}

				this.set("svgSize", new ShapeUtils.Size(width, height));
				return this.get("svgSize");
			} else {
				return new ShapeUtils.Size();
			}
		};

		/**
		 * Check if the svg has been loaded
		 * @return {Boolean}
		 */
		object.isSVGLoaded = function() {
			var svgData = this.get("svgData");
			return svgData && svgData.loaded === true && svgData.rawSVG;
		};

		/**
		 * Returns the svg element
		 * @return {JQueryObject}
		 */
		object.getSVGElement = function() {
			return this.get("svgData") && this.get("svgData").rawSVG;
		};

		object.getAvailableCompareModes = function(refPage) {
			return [
				CompareConstants.mode.SHOW_CURRENT,
				CompareConstants.mode.SHOW_DIFFERENCE,
				CompareConstants.mode.BLINKING,
				CompareConstants.mode.READERSPREAD,
				CompareConstants.mode.SIDEBYSIDE
			];
		};

		object.areCompareOptionsAllowed = function() {
			return false;
		};
	}
};
