import ViewportLayerModel from "@esko/web-viewer/viewport/model/ViewportLayerModel";
import TextSelectionPopoverModel from "./TextSelectionPopoverModel";
import ShapeUtils from "@esko/shapeutils";
import ListenerUtil from "@esko/web-viewer/utils/ListenerUtil";
/**
 * @exports TextSelectionLayerModel
 * @memberof SvgModule
 * @augments ViewportLayerModel
 * @class This class gives the linework to render selected text and show popover.
 * @constructor
 *
 * @param {Core.ViewerFacade} f - Viewer facade
 * @param {String} ID - the ID of the layer model
 * @param {TextSelectionModel} textSelectionModel - Model of the text selection tool
 */
var TextSelectionLayerModel = function(f, ID, textSelectionModel) {
	ViewportLayerModel.call(this, f, ID);
	ListenerUtil.mixin(this, f);

	// Variables
	this._textSelectionModel = textSelectionModel;
	this._textSelectionPopover = null;
	this._textSelectionPopoverListener = null;
	this._worldTextFrames = null;
};

// inherit
TextSelectionLayerModel.prototype = Object.create(ViewportLayerModel.prototype);
TextSelectionLayerModel.prototype.constructor = TextSelectionLayerModel;

/**
 * Start showing the textSelection popover
 */
TextSelectionLayerModel.prototype.showPopover = function() {
	if (!this._textSelectionPopover) {
		this._textSelectionPopover = new TextSelectionPopoverModel(this.f, "TextSelectionPopover");
		this._textSelectionPopoverListener = this._registerListener(
			"popupClosed",
			function(e) {
				this.hidePopover();
			},
			this,
			this._textSelectionPopover
		);
		this.modelChanged();

		this.addPopoverModel(this._textSelectionPopover);
	}
};

/**
 * Hide the textSelection popover
 */
TextSelectionLayerModel.prototype.hidePopover = function() {
	if (this._textSelectionPopover) {
		this.removePopoverModel(this._textSelectionPopover.getID());
		this.removePopover(this._textSelectionPopover.getID());
		this._unregisterListener(this._textSelectionPopoverListener);
		this._textSelectionPopover = null;
	}
};

/**
 * Override the model changed, so the popovermodel is updated when needed.
 * @override
 */
TextSelectionLayerModel.prototype.modelChanged = function() {
	if (this._textSelectionPopover) {
		this._textSelectionPopover.setTextContent(this._textSelectionModel.getContent());
		this._textSelectionPopover.setWorldTextFrames(this._worldTextFrames);
		this._textSelectionPopover.setPopoverLocation(this._textSelectionModel.getEndPoint());
	}
};

/**
 * Set the array of world rects that covers all the selected text area's
 * @param {Array.<ShapeUtils.Rect>} The array of rects that are positioned on the individual text tags
 */
TextSelectionLayerModel.prototype.setWorldTextFrames = function(worldTextFrames) {
	this._worldTextFrames = worldTextFrames;
};

/**
 * Get Popover Model
 * @returns Popover Model
 */
TextSelectionLayerModel.prototype.getPopoverModel = function() {
	return this._textSelectionPopover;
};

export default TextSelectionLayerModel;
