import AbstractModel from "@esko/web-viewer/core/AbstractModel";
import ShapeUtils from "@esko/shapeutils";
/**
 * @exports TextSelectionModel
 * @memberof SvgModule
 * @class The TextSelectionModel is used for representing all text selection tool info
 * @constructor
 * @augments {Core.AbstractModel}
 *
 * @param {Core.ViewerFacade} f - Viewer facade
 * @param {String} privateChannelName - The privateChannelName of the model
 */
var TextSelectionModel = function(f, privateChannelName) {
	AbstractModel.call(this, f, privateChannelName);

	this._startPoint = null;
	this._endPoint = null;
	this._content = "";
};

TextSelectionModel.prototype = Object.create(AbstractModel.prototype);
TextSelectionModel.prototype.constructor = TextSelectionModel;

/**
 * Set the start point.
 * @param {ShapeUtils.Point} startPoint
 */
TextSelectionModel.prototype.setStartPoint = function(startPoint) {
	this._startPoint = startPoint;
};

/**
 * Get the start point.
 * @returns {ShapeUtils.Point} - startPoint
 */
TextSelectionModel.prototype.getStartPoint = function() {
	if (this._startPoint) {
		return this._startPoint;
	} else {
		return new ShapeUtils.Point(0, 0);
	}
};

/**
 * Set the end point.
 * @param {ShapeUtils.Point} endPoint
 */
TextSelectionModel.prototype.setEndPoint = function(endPoint) {
	this._endPoint = endPoint;
};

/**
 * Get the end point.
 * @returns {ShapeUtils.Point} - endPoint
 */
TextSelectionModel.prototype.getEndPoint = function() {
	if (this._endPoint) {
		return this._endPoint;
	} else {
		return new ShapeUtils.Point(0, 0);
	}
};

/**
 * Set the text content.
 * @param {String} content
 */
TextSelectionModel.prototype.setContent = function(content) {
	this._content = content;
};

/**
 * Get the text content
 * @returns {String} - content
 */
TextSelectionModel.prototype.getContent = function() {
	return this._content;
};

export default TextSelectionModel;
