import ViewerUtils from "@esko/web-viewer/utils/ViewerUtils";
import CompareConstants from "@esko/web-viewer/compare/CompareConstants";
/**
 * Handles conversion of coordinates to the correct system.
 * NOTE: At this moment, only CAD coordinate conversions are used
 *
 * @memberof Utils
 * @exports Coordinates
 * @class Coordinates
 * @param {ViewerFacade} f
 */
var Coordinates = function(f) {
	this.f = f;
	this._cadModule = null;
	this._viewportModule = null;
	this._compareModule = null;
};

/**
 * Get the transformed point
 * @param   {ShapeUtils.Point} point     - The point to transform
 * @returns {ShapeUtils.Point} The transformed point
 */
Coordinates.prototype.getTransformedPoint = function(point) {
	if (point) {
		var docController = this.f.getDocumentController();
		var activePage = docController.getActivePage();
		var diffPage = docController.getDifferencePage();
		var cadOverlay = docController.getCadOverlay();

		if (activePage.hasCad() || cadOverlay) {
			// We have CAD
			// get CAD and ViewPort modules
			if (!this._cadModule) {
				this._cadModule = this.f.getModule("cad");
			}
			if (!this._viewportModule) {
				this._viewportModule = this.f.getModule("viewport");
			}
			if (this._cadModule && this._viewportModule) {
				var transformedPoint;
				if (activePage.hasCad()) {
					// CAD as active page
					if (!this._compareModule) {
						this._compareModule = this.f.getModule("compare");
					}

					// Check if we are in diff view or active view
					if (this._compareModule) {
						var diffMode = this._compareModule.getDiffMode();
						if (diffPage && diffPage.hasCad() && diffPage.getCad()) {
							// diff version (= show ref or blinking ref), use diff transform
							// side by side in diff panel takes active transform, this is different than the Java Viewer though, but we don't know the panel of the given point at this point!
							if (diffMode === CompareConstants.diffMode.DIFFVERSION) {
								var diffTransform = this._cadModule.getReferenceTransform();
								if (diffTransform && diffPage.getCad()) {
									transformedPoint = diffTransform.createInverse().transformedPoint(point);

									transformedPoint.y -= diffPage.getCad().getSize().height;
									transformedPoint.y = -transformedPoint.y;
									return transformedPoint;
								}
							}
						}
					}

					// Default active view
					var currentCadModel = this._cadModule.getCurrentPageCadModel();
					if (currentCadModel && currentCadModel.getCad() && activePage.getCad()) {
						var activeOrigin = currentCadModel.getCad().getOrigin();
						transformedPoint = point.copy();
						transformedPoint.x += activeOrigin.x;
						transformedPoint.y -= activeOrigin.y;
						transformedPoint.y -= activePage.getCad().getSize().height;
						transformedPoint.y = -transformedPoint.y;
						return transformedPoint;
					}
				} else {
					// CAD + graphics, use CAD overlay
					var overlayTransform = this._cadModule.getOverlayTransform();
					if (overlayTransform && cadOverlay.getCad()) {
						transformedPoint = overlayTransform.createInverse().transformedPoint(point);
						transformedPoint.y -= cadOverlay.getCad().getSize().height;
						transformedPoint.y = -transformedPoint.y;
						return transformedPoint;
					}
				}
			}
		}
	}
	return point;
};

/**
 * @private
 * Do the calculations
 * @param   {ShapeUtils.Point} point     - The point to transform
 * @returns {ShapeUtils.Point} The transformed point
 */
Coordinates.prototype._calculateTransformedPoint = function(point) {};

export default Coordinates;
