import _ from "underscore";
/**
 * @memberof Utils
 * @exports LineworkPoint
 * @class Describes a linework point and how the linework point is reached from the previous point
 */
var LineworkPoint = function() {
	this.type = -1;
	this.x = 0;
	this.y = 0;

	// the values depend on the type
	this.v1 = 0;
	this.v2 = 0;
	this.v3 = 0;
	this.v4 = 0;
	this.v5 = 0;
};

/**
 * Move to the point, no extra parameters are specified, there is no line between the point and the previous point
 * @param {Number} x
 * @param {Number} y
 */
LineworkPoint.prototype.makeMoveTo = function(x, y) {
	this.type = 0;
	this.x = x;
	this.y = y;
};

/**
 * Makes a straight line to the point
 * @param {Number} x
 * @param {Number} y
 */
LineworkPoint.prototype.makeLineTo = function(x, y) {
	this.type = 1;
	this.x = x;
	this.y = y;
};

/**
 * Makes a bezier curve to the point, it needs two control points to calculate the line between the points
 * @param {Number} x - x-coordinate to move to
 * @param {Number} y - y-coordinate to move to
 * @param {Number} x1 - x-coordinate for the first control point
 * @param {Number} y1 - y-coordinate for the first control point
 * @param {Number} x2 - x-coordinate for the second control point
 * @param {Number} y2 - y-coordinate for the second control point
 */
LineworkPoint.prototype.makeBezier = function(x, y, x1, y1, x2, y2) {
	this.type = 2;
	this.x = x;
	this.y = y;
	this.v1 = x1;
	this.v2 = y1;
	this.v3 = x2;
	this.v4 = y2;
};

/**
 * Makes a curve to the point, it needs extra parameters to define the arc
 * @param {Number} x - x-coordinate to move to
 * @param {Number} y - y-coordinate to move to
 * @param {Number} rx - radius of the circle
 * @param ry - not used
 * @param {Number} angle - Specifies whether the drawing should be counterclockwise or clockwise. true indicates counter-clockwise.
 * @param largeArc - not used
 * @param sweepFlag - not used
 */
LineworkPoint.prototype.makeArc = function(x, y, rx, ry, angle, largeArc, sweepFlag) {
	this.type = 3;
	this.x = x;
	this.y = y;
	this.v1 = rx;
	this.v2 = ry;
	this.v3 = angle;
	this.v4 = largeArc;
	this.v5 = sweepFlag;
};

/**
 * Make a nick
 * @param {Number} x - x-coordinate to move to
 * @param {Number} y - y-coordinate to move to
 * @param {Number} v1 - number of the nick that will get drawn
 * @param {Number} v2 - y-distance for the second point used to draw the nick
 * @param {Number} v3 - x-distance for the second point used to draw the nick
 */
LineworkPoint.prototype.makeNick = function(x, y, v1, v2, v3) {
	this.type = 4;
	this.x = x;
	this.y = y;
	this.v1 = v1;
	this.v2 = v2;
	this.v3 = v3;
};

export default LineworkPoint;
