import AbstractWidget from "@esko/web-viewer/layout/AbstractWidget";
import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import Timestamp from "@esko/web-viewer/video/Timestamp";
import $ from "jquery";
import _ from "underscore";

/**
 * Creates a Keyframe widget that displays miniature icons of certain moments in the video
 *
 * @param {ViewerFacade} f
 * @param {VideoModule} videoModule
 */
var KeyframeWidget = function KeyframeWidget(f, videoModule) {
	AbstractWidget.call(this, f, LayoutConstants.Widget.VIDEO_KEYFRAME);
	this.element = $("<div>", {
		class: "video-keyframe-widget"
	});
	this.setIcon("icon icon-WCR_Video");
	this.f.loadBundle(
		"viewer",
		function() {
			this.setTitle(this.f.t("VideoKeyframeWidgetTitle"));
		},
		this
	);

	videoModule.whenVideoAvailable(
		function(video) {
			this._render(video);
			this._fireResized();
		}.bind(this)
	);
};

KeyframeWidget.prototype = Object.create(AbstractWidget.prototype);
KeyframeWidget.prototype.constructor = KeyframeWidget;
KeyframeWidget.widgetName = LayoutConstants.Widget.VIDEO_KEYFRAME;

/**
 * @override
 */
KeyframeWidget.prototype.setContext = function(context) {
	AbstractWidget.prototype.setContext.call(this, context);
	this.context.append(this.element);
};

/**
 * Render the widget
 */
KeyframeWidget.prototype._render = function(video) {
	this.element.empty();
	var keyframes = this.f.getActivePage().get("keyframes");
	_.each(
		keyframes,
		function(keyframe) {
			var imgWrapper = $("<div>", {
				class: "keyframe",
				on: {
					click: function() {
						video.currentTime = keyframe.timestamp;
					}
				}
			})
				.append(
					$("<img>", {
						class: "keyframe-thumbnail",
						src: keyframe.url
					})
				)
				.append(
					$("<span>", {
						class: "keyframe-timestamp"
					}).append(new Timestamp(keyframe.timestamp).toString())
				);
			this.element.append(imgWrapper);
		}.bind(this)
	);
};

export default KeyframeWidget;
