import Slider from "@esko/slider/Slider";
import SliderConstants from "@esko/slider/SliderConstants";
import $ from "jquery";
import _ from "underscore";
import AnnotationConstants from "@esko/web-viewer/annotation/AnnotationConstants";
var TimelineSlider = function(f, video, videoModule) {
	var fixedValues = function(indicator, value) {
		if (
			this._selectedAnnotation &&
			this._selectedAnnotation.getPermission() !== AnnotationConstants.AccessRight.READ_WRITE &&
			indicator !== 1
		) {
			return [0, 2];
		}
		return [];
	}.bind(this);

	this.module = videoModule;
	this.f = f;

	this._boundOnSelectedAnnotation = function(annotation) {
		this._timelineSlider.element.addClass("video-slider-timeline-selected-annotation");
		this._selectedAnnotation = annotation;
		var currentTime = this._between(video.currentTime, annotation.startTime, annotation.endTime);
		this._timelineSlider.setMode(SliderConstants.Mode.MULTI, {
			values: [annotation.startTime * 1000, currentTime * 1000, annotation.endTime * 1000],
			get fixedValues() {
				return fixedValues();
			},
			keepOrder: true
		});

		// when annotation is selected, remove the loop attribute on the video
		video.loop = false;
		this._timelineSlider.renderMarks([]);
	}.bind(this);

	this._boundOnUnselectAnnotation = function(annotation) {
		this._timelineSlider.element.removeClass("video-slider-timeline-selected-annotation");
		this._selectedAnnotation = null;
		var isLoop = this.f.getOption("PREFERENCES_VIDEO_LOOP") === 1;
		if (isLoop) {
			video.loop = true;
		}
		this._timelineSlider.setMode(SliderConstants.Mode.SINGLE, {
			value: video.currentTime
		});
		this._renderMarks(this._timelineSlider);
	}.bind(this);

	this._boundOnStartEndTimeModified = function(annotation, startModified, endModified) {
		// Prevent any annotation from being larger then the video duration
		if (annotation.startTime > video.duration) {
			annotation.setStartEndTime(video.duration, video.duration);
		} else if (annotation.endTime > video.duration) {
			annotation.setStartEndTime(annotation.startTime, video.duration);
		} else {
			// Update the range slider in case the start/end time changes
			if (annotation === this._selectedAnnotation) {
				var time = this._between(slider.getValues()[1] / 1000, this._selectedAnnotation.startTime, this._selectedAnnotation.endTime);
				this._timelineSlider.setValues([this._selectedAnnotation.startTime * 1000, time * 1000, this._selectedAnnotation.endTime * 1000]);
			}
		}
	}.bind(this);

	this.f.on("annotationModel.annotation.selectedAnnotation", this._boundOnSelectedAnnotation);
	this.f.on("annotationModel.annotation.unselectedAnnotation", this._boundOnUnselectAnnotation);
	this.f.on("Annotation.modified.startEndTime", this._boundOnStartEndTimeModified);

	$(video).on(
		"timeupdate",
		_.throttle(
			function() {
				if (!video.paused && !video.ended) {
					now.text(this._timestr(video.currentTime));
				}
			}.bind(this),
			100
		)
	);

	$(video).on(
		"ended",
		function() {
			if (this._selectedAnnotation && this._selectedAnnotation.startTime !== this._selectedAnnotation.endTime) {
				video.currentTime = this._selectedAnnotation.startTime;
				video.play();
			}
		}.bind(this)
	);

	video.addEventListener(
		"seeking",
		function(e) {
			if (this._selectedAnnotation && !isDragging) {
				// The current time of the video was changed, but we weren't dragging.
				if (
					e.target.currentTime + 0.25 < this._selectedAnnotation.startTime ||
					e.target.currentTime > this._selectedAnnotation.endTime + 0.25
				) {
					// the current time is outside of the selected annotation -> unselect annotations
					this.f.emit("module.annotation.unselectAnnotations");
				} else {
					// the current time is inside the range of the selected annotation -> setValues of slider
					this._timelineSlider.setValues([
						this._selectedAnnotation.startTime * 1000,
						e.target.currentTime * 1000,
						this._selectedAnnotation.endTime * 1000
					]);
				}
			}
		}.bind(this)
	);

	var wasPaused = video.paused || video.ended;
	var isDragging = false;
	var slider = new Slider({
		class: "video-slider-timeline",
		max: video.duration * 1000,
		on: {
			"value.change": function(newValue) {
				video.currentTime = newValue / 1000;
				var nowStr = this._timestr(video.currentTime);
				now.html(nowStr);
			}.bind(this),
			"values.change": function(newValues, i) {
				if (this._selectedAnnotation) {
					this._selectedAnnotation.setStartEndTime(Math.round(newValues[0] * 1000) / 1000000, Math.round(newValues[2] * 1000) / 1000000);
				}
				video.currentTime = Math.round(newValues[i] * 1000) / 1000000;
			}.bind(this),
			"drag.start": function() {
				isDragging = true;

				wasPaused = video.paused || video.ended;
				video.pause();
			}.bind(this),
			"drag.end": function() {
				isDragging = false;
				if (this._selectedAnnotation) {
					var time = this._between(slider.getValues()[1] / 1000, this._selectedAnnotation.startTime, this._selectedAnnotation.endTime);
					video.currentTime = time;
				}
				if (!wasPaused && (!this._selectedAnnotation || this._selectedAnnotation.startTime !== this._selectedAnnotation.endTime)) {
					video.play();
				} else if (this._selectedAnnotation) {
					this._timelineSlider.setValues([this._selectedAnnotation.startTime * 1000, time * 1000, this._selectedAnnotation.endTime * 1000]);
				}
			}.bind(this)
		},
		tooltip: function(mode, value) {
			if (mode === SliderConstants.Mode.MULTI) {
				return this._timestr(value / 1000);
			}
		}.bind(this)
	});

	this._timelineSlider = slider;

	this._renderMarks(slider);
	this._interval = setInterval(
		function() {
			var currentTime = video.currentTime * 1000;
			if (!isDragging) {
				if (this._selectedAnnotation && slider.currentMode === SliderConstants.Mode.MULTI) {
					var values = slider.getValues();
					if (!video.paused) {
						currentTime = this._between(currentTime, values[0], values[2]);
						slider.setValues([values[0], currentTime, values[2]]);
					}
					if (video.currentTime > this._selectedAnnotation.endTime) {
						video.currentTime = this._selectedAnnotation.startTime;
					} else if (video.currentTime < this._selectedAnnotation.startTime) {
						video.currentTime = this._selectedAnnotation.startTime;
					}
				} else if (slider.currentMode === SliderConstants.Mode.SINGLE) {
					if (!video.paused && !video.ended) {
						slider.setValue(currentTime);
					}
				}
			}
		}.bind(this),
		1000 / 60
	);

	var now = $("<strong>", {
		class: "video-timestamp",
		text: "0:00"
	});
	var time = $("<strong>", {
		class: "video-timestamp",
		text: "--:--"
	});

	if (!isNaN(video.duration)) {
		time.html(this._timestr(video.duration));
	}

	this.element = $("<div>", {
		class: "video-slider"
	});
	this.element
		.append(now)
		.append($("<div>", { class: "video-slider-wrapper" }).append(slider.element))
		.append(time);
};

TimelineSlider.prototype.destroy = function() {
	this.f.off("annotationModel.annotation.selectedAnnotation", this._boundOnSelectedAnnotation);
	this.f.off("annotationModel.annotation.unselectedAnnotation", this._boundOnUnselectAnnotation);
	this.f.off("Annotation.modified.startEndTime", this._boundOnStartEndTimeModified);
};

TimelineSlider.prototype._renderMarks = function(slider) {
	this.f.whenModuleAvailable(
		"annotation",
		function(annotationModule) {
			annotationModule.whenAnnotationsAvailableOrChanged(
				function() {
					var annots = annotationModule.annotationModel.getVisibleAnnotations(true);
					var marks = [];
					if (!this._selectedAnnotation) {
						_.each(annots, function(annot) {
							if (annot.startTime !== undefined && annot.endTime !== undefined) {
								marks.push({
									color: annot.annotationcolor,
									start: annot.startTime * 1000,
									end: annot.endTime * 1000
								});
							}
						});
					}
					slider.renderMarks(marks);
				}.bind(this)
			);
		}.bind(this)
	);
};

/**
 * Generates a string from a given number of seconds
 *
 * @param {Number} num time in seconds
 * @returns formatted time string
 */
TimelineSlider.prototype._timestr = function(num) {
	var h = Math.floor(num / 3600);
	var m = Math.floor(num / 60);
	var s = Math.round(num % 60);
	var durStr = (h > 0 ? h + ":" : "") + (m < 10 && h > 0 ? "0" : "") + m + ":" + (s < 10 ? "0" : "") + s;
	return durStr;
};

TimelineSlider.prototype._between = function(value, min, max) {
	if (value < min) {
		return min;
	} else if (value > max) {
		return max;
	}
	return value;
};

export default TimelineSlider;
