import CompareConstants from "@esko/web-viewer/compare/CompareConstants";
import LayoutConstants from "@esko/web-viewer/layout/LayoutConstants";
import LayoutMode from "@esko/web-viewer/layout/LayoutMode";
/**
 * @exports Compare3DMode
 * @memberof Layout
 * @class
 * Mode that is used to Compare two 3D widgets
 * @constructor
 * @augments LayoutMode
 * @param {Core.ViewerFacade} f
 * @param {Layout} layout
 */
var Compare3DMode = function(f, layout) {
	LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.COMPARE_3D);

	this._mainPanelContents = {};
	this._mainPanelContents[CompareConstants.diffMode.SHOW3DSIDEBYSIDE] = [
		LayoutConstants.Widget.VIEW3D,
		LayoutConstants.Widget.VIEW3D_COMPARE
	];
	this._mainPanelContents[CompareConstants.diffMode.SHOWCURRENT3D] = [LayoutConstants.Widget.VIEW3D];
	this._mainPanelContents[CompareConstants.diffMode.SHOWDIFFERENCE3D] = [LayoutConstants.Widget.VIEW3D_COMPARE];

	// This is here for blinking compare. Blinking compare switches from current diffmode to reference diffmode.
	this.f.on(
		"module.compare.changed.diffMode",
		function(oldMode, newMode) {
			if (this.isActive() && newMode !== CompareConstants.diffMode.UNDEFINED) {
				this._emit("changed");
			}
		}.bind(this)
	);
};

Compare3DMode.prototype = new LayoutMode();
Compare3DMode.prototype.constructor = Compare3DMode;

/**
 * Turns On/Off the layoutMode
 * @param {Boolean} toggle
 */
Compare3DMode.prototype.toggle = function(toggle) {
	if (toggle === undefined) {
		toggle = !this._isActive;
	}
	this._isActive = toggle;
};

/**
 * Checks if the item is allowed for this layout mode. Prevents channels and CAD widget from loading.
 *
 * @param {String} itemname
 * @returns {Boolean}
 */
Compare3DMode.prototype.isItemAllowed = function(itemname) {
	if (itemname === LayoutConstants.Widget.VIEW3D_COMPARE || itemname === LayoutConstants.Widget.VIEW3D) {
		var compareModule = this.f.getModule("compare");
		if (compareModule) {
			var mainPanelContent = this._mainPanelContents[compareModule.getDiffMode()];
			if (mainPanelContent) {
				return mainPanelContent.indexOf(itemname) !== -1;
			}
		}
		return false;
	}

	return (
		itemname === LayoutConstants.Widget.COMPARE ||
		itemname === LayoutConstants.ToolbarComponent.APPROVAL ||
		itemname === LayoutConstants.Widget.APPROVAL ||
		itemname === LayoutConstants.Widget.MESSAGE ||
		itemname === LayoutConstants.Widget.DISCUSSION ||
		itemname === LayoutConstants.ToolbarComponent.VIEW3D ||
		itemname === LayoutConstants.ToolbarComponent.DOCUMENTSELECTOR ||
		itemname === LayoutConstants.ToolbarComponent.COMPARE ||
		itemname === LayoutConstants.Widget.ATTRIBUTE_CATEGORY
	);
};

/**
 * We want the 3D widget as Main Content
 * @override
 */
Compare3DMode.prototype.getMainPanelContent = function() {
	var compareModule = this.f.getModule("compare");
	if (compareModule) {
		return this._mainPanelContents[compareModule.getDiffMode()] || [];
	}
	return [];
};

export default Compare3DMode;
