import DropdownToolbarButton from "@esko/web-viewer/layout/component/DropdownToolbarButton";
import ViewControlsConstants from "@esko/web-viewer/viewControls/ViewControlsConstants";
import ListenerUtil from "@esko/web-viewer/utils/ListenerUtil";
import _ from "underscore";

var TrimboxClippingDropdownToolbarButton = function(f, name) {
	DropdownToolbarButton.call(this, f, name, "trimboxClipping", false, _.bind(this._toggleClipping, this));
	ListenerUtil.mixin(this, f);

	this.f.loadBundle(
		"viewer",
		function() {
			// clip when in readerspread
			this.addOption({
				name: "CLIP_IN_READERSPREAD",
				content: this.f.i18n.t("ToolMarginsClipSpread"),
				onchange: _.bind(function() {
					//same as the 'only distortion'-option but for compensate scaling
					this.f.setOption("PREFERENCES_MARGIN_CLIP_MODE", ViewControlsConstants.marginClipMode.CLIP_IN_READERSPREAD);
				}, this),
				userCannotUncheck: true
			});

			// clip always
			this.addOption({
				name: "CLIP",
				content: this.f.i18n.t("ToolMarginsClipOn"),
				onchange: _.bind(function() {
					//same as the 'only distortion'-option but for compensate scaling
					this.f.setOption("PREFERENCES_MARGIN_CLIP_MODE", ViewControlsConstants.marginClipMode.CLIP);
				}, this),
				userCannotUncheck: true
			});

			this._registerListener("options.changed.PREFERENCES_MARGIN_CLIP_MODE", this.update, this, this.f.getCurrentUser());
			this.update();
		},
		this
	);
};

// inherit
TrimboxClippingDropdownToolbarButton.prototype = Object.create(DropdownToolbarButton.prototype);
TrimboxClippingDropdownToolbarButton.prototype.constructor = TrimboxClippingDropdownToolbarButton;

/**
 * Toggle the button
 */
TrimboxClippingDropdownToolbarButton.prototype._toggleClipping = function() {
	if (!this._isClipping()) {
		// enable clipping
		if (this.f.getActivePage().isReaderSpread()) {
			this.f.setOption("PREFERENCES_MARGIN_CLIP_MODE", ViewControlsConstants.marginClipMode.CLIP_IN_READERSPREAD);
		} else {
			this.f.setOption("PREFERENCES_MARGIN_CLIP_MODE", ViewControlsConstants.marginClipMode.CLIP);
		}
	} else {
		this.f.setOption("PREFERENCES_MARGIN_CLIP_MODE", ViewControlsConstants.marginClipMode.CLIP_OFF);
	}
};

/**
 * Update the display of the button
 */
TrimboxClippingDropdownToolbarButton.prototype.update = function() {
	// only update if language bundle is avaialble
	this.f.loadBundle(
		"viewer",
		function() {
			var clippingMode = this.f.getOption("PREFERENCES_MARGIN_CLIP_MODE");
			if (this.f.getActivePage().hasGraphics()) {
				this.show();

				this.setActive(this._isClipping());
				this.toggleOption("CLIP_IN_READERSPREAD", clippingMode === ViewControlsConstants.marginClipMode.CLIP_IN_READERSPREAD);
				this.toggleOption("CLIP", clippingMode === ViewControlsConstants.marginClipMode.CLIP);
			} else {
				this.hide();
			}
		},
		this
	);
};

/**
 * Check if margin clipping is currently enabled
 * @returns {Boolean}
 */
TrimboxClippingDropdownToolbarButton.prototype._isClipping = function() {
	var clippingMode = this.f.getOption("PREFERENCES_MARGIN_CLIP_MODE");
	return (
		clippingMode === ViewControlsConstants.marginClipMode.CLIP ||
		(clippingMode === ViewControlsConstants.marginClipMode.CLIP_IN_READERSPREAD && this.f.getActivePage().isReaderSpread())
	);
};
export default TrimboxClippingDropdownToolbarButton;
