import ViewportLayer from "@esko/web-viewer/viewport/ViewportLayer";
import $ from "jquery";
import _ from "underscore";
/**
 * This class is responsible for drawing a 3D model on the viewport.
 * It makes sure that whenever annotation interaction is required that it will square the 3d viewport in order to
 * keep the world on exactly the same place as the viewer.
 *
 */
var Viewport3DLayer = function() {
	ViewportLayer.apply(this, arguments);

	this._container = $("<div>").addClass("viewport-3D-layer-container");

	this._whenActivePageChanged = function() {
		this.render();
	}.bind(this);

	this.f.getDocumentController().whenActivePageChanged(this._whenActivePageChanged);
};

Viewport3DLayer.prototype = Object.create(ViewportLayer.prototype);
Viewport3DLayer.prototype.constructor = Viewport3DLayer;

Viewport3DLayer.prototype.setLayerModel = function(layerModel) {
	ViewportLayer.prototype.setLayerModel.call(this, layerModel);

	this.f.whenModuleAvailable("view3D", () => {
		if (this.init) {
			this.render();
		}
	});
};

/**
 * Render the widget.
 *
 * Highjack content of View3DWidget and put it in our container
 */
Viewport3DLayer.prototype.render = function() {
	var view3DModule = this.f.getModule("view3D");
	if (!this.init && this.f.getActivePage().is3D() && view3DModule) {
		this.init = true;
		var callback = function() {
			this._widget = view3DModule.get3DWidget();
			this._widget.when3DContentAvailable(function() {
				if (!this._destroyed) {
					this._container.append(this._widget.get3DContent().children());
				}
			}, this);
		}.bind(this);

		// Check if 3d widget is already loaded
		if (view3DModule.get3DWidget() != null) {
			callback();
		} else {
			view3DModule.show3D();
			view3DModule.once("3Dstarted", callback);
		}
	}
};

/**
 * Restore the content of our container back to the original View3DWidget container,
 * and remove other remaining elements
 */
Viewport3DLayer.prototype.destroy = function() {
	ViewportLayer.prototype.destroy.call(this);
	this.f.getDocumentController().off("page.active", this._whenActivePageChanged);
	if (this.init && this._widget) {
		this._widget.get3DContent().append(this._container.children());
	}
	this._destroyed = true;
	this._container.remove();
	this._widget = null;
};

Viewport3DLayer.prototype.getLayerElement = function() {
	return this._container;
};

Viewport3DLayer.prototype.setSize = _.debounce(function(dim) {
	if (this.init) {
		// Update world transformation to make sure annotation follows size of 3d viewer
		this._world.zoomToFitHeight();

		// Update 3d viewer viewport
		if (this._widget) {
			this._widget.resized();
		}
	}
}, 50);

export default Viewport3DLayer;
