import _ from "underscore";
import PrivateChannel from "@esko/web-viewer/core/PrivateChannel";
import Coordinates from "@esko/web-viewer/utils/Coordinates";
/**
 * @exports ViewportPopoverModel
 * @memberof ViewportModule
 * @class
 * A popover model is an abstract model for adding popovers to the viewport
 * It provides the content for the popover, the preferred position of the popover, etc.
 */
var ViewportPopoverModel = function(f, IID) {
	PrivateChannel.installTo(this, f, ["popoverModel", IID]);
	this.f = f;

	/**
	 * {Coordinates} - util for coordinate conversion
	 */
	this._coordinates = new Coordinates(this.f);

	/**
	 * @returns the unique internal id of the popover
	 */
	this.getID = function() {
		return IID;
	};

	/**
	 * @returns {ShapeUtils.Rect} the frame to which the popover is attached within the viewport
	 */
	this.getFrame = function() {
		return null;
	};

	/**
	 * @returns {JQueryObj} jquery object that represents the content of the popover
	 */
	this.getContent = function() {
		return null;
	};

	/**
	 * This function will be executed when the popover is added to the container
	 * Useful for doing things after it is added to the DOM
	 */
	this.onAddedToContainer = function() {
		// override
	};

	/**
	 * This function will be executed just before the popover is destroyed
	 * Useful for cleaning up
	 */
	this.onDestroy = function() {
		// override
	};

	/**
	 * Get the preferred position of the popover
	 */
	this.getPreferredPosition = function() {
		// override
		return "left";
	};

	/**
	 * Get the preferred restrict border for the restricting element
	 */
	this.getRestrictBorder = function() {
		return undefined;
	};

	/**
	 * Get the context for the popover
	 */
	this.getContext = function() {
		return f.getContext();
	};

	/**
	 * Get the class for the popover
	 */
	this.getClass = function() {
		//override
	};

	/**
	 * Is this an interactive popover?
	 * @returns {Boolean} false
	 */
	this.isInteractive = function() {
		return false;
	};
};
export default ViewportPopoverModel;
