import XDrop from "@esko/xdrop/XDrop";
import LabelRenderer from "@esko/xdrop/renderers/LabelRenderer";
import MultiSelectXDropDisplay from "@esko/xdrop/display/MultiSelectXDropDisplay";
import XDropPanel from "@esko/xdrop/panel/XDropPanel";
import MultiSelectToggleController from "@esko/xdrop/controllers/MultiSelectToggleController";
import Observer from "@esko/observer";
import Observable from "@esko/observable";
import _ from "underscore";
/**
 * MultiSelectXDrop - XDrop with a tokennized representations of the results
 *
 * @class
 * @augments XDrop
 *
 * @param {object} options	- extra options
 *                          {
 *                          [maxHeight] - the maximum height of the XDrop input field,
 *                          openOnFocus : true - if true, opens the XDrop when the input field has focus,
 *                          label - Label is shown in the input
 *                          }
 */
var MultiSelectXDrop = function(dataProvider, renderFactories, options, panelOptions) {
	Observable.mixin(this, "XDrop");
	Observer.mixin(this);

	options = _.extend(
		{
			openOnFocus: true
		},
		options
	);

	panelOptions = _.extend(
		{
			multiSelect: true
		},
		panelOptions
	);

	XDrop.call(this, dataProvider, renderFactories, options, panelOptions);

	if (!this._options.isMobile) {
		this.setShowFilterField(false);
	}
};

MultiSelectXDrop.prototype = Object.create(XDrop.prototype);
MultiSelectXDrop.prototype.constructor = MultiSelectXDrop;

/**
 * Init
 */
MultiSelectXDrop.prototype._init = function(dataProvider, renderFactories, options, panelOptions) {
	this._panel = new XDropPanel(dataProvider, renderFactories, panelOptions);
	this._display = new MultiSelectXDropDisplay(renderFactories, this._panel, options);
	this._toggleController = new MultiSelectToggleController(this._display, this._panel, options);
};

/**
 * @override
 */
MultiSelectXDrop.prototype.getValue = function() {
	return this._panel.getValue();
};

/* 
 * Deselects the given ResultEntry
 * (wrapper around the XDrop Renderer API)
 * @param {ResultEntry} resultEntry
 */
MultiSelectXDrop.prototype.deselectResultEntry = function(resultEntry) {
	this._panel.getRenderAPI().deselectResultEntry(resultEntry);
};

/**
 * Renders the Xdrop in a loading state (e.g. when retrieving the selected values takes some time)
 * @param {Boolean} isLoading
 * @param {String} placeholder
 */
MultiSelectXDrop.prototype.loading = function(isLoading, placeholder) {
	this._display.loading(isLoading, placeholder);
};

export default MultiSelectXDrop;
