import ToggleController from "./ToggleController";
/**
 * @augments ToggleController
 * Toggle Controller that handles multiselect xdrops
 * @param {MultiSelectXDropDisplay} xDropDisplay
 * @param {XDropPanel} xDropPanel
 * @param {Object} options
 */
var MultiSelectToggleController = function(xDropDisplay, xDropPanel, options) {
	ToggleController.call(this, xDropDisplay, xDropPanel, options);

	//Open XDrop and focus input when dropdown is clicked
	this._toggleButton.on(
		"mousedown",
		function(e) {
			e.preventDefault(); //Prevents focus event on this._display, which would close the xdrop again
			if (this.isOpen()) {
				this._display.focusInput();
			}
		}.bind(this)
	);

	this._observe(this._display, "focus", function() {
		if (this._options.openOnFocus) {
			if (!this.isOpen()) {
				this.toggle(true);
			}
		}
	});

	this._observe(
		this._display,
		"open",
		function() {
			if (!this.isOpen()) {
				this.toggle(true);
			}
		}.bind(this)
	);

	this._observe(this._display, "input", function() {
		if (!this.isOpen()) {
			this.toggle(true);
		}
	});

	this._observe(this._display, "keydown", function(event) {
		if (event.keyCode === 40 && !this.isOpen()) {
			this.toggle(true);
			event.preventDefault();
		}
	});
};

MultiSelectToggleController.prototype = Object.create(ToggleController.prototype);
MultiSelectToggleController.prototype.constructor = MultiSelectToggleController;

/**
 * @override
 */
MultiSelectToggleController.prototype._init = function() {
	var element = this._display.getElement();
	element.on("focus", this.toggle.bind(this, true));
	if (this._options.showToggleButton) {
		element.append(this._toggleButton);
	}
};

export default MultiSelectToggleController;
