import CompositeDataProvider from "@esko/xdrop/dataproviders/CompositeDataProvider";
import ResultEntry from "@esko/xdrop/dataproviders/ResultEntry";
import _ from "underscore";
/**
 * An Accordion Category DataProvider takes multiple category dataproviders and only allows one of them to be open at any time
 *
 * @class
 * @augments CompositeDataProvider
 * @mixes Observer
 * @param {Object} options
 * @param {XDropDataProvider...,Array.<XDropDataProvider>} dataproviders - list of data provider, currently all of these should be "CategoryDataProvider's".
 */
var AccordionCategoryDataProvider = function(dataproviders) {
	CompositeDataProvider.apply(this, arguments);

	// Register listeners...
	_.each(
		this._providers,
		function(providerEntry) {
			providerEntry.provider.on("change.expand", _.bind(this._collapseOthers, this, providerEntry));
		},
		this
	);
};

AccordionCategoryDataProvider.prototype = Object.create(CompositeDataProvider.prototype);
AccordionCategoryDataProvider.prototype.constructor = AccordionCategoryDataProvider;

/**
 * Collapse all the other CategoryDataProviders
 * @param expandedProvider
 */
AccordionCategoryDataProvider.prototype._collapseOthers = function(expandedProvider) {
	_.each(
		this._providers,
		function(providerEntry) {
			if (providerEntry !== expandedProvider) {
				providerEntry.provider.setCollapsed(true);
			}
		},
		this
	);
};

export default AccordionCategoryDataProvider;
