import XDropDataProvider from "./XDropDataProvider";
import ResultEntry from "./ResultEntry";
import _ from "underscore";
/**
 * An ArrayDataProvider is an XDropDataProvider working with a fixed javascript array of values.
 * @class
 *
 * @param {Object} options - some additional options (like the filterfunc function)
 * @param {Array} values - an array of objects. By default a String, or an object with getLabel() is supported. If not one of those you need to pass the filterfunc.
 */
var ArrayDataProvider = function ArrayDataProvider(options, values) {
	XDropDataProvider.call(
		this,
		_.extend(
			{
				filterfunc: function(data, query) {
					var label = "";
					if (data.getLabel) {
						label = data.getLabel();
					} else if (_.isString(data)) {
						label = data;
					}
					return label.toLowerCase().match(query.toLowerCase());
				}
			},
			options
		)
	);
	this._entries = [];
	_.each(
		values,
		function(val) {
			this._entries.push(new ResultEntry("label", val));
		},
		this
	);
	this._filterfunc = this._options.filterfunc;
};
ArrayDataProvider.prototype = Object.create(XDropDataProvider.prototype);
ArrayDataProvider.prototype.constructor = ArrayDataProvider;

/**
 * Called on first initialization
 */
ArrayDataProvider.prototype._initialize = function() {
	this._updateResults();
};

/**
 * Update the results in the data provider...
 */
ArrayDataProvider.prototype._updateResults = function() {
	this._resultSet.clear();
	_.each(
		this._entries,
		function(entry) {
			if (this._maxResults === -1 || this._resultSet.getSize() < this._maxResults) {
				if (!this._query || this._filterfunc(entry.getData(), this._query)) {
					this._resultSet.append(entry);
				}
			}
		},
		this
	);
	this._resultSet.commitChanges();
};

/**
 * Filter the results of the dataprovider
 * !WARNING! This call is not throttled: to improve performance you should throttle the handling of changing the query
 * @param {String} queryString
 */
ArrayDataProvider.prototype.setQuery = function(queryString) {
	this._query = queryString;
	this._updateResults();
};

/**
 * Limit the number of results returned by the dataprovider
 *
 * @param {Number} maxResults - if maxResults = -1 --> no limit
 */
ArrayDataProvider.prototype.setMaxResults = function(maxResults) {
	this._maxResults = maxResults;
	this._updateResults();
};

export default ArrayDataProvider;
