import CompositeDataProvider from "@esko/xdrop/dataproviders/CompositeDataProvider";
import _ from "underscore";
/**
 * This dataprovider can be used to blacklist certain result entries from the result set.
 */
var BlacklistDataProvider = function(dataproviders, blacklist) {
	CompositeDataProvider.call(this, dataproviders);
	this._blacklist = blacklist ? blacklist.slice() : [];
};

BlacklistDataProvider.prototype = Object.create(CompositeDataProvider.prototype);
BlacklistDataProvider.prototype.constructor = BlacklistDataProvider;

/**
 * returns the list of the composed data providers minus the blacklisted entries
 * @private
 * @returns {Array.<ResultEntry>}
 */
BlacklistDataProvider.prototype._generateResultList = function() {
	var resultEntries = CompositeDataProvider.prototype._generateResultList.call(this);
	return _.filter(
		resultEntries,
		function(entry) {
			return !_.find(this._blacklist, function(blacklistedEntry) {
				return entry.equals(blacklistedEntry);
			});
		}.bind(this)
	);
};

/**
 * Adds a result entry to the list of blacklisted entries
 * @param {ResultEntry} entry - entry to blacklist. The entry is blacklisted based on the equals function of the entry
 */
BlacklistDataProvider.prototype.addBlacklistedEntry = function(entry) {
	this._blacklist.push(entry);
	this._updateResultSet();
};

/**
 * @param {ResultEntry} entry to remove from blacklisted entries. The entry is removed based on the equals method of the entry
 */
BlacklistDataProvider.prototype.removeBlacklistedEntry = function(blacklistedEntry) {
	this._blacklist = _.filter(this._blacklist, function(entry) {
		return !entry.equals(blacklistedEntry);
	});
	this._updateResultSet();
};

export default BlacklistDataProvider;
