import XDropDataProvider from "@esko/xdrop/dataproviders/XDropDataProvider";
import ResultEntry from "@esko/xdrop/dataproviders/ResultEntry";
/**
 * Make a DataProvider from an object and a renderer name.
 * The object should probably be the "model" part of an MVC pattern => so most likely Observable.
 * The row will always be shown and is not filtered!
 *
 * Useful for for example adding a row with a complex component.
 *
 * @class ComponentEntryDataProvider
 * @augments XDropDataProvider
 *
 * @param {String} renderername - the name of the renderer to use (Can be the "view" part of the MVC pattern)
 * @param {Object} objects - an objects. (Can be the "model" part of an MVC pattern)
 */
var ComponentEntryDataProvider = function(renderername, model) {
	XDropDataProvider.call(this);

	this._entry = new ResultEntry(renderername, model);
	this._entry.setAllowSelection(false);

	this._resultSet.clear();
	this._resultSet.append(this._entry);
	this._resultSet.commitChanges();
};

// Inherit from XDropDataProvider
ComponentEntryDataProvider.prototype = Object.create(XDropDataProvider.prototype);
ComponentEntryDataProvider.prototype.constructor = ComponentEntryDataProvider;

/**
 * Limit the number of results returned by the dataprovider
 *
 * @param {Number} maxResults - if maxResults = -1 --> no limit
 * @override
 */
ComponentEntryDataProvider.prototype.setMaxResults = function(maxResults) {
	this._maxResults = maxResults;
	this._resultSet.clear();
	if (this._maxResults === -1 || this._maxResults >= 1) {
		this._resultSet.append(this._entry);
	}
	this._resultSet.commitChanges();
};

/**
 * @override
 */
ComponentEntryDataProvider.prototype.setQuery = function(queryString) {
	// Not implemented
};

export default ComponentEntryDataProvider;
