import CompositeDataProvider from "@esko/xdrop/dataproviders/CompositeDataProvider";
import ResultEntry from "@esko/xdrop/dataproviders/ResultEntry";
import _ from "underscore";
/**
 * A Simple dataprovider which is a composite and applies a filter to the results of the composite providers
 *
 * @class
 * @augments CompositeDataProvider
 * @mixes Observer
 * @param {XDropDataProvider...,Array.<XDropDataProvider>} dataproviders - list of data provider
 */
var FilterDataProvider = function(options, dataproviders) {
	CompositeDataProvider.apply(this, _.rest(arguments));

	this._options = _.extend(
		{
			filter: function(entry) {
				return true;
			}
		},
		options
	);
};

FilterDataProvider.prototype = Object.create(CompositeDataProvider.prototype);
FilterDataProvider.prototype.constructor = FilterDataProvider;

/**
 * Compose the merged results of the sub dataproviders
 * @override
 */
FilterDataProvider.prototype._generateResultList = function() {
	var result = [];

	_.each(
		this._providers,
		function(providerEntry) {
			_.each(
				providerEntry.provider.getResultSet().getEntriesImmutable(),
				function(entry) {
					if (this._options.filter(entry)) {
						result.push(entry);
					}
				},
				this
			);
		},
		this
	);

	return result;
};

export default FilterDataProvider;
