import CompositeDataProvider from "@esko/xdrop/dataproviders/CompositeDataProvider";
import ResultEntry from "@esko/xdrop/dataproviders/ResultEntry";
import _ from "underscore";
/**
 * A SeparatorCompositeDataProvider
 *
 * @class
 * @augments CompositeDataProvider
 * @mixes Observer
 * @param {XDropDataProvider...,Array.<XDropDataProvider>} dataproviders - list of data provider
 */
var SeparatorCompositeDataProvider = function(dataproviders) {
	CompositeDataProvider.apply(this, arguments);
};

SeparatorCompositeDataProvider.prototype = Object.create(CompositeDataProvider.prototype);
SeparatorCompositeDataProvider.prototype.constructor = SeparatorCompositeDataProvider;

/**
 * Compose the merged results of the sub dataprovider
 * @private
 * @returns {Array.<ResultEntry>}
 */
SeparatorCompositeDataProvider.prototype._generateResultList = function() {
	return _.reduce(
		_.map(this._providers, function(providerEntry) {
			return providerEntry.provider.getResultSet().getEntriesImmutable();
		}),
		function(memo, entry) {
			if (memo.length === 0) {
				// First list in the list
				return entry;
			} else {
				// We already have some entries...
				if (entry.length > 0) {
					// And there are also entries in this list
					// So, add a separator + the new values
					var separatorEntry = new ResultEntry("separator", null);
					separatorEntry.setAllowSelection(false);
					return memo.concat([separatorEntry]).concat(entry);
				} else {
					// No values in this list...
					// Don't add a separator and just continue...
					return memo;
				}
			}
		},
		[]
	);
};

export default SeparatorCompositeDataProvider;
