import CompositeDataProvider from "./CompositeDataProvider";
import _ from "underscore";
var SortedCompositeDataProvider = function(options, dataproviders) {
	CompositeDataProvider.apply(this, _.rest(arguments));

	this._options = _.extend(
		{
			sortBy: function(a) {
				return a.getData();
			},
			removeDuplicates: false,
			equals: function(a, b) {
				return a.getData() === b.getData();
			},

			postProcess: null
		},
		options
	);
};

SortedCompositeDataProvider.prototype = Object.create(CompositeDataProvider.prototype);
SortedCompositeDataProvider.prototype.constructor = SortedCompositeDataProvider;

SortedCompositeDataProvider.prototype._generateResultList = function() {
	var resultList = _.reduce(
		this._providers,
		function(results, providerEntry) {
			var providerEntries = providerEntry.provider.getResultSet().getEntriesImmutable();

			_.each(
				providerEntries,
				function(entry) {
					if (
						!this._options.removeDuplicates ||
						!_.find(
							results,
							function(otherEntry) {
								return this._options.equals(entry, otherEntry);
							},
							this
						)
					) {
						results.push(entry);
					}
				},
				this
			);

			return results;
		},
		[],
		this
	);

	if (this._options.postProcess) {
		resultList = this._options.postProcess(resultList);
	}

	return _.sortBy(resultList, this._options.sortBy);
};

export default SortedCompositeDataProvider;
