import $ from "jquery";
import Observable from "@esko/observable";
import _ from "underscore";
/**
 * A static display for XDrop.
 *
 * @param {jQueryElement} element - the element to attach the XDrop to...
 * @param {Object.<Renderer>} renderers
 * @param {XDropPanel} xDropPanel
 * @param {Object} options
 */
var StaticElementXDropDisplay = function(element, renderers, xDropPanel, options) {
	Observable.mixin(this, "XDropDisplay");
	this._options = _.extend(
		{
			isMobile: false
		},
		options
	);

	/**
	 * @member {XDropPanel}
	 * @private
	 */
	this._panel = xDropPanel;

	/**
	 * Used to create renderers for resultentries
	 *  we can provide some default renderers
	 */
	this._renderFactories = renderers;

	/**
	 * Main element of the XDrop - just some div
	 */
	this._element = element;
};

/**
 * Get the main element of the XDrop
 * @returns {JQueryObj}
 */
StaticElementXDropDisplay.prototype.getElement = function() {
	return this._element;
};

/**
 * Enable or disable the XDrop
 *
 * @param disabled
 */
StaticElementXDropDisplay.prototype.toggleEnabled = function(enabled) {
	this._disabled = !enabled;
	if (!enabled) {
		this._emit("disabled");
	}
};

/**
 * Whether or not the dispaly is enabled
 */
StaticElementXDropDisplay.prototype.isEnabled = function() {
	return !this._disabled;
};

/**
 * Call to destroy the XDrop
 */
StaticElementXDropDisplay.prototype.destroy = function() {};

export default StaticElementXDropDisplay;
