import XDropRelativePanelWrapper from "./XDropRelativePanelWrapper";
import $ from "jquery";
import _ from "underscore";
/**
 * Absolutely positioned xdroppanel wrapper
 *
 * @class
 * @augments XDropPanelWrapper
 * @param {XDropPanel} xdropPanel
 * @param {Object} options
 * @param {Function} toggleCallback
 */
var XDropAbsolutePanelWrapper = function(xdropPanel, options) {
	options = _.defaults(options, {
		offsetParent: $("body"),
		borderOffsetTop: 15,
		borderOffsetBottom: 15
	});
	Array.prototype.splice.call(arguments, 1, 1, options);
	XDropRelativePanelWrapper.apply(this, arguments);
	this._boundOnDocumentClick = this._onDocumentClick.bind(this);
};

XDropAbsolutePanelWrapper.prototype = Object.create(XDropRelativePanelWrapper.prototype);
XDropAbsolutePanelWrapper.prototype.constructor = XDropAbsolutePanelWrapper;

/**
 * @override
 */
XDropAbsolutePanelWrapper.prototype.addToDOM = function(container) {
	XDropRelativePanelWrapper.prototype.addToDOM.apply(this, arguments);

	$(this._options.offsetParent).append(this._element);
};

/**
 * @override
 */
XDropAbsolutePanelWrapper.prototype._updatePosition = function(isOpen) {
	if (isOpen) {
		// when doing absolute positioning, we need to set the correct position of the dropdown

		var position = this._getXDropPosition();
		var parentsOffset = this._options.offsetParent.offset();
		var offsetParentBoundingClientRect = this._options.offsetParent[0].getBoundingClientRect();
		var offset = this._container.offset();
		offset.left = offset.left - parentsOffset.left;
		offset.top = offset.top - parentsOffset.top;

		// Handle left/right dropdown alignment...
		var dropdownAlign = this._options.dropdownAlign;
		if (dropdownAlign === "auto") {
			dropdownAlign = offsetParentBoundingClientRect.width - offset.left < this._options.dropdownAutoAlignMinSpace ? "right" : "left";
		}
		if (dropdownAlign === "right") {
			offset.right = offsetParentBoundingClientRect.width - offset.left - (this._container.outerWidth() || null);
		}

		var windowHeight = window.innerHeight;
		position.spaceBelow = position.spaceBelow - Math.max(windowHeight - offsetParentBoundingClientRect.bottom, 0);
		position.spaceAbove = position.spaceAbove - Math.max(offsetParentBoundingClientRect.top, 0);

		var maxHeight,
			height = "";
		var top, bottom;
		var above = false;

		if (position.spaceBelow < this._options.preferredMinPanelHeight && position.spaceAbove >= this._options.preferredMinPanelHeight) {
			// show above
			above = true;
			maxHeight = position.spaceAbove;

			if (position.clientRect.bottom > window.innerHeight) {
				// make sure we don't keep growing in the upwards direction
				maxHeight = this._currentMaxHeight;
			} else {
				this._currentMaxHeight = maxHeight;
			}

			maxHeight = maxHeight - this._options.borderOffsetTop + "px";

			top = "auto";
			bottom = (this._options.offsetParent.innerHeight() || null) - offset.top + "px"; //offset.top; // should be top as well...
		} else {
			maxHeight = position.spaceBelow - this._options.borderOffsetBottom + "px";
			top = offset.top + position.clientRect.height - 1 + "px";
			bottom = "auto";
		}

		this._element
			.css({
				top: top,
				left: dropdownAlign !== "right" ? offset.left : "auto",
				right: dropdownAlign === "right" ? offset.right : "auto",
				bottom: bottom,
				width: dropdownAlign === "fit" ? this._container.outerWidth() || null : "",
				height: height,
				"max-height": maxHeight
			})
			.toggleClass("above", above);
	}
};

export default XDropAbsolutePanelWrapper;
