import Modal from "@esko/modal";
import XDropPanelWrapper from "./XDropPanelWrapper";
import $ from "jquery";
/**
 * Displays xdroppanel in a modal window (i.e. for mobile)
 *
 * @class
 * @augments XDropPanelWrapper
 * @param {XDropPanel} xdropPanel
 * @param {Object} options
 * @param {Function} toggleCallback
 */
var XDropModalPanelWrapper = function(xdropPanel, options) {
	XDropPanelWrapper.apply(this, arguments);

	this._element.removeClass("absolute").addClass("modalWrapper");
	this._repositionOnResize(true);
};

XDropModalPanelWrapper.prototype = Object.create(XDropPanelWrapper.prototype);
XDropModalPanelWrapper.prototype.constructor = XDropModalPanelWrapper;

/**
 * @override Update the position/sizing of the modal
 */
XDropModalPanelWrapper.prototype._updatePosition = function(isOpen) {
	if (isOpen && !this._modal) {
		this._initModal();
	}

	if (isOpen) {
		if (!this._modalOpen) {
			$(":focus").trigger("blur");
			setTimeout(
				function() {
					this._modal.open();
					this._modalOpen = true;
					var header = this._modal.getJQElement().find(".modal-header");
					header.addClass("clearfix");
					var headerHeight = header.outerHeight() || null;
					this._element.css({
						"max-height": window.innerHeight - headerHeight - 40 + "px",
						"max-width": "100vh"
					});
				}.bind(this),
				0
			);
		}
	} else if (this._modal) {
		if (this._modalOpen) {
			this._modal.close();
			this._element.detach();
			this._modal.destroy();
			this._modal = null;
			this._modalOpen = false;
		}
	}
};

/**
 * Initialize the Modal component
 */
XDropModalPanelWrapper.prototype._initModal = function() {
	this._modal = new Modal(this._element, {
		animate: false,
		closeOnBackdropClick: false,
		autoFocus: $("body.mobile").length === 0
	});

	this._modal.setTitle(this._options.modalTitle || this._options.placeholder);

	var self = this;
	this._modal.onOpen(function() {
		setTimeout(function() {
			self._modal.getJQElement()[0].scrollIntoView();
		}, 50);
	});
	this._modal.onClose(function() {
		setTimeout(function() {
			self._toggleCallback(false);
		}, 10);
	});
};

/**
 * Also destroy the modal on destroy
 */
XDropModalPanelWrapper.prototype.destroy = function() {
	XDropPanelWrapper.prototype.destroy.apply(this, arguments);
	if (this._modal) {
		this._modal.destroy();
	}
};

export default XDropModalPanelWrapper;
