import _ from "underscore";
import $ from "jquery";
/**
 * Wraps XDropPanel for positioning
 * @param {XDropPanel} xdropPanel - the panel to wrap
 * @param {Object} options
 * @param {Function} toggleCallback - function that is called to toggle the xdrop
 */
var XDropPanelWrapper = function(xdropPanel, options, toggleCallback) {
	this._panel = xdropPanel;
	this._element = $("<div>", {
		class: "XDropPanelWrapper absolute hidden"
	});

	this._element.append(this._panel.getElement());
	this._panel.getElement().addClass("limitedHeight");
	this._panel.setVisible(false);
	this._toggleCallback = toggleCallback;

	this._isOpen = false;

	this._options = _.extend(
		{
			preferredMinPanelHeight: 300,
			/*
         * dropdownAlign = how to align the dropdown to the input
         *  - fit: we want to fit the dropdown to the size of the display (same width)
         *  - left: we want to make the left side match, but dropdown and display can have different sizes
         *  - right: we want to make the right side match, but dropdown and display can have different sizes
         *  - auto: we pick left unless there is not enough space (see dropdownAutoAlignMinSpace), then right align.
         * 
         * Note: auto is currently only supported when using absolute positioning...
         */
			dropdownAlign: "fit", // fit, left, right, auto
			dropdownAutoAlignMinSpace: 220
		},
		options
	);
};

/**
 * Get the element
 * @returns {JQuerObj}
 */
XDropPanelWrapper.prototype.getElement = function() {
	return this._element;
};

/**
 * Reposition the wrapper on resize
 * @param {Boolean} reposition
 */
XDropPanelWrapper.prototype._repositionOnResize = function(reposition) {
	if (!this._boundOnResize) {
		this._boundOnResize = _.throttle(
			function() {
				this._updatePosition(this._isOpen);
			}.bind(this),
			16,
			{
				leading: false
			}
		);
	}
	this._shouldRepositionOnResize = reposition;
};

/**
 * Toggle (open/close) the xdropwrapper
 * @param {Boolean} isOpen
 */
XDropPanelWrapper.prototype.toggle = function(isOpen) {
	if (this._isOpen !== isOpen) {
		if (isOpen) {
			this._onOpen();
			if (this._shouldRepositionOnResize) {
				$(window).on("resize", this._boundOnResize);
				$(window).on("scroll", this._boundOnResize);
			}
		} else {
			this._onClose();
			$(window).off("resize", this._boundOnResize);
			$(window).off("resize", this._boundOnResize);
		}

		this._updatePosition(isOpen);

		this._isOpen = isOpen;
		this._element.toggleClass("hidden", !isOpen);

		this._panel.setVisible(isOpen);
		this._panel.setActive(isOpen);

		this._updatePosition(isOpen);
	} else if (isOpen) {
		// if already open, focus the panel again
		this._panel.setActive(isOpen);
	}
};

/**
 * Override to register extra things when switching open
 */
XDropPanelWrapper.prototype._onOpen = function() {
	// do extra actions on open
};

/**
 * Override to (un)register extra things when switching to closed state
 */
XDropPanelWrapper.prototype._onClose = function() {
	// do extra actions on close
};

/**
 * Update the position of the wrapper
 */
XDropPanelWrapper.prototype._updatePosition = function(isOpen) {
	// update the position of the xdroppanel
};

/**
 * Add the Panel Wrapper to DOM
 */
XDropPanelWrapper.prototype.addToDOM = function(container) {
	this._container = container;
};

/**
 * Destroy the panel wrapper
 */
XDropPanelWrapper.prototype.destroy = function() {
	this._element.children().detach();
	this._element.remove();
};

export default XDropPanelWrapper;
