import XDropPanelWrapper from "./XDropPanelWrapper";
import $ from "jquery";
import _ from "underscore";
/**
 * Relatively positioned xdroppanel wrapper
 *
 * @class
 * @augments XDropPanelWrapper
 * @param {XDropPanel} xdropPanel
 * @param {Object} options
 * @param {Function} toggleCallback
 */
var XDropRelativePanelWrapper = function(xdropPanel, options) {
	XDropPanelWrapper.apply(this, arguments);

	this._options = _.extend(
		{
			usingJQueryUIDatepicker: false
		},
		this._options
	);

	this._boundOnDocumentClick = this._onDocumentClick.bind(this);
	this._repositionOnResize(true);
};

XDropRelativePanelWrapper.prototype = Object.create(XDropPanelWrapper.prototype);
XDropRelativePanelWrapper.prototype.constructor = XDropRelativePanelWrapper;

/**
 * @Override
 */
XDropRelativePanelWrapper.prototype._onOpen = function() {
	// when we click outside the xdrop, we want to deactivate
	$(document).on("click", this._boundOnDocumentClick);
};

/**
 * @override
 */
XDropRelativePanelWrapper.prototype._onClose = function() {
	// when we click outside the xdrop, we want to deactivate
	$(document).off("click", this._boundOnDocumentClick);
};

/**
 * @override
 */
XDropRelativePanelWrapper.prototype._updatePosition = function(isOpen) {
	if (isOpen) {
		var position = this._getXDropPosition();
		var maxHeight;
		var above = false;
		if (position.spaceBelow < this._options.preferredMinPanelHeight && position.spaceAbove >= this._options.preferredMinPanelHeight) {
			// show above
			above = true;

			maxHeight = position.spaceAbove - 15;
			if (position.clientRect.bottom > window.innerHeight) {
				// make sure we don't keep growing in the upwards direction
				maxHeight = this._currentMaxHeight;
			} else {
				this._currentMaxHeight = maxHeight;
			}
		} else {
			maxHeight = position.spaceBelow - 15;
		}

		this._element.toggleClass("above", above).css({
			"max-height": maxHeight + "px"
		});

		// dropdownAlign option (fit/left/right) = how to align the dropdown to the input
		this._element.css("left", this._options.dropdownAlign == "right" ? "auto" : "");
		this._element.css("right", this._options.dropdownAlign == "left" ? "auto" : "");
	}
};

/**
 * @override
 */
XDropRelativePanelWrapper.prototype.addToDOM = function(container) {
	XDropPanelWrapper.prototype.addToDOM.apply(this, arguments);

	container.append(this._element);
};

/**
 * Get the position of the XDrop element
 * @private
 * @returns {Object} {spaceAbove, spaceBelow and clientRect}
 */
XDropRelativePanelWrapper.prototype._getXDropPosition = function() {
	var position = {};

	position.clientRect = this._container[0].getBoundingClientRect();
	var windowHeight = window.innerHeight;

	position.spaceBelow = windowHeight - position.clientRect.bottom;
	position.spaceAbove = position.clientRect.top;

	return position;
};

/**
 * When the document is clicked, and the click didn't originate in the XDrop or XDrop panel, we need to deactivate
 * @private
 * @param {Event} event
 */
XDropRelativePanelWrapper.prototype._onDocumentClick = function(event) {
	// Check if the event did not originate from inside the XDrop or XDrop panel
	if (!this._element[0].contains(event.target) && !this._container[0].contains(event.target)) {
		// If we are using a jQuery UI Datepicker first check if it was not one of the next month/previous month arrows that was clicked.
		// These will allready be replaced by jQuery UI by the time this method is called, so this is a false positive.
		if (this._options.usingJQueryUIDatepicker) {
			if ($(event.target).parents(".ui-datepicker-header").length === 0) {
				this._toggleCallback(false);
			}
		} else {
			this._toggleCallback(false);
		}
	}
};

export default XDropRelativePanelWrapper;
