import Renderer from "@esko/xdrop/renderers/Renderer";
import $ from "jquery";
/**
 * A renderer for displaying a button which executes "action" on the resultentry
 * @class
 * @augments Renderer
 * @param {JQueryObj}   div
 * @param {ResultEntry} resultEntry
 * @param {Object}      api        -  render API
 */
var ButtonRenderer = function(div, resultEntry, api) {
	Renderer.call(this, div, resultEntry, api);

	this._label = this._resultEntry.getData().getLabel();
	this._button = $("<a>", { class: "btn btn-primary action-button", text: this._label });

	if (resultEntry.getData().getClassNames) {
		this._button.removeClass();
		this._button.addClass(resultEntry.getData().getClassNames());
		this._button.addClass("action-button");
	}

	if (resultEntry.getData().getIcon) {
		this._button.prepend("&nbsp;");
		this._button.prepend(
			$("<i>", {
				class: resultEntry.getData().getIcon(),
				title: this._resultEntry.getData().getLabel()
			})
		);
	}
	this._element.append(this._button);

	// Buttons should not be highlighted
	this.setElementsToHighlightMatches([], false);
};

ButtonRenderer.prototype = Object.create(Renderer.prototype);
ButtonRenderer.prototype.constructor = ButtonRenderer;

/**
 * @override
 */
ButtonRenderer.prototype.render = function() {
	if (this._label !== this._resultEntry.getData().getLabel()) {
		this._label = this._resultEntry.getData().getLabel();
		this._button.text(this._label);
	}

	this._button.toggleClass("disabled", !this._resultEntry.allowSelection());
};

/**
 * On activation we execute the action of the result entry
 * @override
 */
ButtonRenderer.prototype.activate = function(event) {
	this._focusResultEntry(this._resultEntry);
	if (this._resultEntry.allowSelection() && this._resultEntry.getData().doAction) {
		this._resultEntry.getData().doAction(event, this._api);
	}
};

export default {
	make: function(div, resultEntry, api) {
		return new ButtonRenderer(div, resultEntry, api);
	}
};
