import Renderer from "@esko/xdrop/renderers/Renderer";
import $ from "jquery";
/**
 * A renderer for displaying a category title
 * @class
 * @augments Renderer
 * @param {JQueryObj}   div
 * @param {ResultEntry} resultEntry
 * @param {Object}      api         -  render API
 * @param {JSONObject}  options  {
 *                                  highlightingPerWord: (does the highlighting for each word in the query separately)
 *                               }
 */
var CategoryTitleRenderer = function(div, resultEntry, api, options) {
	Renderer.call(this, div, resultEntry, api, options);

	this._element.addClass(resultEntry.getData().getClassName());
	this._icon = $();

	if (resultEntry.getData().allowCollapse()) {
		this._icon = $("<i>", { class: "icon" });
	}

	// Highlight the matched text when filtering on title is enabled
	this._highlightMatchedTextEnabled = resultEntry.getData().allowFilteringOnTitle ? resultEntry.getData().allowFilteringOnTitle() : false;

	this._title = $("<span>", { class: "title", text: resultEntry.getData().getTitle() });

	this._element.attr("data-sahi-id", "XDROPCATEGORY " + resultEntry.getData().getTitle());

	this._element.append(this._icon).append(this._title);

	if (resultEntry.getData().showCount()) {
		var className = resultEntry.getData().getBadgeColor() ? resultEntry.getData().getBadgeColor() : "";
		this._element.append($("<span>", { class: "badge " + className, text: resultEntry.getData().getCount() }));
	}

	this.render();
};

CategoryTitleRenderer.prototype = Object.create(Renderer.prototype);
CategoryTitleRenderer.prototype.constructor = CategoryTitleRenderer;

/**
 * On activation we execute the action of the result entry
 * @override
 */
CategoryTitleRenderer.prototype.activate = function(event) {
	this._resultEntry.getData().toggle();
};

/**
 * @override
 */
CategoryTitleRenderer.prototype.setQuery = function(query) {
	if (this._highlightMatchedTextEnabled) {
		Renderer.prototype.setQuery.call(this, query);
	}
};

/**
 * @override
 */
CategoryTitleRenderer.prototype.render = function() {
	var isCollapsed = this._resultEntry.getData().isCollapsed();
	this._icon.toggleClass("icon-WCR_Right-S", isCollapsed).toggleClass("icon-WCR_Down-S", !isCollapsed);
};

export default {
	make: function(div, resultEntry, api) {
		return new CategoryTitleRenderer(div, resultEntry, api);
	},

	/**
	 * Makes a CategoryTitleRenderer with extra options
	 * @param   {JSONObject} options {
	 *                                   highlightingPerWord: (does the highlighting for each word in the query separately)
	 *                               }
	 */
	categoryTitleWithOptions: function(options) {
		return {
			make: function(div, resultEntry, api) {
				return new CategoryTitleRenderer(div, resultEntry, api, options);
			}
		};
	}
};
