import $ from "jquery";
import _ from "underscore";
import { LabelRenderer } from "./LabelRenderer";
import "./CheckboxLabelRenderer.css";

/**
 * Extends LabelRenderer and shows a checkbox which indicates whether the value is selected!
 * Allows deselecting again when clicking the value again.
 *
 * @class CheckboxLabelRenderer
 *
 * @class
 * @augments LabelRenderer
 * @param {JQueryObj}   div
 * @param {ResultEntry} resultEntry
 * @param {Object}      api         -  render API
 * @param {JSONObject}  options
 */
class CheckboxLabelRenderer extends LabelRenderer {
	constructor(div, resultEntry, api, options) {
		super(div, resultEntry, api, options);

		// Add the checkbox
		if (this._resultEntry.allowSelection()) {
			this._checkbox = $("<input>", { type: "checkbox", class: "xdropmultiselectcheckbox" });
			this._element.prepend(this._checkbox);
		}
	}

	/**
	 * Mark the element as selected
	 *
	 * In this renderer this will also show the checkbox as selected / not selected
	 *
	 * @param {Boolean} isSelected
	 * @override
	 */
	setSelected(isSelected) {
		if (this._isSelected != isSelected) {
			this._element.toggleClass("is-selected", isSelected);
			if (this._resultEntry.allowSelection()) {
				_.defer(() => {
					this._checkbox.prop("checked", isSelected);
				});
			}
			this._isSelected = isSelected;
		}
	}

	/**
	 * In this renderer activate will actually toggle the selection of the item on or off.
	 *
	 * If it is already selected, it will deselect instead.
	 *
	 * @override
	 */
	activate() {
		if (this._resultEntry.allowSelection()) {
			this._focusResultEntry(this._resultEntry);
			if (!this._isSelected) {
				this._selectResultEntry(this._resultEntry);
			} else {
				this._deselectResultEntry(this._resultEntry);
			}
			this._closeXDrop();
		}
	}
}

export default {
	make: function(div, resultEntry, api) {
		return new CheckboxLabelRenderer(div, resultEntry, api);
	}
};
