import Renderer from "@esko/xdrop/renderers/Renderer";
import $ from "jquery";
/**
 * @class LabelRenderer
 *
 * @class
 * @augments Renderer
 * @param {JQueryObj}   div
 * @param {ResultEntry} resultEntry
 * @param {Object}      api         -  render API
 * @param {JSONObject}  options     {
 *                                      highlightingPerWord: (does the highlighting for each word in the query separately)
 *                                  }
 */
var LabelRenderer = function(div, resultEntry, api, options) {
	Renderer.call(this, div, resultEntry, api, options);

	/* this._element is used to render in the XDrop panel, it is returned by renderer.getElement() */
	var data = this._resultEntry.getData();
	var label;
	if (data.getLabel) {
		label = data.getLabel();
	} else {
		label = data;
	}
	this._element.text(label);
};

LabelRenderer.prototype = Object.create(Renderer.prototype);
LabelRenderer.prototype.constructor = LabelRenderer;

/**
 * @override
 */
LabelRenderer.prototype.getToken = function() {
	Renderer.prototype.getToken.call(this);

	/* this._token is used to render in the MultiSelectXDrop input */
	var data = this._resultEntry.getData();
	var label;
	if (data.getTokenLabel) {
		label = data.getTokenLabel();
	} else if (data.getLabel) {
		label = data.getLabel();
	} else {
		label = data;
	}
	this._token.prepend(
		$("<span>", {
			text: label
		})
	);
	return this._token;
};

/**
 * Prepend and Icon
 */
LabelRenderer.prototype.prependIcon = function(icon) {
	this._element.prepend("&nbsp;");
	this._element.prepend(
		$("<i>", {
			class: icon
		})
	);
};

export { LabelRenderer };

export default {
	make: function(div, resultEntry, api) {
		return new LabelRenderer(div, resultEntry, api);
	},

	labelWithIconFactory: function(icon) {
		return {
			make: function(div, resultEntry, api) {
				var renderer = new LabelRenderer(div, resultEntry, api);
				renderer.prependIcon(icon);
				return renderer;
			}
		};
	},

	/**
	 * Makes a LabelRenderer with extra options
	 * @param   {JSONObject} options {
	 *                                   highlightingPerWord: (does the highlighting for each word in the query separately)
	 *                               }
	 */
	labelWithOptions: function(options) {
		return {
			make: function(div, resultEntry, api) {
				return new LabelRenderer(div, resultEntry, api, options);
			}
		};
	}
};
