/**
		 * This is the entry point towards having an Approval setup page. The parameters are bundeled in one JSONObject.
		 * @param {string}   displayId                   element used to render the approval
		 * @param {string}   readURL                     url used to read information about approval
		 * @param {string}   actionURL                   url used to store information
		 * @param {string}   docVersionID                document version id used to load reasons for rejection
		 * @param {string}   docName	                 document name to show in th popup
		 * @param {string}   getProjectFolderSetupURL    url used to read project/folder approval setups
		 * @param {object}   currentUser                 contains information about the logged in user
		 * @param {boolean}  nextVersion                 true if setup for next version is enabled
		 * @param {boolean}  stagedApprovalAllowed       true if the license is available that allows to add stages
		 * @param {string}   categoryID      			 Category of the project where this approvalsetup is done.
		 * @param {boolean}  milestoneAttributeAllowed   true if user can use milestone attributes for due dates   
		 * @param {boolean}  isViewFile                  true if file is viewable
		 * @param {boolean}  isEncapsulated              true if the page should not reload when saving approval information
		 * @param {function} afterInitializationCallback callback that is called when approval has finished initializing
		 * @param {function} onUpdateCallback            callback that is called whenever a client side change happens to the approval setup
		 */

define("approval/ApprovalUtils",["wcr/webcenter_html","utils/webi18n!Approval","utils/datetools","utils/HTTPUtils","utils/XMLUtils"],function(b,a,c,q,n){var k=function(b){var b=b.complexApprovalBootInfo,a=q.constructURL("complexapproval.jsp",{projectID:b.projectID,folderID:"",returnURL:"docdetailsapprovers.jsp",docVerID:b.documentVersionID,docID:b.documentID,menu_file:"",urlwanted:"docdetailsapprovers.jsp"});return{readURL:a,actionURL:a,getProjectFolderSetupURL:a+"&action=Inherit",currentUser:{userId:b.userId,
userName:b.userName,lastName:b.lastName,firstName:b.firstName,delegateUsername:b.delegateusername,delegateFirstname:b.delegatefirstname,delegateLastname:b.delegatelastname,isProjectManager:"1"==b.isProjectManager,isAdmin:"1"==b.isAdmin,canForceApprove:"1"==b.canForceApprove,canForceReject:"1"==b.canForceReject,canChangeSetup:"1"==b.canChangeSetup,canStartApproval:"1"==b.canStartApproval,canSeeOthers:"1"==b.canSeeOthers},nextVersion:!1,stagedApprovalAllowed:"1"==b.stagedApprovalAllowed,languageCodeHelp:b.languageCode,
isViewable:"1"==b.isViewable,isLinkedDocument:"1"==b.isLinkedDocument}},d={findMemberObj:function(b,a,d){try{var c=null;if(!d)return null;for(var k=0;k<d.length&&!c;k++)"User"==d[k].memberType?"User"==b&&d[k].userId==a&&(c=d[k]):("Group"==b&&d[k].groupId==a&&(c=d[k]),!c&&d[k].members&&(c=this.findMemberObj(b,a,d[k].members)));return c}catch(i){window.alert("Problem in findMemberObj: "+i)}},getDateHourString:function(a){try{var d=c.fixDateSummerWinterTime(a,!1);return b.getDateHourString(d)}catch(k){return a}},
getDateHourAttributeString:function(b,c,k){var g="";try{null!=b&&(g=d.getDateHourString(b));if(c){g+=" ["+c;if("0"!=k){0<k?g+=" + ":(g+=" - ",k*=-1);var c=k/3600/1E3,l=Math.floor(c/24);0<l&&(g+=" "+l+" "+a.t("CAppDays"));l=c-24*l;0<l&&(g+=" "+l+" "+a.t("CAppHours"))}g+="]"}return g}catch(i){return b}},getApprovalTypeLangTag:function(b){var a="CApp"+b.approvalType;b.memberObj&&!0===b.memberObj.isRole&&("OneOfGroup"==b.approvalType&&(a="CAppAllOfRoleOneOfGroup"),"AllOfGroup"==b.approvalType&&(a=b.memberObj.isRole?
"CAppAllOfRole":"CAppAllOfGroup"));return a},getNewCurrentTime:function(){var b=new Date;23>b.getHours()&&b.setHours(b.getHours()+1);b.setMinutes(0);b.setSeconds(0);return b},getUserRepresentation:function(d,c){var k={name:""};if(!d)return k;k.isGroup=void 0!==d.groupName;k.isRole=d.isRole;k.isUser=void 0!==d.lastName;k.isUser&&(k.name=b.getUserNameStringActiveHTML(null,d.firstName,d.lastName,d.userName,d.isActive,a.t("CAppUserDeactivated"),!0),c&&(k.name+=" "+a.t("CAppApprovalDoneAsUser")+" "+b.getUserNameStringActiveHTML(null,
c.firstName,c.lastName,c.userName,c.isActive,a.t("CAppUserDeactivated"),!0)));k.isGroup&&(k.name=d.groupName);return k},createApprovalOptionsFromBootInfoXml:function(b){b=n.xml2obj(b);return k(b)},createApprovalOptionsFromBootInfo:k};return d});
define("approval/model/ApprovalNotifications",["approval/ApprovalConstants","utils/Observable","wcr/webcenter_xml","underscore"],function(b,a,c,q){function n(c){a.mixin(this,"notifications");this.approvalModel=c;this.notificationType=b.NotificationType.NO_NOTIFICATIONS;this.projectNotificationsArr=this.defaultNotificationsArr=this.notificationsArr=null}n.fromXML=function(b,a){var c=new n(a);c.readNotificationInfoFromXML(b);return c};n.prototype.readNotificationInfoFromXML=function(a){var d=c.GetFirstFirstLevelChild(a,
"general"),p=c.GetFirstFirstLevelChild(a,"project"),a=c.GetFirstFirstLevelChild(a,"folder");d&&(this.notificationType=c.GetElementText(d,"notificationType"),this.notificationType===b.NotificationType.CUSTOM_NOTIFICATIONS?(this.notificationsArr=this.readNotificationsFromXML(d),0===this.notificationsArr.length&&(this.notificationType=b.NotificationType.NO_NOTIFICATIONS)):this.notificationType||(this.notificationType=b.NotificationType.NO_NOTIFICATIONS));if(p&&(this.defaultNotificationsArr=this.readNotificationsFromXML(p),
!this.defaultNotificationsArr||0===this.defaultNotificationsArr.length))this.defaultNotificationsArr=null;a&&(d=this.readNotificationsFromXML(a),this.projectNotificationsArr=this.defaultNotificationsArr,d&&0<d.length&&(this.defaultNotificationsArr=d));this._emit("update")};n.prototype.readNotificationsFromXML=function(a){var d=[];if(a=c.GetFirstFirstLevelChild(a,"notifications"))for(var p=0;p<b.notificationTypeArr.length;p++){var e={},j=c.GetFirstFirstLevelChild(a,b.notificationTypeArr[p]);j&&(e.projectManager=
c.GetElementBoolean(j,"projectManager"),e.involvedPeople=c.GetElementBoolean(j,"involvedPeople"),e.projectMembers=c.GetElementBoolean(j,"projectMembers"));d.push(e)}return d};n.prototype.toggleNotification=function(b,a,c){if(this.notificationsArr[b])switch(b=this.notificationsArr[b],a){case 0:b.projectManager=null!=c?c:!0!==b.projectManager;break;case 1:b.involvedPeople=null!=c?c:!0!==b.involvedPeople;break;case 2:b.projectMembers=null!=c?c:!0!==b.projectMembers;break;default:throw"notification "+
a+" does not exist";}this._emit("update")};n.prototype.toggleNotificationColumn=function(a,c){q.each(b.notificationTypeArr,function(b,e){this.toggleNotification(e,a,c)}.bind(this))};n.prototype.setNotificationType=function(a){this.notificationType=a;switch(this.notificationType){case b.NotificationType.NO_NOTIFICATIONS:break;case b.NotificationType.DEFAULT_NOTIFICATIONS:null!=this.projectNotificationsArr&&(this.notificationsArr=this.projectNotificationsArr.slice());break;case b.NotificationType.CUSTOM_NOTIFICATIONS:!this.notificationsArr&&
this.defaultNotificationsArr&&(this.notificationsArr=this.defaultNotificationsArr.slice());break;default:throw"Notification type unknown"+this.notificationType;}this._emit("update")};n.prototype.writeToXML=function(){var a="";this.notificationType&&(a+=c.ElementEncode("notificationType",this.notificationType));this.notificationType===b.NotificationType.CUSTOM_NOTIFICATIONS&&this.notificationsArr&&(a+="<notifications>",q.each(b.notificationTypeArr,function(b,p){var e=this.notificationsArr[p];e&&(a+=
"<"+b+">",a+=c.ElementEncodeBoolean("projectManager",e.projectManager),a+=c.ElementEncodeBoolean("involvedPeople",e.involvedPeople),a+=c.ElementEncodeBoolean("projectMembers",e.projectMembers),a+="</"+b+">")}.bind(this)),a+="</notifications>");return a};return n});
define("approval/model/ApprovalMember",["approval/ApprovalConstants","utils/Observable","wcr/webcenter_xml","jquery","underscore"],function(b,a,c){function q(){}q.readMembers=function(b,a){var d=[],p;if(b){var e=c.GetFirstLevelChilds(b,"member");if(e)for(var j=0;j<e.length;j++){var g=c.GetElementText(e[j],"userId");if(g)p={},p.userId=g,p.userName=c.GetElementText(e[j],"userName"),p.firstName=c.GetElementText(e[j],"firstName"),p.lastName=c.GetElementText(e[j],"lastName"),p.eMail=c.GetElementText(e[j],
"eMail"),p.canBeApprovalMaster=c.GetElementBoolean(e[j],"canBeApprovalMaster"),p.isActive=c.GetElementBoolean(e[j],"is_active"),p.memberType="User",p.isMember=a,d.push(p);else if(g=c.GetElementText(e[j],"groupId")){p={};p.groupId=g;p.groupName=c.GetElementText(e[j],"groupName");p.canBeApprovalMaster=c.GetElementBoolean(e[j],"canBeApprovalMaster");p.memberType="Group";g=c.GetElementText(e[j],"isRole");p.isRole="1"==g;p.isMember=a;if((g=c.GetFirstLevelChilds(e[j],"groupMembers"))&&0<g.length)p.members=
this.readMembers(g[0],a);d.push(p)}}return d}};return q});
define("approval/model/Approver",["approval/ApprovalConstants","approval/ApprovalUtils","wcr/webcenter_xml","underscore"],function(b,a,c,q){function n(b,a){this.approvalType=b;this.approvalTime=this.approvedByUserId=this.approvedVersion=this.approvalStatus=null;this.memberObj=a;this.commentArr=[]}n.prototype.hasReasonsForRejection=function(){var b=q.last(this.commentArr);return b&&!!b.commentReasonsForRejection};n.prototype.hasRoleAssigneeGroupMembers=function(){return this.isApproverGroup()||this.isApproverRole()};
n.prototype.getReasonsForRejectionString=function(){var b=q.last(this.commentArr);return b?b.commentReasonsForRejection:""};n.fromXML=function(k,d,p){var e=!0,j=new n;j.approvalType=c.GetElementText(k,"approvalType");j.approvalStatus=c.GetElementText(k,"approvalStatus");j.approvedVersion=c.GetElementText(k,"approvedVersion");var g=c.GetFirstLevelChilds(k,"approvalComment");if(g)for(var l=0;l<g.length;l++){var i={};i.commentText=c.GetElementText(g[l],"comment");i.commentReasonsForRejection=c.GetElementText(g[l],
"reasonsForRejection");i.commentByUserId=c.GetElementText(g[l],"commentByUserId");var h=c.GetElementText(g[l],"commentByDelegateId");h&&(i.commentByDelegateId=h);h=parseInt(c.GetElementText(g[l],"commentTime"));i.commentTime=h&&!isNaN(h)?new Date(h):null;i.commentVersion=c.GetElementText(g[l],"commentVersion");(i.commentText||i.commentReasonsForRejection)&&j.commentArr.push(i)}j.approvedByUserId=c.GetElementText(k,"approvalApprovedByUserId");if(g=c.GetElementText(k,"approvalApprovedAsUserId"))j.approvedAsUserId=
g;if(g=c.GetElementText(k,"original_approval"))j.originalApproval=g;l=c.GetElementText(k,"original_approval_type");g&&(j.originalApprovalType=l);if(g=c.GetElementText(k,"original_approval_id"))j.originalApprovalId=g;if(g=c.GetElementText(k,"original_approval_is_role"))j.originalApprovalIsRole=g;if(g=c.GetElementText(k,"original_approval_group_id"))j.originalApprovalGroupId=g;if(g=c.GetElementText(k,"original_approval_group"))j.originalApprovalGroup=g;g=parseInt(c.GetElementText(k,"approvalTime"));
j.approvalTime=g&&!isNaN(g)?new Date(g):null;j.approvalType===b.ApprovalType.USER?(k=c.GetElementText(k,"userId"),j.memberObj=a.findMemberObj("User",k,d),j.memberObj||(j.memberObj=a.findMemberObj("User",k,p),j.memberObj||(e=!1))):(k=c.GetElementText(k,"groupId"),j.memberObj=a.findMemberObj("Group",k,d),j.memberObj||(j.memberObj=a.findMemberObj("Group",k,p),j.memberObj||(e=!1)));return e?j:null};n.prototype.isApproverRole=function(){return this.originalApprovalIsRole&&"1"==this.originalApprovalIsRole?
!0:this.memberObj&&this.memberObj.isRole};n.prototype.isApproverGroup=function(){return"AllOfGroup"==this.originalApprovalType&&"0"==this.originalApprovalIsRole||"OneOfGroup"==this.originalApprovalType||!this.originalApprovalType&&("AllOfGroup"==this.approvalType||"OneOfGroup"==this.approvalType)};n.prototype.isUserAssignment=function(){return"User"==this.approvalType};n.prototype.getOriginalGroupID=function(){return this.originalApprovalGroupId};n.prototype.getOriginalGroup=function(){return this.originalApprovalGroup};
n.prototype.equalsOriginalApprover=function(b){return this.originalApproval&&this.originalApproval==b.originalApproval&&this.originalApprovalType==b.originalApprovalType?!0:!1};n.prototype.equalsOriginalGroupApprover=function(b){return this.equalsOriginalApprover(b)&&this.originalApprovalGroupId&&b.originalApprovalGroupId&&b.originalApprovalGroupId==this.originalApprovalGroupId?!0:!1};n.prototype.hasExpandedApprover=function(){if(this.originalApprovalType&&(this.originalApprovalType!=this.approvalType||
"1"==this.originalApprovalIsRole&&!this.memberObj.isRole))return!0};n.prototype.needToCreateAllOfGroupRow=function(){return this.isApproverRole()&&!!this.originalApprovalGroupId&&"User"==this.approvalType};n.prototype.getRoleName=function(){return!this.isApproverRole()?"":this.originalApproval?this.originalApproval:this.memberObj.groupName};n.prototype.getGroupID=function(){return!this.isApproverGroup()?"":this.originalApproval?this.originalApprovalId:this.memberObj.groupId};n.prototype.getRoleID=
function(){return!this.isApproverRole()?"":this.originalApproval?this.originalApprovalId:this.memberObj.groupId};n.prototype.getGroupName=function(){return!this.isApproverGroup()?"":this.originalApproval?this.originalApproval:this.memberObj.groupName};n.prototype.writeToXML=function(){var a=this.approvalType,d;d="<approver>"+c.ElementEncode("approvalType",a);this.originalApprovalId&&(d+=c.ElementEncode("originalApproverId",this.originalApprovalId),d+=c.ElementEncode("originalApproverGroupId",this.originalApprovalGroupId),
d+=c.ElementEncode("originalApproverType",this.originalApprovalType));if(a===b.ApprovalType.USER){if(!this.memberObj){window.alert("No memberObj for approver");return}if(!this.memberObj.userId)throw"No userId for approver";d+=c.ElementEncode("approverId",this.memberObj.userId);d+=c.ElementEncode("name",this.memberObj.userName)}else if(a===b.ApprovalType.ONE_OF_GROUP||a===b.ApprovalType.ALL_OF_GROUP||a===b.ApprovalType.ONE_OF_ROLE){if(!this.memberObj.groupId)throw"No groupId for approver";d+=c.ElementEncode("approverId",
this.memberObj.groupId);d+=c.ElementEncode("name",this.memberObj.groupName);d+=c.ElementEncode("is_role",this.memberObj.isRole?"1":"0")}else window.alert("Problem writing approvers.  Unexpected approvalType: "+a);return d+"</approver>"};return n});
define("utils/dateShift",[],function(){return{addDaysHours:function(b,a,c,q,n,k){var d=24;k&&(d=8);b=b.constructor==Date?b.getTime():parseInt(b);try{var p=parseInt(a),e=parseInt(c);q&&(p=Math.floor(q/864E5),e=(q-864E5*p)/36E5);var j=Math.floor(p/5),a=p-5*j,b=this.normalizeDateHour(b,k);e>d&&(p+=Math.floor(e/d),e-=Math.floor(e/d)*d);if(0>p||0>e)throw"No negative days or hours allowed";var g=new Date(b),l=g.getDay()-1;-1==l&&(l=6);l+=a;4<l&&(a+=2);b+=864E5*(7*j+a);k&&17<g.getHours()+e&&(e+=16);b+=36E5*
e;l=(new Date(b)).getDay();if(0==l||6==l)b+=1728E5}catch(i){alert("Problem in  addDaysHours: "+i)}return!0==n?new Date(b):b},subtractDaysHours:function(b,a,c,q,n,k){var d=24;k&&(d=8);b=b.constructor==Date?b.getTime():parseInt(b);try{var p=parseInt(a),e=parseInt(c);q&&(p=Math.floor(q/864E5),e=(q-864E5*p)/36E5);var j=Math.floor(p/5),a=p-5*j,b=this.normalizeDateHour(b,k);e>d&&(p+=Math.floor(e/d),e-=Math.floor(e/d)*d);if(0>p||0>e)throw"No negative days or hours allowed";var g=new Date(b),l=g.getDay()-
1;-1==l&&(l=6);l-=a;0>l&&(a+=2);b-=864E5*(7*j+a);k&&9>g.getHours()-e&&(e+=16);b-=36E5*e;l=(new Date(b)).getDay();if(0==l||6==l)b-=1728E5}catch(i){alert("Problem in  subtractDaysHours: "+i)}return!0==n?new Date(b):b},getWorkingTimeDifference:function(b,a,c){try{b.constructor==Date&&(b=b.getTime());a.constructor==Date&&(a=a.getTime());var q=!1;if(0>a-b)var q=!0,n=a,a=b,b=n;var b=this.normalizeDateHour(b,c),a=this.normalizeDateHour(a,c),k=new Date(b),d=new Date(a),p;if(c){var e=k.getDay();0==e&&(e=7);
var j=5-e;0>j&&(j=0);var g=new Date(b);g.setHours(17);g.setMinutes(0);var l=864E5*j+g.getTime()-k.getTime(),e=d.getDay();0==e&&(e=7);j=e-1;4<j&&(j=4);var i=new Date(a);i.setHours(9);i.setMinutes(0);var h=864E5*j+d.getTime()-i.getTime(),v=Math.floor((a-h-(b+l))/6048E5);p=0;p=0>v?d.getTime()-k.getTime():432E6*v+l+h}else{var f=Math.floor((a-b)/864E5),j=Math.floor(f/7),d=f-7*j,g=2*j,e=k.getDay();0==e&&(e=7);5<e+d&&(g+=2);p=a-b-864E5*g}q&&(p=-p);return p}catch(s){alert("Problem in getWorkingTimeDifference: "+
s)}},normalizeDateHour:function(b,a,c,q){var n=b.constructor,k=0,q=q?q:18;a&&(k=9,q=17);var d=null,d=n!=Date?new Date(b):b;6==d.getDay()?(c?(d=new Date(d.getTime()-864E5),d.setHours(q)):(d=new Date(d.getTime()+1728E5),d.setHours(k)),d.setMinutes(0),d.setSeconds(0),d.setMilliseconds(0)):0==d.getDay()&&(c?(d=new Date(d.getTime()-1728E5),d.setHours(q)):(d=new Date(d.getTime()+864E5),d.setHours(k)),d.setMinutes(0),d.setSeconds(0),d.setMilliseconds(0));a&&(17<=d.getHours()&&(d.setHours(17),d.setMinutes(0),
d.setSeconds(0)),d.setMilliseconds(0),9>d.getHours()&&(d.setHours(9),d.setMinutes(0),d.setSeconds(0)),d.setMilliseconds(0));return n!=Date?d.getTime():d},getLeadTime:function(b,a){var c=0;try{c=864E5*Number(b)+36E5*Number(a)}catch(q){alert("Problem in getLeadTime: "+q)}return new Number(c)},getLeadTimeDays:function(b){var a=0;try{0<b&&(a=Math.floor(b/864E5))}catch(c){alert("Problem in getLeadTimeDays: "+c)}return a},getLeadTimeHours:function(b){var a=0;try{if(0<b)var c=this.getLeadTimeDays(b),a=Math.floor((b-
864E5*c)/36E5)}catch(q){alert("Problem in getLeadTimeHours: "+q)}return a},roundTimeToHours:function(b){var a=b;try{a=36E5*Math.floor((b+18E5)/36E5)}catch(c){alert("Problem in roundTimeToHours method: "+c)}return a},roundTimeToDays:function(b){var a=b;try{a=864E5*Math.floor((b+432E5)/864E5)}catch(c){alert("Problem in roundTimeToDays method: "+c)}return a}}});
define("approval/model/ApprovalStage","approval/model/Approver approval/ApprovalUtils approval/ApprovalConstants utils/Observable utils/Observer utils/webi18n!Approval component/datetimepickerblockinput/DateTimeData component/offsetinput/OffsetData wcr/webcenter_xml underscore utils/dateShift".split(" "),function(b,a,c,q,n,k,d,p,e,j,g){function l(b){q.mixin(this,["Approval",b.getId(),"stage",j.uniqueId()],"Approval");n.mixin(this);this.id=null;this.name="";this.leadTime=null;var a=new Date;d.roundDate(a);
this.dueDateData={mode:"specific",time:a.getTime()};this.approvalStatus=c.ApprovalStatus.NOT_STARTED;this.condApp=!0;this.rejectHandle="RejectStopsApprovalAfterStep";this.requireReviewHandle="RequireReviewNo";this.inheritPreviousApprovals=!1;this.approvers=[];this.approvalModel=b;this.workflowTaskId="";this._observe(this.approvalModel,"changed.stages.*",j.partial(this._emit,"changed.number"));this._observe(this.approvalModel,"changed.stages.deleted",function(){j.contains(arguments,this)&&(this._emit("deleted"),
this._stopObserveAll())}.bind(this));this._observe(this.approvalModel,"changed.stages.added",function(b){j.isEmpty(this.name)&&(this!==b&&2===j.size(this.approvalModel.getStages()))&&this.setStageName(k.t("CAppStage")+" 1")}.bind(this));Object.defineProperty(this,"number",{get:function(){return this.approvalModel?this.approvalModel.getStageNumber(this):"undefined"}.bind(this)})}l.fromXML=function(a,c,d,f){var s=new l(f);s.id=e.GetElementText(a,"stageId");s.name=e.GetElementText(a,"stageName");s.leadTime=
parseInt(e.GetElementText(a,"stageLeadTime"));var w=e.GetElementText(a,"stage_duedate_attribute_id"),m=void 0,g=e.GetElementText(a,"stageDueTimeStamp"),y=e.GetElementText(a,"stage_duedate_attribute_name"),k=e.GetElementText(a,"stage_duedate_offset");g&&(m=parseInt(g));s.dueDateData=w?g?{mode:"offset",item_id:w,item_name:y,offset:+k,time:+m}:{mode:"offset",item_id:w,item_name:y,offset:+k}:g?{mode:"specific",time:+m}:{mode:"none"};s.approvalStatus=e.GetElementText(a,"stageApprovalStatus");s.condApp=
e.GetElementBoolean(a,"allowConditionalApproval");s.rejectHandle=e.GetElementText(a,"uponRejection");s.requireReviewHandle=e.GetElementText(a,"requireReviewState");s.inheritPreviousApprovals=e.GetElementBoolean(a,"inheritPreviousApprovals");s.workflowTaskId=e.GetElementText(a,"workflow_task_id");if(a=e.GetFirstFirstLevelChild(a,"approvers"))a=e.GetFirstLevelChilds(a,"approver"),j.each(a,function(a){a&&(a=b.fromXML(a,c,d))&&s.approvers.push(a)}.bind(this));s.menuFile=f.getMenuFile();s._emit("update");
return s};l.prototype.canModifyDueDate=function(){return this.approvalStatus===c.ApprovalStatus.NOT_STARTED};l.prototype.canModifyApprovers=function(){return this.approvalStatus===c.ApprovalStatus.NOT_STARTED||this.approvalStatus===c.ApprovalStatus.PENDING};l.prototype.writeToXML=function(b){var a="<stage>",a=a+e.ElementEncode("stageId",this.id),a=a+e.ElementEncode("stageName",this.approvalModel.isStagedApprovalAllowed()?this.name:""),a=a+e.ElementEncode("stageNumber",b+1);this.leadTime&&(a+=e.ElementEncode("stageLeadTime",
this.leadTime));this.approvalModel.dueDateType===c.DueDateType.FIXED&&(b=this.dueDateData.mode,"offset"===b?(a+=e.ElementEncode("stage_duedate_attribute_id",this.dueDateData.item_id),a+=e.ElementEncode("stage_duedate_offset",this.dueDateData.offset),a+=e.ElementEncode("stageDueDateStamp",this.dueDateData.time)):"specific"===b&&(a+=e.ElementEncode("stageDueDateStamp",this.dueDateData.time)));a+=e.ElementEncode("stageApprovalStatus",this.approvalStatus);a+=e.ElementEncode("uponRejection",this.rejectHandle);
a+=e.ElementEncode("requireReviewState",this.requireReviewHandle);a=this.approvalModel.systemCondApprovalAllowed?a+e.ElementEncode("allowConditionalApproval",this.condApp):a+e.ElementEncode("allowConditionalApproval",!1);a+=e.ElementEncode("inheritPreviousApprovals",this.inheritPreviousApprovals);this.workflowTaskId&&(a+=e.ElementEncode("workflow_task_id",this.workflowTaskId));a+="<approvers>";this.approvers&&j.each(this.approvers,function(b){a+=b.writeToXML()});a+="</approvers>";return a+="</stage>"};
l.prototype.remove=function(){this.approvalModel.removeStage(this)};l.prototype.removeApprover=function(a){var b=this.approvers;if(!b)throw"appArr is null";if(a<b.length&&0<=a)b.splice(a,1),this._emit("changed.approvers.removed");else throw"approverIndex out of bounds of approvers array";};l.prototype.removeAllApprovers=function(){j.isEmpty(this.approvers)||(this.approvers=[],this._emit("changed.approvers.removeall"))};l.prototype.changeGroupApprover=function(a,b){var c=this.approvers[a];c&&b&&(c.approvalType=
b,c.originalApprovalType&&(c.originalApprovalType=b),this._emit("changed.approvers.modified",c))};l.prototype.setDueDate=function(a){(this.dueDateData.time!==a||"specific"!==this.dueDateData.mode)&&this.setDueDateData({mode:"specific",time:a.getTime()})};l.prototype.hasRealDueDate=function(){return"specific"===this.dueDateData.mode};l.prototype.getRealDueDate=function(){return this.hasRealDueDate()?new Date(this.dueDateData.time):null};l.prototype.addDays=function(a,b){this.shiftDays(!0,a,b)};l.prototype.addTime=
function(a){this.shiftDays(!0,0,0,a)};l.prototype.subtractDays=function(a,b){this.shiftDays(!1,a,b)};l.prototype.subtractTime=function(a){this.shiftDays(!1,0,0,a)};l.prototype.shiftDays=function(a,b,c,d){if(this.hasRealDueDate())d?a?this.setDueDate(g.addDaysHours(this.dueDateData.time,0,0,d,!0)):this.setDueDate(g.subtractDaysHours(this.dueDateData.time,0,0,d,!0)):a?this.setDueDate(g.addDaysHours(this.dueDateData.time,b,c,null,!0)):this.setDueDate(g.subtractDaysHours(this.dueDateData.time,b,c,null,
!0));else{d&&(b=Math.floor(d/msInDay),c=(d-b*msInDay)/msInHour);var s=new p;d?s.setBySeconds(d/1E3):(s.setDays(b),s.setHours(c));s.setPositive(a);this.setDueDateData({mode:"offset",item_name:this.dueDateData.item_name,item_id:this.dueDateData.item_id,offset:this.dueDateData.offset+1E3*s.getBySeconds()})}};l.prototype.setDueDateData=function(a){this.dueDateData!=a&&(this.dueDateData=a,this._emit("changed.duedate"))};l.prototype.setLeadTime=function(a){this.leadTime!==a&&(this.leadTime=a,this._emit("changed.leadtime"))};
l.prototype.getStageName=function(){return this.name};l.prototype.setStageName=function(a){this.name===a||"string"!==typeof a||(this.name=a,this._emit("changed.name"))};l.prototype.hasValidStageName=function(){return this.approvalModel.isComplexApproval()&&(!this.name||!this.name.trim())?"CAppEmptyNameNotAllowed":this.name&&50<this.name.trim().length?"CAppNameTooLong":""};l.prototype.getLeadTimeInDaysAndHours=function(){var a=this.leadTime/36E5,b=Math.floor(a/24),a=Math.round(a-24*b);return{days:b,
hours:a}};l.prototype.setRejectHandle=function(a){this.rejectHandle!==a&&(this.rejectHandle=a,this._emit("changed.rejecthandle"))};l.prototype.setRequireReviewHandle=function(a){this.requireReviewHandle!==a&&(this.requireReviewHandle=a,this._emit("changed.requirereviewhandle"))};l.prototype.setConditionalApproval=function(a){this.condApp!==a&&(this.condApp=a,this._emit("changed.condapp"))};l.prototype.setInheritPreviousApprovals=function(a){this.inheritPreviousApprovals!==a&&(this.inheritPreviousApprovals=
a,this._emit("changed.inheritPreviousApprovals "))};l.prototype.getWorkflowTaskId=function(){return this.workflowTaskId};l.prototype.isWorkflowDriven=function(){return!!this.workflowTaskId};l.prototype.setWorkflowTaskId=function(a){this.workflowTaskId!==a&&(this.workflowTaskId=a,this._emit("changed.workflowTaskId"))};l.prototype.addApprover=function(a){if(a&&!j.some(this.approvers,function(b){b=b.memberObj;return a.userId&&a.userId===b.userId||a.groupId&&a.groupId===b.groupId})){var c=new b(a.userId?
"User":a.isRole?"OneOfRole":"OneOfGroup",a);this.approvers.push(c);this._emit("changed.approvers.added",c)}};l.prototype.getApprovers=function(){return this.approvers};l.prototype.canModifyStageName=function(){return!this.approvalModel.readOnly&&this.approvalModel.approvalStatus===c.ApprovalStatus.NOT_STARTED&&this.approvalStatus===c.ApprovalStatus.NOT_STARTED};l.prototype.hasReasonsForRejection=function(){return j.any(this.getApprovers(),function(a){return a.hasReasonsForRejection()})};l.prototype.hasRoleAssigneeGroupMembers=
function(){return j.any(this.getApprovers(),function(a){return a.hasRoleAssigneeGroupMembers()})};return l});define("approval/stageFactory/SimpleApprovalStageFactory",["approval/model/ApprovalStage","component/datetimepickerblockinput/DateTimeData","utils/dateShift"],function(b,a,c){var q=function(a){this._model=a};q.prototype.createApprovalStage=function(){var q=new b(this._model),k=c.addDaysHours(new Date,1,0,null,!0);a.roundDate(k);q.setDueDate(k);return q};return q});
define("approval/stageFactory/ComplexApprovalStageFactory",["approval/model/ApprovalStage","approval/ApprovalConstants","underscore","utils/webi18n!approval","utils/dateShift"],function(b,a,c,q,n){var k=function(a){this._model=a};k.prototype.createApprovalStage=function(d){var k=new b(this._model);k.condApp=!0;if(this._model.dueDateType===a.DueDateType.FIXED){var e=new Date;e.setMinutes(0);e.setSeconds(0);d&&d.getRealDueDate()&&(e=d.getRealDueDate());k.setDueDate(n.addDaysHours(e,1,0,null,!0))}if((e=
this._model.getStages())&&0<e.length){for(var e=c.pluck(e,"name"),d=this._model.getStageNumber(d),j=q.t("CAppStage")+" "+(d+1),d=function(a){return a===j};c.find(e,d);)j+="_2";k.name=j}return k};return k});
define("approval/model/ApprovalModel","approval/ApprovalConstants approval/ApprovalUtils approval/model/ApprovalNotifications approval/model/ApprovalMember approval/model/ApprovalStage approval/stageFactory/SimpleApprovalStageFactory approval/stageFactory/ComplexApprovalStageFactory component/datetimepickerblockinput/DateTimeData utils/Observable utils/Observer utils/dateShift wcr/webcenter_html wcr/webcenter_xml underscore jquery".split(" "),function(b,a,c,q,n,k,d,p,e,j,g,l,i,h,v){function f(a){this.readURL=
(a||{}).readURL||null;this.actionURL=(a||{}).actionURL||null;this.getProjectFolderSetupURL=(a||{}).getProjectFolderSetupURL||null;var c=(a||{}).nextVersion||null;this.stagedApprovalAllowed=(a||{}).stagedApprovalAllowed||null;this.categoryId=(a||{}).categoryID||null;this.milestoneAttributeAllowed=(a||{}).milestoneAttributeAllowed||null;this.isViewFile=(a||{}).isViewFile||null;this.isLinkedDocument=(a||{}).isLinkedDocument||null;this.menuFile=(a||{}).menuFile||null;this.currentUser=(a||{}).currentUser||
null;this.approvalOptions=a;this._id=h.uniqueId();e.mixin(this,["Approval",this._id],"Approval");j.mixin(this);this.on("stage.*.changed.approvers.added",this._onStageApproverAdded.bind(this));this.onAll(["changed.*","stage.*.changed.**"],function(){this.approvalRuleChanged=!0}.bind(this));this.steps=[];this.approvalStatus=b.ApprovalStatus.NOT_DEFINED;this._stageFactory=this.stagedApprovalAllowed?new d(this):new k(this);this.dueDateType=b.DueDateType.NO;var m=new Date;p.roundDate(m);this.dueDateData=
{mode:"specific",time:m.getTime()};this.approvalMasterType=b.ApprovalMasterType.USER;this.approvalMaster=this.currentUser.userId;this.hasNextVersionSetup=this.hasFolderApprovalSetup=this.hasProjectApprovalSetup=this.passwordValidation=this.approvalRuleChanged=!1;this.nextVersion=!!c;this.readOnly=!(this.currentUser&&!0===this.currentUser.canChangeSetup);this.canSubmitApprovalStatus=!0;this.documentVersion=1;this.uponNewVersion="InheritApproval";this.submitAllowed=!0;this.submitDisabled=!1;this.viewerApprovalCommentType=
"Prompt";this.isMultiDocSetup=this.newVersionWhileWaitingForWorkflow=!1;this.isWithinViewer=a.isWithinViewer||!1;this.languageCodeHelp=a.languageCodeHelp||"en";this.reasonsForRejectionEnabled=!1;if(this.approvalOptions.isLinkedDocument)h.defer(function(){this._emit("update")}.bind(this));else if(this.approvalOptions.readDocument){var f=this.approvalOptions.readDocument;h.defer(function(){this.readReturnXML(f)}.bind(this))}else this.readURL?this.readFromXML(this.readURL):this._emit("update")}f.prototype.setError=
function(a){this.errorObj=a;this._emit("error",a)};f.prototype.getId=function(){return this._id};f.prototype._onStageApproverAdded=function(b){a.findMemberObj(b.memberObj.memberType,b.memberObj.userId||b.memberObj.groupId,this.getProjectMembers())||(this.projectMembers.push(b.memberObj),this._emit("member.added"))};f.prototype.readApprovalFromURL=function(a,b){this.canSubmitApprovalStatus=!0;v.ajax({url:a,type:"GET",data:"xml"}).done(h.bind(function(a){this.reset();(this.approvalRuleChanged=b)?this.readProjectFolderReturnXML(a):
this.readReturnXML(a)},this)).fail(h.bind(function(){this.reset();this.setError("An error occured when loading the approval setup")},this))};f.prototype.readReturnXML=h.wrap(function(a){this.cachedXML=a;var d=i.GetFirstFirstLevelChild(a,"error");if(d)a=i.GetElementText(d,"errorMessage"),this.setError({errors:[{tag:a,inline:!0}]});else{this.errorMsg=null;if(a=i.GetFirstFirstLevelChild(a,"approvalSetup")){this.notificationInfo&&this._stopObserveObject(this.notificationInfo);this.notificationInfo=c.fromXML(a,
this);this._observe(this.notificationInfo,"update",h.partial(this._emit,"changed.notifications"));if(d=i.GetFirstFirstLevelChild(a,"general")){this.uponNewVersion=i.GetElementText(d,"uponNewVersion");this.dueDateType=i.GetElementText(d,"dueDateType");""===this.dueDateType&&(this.dueDateType=b.DueDateType.NO);this.dueDateType===b.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&(this.finalDueDate=(this.finalDueDate=parseInt(i.GetElementText(d,"finalDueDate")))?new Date(this.finalDueDate):null);var m=i.GetFirstFirstLevelChild(a,
"project");if(m){this.projectId=i.GetElementText(m,"projectId");this.projectName=i.GetElementText(m,"projectName");this.projectManagerUserId=i.GetElementText(m,"projectManagerUserId");i.GetFirstFirstLevelChild(m,"CannotSubmitAppStatusProjInactive")&&(this.canSubmitApprovalStatus=!1);var f=i.GetFirstFirstLevelChild(m,"projectMembersWithAccess");f&&(this.projectMembers=q.readMembers(f,!0));if(f=i.GetFirstFirstLevelChild(m,"project_role_assignment_map_list"))this.roleAssignments=[],this.assignedRolesID=
[],this.readRoleAssignmentData(f,this.roleAssignments,this.assignedRolesID);if(m=i.GetFirstFirstLevelChild(m,"usersWithNoAccess"))this.usersWithNoAccess=q.readMembers(m,!1)}var m=i.GetElementText(d,"duedate_attribute_id"),f=0,e=i.GetElementText(d,"finalDueDate");e&&(f=parseInt(e));var g=i.GetElementText(d,"duedate_attribute_name"),k=i.GetElementText(d,"duedate_offset");m?this.dueDateData=e?{mode:"offset",item_id:m,item_name:g,offset:+k,time:f}:{mode:"offset",item_id:m,item_name:g,offset:+k}:(e||(m=
new Date,new p.roundDate(m),f=m.getTime()),this.dueDateData={mode:"specific",time:f});this.approvalStatus=i.GetElementText(d,"generalApprovalStatus");this.viewerApprovalCommentType=i.GetElementText(d,"viewerApprovalCommentType");this.approvalStartedOnce=i.GetElementBoolean(d,"approvalStartedOnce");this.approvalMasterType=i.GetElementText(d,"approvalMasterType");this.approvalMaster=i.GetElementText(d,"approvalMaster");""===this.approvalMasterType&&(this.approvalMasterType=b.ApprovalMasterType.USER,
this.approvalMaster=this.currentUser.userId);this.hasNextVersionSetup=i.GetElementBoolean(d,"hasNextDocumentVersionApprovalSetup");this.passwordValidation=i.GetElementBoolean(d,"passwordValidation");this.systemCondApprovalAllowed=i.GetElementBoolean(d,"systemCondApprovalAllowed");this.hideApprovalOutsideViewer=i.GetElementBoolean(d,"hideApprovalOutsideViewer");this.reasonsForRejectionEnabled=i.GetElementBoolean(d,"reasonsForRejectionEnabled")}if(d=i.GetFirstFirstLevelChild(a,"folder"))this.folderId=
i.GetElementText(d,"folderId"),this.folderName=i.GetElementText(d,"folderName"),this.hasProjectApprovalSetup=i.GetElementBoolean(d,"hasProjectApprovalSetup");if(d=i.GetFirstFirstLevelChild(a,"isMultiDocApprovalSetup")){this.isMultiDocSetup=!0;if(null==i.GetFirstFirstLevelChild(d,"projIsTemplate")&&(null==this.currentUser.canStartApproval||!0===this.currentUser.canStartApproval))this.currentUser.canStartApproval=!0;this.hasProjectApprovalSetup=i.GetElementBoolean(d,"hasProjectApprovalSetup");this.hasFolderApprovalSetup=
i.GetElementBoolean(d,"hasFolderApprovalSetup")}if(d=i.GetFirstFirstLevelChild(a,"document"))this.documentId=i.GetElementText(d,"documentId"),this.documentName=i.GetElementText(d,"documentName"),this.documentVersion=i.GetElementText(d,"documentVersion"),this.hasFolderApprovalSetup=i.GetElementBoolean(d,"hasFolderApprovalSetup"),!0!==this.hasProjectApprovalSetup&&(this.hasProjectApprovalSetup=i.GetElementBoolean(d,"hasProjectApprovalSetup")),this.newVersionWhileWaitingForWorkflow=i.GetElementBoolean(d,
"newVersionWhileWaitingForWorkflow");this.steps=[];(a=i.GetFirstFirstLevelChild(a,"stages"))&&h.each(i.GetFirstLevelChilds(a,"stage"),function(a){this.addStage(n.fromXML(a,this.projectMembers,this.usersWithNoAccess,this))}.bind(this));this.approvalRuleChanged=!1}this.nextVersion&&(this.approvalStatus=b.ApprovalStatus.NOT_STARTED,h.each(this.steps,function(a){a&&(a.approvalStatus=b.ApprovalStatus.NOT_STARTED,a.approvers=h.chain(a.approvers).filter(function(a){return a.memberObj&&a.memberObj.canBeApprovalMaster}).each(function(a){a.approvalStatus=
b.ApprovalStatus.NOT_STARTED;a.approvedVersion=null;a.approvalDate=null;a.approvalHour=null;a.commentArr=[]}).value())}.bind(this)));this.globalStatus={status:this.approvalStatus,userStatus:void 0};this.globalStatus.status!==b.ApprovalStatus.NOT_DEFINED&&this.globalStatus.status!==b.ApprovalStatus.NOT_STARTED&&!1==this.newVersionWhileWaitingForWorkflow&&(this.globalStatus.userStatus=this.currentUserApprovalStatus(0))}},function(a){a.apply(this,h.rest(arguments));this._emit("initialized")});f.prototype.readRoleAssignmentData=
function(a,b,d){if(a){var c=function(a){var b=i.GetElementText(a,"first_name"),s=i.GetElementText(a,"last_name"),d=i.GetElementText(a,"name");return{firstName:b,lastName:s,userName:d,name:s+(b?", "+b:" ")+"("+d+")",isActive:i.GetElementBoolean(a,"is_active"),ID:i.GetElementAttribute(a,"id")}},a=i.GetFirstLevelChilds(a,"project_role_assignment_map");h.each(a,function(a){var s=i.GetFirstFirstLevelChild(a,"role_group"),f=i.GetElementAttribute(s,"id"),e=i.GetElementSelfTextContent(s),s={};s.roleID=f;
s.roleName=e;d.push(f);var r=[];if(f=i.GetFirstFirstLevelChild(a,"assigned_users_list"))(f=i.GetFirstLevelChilds(f,"assigned_user"))&&h.each(f,function(a){a=c(i.GetFirstFirstLevelChild(a,"user"));r.push(a)});r&&0<r.length&&(s.userRoleAssignments=r);var g=[];if(a=i.GetFirstFirstLevelChild(a,"assigned_groups_list"))(a=i.GetFirstLevelChilds(a,"assigned_group"))&&h.each(a,function(a){var b=i.GetElementText(a,"assigned_group_name"),s=i.GetElementAttribute(a,"id"),d={};d.name=b;d.ID=s;if(a=i.GetFirstFirstLevelChild(a,
"assigned_group_assignee"))d.assignee=c(i.GetFirstFirstLevelChild(a,"user"));g.push(d)});g&&0<g.length&&(s.groupRoleAssignments=g);b.push(s)}.bind(this))}};f.prototype.loadProjectFolderApproval=function(a){var b=this.getProjectFolderSetupURL;if(!b)throw"getProjectFolderSetupURL is null";b=-1==b.indexOf("?")?b+"?":b+"&";this.readApprovalFromURL(!0===a?b+"folder=true":b+"folder=false",!0)};f.prototype.readProjectFolderReturnXML=h.wrap(function(a){var d=i.GetFirstFirstLevelChild(a,"error");if(d)a=i.GetElementText(d,
"errorMessage"),this.setError({errorMsg:"CAppCouldNotLoad",errors:[{tag:a,inline:!0}]});else if(this.errorMsg=null,this.reset(),a=i.GetFirstFirstLevelChild(a,"approvalSetup")){if(d=i.GetFirstFirstLevelChild(a,"stages")){d=i.GetFirstLevelChilds(d,"stage");if(0===d.length){this.setError({errorMsg:"CAppNoProjectApproval"});return}this.steps=[];h.each(d,function(a){this.addStage(n.fromXML(a,this.projectMembers,this.usersWithNoAccess,this))}.bind(this))}this.approvalStatus=b.ApprovalStatus.NOT_STARTED;
this.notificationInfo.setNotificationType(b.NotificationType.DEFAULT_NOTIFICATIONS);if(a=i.GetFirstFirstLevelChild(a,"general")){this.uponNewVersion=i.GetElementText(a,"uponNewVersion");this.dueDateType=i.GetElementText(a,"dueDateType");var d=i.GetElementText(a,"duedate_attribute_id"),c=0;(c=i.GetElementText(a,"finalDueDate"))?c=parseInt(c):(c=new Date,new p.roundDate(c),c=c.getTime());var f=i.GetElementText(a,"duedate_attribute_name"),e=i.GetElementText(a,"duedate_offset");this.dueDateData=d?{mode:"offset",
item_id:d,item_name:f,offset:e,time:c}:{mode:"specific",time:c};this.approvalMasterType=i.GetElementText(a,"approvalMasterType");this.approvalMaster=i.GetElementText(a,"approvalMaster")}this.approvalRuleChanged=!0}},function(a){a.apply(this,h.rest(arguments));this._emit("initialized")});f.prototype.editSetupForNextVersion=function(){this.nextVersion=!0;if(this.hasNextVersionSetup||this.approvalStartedOnce){var a=this.readURL,a=-1==a.indexOf("?")?a+"?":a+"&";this.readApprovalFromURL(a+"nextDocVersion=true",
!1)}else this.approvalStatus===b.ApprovalStatus.NOT_DEFINED?(this.setApprovalStatus(b.ApprovalStatus.NOT_STARTED),a=this._stageFactory.createApprovalStage(),this.addStage(a,0)):(h.each(this.steps,function(a){a.approvalStatus=b.ApprovalStatus.NOT_STARTED;a.id=null;h.each(a.approvers,function(a){a.approvalStatus=b.ApprovalStatus.NOT_STARTED;a.approvedVersion=null;a.approvalDate=null;a.approvalHour=null;a.commentArr=[];a.approvedByUserId=null;a.approvedAsUserId=null;a.approvalTime=null}.bind(this))}.bind(this)),
this.approvalStatus!==b.ApprovalStatus.NOT_DEFINED&&this.setApprovalStatus(b.ApprovalStatus.NOT_STARTED)),this.approvalRuleChanged=!0,this._emit("initialized")};f.prototype.cancel=function(){this.readFromXML(this.readURL)};f.prototype.clear=function(){this.removeAllStages();this.approvalStatus=b.ApprovalStatus.NOT_DEFINED;this.dueDateType=b.DueDateType.NO;this.currentUser&&this.currentUser.userId&&(this.approvalMasterType=b.ApprovalMasterType.USER,this.approvalMaster=this.currentUser.userId);(this.documentId||
this.folderId)&&this.notificationInfo.setNotificationType(b.NotificationType.DEFAULT_NOTIFICATIONS);this.approvalRuleChanged=!0;this._emit("update")};f.prototype.backToCurrentVersion=function(){this.nextVersion=!1;this.readFromXML(this.readURL)};f.prototype.findRoleUserObj=function(b,d){try{var c=null;if(!this.roleAssignments)return null;for(var f=0;f<this.roleAssignments.length&&!c;f++)if(this.roleAssignments[f].roleID==d){if(this.roleAssignments[f].userRoleAssignments)for(var e=this.roleAssignments[f].userRoleAssignments,
h=0;h<e.length&&!c;h++)e[h].ID==b&&(c=a.findMemberObj("User",e[h].ID,this.projectMembers));if(this.roleAssignments[f].groupRoleAssignments)for(var g=this.roleAssignments[f].groupRoleAssignments,h=0;h<g.length&&!c;h++)var k=a.findMemberObj("Group",g[h].ID,this.projectMembers),c=a.findMemberObj("User",b,k.members)}return c}catch(r){window.alert("Problem in findRoleUserObj: "+r)}};f.prototype.getApprovalActions=function(a){var d={list:[],text:void 0,showContent:!0},c,f;a&&this.globalStatus&&(c=this.globalStatus.status,
f=this.globalStatus.userStatus);try{if(this.hideApprovalOutsideViewer&&!this.isWithinViewer||!this.canSubmitApprovalStatus&&c!==b.ApprovalStatus.PENDING||this.approvalStatus===b.ApprovalStatus.NOT_STARTED||this.globalStatus&&this.globalStatus.status===b.ApprovalStatus.NOT_STARTED)return d;var a=0,e=this.currentUser;if(e){var h=e.mustApprove;if(null==e.mustApprove){if(void 0!==this.forcedStep)a=this.forcedStep;else{for(var g=!1,a=0;a<this.steps.length&&!g;a++)this.steps[a]&&this.steps[a].approvalStatus===
b.ApprovalStatus.PENDING&&(g=!0);if(g){a--;var k=this.steps[a].approvers;k&&0<k.length&&(h=this.currentUserApprovalStatus(a))}}if(a>=this.steps.length&&"Pending"!=c)return d}var r;"MustApprove"==h||"MustApprove"==f?(d.text="CAppApprovalYouMustApprove",r="MustApprove"!=h?"Remaining":"",d.list.push({name:"Approve"+r,text:"CAppApprove"+r,internalName:"Approved",step:a}),d.list.push({name:"Reject"+r,text:"CAppReject"+r,internalName:"Rejected",step:a}),d.list.push({name:"Comment"+r,text:"CAppComment"+
r,internalName:"Comment",step:a})):null!=h&&(d.text="CAppYouHave"+h);r=this.approvalStatus!==b.ApprovalStatus.PENDING?"Remaining":"";e.canForceApprove&&d.list.push({name:"ForceApprove"+r,text:"CAppForceApprove"+r,internalName:"ForceApproved",step:a});e.canForceReject&&d.list.push({name:"ForceReject"+r,text:"CAppForceReject"+r,internalName:"ForceRejected",step:a})}}catch(x){window.alert("Problem in Approval.getApprovalActions: "+x)}d.showContent=!0;return d};f.prototype.currentUserApprovalStatus=function(d,
c){try{for(var m=null,f=this.currentUser,e=this.steps[d].approvers,h=0;h<e.length;h++)if(!(null!=c&&c!=h))if(e[h].approvalType===b.ApprovalType.USER)e[h].memberObj.userId==f.userId&&(e[h].approvalStatus===b.ApprovalStatus.PENDING&&(m="MustApprove"),"MustApprove"!=m&&(m=e[h].approvalStatus));else{if((e[h].approvalType===b.ApprovalType.ONE_OF_ROLE?this.findRoleUserObj(f.userId,e[h].memberObj.groupId):a.findMemberObj("User",f.userId,e[h].memberObj.members))&&e[h].approvalStatus===b.ApprovalStatus.PENDING)m=
"MustApprove";"MustApprove"!=m&&e[h].approvedByUserId==f.userId&&(m=e[h].approvalStatus)}return m}catch(g){return window.alert("Problem in Approval.currentUserApprovalStatus: "+g),"MustApprove"}};f.prototype.reset=function(){this.approvalStatus=b.ApprovalStatus.NOT_DEFINED;this.documentVersion=1;this.uponNewVersion="InheritApproval";this.removeAllStages();this.canSubmitApprovalStatus=!0};f.prototype.addTimeToStages=function(a,b){if(!isNaN(a)&&!isNaN(b)&&!(0>a||0>b||24<=b)){var d=new Date;h.each(this.steps,
function(c){c.canModifyDueDate()&&(d=g.addDaysHours(d,a,b,null,!0),c.setDueDate(d))}.bind(this));return!0}return!1};f.prototype.shiftDueDatesOfStages=function(a,b){return!isNaN(a)&&!isNaN(b)&&!(0>a*b||24<=b||-24>=b)?(h.each(this.steps,function(d){d.canModifyDueDate()&&(0<=a&&0<=b?d.addDays(a,b):d.subtractDays(Math.abs(a),Math.abs(b)))}.bind(this)),!0):!1};f.prototype.shiftDueDatesToLatest=function(a,b){var d=h.last(this.steps);if(d.hasRealDueDate()){var c=g.getWorkingTimeDifference(d.getRealDueDate(),
a);d.setDueDate(a);h.each(this.steps.slice().reverse(),function(a,b){0<b&&a.canModifyDueDate()&&(0<c?a.addTime(c):a.subtractTime(-c))}.bind(this));return!0}window.alert(b.t("CAppLastDateAttribute"));return!1};f.prototype.shiftDueDatesToFirst=function(a,b){if(this.steps[0].hasRealDueDate()){var d=g.getWorkingTimeDifference(this.steps[0].getRealDueDate(),a);h.each(this.steps,function(a){a.canModifyDueDate()&&(0<d?a.addTime(d):a.subtractTime(-d))}.bind(this))}else window.alert(b.t("CAppFirstDateAttribute"));
return!0};f.prototype.distributeDueDatesEvenly=function(a,b){var d=g.getWorkingTimeDifference(a,b);if(0>d)return!1;var c=h.filter(this.steps,function(a){return a.canModifyDueDate()});if(0<c.length){var f=a;h.each(c,function(a){f=g.addDaysHours(f,0,0,d/c.length,!0);a.setDueDate(f)}.bind(this))}return!0};f.prototype.changeDueDateType=function(d){var c=this.dueDateType;if(c!==d){this.dueDateType=d;if(this.dueDateType===b.DueDateType.FIXED){var f=a.getNewCurrentTime();c===b.DueDateType.LEAD_TIMES||c===
b.DueDateType.LEAD_TIMES_WITH_FINAL_DATE?h.each(this.steps,function(a){if(a.canModifyDueDate()){var b=a.leadTime;b&&0<b&&(f=g.addDaysHours(f,0,0,b,!0));a.setDueDate(f)}}.bind(this)):c==b.DueDateType.NO&&h.each(this.steps,function(a){a.canModifyDueDate()&&(f=g.addDaysHours(f,1,0,0,!0),a.setDueDate(f))}.bind(this))}else this.dueDateType===b.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&!this.finalDueDate&&(this.finalDueDate=a.getNewCurrentTime());this._emit("changed.duedatetype")}};f.prototype.setFinalDueDate=
function(a){this.finalDueDate!==a&&(this.finalDueDate=a,this._emit("changed.finalduedate"))};f.prototype.setDueDateData=function(a){this.dueDateData!=a&&(this.dueDateData=a,this._emit("changed.duedate"))};f.prototype.changeInheritApproval=function(a){this.uponNewVersion!==a&&(this.uponNewVersion=a,this._emit("changed.uponnewversion"))};f.prototype.changeApprovalMaster=function(a){"$Me$"==a.substring(0,4)?this.currentUser?(this.approvalMasterType=b.ApprovalMasterType.USER,this.approvalMaster=this.currentUser.userId):
this.setError({errorMsg:"No current user while trying to put the approval master on Me"}):"$PM$"==a.substring(0,4)?(this.approvalMasterType=b.ApprovalMasterType.PROJECT_MANAGER,this.approvalMaster=null):"$Uploader$"==a.substring(0,10)?(this.approvalMasterType=b.ApprovalMasterType.UPLOADER,this.approvalMaster=null):"$Group$"==a.substring(0,7)?(this.approvalMasterType=b.ApprovalMasterType.GROUP,this.approvalMaster=a.substring(7,a.length)):(this.approvalMasterType=b.ApprovalMasterType.USER,this.approvalMaster=
a);this._emit("changed.approvalmaster")};f.prototype.readFromXML=function(a){a&&(this.nextVersion&&(a=-1==a.indexOf("?")?a+"?":a+"&",a+="nextDocVersion=true"),this.readApprovalFromURL(a))};f.prototype.validate=function(){var a={errorMsg:"CAppCouldNotSave",errors:[],warnings:[]},d=(new Date).getTime()-72E5,c=-1;this.isComplexApproval()&&h.some(this.steps,function(a){return h.isEmpty(a.getStageName().trim())}.bind(this))&&a.errors.push({tag:"CAppEmptyNameNotAllowed"});h.some(this.steps,function(a){return 50<
a.getStageName().trim().length}.bind(this))&&a.errors.push({tag:"CAppNameTooLong"});var f=h.filter(this.steps,function(a){return a.getStageName().trim()}),e=h.groupBy(f,"name");h.each(h.keys(e),function(b){e[b]&&1<e[b].length&&a.warnings.push({tag:"CAppSameNameWarning",parameters:[b]})});if(this.approvalStatus!==b.ApprovalStatus.NOT_DEFINED)if(!this.steps||0===this.steps.length)!0!==this.approvalRuleChanged&&a.errors.push({tag:"CAppCannotSaveOrStartAnEmptyApprovalSetup"});else{for(f=0;f<this.steps.length;f++){var g=
this.steps[f];if(!g||!g.approvers||0===g.approvers.length)0===f&&""===g.name?a.errors.push({tag:"CAppPleaseSelectApprovers"}):a.errors.push({tag:"CAppEmptyStage",parameters:[f+1+": "+g.name]});this.dueDateType===b.DueDateType.FIXED&&g.canModifyDueDate()&&g.hasRealDueDate()&&(g.getRealDueDate().getTime()<d&&(0===f&&""===g.name?a.warnings.push({tag:"CAppDueDateInPast"}):a.warnings.push({tag:"CAppStageDueDateInPast",parameters:[f+1+": "+g.name]})),g.getRealDueDate().getTime()<c?a.warnings.push({tag:"CAppDueDateBeforePreviousStage",
parameters:[f+1+": "+g.name]}):c=g.getRealDueDate().getTime())}this.dueDateType===b.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&("specific"===this.dueDateData.mode&&this.dueDateData.time&&0<this.dueDateData.time||"offset"===this.dueDateData.mode&&this.dueDateData.item_id?"specific"===this.dueDateData.mode&&this.dueDateData.time<d&&a.warnings.push({tag:"CAppDueDateInPast"}):a.errors.push({tag:"CAppFinalDueDateEmpty"}))}return a};f.prototype.writeToXML=function(){var a;a="<approvalSetup>";this.projectId&&
(a=a+"<project>"+i.ElementEncode("projectId",this.projectId),a+=i.ElementEncode("projectName",this.projectName),a+=i.ElementEncode("projectManagerUserId",this.projectManagerUserId),a+="</project>");this.folderId&&(a+="<folder>",a+=i.ElementEncode("folderId",this.folderId),a+=i.ElementEncode("folderName",this.folderName),a+="</folder>");this.documentId&&(a+="<document>",a+=i.ElementEncode("documentId",this.documentId),a+=i.ElementEncode("documentName",this.documentName),a+=i.ElementEncode("documentVersion",
this.documentVersion),a+="</document>");a+="<general>";a+=i.ElementEncode("dueDateType",this.dueDateType);if(this.dueDateType===b.DueDateType.LEAD_TIMES_WITH_FINAL_DATE)if("offset"==this.dueDateData.mode){var d=this.dueDateData.offset;a+=i.ElementEncode("duedate_attribute_id",this.dueDateData.item_id);a+=i.ElementEncode("duedate_offset",d)}else a+=i.ElementEncode("finalDueDate",this.dueDateData.time);a+=i.ElementEncode("uponNewVersion",this.uponNewVersion);a+=i.ElementEncode("generalApprovalStatus",
this.approvalStatus);a+=i.ElementEncode("approvalMasterType",this.approvalMasterType);this.approvalMaster&&(a+=i.ElementEncode("approvalMaster",this.approvalMaster));a+=this.notificationInfo.writeToXML();a+="</general>";if(this.steps&&0<this.steps.length){a+="<stages>";for(d=0;d<this.steps.length;d++){var c=this.steps[d];if(c)a+=c.writeToXML(d);else throw"Inconsistency in steps, stepObj == null";}a+="</stages>"}return a+="</approvalSetup>"};f.prototype.addNewStage=function(a){var b=this._stageFactory.createApprovalStage();
this.addStage(b,a)};f.prototype.addStage=function(a,b){if(-1<this.steps.indexOf(a))throw"Stage already in steps";"number"===typeof b&&0<=b&&b<this.steps.length?this.steps.splice(b,0,a):this.steps.push(a);this._emit("changed.stages.added",a)};f.prototype.addStageAfter=function(a){var b=this._stageFactory.createApprovalStage(a),a=this.steps.indexOf(a);-1<a&&this.addStage(b,a+1)};f.prototype.removeStage=function(a){var d=this.steps.indexOf(a);-1<d&&this.steps.splice(d,1);0===this.steps.length&&this.setApprovalStatus(b.ApprovalStatus.NOT_DEFINED);
this._emit("changed.stages.deleted",a)};f.prototype.removeAllStages=function(){var a=["changed.stages.deleted"];Array.prototype.push.apply(a,this.steps);this.steps=[];this.setApprovalStatus(b.ApprovalStatus.NOT_DEFINED);this._emit.apply(this,a)};f.prototype.setApprovalStatus=function(a){this.approvalStatus!==a&&(this.approvalStatus=a,this._emit("changed.approvalstatus"))};f.prototype.getStageNumber=function(a){return this.steps.indexOf(a)+1};f.prototype.getStageAtIndex=function(a){return this.steps[a]};
f.prototype.getStageCount=function(){return this.steps.length};f.prototype.getStages=function(){return this.steps};f.prototype.moveStage=function(a,b){b>=this.steps.length&&(b=this.steps.length-1);if(a!==b){var d=this.steps[a];d&&(this.steps.splice(a,1),this.steps.splice(b,0,d),this._emit("changed.stages.moved",d))}};f.prototype.getCurrentUserString=function(){var b="";if(this.currentUser&&this.currentUser.userId){var d=a.findMemberObj("User",this.currentUser.userId,this.projectMembers);d&&(b+=l.getUserNameString(d.firstName,
d.lastName,d.userName))}return b};f.prototype.getDelegateUserString=function(){var a="";if(this.currentUser){var b=this.currentUser.delegateUsername,d=this.currentUser.delegateFirstname,c=this.currentUser.delegateLastname;if(b||d||c)a=l.getUserNameString(d,c,b)}return a};f.prototype.isValidStageName=function(a){return!h.find(this.steps,function(b){return a&&b&&b!==a&&b.getStageName()===a.getStageName()})};f.prototype.getApprovalStatus=function(){return this.approvalStatus===b.ApprovalStatus.PENDING&&
this.globalStatus&&this.globalStatus.status===b.ApprovalStatus.NOT_STARTED?this.globalStatus.status:this.approvalStatus};f.prototype.getApprovalDetailsData=function(){var d={};d.isComplexApproval=this.isComplexApproval();d.steps=[];h.each(this.steps,function(c,f){var e={};d.steps.push(e);e.internalNumber=f;e.number=f+1;e.name=c.name;e.status=c.approvalStatus;if(c.approvalStatus!==b.ApprovalStatus.NOT_STARTED&&c.approvalStatus!==b.ApprovalStatus.PENDING){var g=-1;h.each(c.approvers,function(a){(a=
a.approvalTime)&&a.constructor==Date&&(a=a.getTime());a>g&&(g=a)}.bind(this));0<g&&(e.approvalTime=new Date(g))}e.approvers=[];if(c.approvers)for(var k=0;k<c.approvers.length;k++){var j={};e.approvers.push(j);var i=c.approvers[k];if(i){var r=i.memberObj;if(r){j.user=a.getUserRepresentation(r);j.internalNumber=k;j.type=i.approvalType;j.isRole&&(j.type=j.type.replace("Group","Role"));j.typeLangTag=a.getApprovalTypeLangTag(i);j.status=i.approvalStatus;i.approvedVersion&&(j.approvedVersion=i.approvedVersion,
j.isDifferentVersionApproved=i.approvedVersion!=this.documentVersion);j.approvalTime=i.approvalTime;if(i.approvedByUserId){var r=this.getUserObj(i.approvedByUserId),x=i.approvedAsUserId?this.getUserObj(i.approvedAsUserId):null;j.approvedBy=a.getUserRepresentation(r,x)}i.commentArr&&0<i.commentArr.length&&(j.comments=i.commentArr)}}}}.bind(this));return d};f.prototype.isApprovalStarted=function(){return!(this.approvalStatus===b.ApprovalStatus.NOT_STARTED||this.approvalStatus===b.ApprovalStatus.NOT_DEFINED)};
f.prototype.forceStep=function(a){this.forcedStep=a};f.prototype.getActiveStep=function(){for(var a=0;a<this.steps.length;a++)if(this.steps[a]&&this.steps[a].approvalStatus===b.ApprovalStatus.PENDING)return a;return-1};f.prototype.isUserPendingApprover=function(){return 0<=this.getActiveStep()?"MustApprove"===this.currentUserApprovalStatus(this.getActiveStep()):!1};f.prototype.isUserApprover=function(){for(var d=this.currentUser.userId,c=0;c<this.steps.length;c++){var f=this.steps[c];if(f.approvers)for(var e=
0;e<f.approvers.length;e++){var h=f.approvers[e];if(h.approvalType===b.ApprovalType.USER&&h.memberObj.userId==d||h.approvalType===b.ApprovalType.ONE_OF_ROLE&&this.findRoleUserObj(d,h.memberObj.groupId)||a.findMemberObj("User",d,h.memberObj.members))return!0}}return!1};f.getApprovalInfo=function(a){window.gProjectId&&v.ajax({url:"complexapproval.jsp?action=GetBootInfo&projectID="+window.gProjectId+"&docVerID="+window.gDocVersionId,type:"GET",data:"xml",debug:!1,timeout:12E4,synchronous:!1,cache:!1,
success:function(b){b=i.xml2obj(b);if(!b.error&&(b=b.complexApprovalBootInfo)&&"1"!=b.isLinkedDocument){var d="complexapproval.jsp?projectID="+window.gProjectId+"&docVerID="+window.gDocVersionId+"&returnURL=docdetailsapprovers.jsp&urlwanted=docdetailsapprovers.jsp&menu_file=&docID="+window.gDocId+"&folderID=",b=new f({readURL:d,actionURL:d,getProjectFolderSetupURL:d+"&action=Inherit",currentUser:{userId:b.userId,userName:b.userName,lastName:b.lastName,firstName:b.firstName,isProjectManager:"1"==b.isProjectManager,
isAdmin:"1"==b.isAdmin,canForceApprove:"1"==b.canForceApprove,canForceReject:"1"==b.canForceReject,canChangeSetup:"1"==b.canChangeSetup,canStartApproval:"1"==b.canStartApproval,canSeeOthers:"1"==b.canSeeOthers,canCreateUsers:"1"==b.canCreateUsers},nextVersion:!1,stagedApprovalAllowed:"1"==b.stagedApprovalAllowed,isViewFile:"1"===b.isViewable,menuFile:this.menuFile});b.on("initialized",h.partial(a,b))}},error:function(a,b,d){"SESSION_EXP"==d&&null!=window.loginForm?window.loginForm.submit():window.alert("Error in loadApprovalUser: "+
a)}})};f.prototype.getProjectMembers=function(){return this.projectMembers};f.prototype.getProjectId=function(){return this.projectId};f.prototype.getFolderId=function(){return this.folderId};f.prototype.submit=function(a){this._emit("submit",a)};f.prototype.isStagedApprovalAllowed=function(){return this.stagedApprovalAllowed};f.prototype.isComplexApproval=function(){return 1<this.steps.length};f.prototype.isProjectSetupAvailable=function(){return(this.documentId||this.folderId||!0===this.isMultiDocSetup)&&
this.hasProjectApprovalSetup};f.prototype.isFolderSetupAvailable=function(){return(this.documentId||!0===this.isMultiDocSetup)&&this.hasFolderApprovalSetup};f.prototype.userCanChangeSetup=function(){return this.currentUser&&this.currentUser.canChangeSetup};f.prototype.getUserObj=function(b){var d=a.findMemberObj("User",b,this.projectMembers);d||(d=a.findMemberObj("User",b,this.usersWithNoAccess));return d};f.prototype.getUserAndDelegatorNameString=function(a,b,d){var c=this.getUserObj(a),a=c?l.getUserNameStringActiveText(c.firstName,
c.lastName,c.userName,c.isActive,d.t("CAppUserDeactivated")):a;b&&(b=(c=this.getUserObj(b))?l.getUserNameStringActiveText(c.firstName,c.lastName,c.userName,c.isActive,d.t("CAppUserDeactivated")):b,a+=" "+d.t("CAppApprovalDoneAsUser")+" "+b);return a};f.prototype.getWorkflowTaskId=function(){for(var a=this.getStages(),b="",d=0;d<this.getStageCount();d++)b=a[d].workflowTaskId;return b};f.prototype.isWorkflowDriven=function(){return 0<this.getWorkflowTaskId().length};f.prototype.getMenuFile=function(){return this.menuFile};
f.prototype.hasReasonsForRejection=function(){return h.any(this.getStages(),function(a){return a.hasReasonsForRejection()})};f.prototype.hasRoleAssigneeGroupMembers=function(){return h.any(this.getStages(),function(a){return a.hasRoleAssigneeGroupMembers()})};f.prototype.isReasonsForRejectionEnabled=function(){return this.reasonsForRejectionEnabled};return f});
define("approval/model/ApproveRejectViewModel",["utils/Observable","underscore"],function(b){function a(a){b.mixin(this,"approval");this.actionURL=a.actionURL||null;this.isEncapsulated=a.isEncapsulated||null;this.isViewable=a.isViewable||null;this.onUpdateCallback=a.onUpdateCallback||function(){};this.docVersionID=a.docVersionID||null;this.docName=a.docName||null;this.pageRange=this.approveRejectCallback=null}a.prototype.setPageRange=function(a,b,n){var k="";void 0!==a&&(a=String(a));if(!a||!a.trim()){if(n)return"CAppEmptyPageRange";
this.pageRange=null}else{if("all"!=a.trim())for(var n=!0,d=a.trim().split(","),p=0;p<d.length;p++){n?n=!1:k+=",";var e=d[p].trim().split("-");if(1>e.length||2<e.length)return"CAppInvalidPageRangeExample";for(var j=0;j<e.length;j++){var g=e[j].trim();if(isNaN(parseInt(g)))return"CAppInvalidPageRangeExample";if(1===j){var l=e[0].trim();if(parseInt(g)<parseInt(l))return"CAppInvalidPageRangeExample";k+="-"}k+=parseInt(e[j])-1}}this.pageRange=b?k:a}return""};a.prototype.setBeforeSubmitAction=function(a){this.beforesubmit=
a};a.prototype.submit=function(a){this._emit("submit",a)};return a});
define("approval/controller/SortableController",["jquery","jqueryUI","jqueryUITouchPunch"],function(){var b=function(a,b){var q=null,n=null;this._approvalView=a;a.getStagesContainer().sortable({axis:"y",items:".approval-stage-container-sortable",cancel:"input,select,a,label",scroll:"false",cursor:"grabbing",containment:"body",placeholder:"approval-stage-container-sortable-placeholder",forcePlaceholderSize:!0,handle:".sortable-handler",tolerance:"intersect",start:function(a,b){b.item.addClass("being-sorted");
q=b.item.index()},stop:function(a,d){n=d.item.index();d.item.removeClass("being-sorted");b.moveStage(q,n)}.bind(this)})};b.prototype.disable=function(){this._approvalView.getStagesContainer().sortable("disable")};b.prototype.enable=function(){this._approvalView.getStagesContainer().sortable("enable")};return b});
define("approval/view/NotificationView",["approval/ApprovalConstants","utils/webi18n!Approval","underscore","wcr/webcenter_xml"],function(b,a,c,q){function n(a,b){this._model=a;this._showNotifications=!0;this._editable=b;this._editMode=!1;this._model.on("update",c.bind(this.render,this))}n.prototype.setElement=function(a){this.elem=a;this.render()};n.prototype.render=function(){if(this.elem){var k=$("<div />").addClass("form-group");if(this._editMode){k.append($("<label />").text(a.t("CAppNotifications")));
this.notificationSelector=this._displayNotificationsSelector();k.append($("<div />").addClass("form-entry").html(this.notificationSelector));if(this._model.notificationType!==b.NotificationType.NO_NOTIFICATIONS){var d=$("<div />").addClass("form-group");d.append($("<label />").addClass("offset-label"));var p=$('<a href="#" />').click(c.bind(function(a){this._toggleShowNotifications();a.preventDefault()},this)).text(this._showNotifications?a.t("CAppHideNotifications"):a.t("CAppShowNotifications"));
d.append($("<div />").addClass("form-entry").append($("<p />").append(p)));k.append(d)}this._showNotifications&&k.append(this._displayNotifications())}else if(d=this._model.notificationType,$("<label>",{text:a.t("CAppNotifications")}).appendTo(k),p=$("<div/>",{"class":"form-entry"}).appendTo(k),d=$("<p>",{text:this._getLabel(d)}).appendTo(p),this._editable)d.append($("<a>",{"class":"btn btn-no-border","data-sahi-id":"approval_notif_select_edit"}).append($("<i>",{"class":"icon icon-WCR_Actions-Edit12"}))).on("click",
c.bind(function(){this._editMode=!0;this.render()},this));this.elem.html(k)}};n.prototype._displayNotificationsSelector=function(){var a=[b.NotificationType.NO_NOTIFICATIONS,b.NotificationType.DEFAULT_NOTIFICATIONS,b.NotificationType.CUSTOM_NOTIFICATIONS];!this._model.approvalModel.documentId&&!this._model.approvalModel.folderId&&(a=[b.NotificationType.NO_NOTIFICATIONS,b.NotificationType.CUSTOM_NOTIFICATIONS]);var d=$("<select>",{"class":"form-control","data-sahi-id":"approval_notif_select"});d.change(c.bind(this._changeNotificationSelector,
this));c.each(a,function(a){var b=$("<option>",{value:a,text:this._getLabel(a)});this._model.notificationType===a&&b.prop("selected","true");d.append(b)}.bind(this));return d};n.prototype._displayNotifications=function(){var k=null,d=!1;this._model.notificationType===b.NotificationType.DEFAULT_NOTIFICATIONS&&(k=null!=this._model.approvalModel.folderId&&null==this._model.approvalModel.documentId?this._model.projectNotificationsArr:this._model.defaultNotificationsArr,d=!0);this._model.notificationType==
b.NotificationType.CUSTOM_NOTIFICATIONS&&(k=this._model.notificationsArr);if(!k)return"";var p=$("<div />").addClass("form-group");p.append($("<label />").addClass("offset-label"));var e=$("<table>",{"class":"table",name:"CAppNotificationTable"}),j=$("<tr />");e.append($("<thead />").append(j));p.append($("<div />").addClass("form-entry").append(e));j.append($("<th />").text(a.t("CAppNotification")));for(var g,l=b.notificationTypeArr,i=["projectManager","involvedPeople","projectMembers"],h,n=0;n<
i.length;n++){var f=!0;for(h=0;h<l.length;h++)if(!1===k[h][i[n]]){f=!1;break}g='<th class="td-checkbox"><div><div>';"projectManager"==i[n]?g+=q.xmlencode(a.t("CAppManager")):"involvedPeople"==i[n]?g+="<a target='blank' href='projdetailsevents_invpeople.jsp'>"+q.xmlencode(a.t("CAppInvolvedPeople"))+"</a>":"projectMembers"==i[n]&&(g+=q.xmlencode(a.t("CAppMembers")));g+="</div>";!1===d&&(g+='<div><input id="notification_'+n+'_All" type="checkbox"',f&&(g+=" checked "),g+="></div>");g+="</div>";g+="</th>";
h=$(g);g=n;h.find("#notification_"+n+"_All").click(c.bind(function(a,b){this._model.toggleNotificationColumn(a,b.is(":checked"))},this,g,h.find("#notification_"+n+"_All")));j.append(h)}for(h=0;h<l.length;h++){j=h;g="<tr>";g+="<td>"+q.xmlencode(a.t("CApp"+l[h]))+"</td>";i="notificationCheck_"+h;g+='<td class="td-checkbox"><input id="'+i+'_0" data-sahi-id='+i+'_0" type="checkbox"';!0===k[h].projectManager&&(g+=" checked ");d&&(g+=' disabled="disabled" ');g+="></td>";g+='<td class="td-checkbox"><input id="'+
i+'_1" data-sahi-id='+i+'_1" type="checkbox"';!0===k[h].involvedPeople&&(g+=" checked ");d&&(g+=' disabled="disabled" ');g+="></td>";g+='<td class="td-checkbox"><input id="'+i+'_2" data-sahi-id='+i+'_2" type="checkbox"';!0===k[h].projectMembers&&(g+=" checked ");d&&(g+=' disabled="disabled" ');g+='"></td>';g+="</tr>";g=$(g);for(i=0;3>i;i++)n=i,g.find("#notificationCheck_"+j+"_"+n).click(c.bind(c.bind(function(a,b,d){this._model.toggleNotification(a,b,d.is(":checked"))},this,j,n,g.find("#notificationCheck_"+
j+"_"+n))));e.append(g)}return p};n.prototype._toggleShowNotifications=function(){this._showNotifications=!this._showNotifications;this.render()};n.prototype._changeNotificationSelector=function(){this._model.setNotificationType(this.notificationSelector.val())};n.prototype._getLabel=function(c){if(c===b.NotificationType.DEFAULT_NOTIFICATIONS)return this._model.approvalModel.documentId&&this._model.approvalModel.folderId&&this._model.approvalModel.hasFolderApprovalSetup?a.t("CAppFolderNotifications"):
a.t("CAppProjectNotifications");if(c===b.NotificationType.CUSTOM_NOTIFICATIONS)return!this._model.approvalModel.documentId&&!this._model.approvalModel.folderId?a.t("CAppProjectNotifications"):a.t("CAppCustomNotifications");if(c===b.NotificationType.NO_NOTIFICATIONS)return a.t("CAppNoNotifications")};return n});
define("tpl!approval/view/template/ApproversTableCommentHover",function(){return function(b){var a;return b=""+('<table class="table comment-hover" name="comment-hover-table">\r\n\t<tr>\r\n\t\t<th style="text-align:left">'+(null==(a=b.i18n("CAppUser"))?"":_.escape(a))+'</th>\r\n\t\t<th style="text-align:center">'+(null==(a=b.i18n("CAppCommentTime"))?"":_.escape(a))+'</th>\r\n\t\t<th style="text-align:center">'+(null==(a=b.i18n("CAppVersion"))?"":_.escape(a))+"</th>\r\n\t\t<th>"+(null==(a=b.i18n("CAppComment"))?
"":_.escape(a))+"</th>\r\n\t</tr>\r\n</table>")}});
define("approval/view/CommentHoverView","approval/ApprovalUtils tpl!approval/view/template/ApproversTableCommentHover utils/webi18n!Approval Template underscore wcr/webcenter_html".split(" "),function(b,a,c,q,n){function k(a){this.model=a}k.prototype.open=function(d,k){if(!n.isEmpty(this.model.approvers)){var e=this.model.approvers[d];if(e&&!n.isEmpty(e.commentArr)){var j=new q(c,a),g=$(j.getRenderedHtml());n.each(e.commentArr,function(a,d){var e=$("<tr>",{name:"comment_"+d}),j="";a.commentTime&&
(j=b.getDateHourString(a.commentTime));e.append($('<td valign="top" class="comment-by">'),$('<td valign="top" style="text-align:center">').text(j),$('<td valign="top" style="text-align:center">').text(a.commentVersion),$('<td valign="top" class="comment-text">').text(a.commentText));g.append(e);var j=a.commentByUserId,f="";a.commentByDelegateId&&(f=j,j=a.commentByDelegateId);j=this.model.approvalModel.getUserAndDelegatorNameString(j,f,c);$("td.comment-by",e).text(j)}.bind(this));this._showCommentHoverView(k,
g)}}};k.prototype._showCommentHoverView=function(a,b){var c=$(a.target),j=$("#dropmenudiv"),g=b.wrap("<div/>").parent().html();dropdownmenu(c.get(0),a,[g],600,"auto",null,!0,"#ffffcc",!1,null,350);j.addClass("approval_comment_popup");var g=$(window).height(),k=$(window).scrollTop(),i=j.outerHeight(!0),h=j.offset(),q=c.height(),c=c.offset();g<=c.top-k+q+i&&j.offset({top:c.top-i,left:h.left})};return k});
define("approval/view/ReasonsForRejectionView",["underscore","component/contentoverflow/OverflowContentContainer","utils/init","wcr/webcenter_xml"],function(b,a,c,q){var n=function(a){this._element=$("<div>").addClass("reasonsForRejection");this._reasons=this._parseReasons(a)};n.prototype.getOverflowContainer=function(){this._overflow||(this._renderReasonsAsDiv(this._reasons),this._overflow=new a(this._element,100));return this._overflow};n.prototype.onChanged=function(a){if(this._overflow)this._overflow.onChanged(a);
else throw Error("Call getOverflowContainer first");};n.prototype.connectToOverflowContainer=function(a){if(!this._overflow)throw Error("Call getOverflowContainer first");c.whenInitialized(a,b.bind(function(){$.each(a,b.bind(function(a,c){var e=$(c).closest(".overflowcontentcontainer");if(e&&1===e.length){var j=e.get(0).OverflowContentContainer;j&&(j.onChanged(b.bind(function(a,b){"CLICK"===b&&(a?this._overflow.expand("CLICK_OTHER"):this._overflow.collapse("CLICK_OTHER"))},this)),this._overflow.onChanged(b.bind(function(a,
b){"CLICK"===b&&(a?j.expand("CLICK_OTHER"):j.collapse("CLICK_OTHER"))},this)))}},this))},this))};n.prototype.getSimpleListElement=function(){this._renderReasonsAsUlLi(this._reasons);return this._element};n.prototype.getSimpleElement=function(){this._renderReasonsAsBr(this._reasons);return this._element};n.prototype._renderReasonsAsDiv=function(a){this._element.empty();b.each(a,function(a){var b=a.reason;a.category&&(b+=" ("+a.category+")");this._element.append($("<div>").text(b))},this)};n.prototype._renderReasonsAsBr=
function(a){var d="";b.each(a,function(a,b){0<b&&(d+="<br>");d+=q.xmlencode(a.reason);a.category&&(d+=q.xmlencode(" ("+a.category+")"))});this._element.empty().append(d)};n.prototype._renderReasonsAsUlLi=function(a){var d="<ul>";b.each(a,function(a){d+="<li>"+q.xmlencode(a.reason);a.category&&(d+=q.xmlencode(" ("+a.category+")"));d+="</li>"});d+="</ul>";this._element.empty().append(d)};n.prototype._parseReasons=function(a){var a=a.split(" | "),d=[];b.each(a,function(a){var b="",c="",g=a.lastIndexOf(" @ ");
-1<g?(b=a.substring(0,g),c=a.substring(g+3)):b=a;d.push({reason:b,category:c})});return b.sortBy(d,function(a){return a.category+a.reason})};n.wcrinit=function(a){var b=$(a).attr("data-reasonsForRejection"),c=$(a).attr("data-connectedOverflowContainers"),b=new n(b),e=b.getOverflowContainer().getJQElement();$(a).append(e);c&&(a=$(a).parent().parent(),c=$(c,a),b.connectToOverflowContainer(c))};return n});
define("tpl!approval/view/template/ApproversTable",function(){return function(b){var a,c;c=""+('<div class="wcr-table no-margin" data-init="component/table/Table" >\r\n\t<div class="wcr-table-section">\r\n\t\t<table class="ordtable" data-sahi-id="CAppObjApprovalTable_'+(null==(a=b.stageIndex)?"":_.escape(a))+'">\r\n\t\t\t<thead>\r\n\t\t\t\t<tr>\r\n\t\t\t\t\t');b.showRemoveColumn&&(c+='\r\n\t\t\t\t\t\t<th class="td-narrow">\r\n\t\t\t\t\t\t\t<i class="icon icon-normal icon-WCR_Remove show-cursor-pointer approval-delete-icon" name="approvers-remove-all" title="'+
(null==(a=b.i18n("CAppRemoveAllApprovers"))?"":_.escape(a))+'"></i>\r\n\t\t\t\t\t\t</th>\r\n\t\t\t\t\t');c+="\r\n\r\n\t\t\t\t\t<th>"+(null==(a=b.i18n("CAppApprover"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t";b.showRoleAssigneeGroupMembersColumn&&(c+="\r\n\t\t\t\t\t\t<th>"+(null==(a=b.i18n("CAppRoleAssigneesOrGroupMembers"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t");c+="\r\n\t\t\t\t\t";b.simpleLayout||(c+="\t\t\t\t\t\t\r\n\t\t\t\t\t<th>"+(null==(a=b.i18n("CAppUserType"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t");
c+="\t\t\t\t\t\r\n\t\t\t\t\t";if(b.showAllColumns||b.simpleLayout)c=b.simpleLayout?c+('\r\n\t\t\t\t\t\t\t<th class="status">'+(null==(a=b.i18n("CAppStatus"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t\t"):c+('\r\n\t\t\t\t\t\t<th class="td-status">'+(null==(a=b.i18n("CAppStatusVersion"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t\t"),c+="\r\n\t\t\t\t\t";c+="\r\n\t\t\t\t\t";b.showAllColumns&&!b.simpleLayout?(c+='\r\n\t\t\t\t\t\t<th class="td-date">'+(null==(a=b.i18n("CAppApprovalDate"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t\t<th>"+
(null==(a=b.i18n("CAppApprovedBy"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t\t",b.showReasonsForRejectionColumn&&(c+="\r\n\t\t\t\t\t\t\t<th>"+(null==(a=b.i18n("CAppReasonsForRejection"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t\t"),c+="\r\n\t\t\t\t\t\t<th>"+(null==(a=b.i18n("CAppApprovalCommentCondition"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t"):b.simpleLayout&&b.hasComments&&(c+='\r\n\t\t\t\t\t\t<th class="td-status">'+(null==(a=b.i18n("CAppComment"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t");return c+'\r\n\r\n\t\t\t\t</tr>\r\n\t\t\t</thead>\r\n\t\t\t<tbody name="approvers-body">\r\n\t\t\t\t\t<\!-- Filled in by ApproversTable.js --\>\t\r\n\t\t\t</tbody>\r\n\t\t</table>\r\n\t</div>\r\n</div>'}});
define("approval/view/ApproversTable","approval/ApprovalConstants approval/ApprovalUtils approval/view/CommentHoverView approval/view/ReasonsForRejectionView utils/Observer tpl!approval/view/template/ApproversTable utils/webi18n!Approval utils/Promisify component/tooltip/Tooltip component/contentoverflow/OverflowContentContainer component/objectdetailspopover/ObjectDetailsPopoverFactory webcenterapi/data/WebCenterUser webcenterapi/data/WebCenterGroup webcenterapi/data/WebCenterRole Template jquery underscore wcr/webcenter_html wcr/webcenter_xml".split(" "),
function(b,a,c,q,n,k,d,p,e,j,g,l,i,h,v,f,s,w,m){function u(a,b){n.mixin(this);this._options=s.extend({},b);this.model=a;this._observe(this.model,"changed.approvers.*",this.render,this);this._observe(this.model,"deleted",this._stopObserveAll,this);this._commentHoverView=new c(this.model)}u.prototype.setElement=function(a){this.elem=a;this.render()};u.prototype.render=function(){if(this.elem){var a=new v(d,k);a.d.showRemoveColumn=this._showRemoveColumn();a.d.showAllColumns=this._showAllColumns();a.d.stageIndex=
this.model.number-1;a.d.showReasonsForRejectionColumn=this._showReasonsForRejection();a.d.showRoleAssigneeGroupMembersColumn=this._showRoleAssigneeGroupMembersColumn();a.d.hasComments=!!s.find(this.model.approvers,function(a){return a.commentArr&&0<a.commentArr.length});a.d=s.extend(a.d,this._options);a.setContext(this.elem);a.bind("click","[name=approvers-remove-all]",function(){this.model.removeAllApprovers()}.bind(this));var a=f(a.getRenderedHtml()),b=a.find("[name=approvers-body]");s.isEmpty(this.model.approvers)?
b.append(f("<tr>").append(f('<td colspan="7">').append(f("<em>",{text:d.t("CAppNoApproversInStep")})))):s.each(this.model.approvers,function(a,d){if(a&&a.memberObj){var c=!1,f=!1;0<d&&(f=a.equalsOriginalGroupApprover(this.model.approvers[d-1]));a.needToCreateAllOfGroupRow()&&!f&&(b.append(this._generateDummyAllOfGroupRowElement(a,d)),c=!0);b.append(this._generateRowElement(a,d,c))}}.bind(this));g.enablePopoversInContainer(b,".approver",function(a){var b=f(a).attr("data-type"),d=f(a).attr("data-id");
if("user"===b)return{type:"user",data:Promise.resolve().then(function(){return p.require("webcenterapi/UserAPI").then(function(a){return(new a(window.webcenterConfig)).getUser(d)})})};if("group"===b)return a=s.find(this.model.approvalModel.projectMembers,function(a){return a.groupId&&a.groupId===d}),b=s.map(a.members,function(a){return new l(a.userId,a.userName,a.firstName,a.lastName,a.eMail,a.isActive)}),{type:"group",data:new i(a.groupId,a.groupName,b)};if("role"===b){var a=s.find(this.model.approvalModel.roleAssignments,
function(a){return d===a.roleID}),b=s.map(a.userRoleAssignments,function(a){return new l(a.ID,a.userName,a.firstName,a.lastName,"",a.isActive)}),c=s.map(a.groupRoleAssignments,function(a){var b=new i(a.ID,a.name);a.assignee&&b.setGroupAssignee(new l(a.assignee.ID,a.assignee.userName,a.assignee.firstName,a.assignee.lastName,"",a.assignee.isActive));return b});return{type:"group",data:new h(a.roleID,a.roleName,[].concat(b).concat(c))}}}.bind(this),{placement:"right"});this.elem.html(a)}};u.prototype._generateDummyAllOfGroupRowElement=
function(a,b){var c=f("<tr>");this._showRemoveColumn()&&this._generateRemoveButtonHTML(c,b);this._generateApproverHTML(c,a,b);var e=a.getOriginalGroup(),r=!1;0<b&&(r=a.equalsOriginalGroupApprover(this.model.approvers[b-1]));e&&!r&&(e=f('<td class="td-nowrap add-spacing-right">').append(f("<span>",{"class":"approver",text:e}).prepend(f("<i>",{"class":"icon icon-normal icon-green icon-WCR_Assignee-Group",title:d.t("CAppGroup")}),"&nbsp;").attr({"data-type":"group","data-id":a.originalApprovalGroupId})),
c.append(e));e=f("<td>");c.append(e);e.append(d.t("CAppAllOfGroup"));e=f("<td colspan='7'/>");c.append(e);return c};u.prototype._generateRowElement=function(c,h,g){var i=f("<tr>"),r=c.memberObj;this._showRemoveColumn()&&this._generateRemoveButtonHTML(i,h);this._generateApproverHTML(i,c,h,g);this._showRoleAssigneeGroupMembersColumn()&&this._generateRoleAssignmentGroupMembersHTML(i,c,h);var g=!this.model.canModifyApprovers(),x="User"===c.approvalType||this.model.approvalModel.approvalStatus!==b.ApprovalStatus.NOT_STARTED||
this.model.approvalModel.readOnly||g;this._options.simpleLayout||(g=f('<td class="td-nowrap ">'),i.append(g),x?c.needToCreateAllOfGroupRow()||g.append(d.t(a.getApprovalTypeLangTag(c))):(x=f("<select>",{"class":"form-control",on:{change:function(a){this.model.changeGroupApprover(h,a.target.value)}.bind(this)}}),g.addClass("type-drop-down"),g.append(x),x.attr("data-sahi-id","CAppObjGroupApproverSelector_"+(this.model.number-1)+"_"+h),r.isRole&&x.append(f("<option>",{value:"OneOfRole",text:d.t("CAppOneOfRole")})),
x.append(f("<option>",{value:"OneOfGroup",text:r.isRole?d.t("CAppAllOfRoleOneOfGroup"):d.t("CAppOneOfGroup")})),x.append(f("<option>",{value:"AllOfGroup",text:r.isRole?d.t("CAppAllOfRole"):d.t("CAppAllOfGroup")})),x.val(c.approvalType)));var r=f("<td>").addClass("td-status"),k;if(this._showAllColumns()||this._options.simpleLayout){var l=c.approvalStatus===b.ApprovalStatus.PENDING&&this.model.approvalStatus!==b.ApprovalStatus.PENDING;i.append(r);c.approvalStatus&&(c.approvalStatus!==b.ApprovalStatus.NOT_STARTED&&
!l)&&(k=f("<i>",{"class":b.images[c.approvalStatus]+" "+b.imageColors[c.approvalStatus]}),r.append(k),this._options.simpleLayout?r.addClass("status"):c.approvedVersion&&(c.approvedVersion!==this.model.approvalModel.documentVersion?r.append(f("<span>").append("&nbsp;("+c.approvedVersion+")")):r.append("&nbsp;("+c.approvedVersion+")")))}if(this._showAllColumns()){var r=f("<div>"),n;this._options.simpleLayout||(n=f("<td>"),i.append(n));c.approvalTime&&(this._options.simpleLayout&&(n=f("<div>"),r.append(n)),
n.addClass("td-date"),n.append(a.getDateHourString(c.approvalTime)));var p;this._options.simpleLayout||(p=f("<td>"),i.append(p));n=c.approvedByUserId;g=c.approvedAsUserId;n&&(this._options.simpleLayout&&(p=f("<div>"),r.append(p)),g=this.model.approvalModel.getUserAndDelegatorNameString(n,g,d),p.append(f("<span>",{"class":"approver",text:g}).attr({"data-type":"user","data-id":n})));l||r.append(f("<div>").text(d.t("CApp"+c.approvalStatus)));l=null;this._showReasonsForRejection()&&(l=new q(c.getReasonsForRejectionString()),
this._options.simpleLayout||(p=l.getOverflowContainer(),i.append(f("<td>").addClass("td-fill-half").append(p.getJQElement()))));var w;this._options.simpleLayout?s.find(this.model.approvers,function(a){return a.commentArr&&0<a.commentArr.length})&&(w=f("<td class='status'>"),i.append(w)):(w=f("<td>").addClass("td-fill-half"),i.append(w));s.isEmpty(c.commentArr)||(c=s.map(c.commentArr,function(a){return m.xmlencode(a.commentText)}).join("<br>"),this._options.simpleLayout?(p=f("<i>").addClass("icon icon-WCR_Text-Comment icon-normal"),
w.append(p),w=f("<div>"),l&&(w.append(f("<div>").text(d.t("CAppReasonsForRejection"))),w.append(l.getSimpleListElement())),c&&(l&&w.append(f("<div>").text(d.t("CAppComment"))),w.append(f("<div>").html(c))),c=new e(d,p,f("body"),f("body"),!1,""),c.setContent(w)):c&&(this._hideCommentHoverView||(this._hideCommentHoverView=function(){f("#dropmenudiv").is(":hover")||(delayhidemenu(),f("#dropmenudiv").unbind("mouseout"))}),w.mouseover(function(a){this._commentHoverView.open(h,a);f("#dropmenudiv").mouseout(this._hideCommentHoverView)}.bind(this)),
w.mouseout(this._hideCommentHoverView),p=f("<div>"),p.html(c),c=(new j(p,100)).getJQElement(),w.append(c),l&&l.connectToOverflowContainer(c)));0<r.children().length&&(c=new e(d,k?k:this.elem,f("body"),f("body"),!1,""),c.setContent(r))}return i};u.prototype._showAllColumns=function(){return this.model.approvalModel.steps[0].approvalStatus!==b.ApprovalStatus.NOT_STARTED};u.prototype._generateApproverHTML=function(b,c,e,h){var r=c.memberObj,g=!1;0<e&&(g=c.equalsOriginalApprover(this.model.approvers[e-
1]));g||h?(b.addClass("tr-no-top-border"),b.append(f("<td>",{"class":"td-nowrap"}).append(f("<td>")))):c.isApproverRole()?(r=c.getRoleName(),b.append(f("<td>",{"class":"td-nowrap"}).append(f("<span>",{"class":"approver",text:r}).prepend(f("<i>",{"class":"icon icon-normal icon-blue icon-WCR_Assignee-Role"}),"&nbsp;").attr({"data-type":"role","data-id":c.getRoleID()})))):c.isApproverGroup()?(r=c.getGroupName(),r=f('<td class="td-nowrap">').append(f("<span>",{"class":"approver",text:r}).prepend(f("<i>",
{"class":"icon icon-normal icon-green icon-WCR_Assignee-Group",title:d.t("CAppGroup")}),"&nbsp;").attr({"data-type":"group","data-id":c.getGroupID()})),(c=a.findMemberObj("Group",c.getGroupID(),this.model.approvalModel.getProjectMembers()))&&(c.isMember&&s.isEmpty(c.members))&&r.append(document.createTextNode(" "+d.t("CAppEmptyIndicator"))),b.append(r)):(c=w.getUserNameStringActiveHTML(null,r.firstName,r.lastName,r.userName,r.isActive,d.t("CAppUserDeactivated")),b.append(f('<td class="td-nowrap">').attr({"data-user-id":r.userName}).append(f("<span>",
{"class":"approver"}).append(f(c)).attr({"data-type":"user","data-id":r.userId}))))};u.prototype._needToGenerateAllOfGroupRow=function(a){return a.isApproverRole()&&a.hasExpandedApprover()&&a.getOriginalGroup()};u.prototype._generateRemoveButtonHTML=function(a,b){a.append(f('<td class="td-centered">').append(f("<i>",{"class":"icon icon-normal icon-WCR_Remove show-cursor-pointer approval-delete-icon",title:d.t("CAppRemove"),on:{click:function(){this.model.removeApprover(b)}.bind(this)}})))};u.prototype._generateRoleAssignmentGroupMembersHTML=
function(b,c){var e=c.memberObj;if(c.hasExpandedApprover())if(c.isUserAssignment()){var h=c.getOriginalGroup(),r=w.getUserNameStringActiveHTML(null,e.firstName,e.lastName,e.userName,e.isActive,d.t("CAppUserDeactivated"));h?(c.isApproverRole()&&(r=w.getUserNameStringActiveHTML(null,e.firstName,e.lastName,e.userName,e.isActive,d.t("CAppUserDeactivated"),!1,"add-spacing-left")),b.append(f('<td class="td-nowrap" >').attr("data-user-id",e.userName).append(f("<span>",{"class":"approver"}).append(f(r)).attr({"data-type":"user",
"data-id":e.userId})))):b.append(f('<td class="td-nowrap" >').attr("data-user-id",e.userName).append(f("<span>",{"class":"approver"}).append(f(r)).attr({"data-type":"user","data-id":e.userId}))).addClass("add-spacing-left")}else h=f('<td class="td-nowrap">').append(f("<span>",{"class":"approver",text:e.groupName}).prepend(f("<i>",{"class":"icon icon-normal icon-green icon-WCR_Assignee-Group",title:d.t("CAppGroup")}),"&nbsp;").attr({"data-type":"group","data-id":c.memberObj.groupId})),(e=a.findMemberObj("Group",
e.groupId,this.model.approvalModel.getProjectMembers()))&&(e.isMember&&s.isEmpty(e.members))&&h.append(document.createTextNode(" "+d.t("CAppEmptyIndicator"))),b.append(h);else b.append(f("<td/>"))};u.prototype._showReasonsForRejection=function(){return this.model.hasReasonsForRejection()};u.prototype._showRoleAssigneeGroupMembersColumn=function(){return!this._options.simpleLayout&&this.model.hasRoleAssigneeGroupMembers()};u.prototype._showRemoveColumn=function(){return!this.model.approvalModel.readOnly&&
this.model.approvalModel.approvalStatus===b.ApprovalStatus.NOT_STARTED&&this.model.canModifyApprovers()&&!1!==this._options.showRemoveColumn};return u});
define("tpl!approval/view/template/ApprovalStage",function(){return function(b){var a,c;c=""+('<div data-sahi-id="Step_'+(null==(a=b.step)?"":_.escape(a))+'">\r\n\t');b.showApprovalStageCollapse&&(c+='\r\n\t<div class="collapseApprovalStage">\r\n\t\t<a class="pull-right '+(null==(a=b.collapseStage?"":"collapsed")?"":_.escape(a))+'" title="'+(null==(a=b.collapseStage?b.i18n("CAppHideStepConfigurationDetails"):b.i18n("CAppShowStepConfigurationDetails"))?"":_.escape(a))+'" name="collapse-button">\r\n\t\t\t<i class="icon icon-normal" />\r\n\t\t</a>\r\n\t</div>\r\n\t');
c+='\r\n\t<div class="wcr-approval-stage-panel-container">\r\n\t\t<div class="panel wcr-form '+(null==(a=b.extraPanelClass)?"":_.escape(a))+'" name="'+(null==(a=b.panelName)?"":_.escape(a))+'">\r\n\t\t\t<div class="panel-heading '+(null==(a=b.simpleLayout?" wcr-approval-stage-simple-layout":"")?"":a)+' sortable-handler">\r\n\t\t\t\t<label class="stageNumber">'+(null==(a=b.step+1)?"":_.escape(a))+"</label>\r\n\t\t\t\t";if(b.showcollapse||b.stepEditable)c+='\r\n\t\t\t\t\t<a name="collapse-details-button" data-sahi-id="collapse-details_'+
(null==(a=b.step)?"":_.escape(a))+'" class="pull-right add-spacing-right btn  approval-action" title="'+(null==(a=b.i18n("CAppShowStepConfigurationDetails"))?"":_.escape(a))+'">\r\n\t\t\t\t\t\t<i class="icon icon-WCR_AE-min"></i>\r\n\t\t\t\t\t</a>\r\n\t\t\t\t\t';c+="\r\n\t\t\t\t";2===b.stepEditable&&!b.readOnly&&(c+='\r\n\t\t\t\t\t<a href="#" class="pull-right add-spacing-right btn approval-action action-remove-stage" title="'+(null==(a=b.i18n("CAppRemoveStage"))?"":_.escape(a))+'" data-sahi-id="remove_stage_'+
(null==(a=b.step)?"":_.escape(a))+'">\r\n\t\t\t\t\t\t<i class="icon icon-normal icon-WCR_Trash"></i>\r\n\t\t\t\t\t</a>\r\n\t\t\t\t\t');c+="\r\n\t\t\t\t\t";b.workflowTaskId&&(c+='\r\n\t\t\t\t\t\t<a href="#" class="pull-right add-spacing-right btn approval-action action-open-workflow" title="'+(null==(a=b.i18n("CAppStartedByWorkflow"))?"":_.escape(a))+'" data-sahi-id="open_workflow_'+(null==(a=b.step)?"":_.escape(a))+'" data-init="WFEditorWCR/wfPopup/WFEditorWCRPopupAnchor" data-taskId="'+(null==(a=
b.workflowTaskId)?"":_.escape(a))+'" data-autorefresh="1" data-inPopup="'+(null==(a=b.inPopup)?"":_.escape(a))+'">\r\n\t\t\t\t\t\t\t<i class="icon icon-normal icon-WCR_Workflow"></i>\r\n\t\t\t\t\t\t</a>\r\n\t\t\t\t\t');c+='\r\n\t\t\t<label class="label statusLabel" ';b.approvalTime&&(c+='\r\n\t\t\t\t   data-toggle="tooltip" data-placement="top" data-title="'+(null==(a=b.approvalTime)?"":_.escape(a))+'"\r\n\t\t\t\t\t');c+="\r\n\t\t\t>\r\n\t\t\t\t";"NotStarted"!=b.approvalStatus&&(c+='\r\n\t\t\t\t\t<i title="'+
(null==(a=b.i18n("CApp"+b.approvalStatus))?"":_.escape(a))+'" class="'+(null==(a=b.images[b.approvalStatus])?"":_.escape(a))+'"></i>&nbsp;\r\n\t\t\t\t');c+="\r\n\t\t\t\t"+(null==(a=b.i18n("CApp"+b.approvalStatus))?"":_.escape(a))+'\r\n\t\t\t</label>\r\n\t\t\t<div class="stage-name-container" name="stage-name" />\r\n\t\t\t</div>\r\n\t\t\t<div class="collapse '+(null==(a=b.collapseStage?"in":"")?"":_.escape(a))+'" name="collapse-target">\r\n\t\t\t\t<div class="panel-body" id="'+(null==(a=b.model.id)?
"":_.escape(a))+"panel_"+(null==(a=b.step)?"":_.escape(a))+'">\r\n\t\t\t\t\t';if(b.showcollapse||b.stepEditable){c+='\r\n\t\t\t\t\t\t<div name="collapse-details-target" class="collapse">\r\n\t\t\t\t\t\t\t<div class="'+(null==(a=b.showcollapse?"step-details-collapse-uneditable":"step-details-collapse")?"":_.escape(a))+'">\r\n\t\t\t\t\t\t\t\t';b.showcollapse&&(c+='\r\n\t\t\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t\t\t<label class="offset-label" />\r\n\t\t\t\t\t\t\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t\t\t\t\t\t\t<div class="checkbox">\r\n\t\t\t\t\t\t\t\t\t\t\t\t<label>\r\n\t\t\t\t\t\t\t\t\t\t\t<input type="checkbox" class="Chkbx_CondApp" disabled="disabled" '+
(null==(a=b.model.condApp?"checked":"")?"":_.escape(a))+" />   \r\n\t\t\t\t\t\t\t\t\t\t\t"+(null==(a=b.i18n("CAppAllowCondApp"))?"":_.escape(a))+' \r\n\t\t\t\t\t\t\t\t\t\t</label>\r\n\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\r\n\t\t\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t\t\t<label class="offset-label" />\r\n\t\t\t\t\t\t\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t\t\t\t\t\t\t<div class="checkbox">\r\n\t\t\t\t\t\t\t\t\t\t\t\t<label>\r\n\t\t\t\t\t\t\t\t\t\t\t<input type="checkbox" class="Chkbx_InheritPreviousApprovals" disabled="disabled" '+
(null==(a=b.model.inheritPreviousApprovals?"checked":"")?"":_.escape(a))+" />   \r\n\t\t\t\t\t\t\t\t\t\t\t"+(null==(a=b.i18n("CAppInheritPrevApprovals"))?"":_.escape(a))+' \r\n\t\t\t\t\t\t\t\t\t\t</label>\r\n\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\r\n\r\n\t\t\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t\t\t<label style="width: inherit;">'+(null==(a=b.i18n("CAppWhenOneUserRejects"))?"":_.escape(a))+'</label>\r\n\t\t\t\t\t\t\t\t\t\t<div class="form-entry" style="width: inherit;">\r\n\t\t\t\t\t\t\t\t\t\t\t<p>\r\n\t\t\t\t\t\t\t\t\t\t\t\t'+
(null==(a=b.rejectHandle?b.i18n("CApp"+(b.model.isWorkflowDriven()?"Stage":"")+b.rejectHandle):b.i18n("CAppStopApprovalAfterEverybodyDecided"))?"":_.escape(a))+'\r\n\t\t\t\t\t\t\t\t\t\t\t</p>\r\n\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t</div>\r\n\r\n\t\t\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t\t\t<label style="width: inherit;">'+(null==(a=b.i18n("CAppRequiresReviewState"))?"":_.escape(a))+'</label>\r\n\t\t\t\t\t\t\t\t\t\t<div class="form-entry" style="width: inherit;">\r\n\t\t\t\t\t\t\t\t\t\t\t<p>\r\n\t\t\t\t\t\t\t\t\t\t\t\t'+
(null==(a=b.i18n("CApp"+b.model.requireReviewHandle))?"":_.escape(a))+"\r\n\t\t\t\t\t\t\t\t\t\t\t</p>\r\n\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t");c+="\r\n\r\n\t\t\t\t\t\t\t\t\t\t";if(2===b.stepEditable){c+='\r\n\t\t\t\t\t\t\t\t\t\t\t<div class="form-group '+(null==(a=!b.model.approvalModel.systemCondApprovalAllowed||b.model.condApp&&b.readOnly?"hidden":"")?"":_.escape(a))+'">\r\n\t\t\t\t\t\t\t\t\t\t\t\t<label class="offset-label"></label>\r\n\t\t\t\t\t\t\t\t\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t<div class="checkbox">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t<label>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t<input  type="checkbox" name="ConditionalApproval"\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t  '+
(null==(a=b.model.condApp&&(b.model.approvalModel.systemCondApprovalAllowed||b.readOnly)?"checked":"")?"":_.escape(a))+"\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t  "+(null==(a=b.readOnly?'disabled="disabled"':"")?"":_.escape(a))+'\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tdata-sahi-id="Chkbx_CondApp_'+(null==(a=b.step)?"":_.escape(a))+'"\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t/>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t'+(null==(a=b.i18n("CAppAllowCondApp"))?"":_.escape(a))+'\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t</label>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t\r\n\t\t\t\t\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t\t\t\t\t<label class="offset-label"></label>\r\n\t\t\t\t\t\t\t\t\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t<div class="checkbox">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t<label>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t<input  type="checkbox" name="InheritPreviousApprovals"\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t  '+
(null==(a=b.model.inheritPreviousApprovals?"checked":"")?"":_.escape(a))+"\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t  "+(null==(a=b.readOnly?'disabled="disabled"':"")?"":_.escape(a))+'\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tdata-sahi-id="Chkbx_InheritPreviousApprovals_'+(null==(a=b.step)?"":_.escape(a))+'"\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t/>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t'+(null==(a=b.i18n("CAppInheritPrevApprovals"))?"":_.escape(a))+' \r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t</label>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t\r\n\r\n\t\t\t\t\t\t\t\t\t\t\t<\!-- At rejection dropdown label and dropdown --\>\r\n\t\t\t\t\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t\t\t\t\t<label>'+
(null==(a=b.i18n("CAppWhenOneUserRejects"))?"":_.escape(a))+'</label>\r\n\t\t\t\t\t\t\t\t\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t<div class="input-group">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t<select class="form-control" name="RejectionSelect" data-sahi-id="RejectionSelect_'+(null==(a=b.step)?"":_.escape(a))+'" />\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t<div class="input-group-btn">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t<a class="inline_help" title="'+(null==(a=b.i18n("CAppHelp"))?"":_.escape(a))+
'" help-info="CAppRejectionHandlerHelp">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t<i class="icon icon-WCR_Info-Balloon"></i>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t</a>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t\t\t\t\t<label class="">'+(null==(a=b.i18n("CAppRequiresReviewState"))?"":_.escape(a))+'</label>\r\n\t\t\t\t\t\t\t\t\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t<div class="input-group">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t<select class="form-control" name="RequireReviewSelect" data-sahi-id="RequireReviewSelect_'+
(null==(a=b.step)?"":_.escape(a))+'">\r\n\t\t\t\t\t\t\t\t\t\t\t';for(var q=0;q<b.requireReviewHandlers.length;q++)c+='\r\n\t\t\t\t\t\t\t\t\t\t\t<option value="'+(null==(a=b.requireReviewHandlers[q])?"":_.escape(a))+'" '+(null==(a=b.requireReviewHandlers[q]==b.model.requireReviewHandle?"selected":"")?"":_.escape(a))+" >\r\n\t\t\t\t\t\t\t\t\t\t\t\t"+(null==(a=b.i18n("CApp"+b.requireReviewHandlers[q]))?"":_.escape(a))+"\r\n\t\t\t\t\t\t\t\t\t\t\t</option>\r\n\t\t\t\t\t\t\t\t\t\t\t";c+='\t\t        \r\n\t\t\t\t\t\t\t\t\t\t</select>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t<div class="input-group-btn">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t<a class="inline_help" title="'+
(null==(a=b.i18n("CAppHelp"))?"":_.escape(a))+'" help-info="CAppRequireReviewStateHelp">\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t<i class="icon icon-WCR_Info-Balloon"></i>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t</a>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t\t\t'}c+="\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t"}c+='\r\n\t\t\t\t\t\t\t<div name="ApproversTable" />\r\n\t\t\t\t</div>\r\n\t\t\t\t<div class="panel-footer hidden" name="footer">\r\n\t\t\t\t\t<div class="x-drop-form-entry form-entry">\r\n\t\t\t\t\t\t';
b.stepEditable&&(c+='\r\n\t\t\t\t\t\t\t<div class="approvers-xdrop input-group">\r\n\t\t\t\t\t\t\t\t<div class="input-group-addon" name="xdrop-addon">\r\n\t\t\t\t\t\t\t\t\t<i class="icon icon-WCR_Actions-User-Add12" />\r\n\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t');return c+'\r\n\t\t\t\t\t</div>\r\n\t\t\t\t\t<div class="due-date-footer" name="due-date-footer" />\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\t</div>\r\n</div>'}});
define("tpl!approval/view/template/HourDropDown",function(){return function(b){var a,c;c=""+('<div class="input-group">\r\n\r\n\t<select class="form-control" id="'+(null==(a=b.d.id)?"":_.escape(a))+'" data-sahi-id="'+(null==(a=b.d.id)?"":_.escape(a))+'" name="'+(null==(a=b.d.name)?"":_.escape(a))+'">\r\n\t');for(var q=0;24>q;q++)c+=' \r\n\t\t<option value="'+(null==(a=2*q)?"":_.escape(a))+'" '+(null==(a=b.d.dueHour==2*q?"selected":"")?"":_.escape(a))+" >"+(null==(a=(10>q?"0":"")+q)?"":_.escape(a))+
':00</option>\r\n\t\t<option value="'+(null==(a=2*q+1)?"":_.escape(a))+'" '+(null==(a=b.d.dueHour==2*q+1?"selected":"")?"":_.escape(a))+" >"+(null==(a=(10>q?"0":"")+q)?"":_.escape(a))+":30</option>\r\n\t";return c+='\r\n\t</select>\r\n\t<span for="'+(null==(a=b.d.id)?"":_.escape(a))+'" class="form-datetime-btn input-group-addon">\r\n\t\t<i class="icon icon-normal icon-WCR_Clock"></i>\r\n\t</span>\r\n</div>'}});
define("approval/view/approvalXdrop/ApprovalXDropConversionUtils","webcenterapi/data/WebCenterUser webcenterapi/data/WebCenterGroup webcenterapi/data/WebCenterRole underscore xdrop/dataproviders/ResultEntry utils/FilterUtils".split(" "),function(b,a,c,q,n){function k(a){var b={};b.userId=a.getId();b.userName=a.getName();b.firstName=a.getFirstName();b.lastName=a.getLastName();b.memberType="User";b.isActive=a.isActiveUser();return b}function d(a){return{type:"user",data:new b(a.userId||a.ID,a.userName,
a.firstName,a.lastName,a.eMail,a.isActive)}}function p(c){var j=q.map(c.members,function(a){return new b(a.userId,a.userName,a.firstName,a.lastName,a.eMail,a.isActive)}),g=new a(c.groupId||c.ID,c.groupName||c.name,j);c.assignee&&(j=q.find(j,function(a){return a.getId()===c.assignee.ID}),j||(j=d(c.assignee).data),g.setGroupAssignee(j));return{type:"group",data:g}}return{convertToMember:function(d){var j={};if(d instanceof b)j=k(d);else if(d instanceof c)j.groupId=d.getId(),j.groupName=d.getName(),
j.memberType="Group",j.isRole=!0;else if(d instanceof a)j.groupId=d.getId(),j.groupName=d.getName(),j.memberType="Group",j.isRole=!1,j.members=q.map(d.getMembers(),k);else throw"Illegal argument: expected a WebCenterUser, WebCenterGroup or WebCenterRole";return j},transformWebCenterUserToMember:k,createMembersXDropData:function(a,b){var g=q.groupBy(a,function(a){return"Group"===a.memberType?a.isRole?"role":"group":"user"}),k=[];k.push.apply(k,q.flatten(q.map(g.role,function(a){var e=[],g=q.find(b,
function(b){return b.roleID===a.groupId});g&&(e.push.apply(e,q.pluck(q.map(g.userRoleAssignments,d),"data")),e.push.apply(e,q.pluck(q.map(g.groupRoleAssignments,p),"data")));g={type:"role",data:new c(a.groupId,a.groupName)};g.data.setMembers(e);return g})));k.push.apply(k,q.map(g.user,d));k.push.apply(k,q.map(g.group,p));return q.map(k,function(a){return new n(a.type,a.data)})},createWebCenterGroupFromMember:p,createWebCenterUserFromMember:d}});
define("approval/view/approvalXdrop/ApprovalMemberXDropDataProvider",["underscore","xdrop/dataproviders/XDropDataProvider","approval/view/approvalXdrop/ApprovalXDropConversionUtils","utils/Observer"],function(b,a,c,q){var n=function(b){a.call(this);q.mixin(this);this._approvalStage=b;this.setQuery("");this._observe(this._approvalStage.approvalModel,"stage.*.changed.approvers.*",function(){this.setQuery(this._query||"")}.bind(this));this._observe(b,"deleted",function(){this._stopObserveAll()}.bind(this))};
n.prototype=Object.create(a.prototype);n.prototype.constructor=n;n.prototype._memberInStage=function(a){return b.some(b.pluck(this._approvalStage.getApprovers(),"memberObj"),function(b){return a.userId&&a.userId===b.userId||a.groupId&&a.groupId===b.groupId})};n.prototype.setMaxResults=function(){};n.prototype.setQuery=function(a){this._query=a;this._resultSet.clear();this._resultSet.appendAll(b.filter(b.filter(this._getXDropReadyMembers(),this._notInStage.bind(this)),function(b){return b.getData().match(a,
!0)}));this._resultSet.commitChanges()};n.prototype._getXDropReadyMembers=function(){var a=b.map(b.clone(this._approvalStage.approvalModel.roleAssignments),b.clone);b.each(a,function(a){a.userRoleAssignments=b.filter(a.userRoleAssignments,b.compose(b.negate(this._memberInStage.bind(this)),function(a){return{userId:a.ID}}));a.groupRoleAssignments=b.filter(a.groupRoleAssignments,b.compose(b.negate(this._memberInStage.bind(this)),function(a){return{groupId:a.ID}}))},this);return c.createMembersXDropData(this._approvalStage.approvalModel.getProjectMembers(),
a)};n.prototype._notInStage=function(a){var d=c.convertToMember(a.getData()),n=!1,e=this._memberInStage(d);d.groupName&&(n=b.some(a.getData().getMembers(),b.compose(b.negate(this._memberInStage.bind(this)),c.convertToMember)),e&&a.setAllowSelection(!1));d.groupName&&(a.getData()._members=b.filter(a.getData().getMembers(),b.compose(b.negate(this._memberInStage.bind(this)),c.convertToMember)));return!e||n};return n});
define("approval/view/approvalXdrop/ApprovalAllUserXDropDataProvider","underscore webcenterapi/data/WebCenterUser component/xdrop/dataproviders/WCRUserDataProvider xdrop/dataproviders/ResultEntry ./ApprovalXDropConversionUtils approval/ApprovalUtils utils/Observer utils/FilterUtils utils/webi18n!xdrop/locales".split(" "),function(b,a,c,q,n,k,d,p,e){a=function(a,b,e){c.call(this,"user",e);d.mixin(this);this._approvalStage=a;this._projectID=b;this._observe(this._approvalStage.approvalModel,"stage.*.changed.approvers.*",
function(){this.setQuery(this._query||"")}.bind(this));this._observe(a,"deleted",function(){this._stopObserveAll()}.bind(this))};a.prototype=Object.create(c.prototype);a.prototype.constructor=a;a.prototype.setEntries=function(){this._resultSet.clear();var a=b.filter(this._data,this._notInProject.bind(this)),c=a;0<=this.getMaxResults()&&(c=b.first(a,this.getMaxResults()));c=b.map(c,function(a){return new q(this._rendertype,a)}.bind(this));c=b.filter(c,function(a){a.getData().setExtraSAHIMarkers("not-invited");
return a.getData().match(this._query,!0)}.bind(this));this._resultSet.appendAll(c);0<this.getMaxResults()&&a.length>this.getMaxResults()&&(a=new q("label",e.t("TypeToRefineResults")),a.setAllowSelection(!1),this._resultSet.append(a));this._resultSet.commitChanges()};a.prototype._getDataListParam=function(){var a=this._approvalStage.approvalModel.getProjectMembers(),a=b.reduce(a,function(a,c){if("User"===c.memberType)return a+(n.createWebCenterUserFromMember(c).data.match(this._query)?1:0);if(c.isGroup)return a+
b.reduce(n.createWebCenterGroupFromMember(c).data.getMembers(),function(a,b){return a+(b.match(this._query)?1:0)}.bind(this),0)}.bind(this),0),c=this.getMaxResults();0<c&&a&&(c+=a+1);return{list:this._list,filter:p.preprocessPattern(this._query),maxcount:c,xdropData:1,json:0}};a.prototype._notInProject=function(a){var b=this._approvalStage.approvalModel.getProjectMembers();return!k.findMemberObj("User",a.getId(),b)};return a});
define("approval/view/ApprovalXDrop","underscore approval/view/approvalXdrop/ApprovalMemberXDropDataProvider approval/view/approvalXdrop/ApprovalAllUserXDropDataProvider xdrop/dataproviders/CompositeDataProvider xdrop/dataproviders/LimitResultsDataProvider component/xdrop/dataproviders/CreateUserDataProvider xdrop/dataproviders/CategoryDataProvider component/xdrop/renderers/UserRenderer component/xdrop/renderers/GroupRenderer component/xdrop/renderers/RoleRenderer xdrop/renderers/ButtonRenderer xdrop/renderers/CategoryTitleRenderer approval/view/approvalXdrop/ApprovalXDropConversionUtils approval/ApprovalUtils xdrop/XDrop webcenterapi/UserAPI utils/Observable utils/Observer utils/webi18n!Approval require".split(" "),function(b,
a,c,q,n,k,d,p,e,j,g,l,i,h,v,f,s,w,m,u){var y={user:p,group:e,role:j,button:g,categoryTitle:l},p=function(e,h,g){s.mixin(this,"ApprovalXDrop");w.mixin(this);this._approvalStage=e;this._projectMembersDataProvider=new a(e);var r=[],i=new d({title:m.t("CAppXDropCurrentProjectCategory"),hideIfNoResults:!1},this._projectMembersDataProvider);r.push(i);var j,l=new n({maxResults:50},r),r=e.approvalModel.currentUser;if(r.isProjectManager||r.isAdmin)if(this._allActiveUserXDropDataProvider=new c(e,h,{maxResults:"20",
list:"User"}),i=new d({title:m.t("CAppXDropOtherCategory"),isCollapsed:!0,hideIfNoResults:!1,expandWhenQueryIsSet:!0},this._allActiveUserXDropDataProvider),l.addDataProvider(i),(new f(window.webcenterConfig)).hasDeactivatedUsers().then(function(a){a&&(this._allInactiveUserXDropDataProvider=new c(e,h,{maxResults:"20",list:"InactiveUsers"}),a=new d({title:m.t("CAppXDropDeactivatedUser"),isCollapsed:!0,expandWhenQueryIsSet:!0,hideIfNoResults:!1},this._allInactiveUserXDropDataProvider),l.addDataProvider(a))}.bind(this)),
r.canCreateUsers||r.isAdmin)j=e.approvalModel.getFolderId(),j=new k(h,j);j=j?new q(l,j):l;g=b.extend({placeholder:m.t("CAppXDropPlaceholder"),absoluteXDropPanel:!0},g);this._xdrop=new v(j,y,g);this.element=this._xdrop.getElement();this.element.attr("data-sahi-id","AddApproverXDrop_"+(e.number-1));this._observe(this._xdrop,"selected",this._handleXDropSelection)};p.prototype._handleXDropSelection=function(a){var c=this._approvalStage.approvalModel;if(a){var d=h.findMemberObj("group"===a.getType()||
"role"===a.getType()?"Group":"User",a.getData().getId(),c.getProjectMembers()),f=!0;d||(f=!1,d=i.convertToMember(a.getData()));if("user"==a.getType()){var e=a.getData();if(!e.INCONTEXTCREATED&&(!f||!e.isActiveUser())){var g=c.getProjectId(),m=c.getFolderId();u(["component/usercreation/InviteMemberPopup"],function(h){var i=f&&!e.isActiveUser(),h=new h(a.getData(),g,m,i);h.onSubmit(function(){d.isActive=!0;"User"===d.memberType&&(b.chain(c.getProjectMembers()).where({memberType:"Group",isRole:!1}).pluck("members").flatten().where({userId:d.userId}).each(function(a){a.isActive=
!0}),b.chain(c.roleAssignments).pluck("userRoleAssignments").flatten().where({ID:d.userId}).each(function(a){a.isActive=!0}));this._emit("selected",d)}.bind(this));h.onCancel(function(){this.setValue(null)}.bind(this));h.show()}.bind(this));return}}this._emit("selected",d)}};p.prototype.setValue=function(a){this._xdrop.setValue(a)};p.prototype.toggle=function(){this._xdrop.toggle(!this._xdrop.isOpen())};return p});
define("approval/view/ApprovalStageView","approval/ApprovalConstants approval/ApprovalUtils approval/view/ApproversTable component/tooltip/Tooltip Template tpl!approval/view/template/ApprovalStage tpl!approval/view/template/HourDropDown utils/Observer utils/webi18n!Approval approval/view/ApprovalXDrop component/relativedatetimepicker/RelativeDateTimePicker utils/datetools utils/init jquery underscore".split(" "),function(b,a,c,q,n,k,d,p,e,j,g,l,i,h,v){function f(a,b){p.mixin(this);b=b||{};this._options=
v.extend({showApprovalStageCollapse:!0,dueDateReadOnly:b.simpleLayout,inPopup:!1},b);this.model=a;this._observe(this.model,"changed.number",this._updateNumber.bind(this));this._observe(this.model,"changed.number",this._renderRejectHandleOptions.bind(this));this._helpArr={};this._helpArr.CAppRejectionHandlerHelp="./help/RejectionHandlerHelp_"+this.model.approvalModel.languageCodeHelp+".htm";this._helpArr.CAppRequireReviewStateHelp="./help.jsp?topic=common/wc/task/ta_wc_RequireAnnotationsReview-Approval&lang="+
(window.webcenterConfig.userLang||"en");this.approvalsTableView=new c(this.model,this._options);this.t=new n(e,k);this.t.bind("click","div.panel-heading .action-remove-stage",this.removeStepDialog,this);this.t.bind("click","a.inline_help",function(a){a=h(a).attr("help-info");window.open(this._helpArr[a],a).focus()},this);this.t.bind("change","[name=ConditionalApproval]",this.changeCondApproval,this);this.t.bind("change","[name=InheritPreviousApprovals]",this.changeInheritPreviousApprovals,this);this.t.bind("change",
"[name=RejectionSelect]",this.changeRejection,this);this.t.bind("change","[name=RequireReviewSelect]",this.changeRequireReview,this);this.t.bind("click","[name=collapse-button]",function(){h("[name=collapse-target]",this.elem).collapse("toggle")},this);this._options.simpleLayout&&this.t.bind("click",".wcr-approval-stage-simple-layout",function(){h("[name=collapse-target]",this.elem).collapse("toggle")},this);this.t.bind("show.bs.collapse","[name=collapse-target]",function(a,b){b.target===a&&h("[name=collapse-button]",
this.elem).removeClass("collapsed").prop("title",e.t("CAppHideStepConfigurationDetails"));"true"===h("[name=collapse-details-target]",this.elem).attr("aria-expanded")&&h("[name=collapse-details-button]",this.elem).prop("title",e.t("CAppHideStepConfigurationDetails"))},this);this.t.bind("hide.bs.collapse","[name=collapse-target]",function(a,b){b.target===a&&h("[name=collapse-button]",this.elem).addClass("collapsed").prop("title",e.t("CAppShowStepConfigurationDetails"));h("[name=collapse-details-button]",
this.elem).prop("title",e.t("CAppShowStepConfigurationDetails"))},this);this.t.bind("show.bs.collapse","[name=collapse-details-target]",function(){h("[name=collapse-details-button]",this.elem).prop("title",e.t("CAppHideStepConfigurationDetails"))},this);this.t.bind("hide.bs.collapse","[name=collapse-details-target]",function(){h("[name=collapse-details-button]",this.elem).prop("title",e.t("CAppShowStepConfigurationDetails"))},this);this.t.bind("click","[name=collapse-details-button]",function(){var a=
h("[name=collapse-target]",this.elem),b=h("[name=collapse-details-target]",this.elem);"true"!==a.attr("aria-expanded")?b.add(a).collapse("show"):b.collapse("toggle")},this);this.t.bind("click","[name=xdrop-addon]",function(a,b){b.stopPropagation();this._approverXDrop.toggle()},this);this._observeAll(this.model.approvalModel,["stage.*.changed.name","changed.stages.**"],this._renderStageName.bind(this));this._observe(this.model.approvalModel,"changed.duedatetype",this._renderDueDate.bind(this));this._observeAll(this.model.approvalModel,
["changed.stages.deleted","changed.stages.added"],this._updateActions.bind(this));this._observeAll(this.model,["changed.duedate","changed.leadtime"],this._renderDueDate.bind(this));this._relativeDatePickerChangingNow=!1;this._observe(this.model,"deleted",function(){this.elem.remove();this._stopObserveAll()}.bind(this));this._approverXDrop=new j(a,a.approvalModel.getProjectId());this._approverXDrop.on("selected",a.addApprover.bind(a));this._observe(this.model,"changed.approvers.added",function(){this._approverXDrop.setValue(null)}.bind(this));
this.elem=h("<div>").addClass("wcr-approval-stage");this.t.setContext(this.elem)}f.prototype._updateNumber=function(){this.elem&&this.elem.find(".stageNumber").text(this.model.number)};f.prototype.render=function(){this.elem&&(this._approverXDrop.element.detach(),this._renderStep(),this._renderApproverTable(),this._renderDueDate(),this._renderRejectHandleOptions(),this._renderXDrop(),this._renderStageName(),this._updateActions())};f.prototype._renderStep=function(){this._approverXDrop.element.detach();
var c=this.model.number-1;this.t.d.step=c;this.t.d.model=this.model;this.t.d.readOnly=this.model.approvalModel.readOnly;this.t.d.collapseStage=this.model.canModifyApprovers()||!this.model.approvalModel.isComplexApproval();var d=2;this.model.approvalModel.readOnly&&(d=0);this.model.approvalModel.approvalStatus!==b.ApprovalStatus.NOT_STARTED&&(d=0);this.model.approvalStatus!==b.ApprovalStatus.NOT_STARTED&&this.model.approvalStatus!==b.ApprovalStatus.PENDING&&(d=0);2===d&&this.model.approvalStatus===
b.ApprovalStatus.PENDING&&(d=1);this.t.d.stepEditable=d;this.t.d.approvalStatus=this.model.approvalStatus;this.t.d.workflowTaskId=this.model.workflowTaskId;this.t.d.inPopup=this._options.inPopup;this.t.d.projectId=this.model.approvalModel.getProjectId();this.t.d.menuFile=this.model.menuFile;this.t.d.images=b.images;this.t.d.approvalTime="";if(this.model.approvalStatus!=b.ApprovalStatus.NOT_STARTED&&this.model.approvalStatus!=b.ApprovalStatus.PENDING){for(var f=-1,e=0;e<this.model.approvers.length;e++){var g=
this.model.approvers[e].approvalTime;g&&g.constructor==Date&&(g=g.getTime());g>f&&(f=g)}0<f&&(this.t.d.approvalTime=a.getDateHourString(new Date(f)))}this.t.d.showcollapse=!1;this.model.approvalModel.readOnly&&this.model.approvalModel.userCanChangeSetup()?this.t.d.showcollapse=!0:this.model.approvalModel.readOnly||(this.t.d.showcollapse=2==d?!1:!0);if(this.model.approvalStatus!=b.ApprovalStatus.NOT_STARTED&&!1===this.model.approvalModel.readOnly){this.t.d.allowConditional=!1;if(this.model.systemCondApprovalAllowed||
this.model.condApp)this.t.d.allowConditional=!0;this.t.d.inheritPreviousApprovals=this.model.inheritPreviousApprovals;this.t.d.rejectHandle=null;if("RejectStopsApprovalAfterStep"!=this.model.rejectHandle||this.model.approvalModel.isComplexApproval()||this.model.isWorkflowDriven())this.t.d.rejectHandle=this.model.rejectHandle}this.t.d.optionArr=this.model===v.last(this.model.approvalModel.steps)?b.rejectionHandlersSimple:b.rejectionHandlersComplex;d&&(this.t.d.requireReviewHandlers=b.requireReviewHandlers);
d="";this.t.d.showcollapse&&!this.t.d.showBottom&&(d+=" only-approvers-table");d+=" panel-"+this.model.approvalStatus;this.t.d.extraPanelClass=d;this.t.d.extraPanelName="panel_"+c;this.t.d=v.extend(this.t.d,this._options);this.t.render();i.doinit(this.elem);c=h('[data-toggle="tooltip"]',this.elem);v.each(c,function(a){new q(void 0,h(a),this.elem,h("body"),!1,h(a).attr("data-title"),void 0,void 0,{prefPosition:h(a).attr("data-placement")})}.bind(this))};f.prototype._renderApproverTable=function(){this.approvalsTableView.setElement(h("[name=ApproversTable]",
this.elem))};f.prototype.removeStepDialog=function(a,b){b.preventDefault();b.stopPropagation();this._confirm(e.t("CAppConfirmRemoveStep"),function(){this.model.remove()}.bind(this))};f.prototype._confirm=function(a,b,c){window.confirm(a)?v.isFunction(b)&&b():v.isFunction(c)&&c()};f.prototype.changeCondApproval=function(a){this.model.setConditionalApproval(a.checked)};f.prototype.changeRejection=function(a){this.model.setRejectHandle(a.value)};f.prototype.changeRequireReview=function(a){this.model.setRequireReviewHandle(a.value)};
f.prototype.changeInheritPreviousApprovals=function(a){this.model.setInheritPreviousApprovals(a.checked)};f.prototype._renderDueDate=function(){if(!this._relativeDatePickerChangingNow){var a=h("[name=due-date-footer]",this.elem);if(this.model.approvalModel.readOnly||this.model.approvalModel.approvalStatus!==b.ApprovalStatus.NOT_STARTED||this.model.approvalStatus!==b.ApprovalStatus.NOT_STARTED||this._options.dueDateReadOnly)a.html(this._renderReadOnlyFooter()),a.removeClass("hidden");else{var c=this.model.approvalModel.dueDateType;
"FixedDueDates"===c?(a.html(this._renderFixedDueDatesFooter()),a.removeClass("hidden")):"LeadTimes"===c||"LeadTimesFinalDueDate"===c?("NotStarted"==this.model.approvalStatus?a.html(this._renderLeadTimesFooter()):a.html(this._renderFixedDueDatesFooter()),a.removeClass("hidden")):a.addClass("hidden")}}};f.prototype._renderXDrop=function(){var a=h("[name=footer]",this.elem);h(".approvers-xdrop",this.elem).append(this._approverXDrop.element);a.removeClass("hidden")};f.prototype._renderFixedDueDatesFooter=
function(){var a=h("<div>"),b=new g({requireCategory:!0,categoryId:this.model.approvalModel.categoryId,supportOffset:this.model.approvalModel.milestoneAttributeAllowed,sahiId:"dueDateXDrop_"+(this.model.number-1)});b.setValue(this.model.dueDateData);"offset"==this.model.dueDateData.mode&&b.openCategoryDateWithOffset();b.onChange(v.bind(function(){var a=b.getValue();a&&(this._relativeDatePickerChangingNow=!0,this.model.setDueDateData(a),this._relativeDatePickerChangingNow=!1)},this));a.append(b.getElement());
return a};f.prototype._renderLeadTimesFooter=function(){var a=h("<div>");this.model.leadTime||this.model.setLeadTime(864E5);var b=this.model.getLeadTimeInDaysAndHours(),c=h("<input>",{"class":"form-control","data-sahi-id":"leadTimeHours_"+(this.model.number-1),type:"text",value:b.hours}),d=h("<input>",{"class":"form-control","data-sahi-id":"leadTimeDays_"+(this.model.number-1),type:"text",value:b.days});a.append(h('<div class="input-group input-group-leadtime">').append(c).append(h('<span class="input-group-addon">').append(e.t("CAppHours")))).append(h('<div class="input-group input-group-leadtime">').append(d).append(h('<span class="input-group-addon">').append(e.t("CAppDays"))));
var f=function(){var a=this.model.getLeadTimeInDaysAndHours();d.val(a.days);c.val(a.hours)}.bind(this),b=function(){var a=parseInt(d.val(),10),b=parseInt(c.val(),10);isNaN(a)||0>a?f():isNaN(b)||0>b?f():(a=24*a+b,8760>=a?this.model.setLeadTime(36E5*a):31536E6!==this.model.leadTime?this.model.setLeadTime(31536E6):f())}.bind(this);c.change(b);d.change(b);return a};f.prototype._renderReadOnlyFooter=function(){var b=h("<div>");if(this.model.dueDateData.time||this.model.dueDateData.item_id){var c,d=0;c=
this.model.dueDateData.item_name;d=this.model.dueDateData.offset;return b.append(h("<span>").append(h("<strong>").text(e.t("CAppDueDate"))).append(a.getDateHourAttributeString(this.model.dueDateData.time?new Date(this.model.dueDateData.time):null,c,d)))}if(this.model.leadTime)return c=this.model.getLeadTimeInDaysAndHours(),b.append(h("<span>").append(h("<strong>").text(e.t("CAppLeadTime"))).append(c.days+e.t("CAppDaysAbbreviation")+" "+c.hours+e.t("CAppHoursAbbreviation")))};f.prototype._createCalendar=
function(a,b){h(a).datepicker({dateFormat:"M dd, yy",onClose:function(){var a=h(b)[0];a&&0===a.selectedIndex&&(a.selectedIndex=37)}})};f.prototype._renderRejectHandleOptions=function(){var a=h("[name=RejectionSelect]",this.elem),c;c=this.model===v.last(this.model.approvalModel.steps)?b.rejectionHandlersSimple:b.rejectionHandlersComplex;var d=[];v.each(c,function(a){var b;this.model.isWorkflowDriven()||(b="RejectStopsApprovalAfterStep"===a&&!this.model.approvalModel.isComplexApproval()?e.t("CAppStopApprovalAfterEverybodyDecided"):
e.t("CApp"+a));d.push(h("<option>",{value:a,text:b}))}.bind(this));a.html(d);a.val(this.model.rejectHandle)};f.prototype._renderStageName=function(){var a=h("[name=stage-name]",this.elem);if(0<a.length&&(a.empty(),this.model.approvalModel.isStagedApprovalAllowed()))if(this.model.canModifyStageName()&&!this._options.simpleLayout){a.addClass("editable");var b=this.model.hasValidStageName();b?a.addClass("has-error"):a.removeClass("has-error");a.append(h("<input>",{"class":"form-control stageNameEditable",
type:"text",value:this.model.name,on:{change:function(a){this.model.setStageName(a.currentTarget.value)}.bind(this)},"data-sahi-id":"stepName_"+(this.model.number-1),placeholder:e.t("CAppStage")})).append(h("<span>",{"class":"stageNameErrorMsg danger",text:e.t(b)}))}else a.removeClass("editable"),a.append(h("<label>",{"class":"stageName",text:this.model.name}))};f.prototype._updateActions=function(){var a=h(".action-remove-stage",this.elem);1<this.model.approvalModel.steps.length?a.removeClass("displayNone"):
a.addClass("displayNone");a=h(".action-open-workflow",this.elem);this.model.workflowTaskId?a.removeClass("displayNone"):a.addClass("displayNone")};return f});
define("approval/view/AddApprovalStageView",["jquery","approval/model/ApprovalStage","utils/webi18n!Approval","utils/Observer"],function(b,a,c,q){a=function(a,k){q.mixin(this);this._model=a;this._stage=k;this._observe(this._model,"changed.stages.*",this._updateAlwaysVisible.bind(this));this._observe(this._stage,"deleted",function(){this._stopObserveAll();this._container.remove()},this);this._alwaysVisible=null;this._element=b("<div>",{"class":"add-approval-stage"});this._icon=b("<span>",{}).text(" "+
c.t("CAppInsertStep")).prepend(b("<i>",{"class":"icon icon-WCR_Actions-Add"})).appendTo(this._element);this._container=b("<div>",{"class":"add-approval-stage-container"});this._element.appendTo(this._container);this._element.attr("data-sahi-id","add_stage_"+(this._stage.number-1));this._element.on("click",function(a){a&&(this._timeout&&(window.clearInterval(this._timeout),this._timeout=null),a.stopPropagation(),a.preventDefault(),this._container.removeClass("add-approval-stage_expanded"));this._addNewStage()}.bind(this));
this._element.on("touchstart",function(a){a.stopPropagation();a.preventDefault();this._container.removeClass("add-approval-stage_expanded");this._addNewStage()}.bind(this));this._container.on("touchstart",function(a){a.preventDefault();this._container.addClass("add-approval-stage_expanded");window.setTimeout(function(){this._container.removeClass("add-approval-stage_expanded")}.bind(this),1750)}.bind(this));this._container.on("mouseenter",function(){this._timeout=window.setTimeout(function(){this._timeout=
null;this._container.addClass("add-approval-stage_expanded")}.bind(this),100)}.bind(this));this._container.on("mouseleave",function(){this._collapsePlaceholder()}.bind(this));this._updateAlwaysVisible()};a.prototype.getElement=function(){return this._container};a.prototype._addNewStage=function(){this._model.addStageAfter(this._stage)};a.prototype._collapsePlaceholder=function(){this._timeout&&(window.clearInterval(this._timeout),this._timeout=null);this._container.removeClass("add-approval-stage_expanded")};
a.prototype._updateAlwaysVisible=function(){var a=this._model.getStageNumber(this._stage)===this._model.getStageCount();a!==this._alwaysVisible&&((this._alwaysVisible=a)?(this._container.addClass("add-approval-stage_always-visible"),this._icon.text(" "+c.t("CAppAddStep")).prepend(b("<i>",{"class":"icon icon-WCR_Actions-Add"}))):(this._container.removeClass("add-approval-stage_always-visible"),this._icon.text(" "+c.t("CAppInsertStep")).prepend(b("<i>",{"class":"icon icon-WCR_Actions-Add"}))))};return a});
define("approval/view/ApprovalStageContainer","jquery approval/view/ApprovalStageView approval/view/AddApprovalStageView approval/ApprovalConstants utils/Observer utils/AnimationFrameRenderer".split(" "),function(b,a,c,q,n,k){var d=function(c,d,j){n.mixin(this);k.mixin(this);this.element=b("<div>",{"class":"approval-stage-container"});this._approvalModel=c;this.stageModel=d;this._approvalStageView=new a(d,j);this._observe(d,"deleted",function(){this.element.remove();this._stopObserveAll()}.bind(this))};
d.prototype.render=function(){this._render()};d.prototype._doRender=function(){!this._approvalModel.readOnly&&this._approvalModel.isStagedApprovalAllowed()&&(this._approvalModel.approvalStatus===q.ApprovalStatus.NOT_STARTED||this._approvalModel.approvalStatus===q.ApprovalStatus.NOT_DEFINED)&&(this.stageModel.approvalStatus===q.ApprovalStatus.NOT_STARTED||this.stageModel.approvalStatus===q.ApprovalStatus.PENDING)&&!this.stageModel.isWorkflowDriven()?this._addApprovalStageView||(this._addApprovalStageView=
new c(this._approvalModel,this.stageModel),this.stageModel.approvalStatus!==q.ApprovalStatus.PENDING?this.element.addClass("approval-stage-container-sortable"):this.element.removeClass("approval-stage-container-sortable"),this.element.addClass("approval-stage-container-insertable")):(this._addApprovalStageView=null,this.element.removeClass("approval-stage-container-sortable"));this._approvalStageView.elem.detach();this._addApprovalStageView&&this._addApprovalStageView.getElement().detach();this.element.empty();
this.element.append(this._approvalStageView.elem);this._addApprovalStageView&&this.element.append(this._addApprovalStageView.getElement());this._approvalStageView.render();return this.element};return d});
define("tpl!approval/view/template/ApproveRejectDialog",function(){return function(b){var a,c;c=""+('<form="" name="approveRejectDialog" onsubmit="return false;" class="wcr-form form-labels-on-top">\r\n\t<div class="approve-reject-dialog-message-bar"></div>\r\n    <div id="extraApprovalContent"></div>\r\n\t<div class="rolesPlaceholder loading">\r\n\t\t'+(null==(a=b.i18n("CAppLoadingRoles"))?"":_.escape(a))+'\r\n\t</div>\r\n    <div class="roleInfoWrapper"></div>\r\n    <div class="roleSelectWrapper form-entry"></div>\r\n    ');
"Approved"===b.approvalStatus||"ForceApproved"===b.approvalStatus?(c+="\t\r\n        ",b.conditionApproval?c+='\r\n            <div class="form-group">\r\n                <div class="form-entry">\r\n                    <div class="checkbox">\r\n                        <label>\r\n                            <input type="checkbox" name="approvalConditionChkBx" /> '+(null==(a=b.i18n("CAppSetApprovalCondition"))?"":_.escape(a))+'\r\n                        </label>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n            <textarea class="form-control form-control-resize-vertical" style="display:none;" rows="4" name="ApprovalComments" id="ApproveRejectComments"></textarea>\r\n            <span id="UseAnnotationsMsg" class="help-block" style="display: none;">'+
(null==(a=b.i18n("CAppUseAnnotations"))?"":_.escape(a))+"</span>\r\n        ":(c+="\r\n            "+(null==(a=b.i18n("CAppConfirmNoConditions"))?"":_.escape(a))+"<br/>\r\n            ",c=b.isViewFile?c+("\r\n                "+(null==(a=b.i18n("CAppAnnotationsDisregarded"))?"":_.escape(a))+"\r\n            "):c+("\r\n                "+(null==(a=b.i18n("CAppCommentsDisregarded"))?"":_.escape(a))+"\r\n            "),c+="\r\n        ")):(c+='\r\n    \t<div class="reasonsPlaceholder"></div>\r\n        <div class="reasonsHeader"></div>\r\n        <div class="form-entry reasonsXDropWrapper add-spacing-bottom"></div>\r\n        ',
c=b.blockComment?c+('\r\n            <textarea  style="display: none;" rows="4"  class="form-control form-control-resize-vertical" name="ApprovalComments"  id="ApproveRejectComments" disabled="disabled">'+(null==(a=b.i18n("CAppDocumentAnnotated"))?"":_.escape(a))+'</textarea>\r\n            <span id="UseAnnotationsMsg" class="help-block">'+(null==(a=b.i18n("CAppUseAnnotations"))?"":_.escape(a))+"</span>\r\n        "):c+("\r\n            <label>"+(null==(a=b.i18n("CAppComment"))?"":_.escape(a))+'</label>\r\n            <textarea class="form-control form-control-resize-vertical" style="" rows="4" name="ApprovalComments" id="ApproveRejectComments"></textarea>\r\n        '));
c+="\r\n    \r\n    ";b.passwordValidation&&(c+='\r\n        <div class="add-spacing-top clearfix">\r\n            <label>'+(null==(a=b.i18n("CAppReenterPassword"))?"":_.escape(a))+":</label>\r\n            <div><label>"+(null==(a=b.userString)?"":_.escape(a))+'</label></div>\r\n            <input type="password" class="form-control"  name="passwordEntry">\r\n        </div>\r\n    ');return c+="\r\n</form>"}});
define("approval/view/ApproveRejectView","Template component/helpIcon/HelpIcon component/modal/Modal approval/ApprovalConstants tpl!approval/view/template/ApproveRejectDialog utils/LoggedInTool utils/webi18n!Approval webcenterapi/ApprovalAPI utils/Observable wcr/hover wcr/webcenter_xml jquery underscore require lib/PromisePolyfill".split(" "),function(b,a,c,q,n,k,d,p,e,j,g,l,i,h){function v(a,b){e.mixin(this,"ApproveRejectView");this.approvalModel=a;this.viewModel=b;this._showReasons=this._selectedRole=
this._roles=this._stage=this._template=this._reasonsXDrop=this._roleSelect=this._reasonsXDropWrapper=this._reasonsHeaderLabel=this._reasonsHeader=this._reasonsPlaceholder=this._roleSelectWrapper=this._roleInfoWrapper=this._rolesPlaceHolder=this._checkbox=this._pswdField=this._conditionField=this._submitBtn=this._cancelBtn=null}v.prototype.open=function(a,e,h,g){var j=this.viewModel.isViewable&&"Prompt"!==this.approvalModel.viewerApprovalCommentType,a=new b(d,n);void 0!==this.approvalModel.forcedStep&&
(h=this.approvalModel.forcedStep);a.d.approvalStatus=e;a.d.conditionApproval=this.approvalModel.steps[h].condApp;a.d.passwordValidation=this.approvalModel.passwordValidation;a.d.blockComment=j;a.d.isViewFile=!0===this.viewModel.isViewable;var k=this.approvalModel.getCurrentUserString(),p=this.approvalModel.getDelegateUserString();p&&(k=p+" "+d.t("CAppActAs")+" "+k);a.d.userString=k;e===q.ApprovalStatus.APPROVED||e===q.ApprovalStatus.FORCE_APPROVED?(k="btn-success",p=d.t("CAppCommitApproval")):e==
q.ApprovalStatus.REJECTED||e==q.ApprovalStatus.FORCE_REJECTED?(k="btn-danger",p=d.t("CAppCommitRejection")):(k="btn-info",p=d.t("CAppCommitComment"));this._modal=new c(a.getRenderedHtml(),{draggable:!0,destroyOnClose:!0});g=d.t("CApp"+(g?g:e));this.viewModel.docName&&(g+=": "+this.viewModel.docName);this._modal.setTitle(g);g=l("<div>");g.append(l("<input>",{"class":"btn btn-default",type:"button",name:"cancelBtn",value:d.t("CAppCancel")}));j&&"Comment"===e||g.append(l("<input>",{"class":"btn "+k,
type:"button",name:"submitBtn",value:p,disabled:"disabled"}));this._modal.setFooter(g);this._modal.open();this._modalDialog=this._modal.getModalDialog();this._rolesPlaceholder=l(".rolesPlaceholder",this._modalDialog);this._roleInfoWrapper=l(".roleInfoWrapper",this._modalDialog);this._roleSelectWrapper=l(".roleSelectWrapper",this._modalDialog);this._reasonsPlaceholder=l(".reasonsPlaceholder",this._modalDialog);this._reasonsHeader=l(".reasonsHeader",this._modalDialog);this._reasonsXDropWrapper=l(".reasonsXDropWrapper",
this._modalDialog);this._reasonsXDrop=this._roleSelect=null;this._conditionField=l("#ApproveRejectComments",this._modalDialog);this._pswdField=l("[name=passwordEntry]",this._modalDialog);this._checkbox=l("[name=approvalConditionChkBx]",this._modalDialog);this._submitBtn=l("[name=submitBtn]",this._modalDialog);this._cancelBtn=l("[name=cancelBtn]",this._modalDialog);this._messageBar=l(".approve-reject-dialog-message-bar",this._modalDialog);this._cancelBtn.on("click",function(){this._modal.close()}.bind(this));
this._submitBtn.on("click",function(){this._approveReject(e,h)}.bind(this));if(0<this._checkbox.length)this._checkbox.on("change",i.bind(function(){this._conditionField&&this._checkbox&&(!0===this._checkbox.is(":checked")?j?(this._conditionField.val(d.t("CAppDocumentAnnotated")),this._conditionField.hide(),l("#UseAnnotationsMsg").show()):(this._conditionField.prop("disabled",!1),this._conditionField.show()):(this._conditionField.prop("disabled",!0),this._conditionField.val(""),this._conditionField.hide(),
l("#UseAnnotationsMsg").hide()))},this));if(0<this._pswdField.length)this._pswdField.on("keydown",i.bind(function(a){this._submitOnEnter(a,i.bind(function(){this._submitBtn.prop("disabled")||this._submitBtn.click()},this))},this));this._showReasons=e===q.ApprovalStatus.REJECTED&&this._showReasonsForRejection();e!=q.ApprovalStatus.FORCE_APPROVED&&e!=q.ApprovalStatus.FORCE_CONDITIONAL_APPROVED&&e!=q.ApprovalStatus.FORCE_REJECTED?this._getRoles().then(function(a){1<a.length&&!this._showReasons&&a.push({roleName:d.t("CAppForRoleOrGroupOrUser"),
roleId:"roles_groups_and_users"});a.sort(function(a,b){return"groups_and_users"===a.roleId||"roles_groups_and_users"===b.roleId?1:"roles_groups_and_users"===a.roleId||"groups_and_users"===b.roleId?-1:a.roleName.toLowerCase().localeCompare(b.roleName.toLowerCase())});this._roles=a;0<a.length&&(this._selectedRole=a[0]);this._loadingRolesDone();this._renderRoles();this._showReasons&&this._setupReasonsForRejection()}.bind(this)).catch(function(a){this._rolesPlaceholder.removeClass().empty().addClass("rolesPlaceholder alert alert-danger").text(d.t("CAppRolesLoadingError")+
(a?": "+a:""));this._renderSubmitButton()}.bind(this)):(this._loadingRolesDone(),this._loadingReasonsDone());return this._modalDialog};v.prototype._getRoles=function(){return this.viewModel.docVersionID?-1!==this.viewModel.docVersionID.indexOf(";")||-1!==this.viewModel.docVersionID.indexOf(",")?Promise.resolve([]):(new p(window.webcenterConfig)).getUserApprovers(this.viewModel.docVersionID,this.viewModel.pageRange).then(function(a){this._template=a.template;this._stage=a.stage;return Promise.all(a.approvers.map(function(a){return"1"===
a.isRole?{roleName:a.originalApproval,roleId:a.originalApprovalId}:{roleName:d.t("CAppNotForRole"),roleId:"groups_and_users"}})).then(function(a){return i.uniq(a,function(a){return a.roleId})})}.bind(this)):Promise.reject("DocVersionID is not specified")};v.prototype._setupReasonsForRejection=function(){this._reasonsXDrop&&this._reasonsXDrop.destroy();this._reasonsHeader.empty();this._reasonsXDropWrapper.empty();this._reasonsPlaceholder.empty().removeClass().addClass("reasonsPlaceholder loading").text(d.t("CAppLoadingRoles"));
h(["approval/view/ReasonsForRejectionXDropWrapper"],function(a){this._reasonsXDrop=new a({criteria:{template:this._template?this._template:"",stage:this._stage?this._stage:"",role:this._selectedRole&&"roles_groups_and_users"!==this._selectedRole.roleId&&"groups_and_users"!==this._selectedRole.roleId?this._selectedRole.roleName:""},hideWhenNoReasons:!0});this._reasonsXDrop.on("loaded",function(a,b){this._loadingReasonsDone();a?this._renderReasons():(this._reasonsPlaceholder.removeClass().empty().addClass("reasonsPlaceHolder alert alert-danger").text(d.t("CAppReasonsForRejectionLoadingError")+
(b?": "+b:"")),this._renderSubmitButton())}.bind(this));this._reasonsXDrop.on("changed",function(){this._renderSubmitButton()}.bind(this))}.bind(this))};v.prototype._loadingRolesDone=function(){this._rolesPlaceholder.removeClass("loading");this._rolesPlaceholder.empty();this._roleInfoWrapper.empty();this._roleSelectWrapper.empty();this._renderSubmitButton()};v.prototype._loadingReasonsDone=function(){this._reasonsPlaceholder.removeClass("loading");this._reasonsPlaceholder.empty();this._reasonsHeader.empty();
this._reasonsXDropWrapper.empty();this._renderSubmitButton()};v.prototype._renderSubmitButton=function(){var a=this._rolesPlaceholder.text().length+this._reasonsPlaceholder.text().length,b="";if(this._reasonsXDrop){var c=this._reasonsXDrop.getMinRequiredReasons(),e=this._reasonsXDrop.getMaxAllowedReasons();this._reasonsHeaderLabel&&this._reasonsHeaderLabel.toggleClass("form-required",0<c);var g=this._reasonsXDrop.getValue(),h=0;g&&(h=g.length);h<c?b=d.t("CAppMinRequiredReasons",c):-1!==e&&h>e&&(b=
d.t("CAppMaxAllowedReasons",e))}this._submitBtn.attr("title",b);0===a&&0===b.length?this._submitBtn.prop("disabled",!1):this._submitBtn.prop("disabled",!0)};v.prototype._renderRoles=function(){1<i.size(this._roles)?(this._roleSelect=l("<select>",{"class":"form-control"}),i.each(this._roles,function(a){a=l("<option>",{value:a.roleId,text:a.roleName});this._roleSelect.append(a)}.bind(this)),this._roleInfoWrapper.append(l("<label>",{text:d.t("CAppForRoleOrGroup")})),this._roleSelect.on("change",function(a){var b=
a.target.value;this._selectedRole=i.find(this._roles,function(a){return a.roleId==b});this._showReasons&&this._setupReasonsForRejection()}.bind(this)),this._roleSelectWrapper.append(l("<div>",{"class":"input-group"}).append(this._roleSelect).append(a.getInlineHelpTopicJQuery("approveridentity"))),this._roleSelectWrapper.addClass("add-spacing-bottom")):2>i.filter(this._roles,function(a){return"roles_groups_and_users"!==a.roleId}).length&&(this._roles[0]&&"groups_and_users"!==this._roles[0].roleId)&&
(this._roleInfoWrapper.append(l("<span>",{text:d.t("CAppForRoleOrGroup")+": "+this._roles[0].roleName})),this._roleSelectWrapper.addClass("add-spacing-bottom"))};v.prototype._renderReasons=function(){this._reasonsXDrop&&this._reasonsXDrop.getElement()&&(this._reasonsHeaderLabel=l("<label>",{text:d.t("CAppReasonsForRejection")}),this._reasonsHeader.append(this._reasonsHeaderLabel),this._reasonsXDropWrapper.append(this._reasonsXDrop.getElement()),this._renderSubmitButton())};v.prototype._approveReject=
function(a,b){if(this.viewModel.beforesubmit)try{this.viewModel.beforesubmit()}catch(c){return}var e={action:"",comment:"",password:"",approverID:"",approverAsUserOrGroup:"0",reasonsForRejection:""};e.action=a.toLowerCase();e.approverID=this._selectedRole&&this._selectedRole.roleId||"";"groups_and_users"===e.approverID&&(e.approverAsUserOrGroup="1");this._showReasons&&(e.reasonsForRejection=this._getReasonsForRejectionAsString());if(0<this._conditionField.length&&(0===this._checkbox.length||this._checkbox.is(":checked"))){if(""===
this._conditionField.val()||null===this._conditionField.val()){if(a===q.ApprovalStatus.COMMENT){window.alert(d.t("CAppYouCannotGiveEmptyComment"));return}if(a===q.ApprovalStatus.APPROVED||a===q.ApprovalStatus.FORCE_APPROVED){window.alert(d.t("CAppYouCannotGiveEmptyCondition"));return}}e.comment=this._conditionField.val();if(512<e.comment.length){window.alert(d.t("CApp_SUBMIT_ERR__COMMENTFIELD_TOO_LONG"));return}}if(a===q.ApprovalStatus.APPROVED)for(var h=this.approvalModel.steps[b],j=0;j<h.approvers.length;j++)if("MustApprove"===
this.approvalModel.currentUserApprovalStatus(b,j)&&0<h.approvers[j].commentArr.length){for(var n="",n=0<e.comment.length?d.t("CAppCommentsWillBeOmitted")+"\n":d.t("CAppCommentsWillBeOmitted_NoCurrentComment")+"\n",p=0;p<h.approvers[j].commentArr.length;p++)n+="\n"+h.approvers[j].commentArr[p].commentText;if(!window.confirm(n))return}if(!0===this.approvalModel.passwordValidation)if(0<this._pswdField.length)e.password=g.encode64(this._pswdField.val());else throw"pwField or pwEntryField does not exist";
this.viewModel.pageRange&&(e.pageindex=this.viewModel.pageRange);if(this.approvalModel.submitDisabled)window.alert(d.t("CAppApprovalActionOngoing"));else{this._messageBar.empty();var t=[],r=this,x={get roles(){return"roles_groups_and_users"===e.approverID?i.chain(r._roles).filter(function(a){return"groups_and_users"!==a.roleId&&"roles_groups_and_users"!==a.roleId}).pluck("roleName").value():"groups_and_users"===e.approverID?[]:i.chain(r._roles).filter(function(a){return a.roleId===e.approverID}).pluck("roleName").value()},
get action(){return a},preventApproval:function(a){if(!a)throw"Supply a reason for approval prevention";t.push(a)}};Promise.resolve().then(function(){this._submitBtn.prop("disabled",!0);this._cancelBtn.prop("disabled",!0);this._emit("approvalsubmit",x);return Promise.all(t.map(function(a){return Promise.resolve(a)}))}.bind(this)).catch(function(a){return"string"===typeof a?[a]:["An Error Occurred: "+a]}).then(function(b){b=i.compact(b);0<b.length?(b.forEach(function(a){r._messageBar.append(l("<div class='alert alert-danger'/>").text(a))}),
this._submitBtn.prop("disabled",!1),this._cancelBtn.prop("disabled",!1)):(this.approvalModel.submitDisabled=!0,this.approvalModel.submitAllowed?(this.approvalModel.confirmNeeded=!1,this.viewModel.isEncapsulated?(e.encapsulated=1,this._submitBtn.prop("disabled",!0),this._cancelBtn.prop("disabled",!0),k.requireLogin({success:i.bind(function(){l.ajax(this.viewModel.actionURL,{data:e,type:"post",success:i.bind(function(b){this.approvalModel.submitDisabled=!1;this._submitBtn.prop("disabled",!1);this._cancelBtn.prop("disabled",
!1);var c=null,e=!0,r=l("error",l(b)),h=l("ok",l(b));0<r.length?l.each(r,i.bind(function(a,b){var d=l("code",b).text(),r=l("msg",b).text();c=null===c?"":c+"\n";c+=r;"999"===d&&(this._pswdField.val(""),this._pswdField.focus(),e=!1)},this)):0<h.length||((r=b.match(/<title>Document Details - Approval Rule<\/title>/gim))&&0<r.length?(r=b.match(/errorOccured ?= ?true ?;/g))&&0<r.length&&(c=l(b).find("#errorFeedBack").text().trim()):c=d.t("CAppSessionExpired"));e&&this._modal.close();if(c){if(window.alert(c),
this.viewModel.approveRejectCallback&&this.viewModel.approveRejectCallback(!1,a,c),this.viewModel.onUpdateCallback)this.viewModel.onUpdateCallback(this.approvalModel)}else if(this.approvalModel.readURL){if(this.approvalModel.readFromXML(this.approvalModel.readURL),this.viewModel.approveRejectCallback)this.approvalModel.once("initialized",i.bind(this.viewModel.approveRejectCallback,this,!0,a))}else this.viewModel.approveRejectCallback(!0,a)},this),error:i.bind(function(){this.approvalModel.submitDisabled=
!1;window.alert("Error while submitting approval, please try again")},this)})},this)})):this.viewModel.submit(e)):(this._modal.close(),this.approvalModel.submitDisabled=!1))}.bind(this))}};v.prototype._getReasonsForRejectionAsString=function(){var a="";if(this._reasonsXDrop){var b=this._reasonsXDrop.getValue();i.each(b,function(b){var c=b.getData(),b=c.getReason(),c=c.getCategory();a+=" | "+b;c&&(a+=" @ "+c)});0===a.indexOf(" | ")&&(a=a.substr(3))}return a};v.prototype._submitOnEnter=function(a,b){13===
(a.keyCode||a.which)&&b()};v.prototype._showReasonsForRejection=function(){return this.approvalModel.isReasonsForRejectionEnabled()};v.prototype.getModal=function(){return this._modal};return v});
define("approval/view/ApproveButtonsToolbar","approval/ApprovalConstants approval/view/ApproveRejectView component/actionmenu/ActionMenu utils/webi18n!Approval utils/AnimationFrameRenderer utils/Observable jquery underscore".split(" "),function(b,a,c,q,n,k,d,p){function e(b,c){k.mixin(this,"ApproveButtonsToolbar");n.mixin(this);this.model=b;this._maxButtons=6;this._showStopAppButton=!1;this._container=null;this._approveRejectDialog=new a(b,c);this._approveRejectDialog.on("approvalsubmit",this._emit.bind(this,
"approvalsubmit"))}e.prototype.setElement=function(a){this._container=a};e.prototype.render=function(a,b){this._maxButtons=a;this._showStopAppButton=b;this._render()};e.prototype._doRender=function(){this._container.append(this._renderApprovalActionButtons())};e.prototype._renderApprovalActionButtons=function(){var a=d("<div/>",{"class":"btn-toolbar",role:"toolbar"}),e=this.model.getApprovalActions();if(!e.showContent)return"";var k=d("<div>",{"class":"action-menu-component"}).appendTo(a);p.each(e.list,
p.bind(function(a,c){var e="action ",f;switch(a.name){case "Approve":e+="action-success";f=b.images.Approve+" icon-white";break;case "ForceApprove":f=b.images.ForceApprove+" "+b.imageColors.ForceApprove;break;case "Reject":e+="action-danger";f=b.images.Reject+" icon-white";break;case "ForceReject":f=b.images.ForceReject+" "+b.imageColors.ForceReject;break;case "Comment":f=b.images.Comment}k.append(d("<a>",{"class":e,"data-icon":f,"data-visibility":c>=this._maxButtons?"-1":"1",title:q.t(a.text)+"\u2026",
text:q.t(a.text),on:{click:p.bind(function(b){this._approveRejectDialog.open(b,a.internalName,a.step,a.name)},this)}}))},this));this._showStopAppButton&&d("<a>",{"class":"action","data-icon":"icon-WCR_Stopped","data-visibility":e.list.length>=this._maxButtons?"-1":"1",title:q.t("CAppStopApprovalCycle"),text:" "+q.t("CAppStopApprovalCycle"),on:{click:p.bind(function(){this.model.submitDisabled?this.model.setError({errorMsg:"CAppApprovalActionOngoing"}):(this.model.submitDisabled=!0,this.model.confirmNeeded=
!1,this.model.submit({action:"stopCycle"}))},this)}}).appendTo(k);new c(k);return a};return e});
define("tpl!approval/view/template/ApprovalDueDateDialog",function(){return function(b){var a;return b=""+('<div class="ui-dialog ui-widget ui-widget-content ui-corner-all ui-draggable ui-resizable" style="height: 200px; min-height: 109px; width: 500px; display:none;" id="dueDateRecalcDialog" title="'+(null==(a=b.i18n("CAppDueDateCalculation"))?"":_.escape(a))+'">\r\n\t<div class="wcr-form form-no-labels duedaterecalc_dialogbody">\r\n\t\t<div class="form-section add-padding-left add-padding-right">\r\n\t\t\t<div class="section-title"><label class="offset-label"></label>\r\n\t\t\t\t<h3>'+(null==
(a=b.i18n("CAppCalculateNewDueDates"))?"":_.escape(a))+'</h3>\r\n\t\t\t</div>\r\n\t\t\t<div class="form-group"><label class="offset-label"></label>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="radio"><label><input type="radio" name="dueDateOperations" value="0">'+(null==(a=b.i18n("CAppGiveEachStage"))?"":_.escape(a))+'</label><label class="duedate-calc-inline-input"><input type="text" value="1" size="4" id="giveDays">&nbsp;'+(null==(a=b.i18n("CAppDays"))?"":_.escape(a))+'</label><label class="duedate-calc-inline-input"><input type="text" value="0" size="4" id="giveHours">&nbsp;'+
(null==(a=b.i18n("CAppHours"))?"":_.escape(a))+'</label></div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t\t<div class="form-group"><label class="offset-label"></label>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="radio"><label><input type="radio" name="dueDateOperations" value="1">'+(null==(a=b.i18n("CAppShiftDueDatesWith"))?"":_.escape(a))+'</label><label class="duedate-calc-inline-input"><input type="text" value="1" size="4" id="shiftDays">&nbsp;'+(null==(a=b.i18n("CAppDays"))?"":
_.escape(a))+'</label><label class="duedate-calc-inline-input"><input type="text" value="0" size="4" id="shiftHours">&nbsp;'+(null==(a=b.i18n("CAppHours"))?"":_.escape(a))+'</label></div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t\t<div class="form-group"><label class="offset-label"></label>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="radio"><label><input type="radio" name="dueDateOperations" value="2">'+(null==(a=b.i18n("CAppShiftDueLatestOn"))?"":_.escape(a))+'</label></div>\r\n\t\t\t\t\t<div class="form-datetime">\r\n\t\t\t\t\t\t'+
(null==(a=b.callTemplate("approval/view/template/Calendar",{id:"shiftLatestToDate",name:"shiftLatestToDate"}))?"":a)+"\r\n\t\t\t\t\t\t"+(null==(a=b.callTemplate("approval/view/template/HourDropDown",{dueHour:b.defaultDueHour,id:"shiftLatestToHour",name:"shiftLatestToHour"}))?"":a)+'\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t\t<div class="form-group"><label class="offset-label"></label>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="radio"><label><input type="radio" name="dueDateOperations" value="3">'+
(null==(a=b.i18n("CAppShiftDueFirstOn"))?"":_.escape(a))+'</label></div>\r\n\t\t\t\t\t<div class="form-datetime">\r\n\t\t\t\t\t\t'+(null==(a=b.callTemplate("approval/view/template/Calendar",{id:"shiftFirstToDate",name:"shiftFirstToDate"}))?"":a)+"\r\n\t\t\t\t\t\t"+(null==(a=b.callTemplate("approval/view/template/HourDropDown",{dueHour:b.defaultDueHour,id:"shiftFirstToHour",name:"shiftFirstToHour"}))?"":a)+'\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t\t<div class="form-group"><label class="offset-label"></label>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="radio"><label><input type="radio" name="dueDateOperations" value="4">'+
(null==(a=b.i18n("CAppDistributeEvenly"))?"":_.escape(a))+'</label></div>\r\n\t\t\t\t</div>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="form-datetime distribute-evenly">\r\n\t\t\t\t\t\t<table>\r\n\t\t\t\t\t\t\t<tr>\r\n\t\t\t\t\t\t\t\t<td class="add-padding-bottom">'+(null==(a=b.i18n("CAppFrom"))?"":_.escape(a))+'</td>\r\n\t\t\t\t\t\t\t\t<td class="add-padding-bottom">\r\n\t\t\t\t\t\t\t\t\t'+(null==(a=b.callTemplate("approval/view/template/Calendar",{id:"distributeFromDate",name:"distributeFromDate"}))?
"":a)+"\r\n\t\t\t\t\t\t\t\t\t"+(null==(a=b.callTemplate("approval/view/template/HourDropDown",{dueHour:b.defaultDueHour,id:"distributeFromHour",name:"distributeFromHour"}))?"":a)+"\r\n\t\t\t\t\t\t\t\t</td>\r\n\t\t\t\t\t\t\t</tr>\r\n\t\t\t\t\t\t\t<tr>\r\n\t\t\t\t\t\t\t\t<td>"+(null==(a=b.i18n("CAppTo"))?"":_.escape(a))+"</td>\r\n\t\t\t\t\t\t\t\t<td>\r\n\t\t\t\t\t\t\t\t\t"+(null==(a=b.callTemplate("approval/view/template/Calendar",{id:"distributeToDate",name:"distributeToDate"}))?"":a)+"\r\n\t\t\t\t\t\t\t\t\t"+
(null==(a=b.callTemplate("approval/view/template/HourDropDown",{dueHour:b.defaultDueHour,id:"distributeToHour",name:"distributeToHour"}))?"":a)+"\r\n\t\t\t\t\t\t\t\t</td>\r\n\t\t\t\t\t\t\t</tr>\r\n\t\t\t\t\t\t</table>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\t</div>\r\n</div>")}});
define("tpl!approval/view/template/Calendar",function(){return function(b){var a;return b=""+('<div class="form-date">\r\n\t<div class="input-group">\r\n\t\t\r\n\t\t<input type="text" id="'+(null==(a=b.d.id)?"":_.escape(a))+'" name="'+(null==(a=b.d.name)?"":_.escape(a))+'" class="form-control">\r\n\t\t<span class="form-datetime-btn input-group-addon" onclick="$(\'#'+(null==(a=b.d.id)?"":_.escape(a))+'\').datepicker(\'show\'); return false;">\r\n\t\t\t<i class="icon icon-WCR_Calendar" id="IMG1"></i>\r\n\t\t</span>\r\n\t</div>\r\n</div>')}});
define("approval/view/ApprovalView","Template approval/ApprovalConstants approval/ApprovalUtils approval/view/NotificationView approval/view/ApprovalStageContainer approval/view/ApproveRejectView approval/view/ApproveButtonsToolbar component/message/MessageComponent utils/Observer utils/Observable tpl!approval/view/template/ApprovalDueDateDialog tpl!approval/view/template/HourDropDown tpl!approval/view/template/Calendar utils/webi18n!Approval utils/Promisify utils/AnimationFrameRenderer utils/dateShift utils/datetools jquery underscore wcr/webcenter_html wcr/webcenter_xml component/relativedatetimepicker/RelativeDateTimePicker".split(" "),
function(b,a,c,q,n,k,d,p,e,j,g,l,i,h,v,f,s,w,m,u,y,z,A){function t(b,c,h,g,i,k){f.mixin(this);e.mixin(this);j.mixin(this,"ApprovalView");this._options=u.extend({ajax:!1,showEditNextVersion:!0,inPopup:!1},k);this.model=b;this.currentUser=g;this.displayElem=h;this.loading();this.MSG_TAG="APPROVAL";this.stageViews=[];this._boundOnUpdate=this.onUpdate.bind(this);this._boundShowChangesApprovalMessage=u.debounce(this._toggleSaveButtonEnabled.bind(this),10);this._stagesContainer=m("<div />");this._saveButton=
null;this._messageModel=new p.MessageModel;this._stagesMessageModel=new p.MessageModel;c.on("submit",this._submitForm.bind(this));this.approveButtonsToolbar=new d(this.model,c);this.approveButtonsToolbar.on("approvalsubmit",this._emit.bind(this,"approvalsubmit"));b.onAll(["update","changed.approvalstatus","initialized"],this._boundOnUpdate);b.onAll(["changed.*","stage.*.changed.*","stage.*.changed.approvers.*","initialized"],this._boundShowChangesApprovalMessage);b.on("error",this._showErrors.bind(this));
b.on("changed.stages.deleted",this._deleteStageView.bind(this));b.on("changed.stages.deleted",function(){var b=u.last(this.model.steps);b&&b.approvalStatus!==a.ApprovalStatus.NOT_STARTED&&this._renderDueDateElement()}.bind(this));b.on("changed.stages.added",this._addStage.bind(this));b.on("changed.stages.added",function(){var b=this.model.steps[this.model.steps.length-2],c=u.last(this.model.steps);b&&(b.approvalStatus!==a.ApprovalStatus.NOT_STARTED&&c.approvalStatus===a.ApprovalStatus.NOT_STARTED)&&
this._renderDueDateElement()}.bind(this));b.on("submit",this._submitForm.bind(this));this._isSimplePage=!0===i;b=b.languageCodeHelp;this._helpArr={};this._helpArr.CAppApprovalStatusHelp="./help/ApprovalStatusHelp_"+b+".htm";this._helpArr.CAppDueDateHelp="./help/DueDateHelp_"+b+".htm";this._helpArr.CAppApprovalMasterHelp="./help/ApprovalMasterHelp_"+b+".htm";this._helpArr.CAppEditNextVersionHelp="./help/EditNextVersionHelp_"+b+".htm";this._helpArr.CAppWhenNewVersionUploadedHelp="./help/WhenNewVersionUploadedHelp_"+
b+".htm"}t.prototype.onUpdate=function(){this._loadingMsg.remove();this._render()};t.prototype.loading=function(){this.displayElem.empty();this._loadingMsg=m("<div/>").html(h.t("CAppLoadingApprovalSetup"));this.displayElem.append(this._loadingMsg)};t.prototype._doRender=function(){var b=m("<div/>",{"class":"container-fluid wcr-approval"});this._messageWidget||(this._messageWidget=m("<div>",{"class":"messagebar messageWidget add-spacing-bottom"}),new p.MessageWidget(this._messageModel,this._messageWidget));
b.append(this._messageWidget);this._isSimplePage||(!this._header&&!this._options.ajax&&(this._header=m(".page-sub-title")),this._header&&(this._header.addClass("approvalTitle"),b.append(this._header)),this.model.documentId&&(this._approvalStatusElem&&this._approvalStatusElem.remove(),this.model.nextVersion||(this._approvalStatusElem=this._getStatusElement(),this._approvalStatusElem.insertAfter(this._header))));var c=this._getForm();b.append(c);if(this.model.errorObj)this._showErrors(this.model.errorObj);
else if(this.model.isLinkedDocument)c=m("<div>").addClass("next-version-message alert alert-warning").append(m("<div>").text(h.t("CAppNoApprovalSettingsOnLinkedDocs")+". "+h.t("CAppNoApprovalSettingsOnLinkedDocsAdv")+".")),b.append(c),this.displayElem.empty(),this.displayElem.append(b);else if(this.model.newVersionWhileWaitingForWorkflow){c=m("<div>").addClass("next-version-message alert alert-warning").append(m("<div>").text(h.t("CAppWaitingForWorkflowOnPreviousVersion")));b.append(c);var c=m("<div/>",
{"class":"row add-spacing-bottom add-spacing-top"}).appendTo(b),d=m("<div />",{"class":"col-lg-8  col-xs-12"}).append(this._getActionButtons());c.append(d);this.displayElem.empty();this.displayElem.append(b)}else{this.model.nextVersion&&(c=m("<div>").addClass("next-version-message alert alert-warning").append(m("<div>").text(h.t("CAppEditingNextVersion"))),b.append(c));var c=m("<div/>",{"class":"row add-spacing-bottom add-spacing-top"}).appendTo(b),e=m("<div/>",{"class":"add-spacing-bottom"});this._isSimplePage?
this.model.documentId&&!this.model.nextVersion&&e.append(this._getStatusElement()):(e.addClass("nextVersionButtonOnTop"),this.model.nextVersion&&e.addClass("with-message"));this.model.approvalStatus!==a.ApprovalStatus.NOT_DEFINED&&(this.model.documentId&&!this.model.readOnly&&!this.model.isWorkflowDriven())&&(d=this._createHelpBalloon("CAppEditNextVersionHelp"),e.append(m("<div/>").addClass("nextVersionButton").append(this._getSwitchToNextVersionBtn()).append(d)));this._options.showEditNextVersion?
(d=m("<div />",{"class":"col-lg-9 col-lg-pull-3 col-xs-12"}).append(this._getActionButtons()),c.append(m("<div/>",{"class":"col-lg-3 col-lg-push-9 col-xs-12"}).append(e))):d=m("<div />",{"class":"col-xs-12"}).append(this._getActionButtons());c.append(d);c=m("<div/>",{"class":"row add-spacing-bottom"}).appendTo(b);e=m("<div />",{"class":"col-xs-12"+(this.shouldShowSettingsPanel()?" col-lg-9":"")});c.append(e);e.append(this._stagesContainer);this._stagesMessageWidget||(this._stagesMessageWidget=m("<div>",
{"class":"messagebar messageWidget add-spacing-bottom"}),new p.MessageWidget(this._stagesMessageModel,this._stagesMessageWidget));e.append(this._stagesMessageWidget);this.shouldShowSettingsPanel()&&c.append(m("<div/>",{"class":"col-lg-3 col-xs-12 approval-settings-panel"}).append(this._getGeneralSettingsPanel()));this.displayElem.empty();this.displayElem.append(b);u.each(this.stageViews,u.bind(function(a){a.render()},this))}b=u.contains([a.ApprovalStatus.WAITING_FOR_WORKFLOW,a.ApprovalStatus.PENDING],
this.model.approvalStatus);this.model.isWorkflowDriven()&&b&&this._showWorkflowManagedMessage()};t.prototype._getForm=function(){var a=this.model.actionURL;this._options.ajax&&(a+="&ajax=1");this.form=m("<form>",{name:"actionform",id:"actionform",method:"post",action:a});this.xmlContentField=m("<input>",{type:"hidden",id:"xmlcontent",name:"xmlcontent"}).appendTo(this.form);this.actionField=m("<input>",{type:"hidden",id:"actionField",name:"action"}).appendTo(this.form);this.passwordField=m("<input>",
{type:"hidden",id:"password",name:"password"}).appendTo(this.form);this.commentField=m("<input>",{type:"hidden",id:"commentField",name:"comment"}).appendTo(this.form);this.approverIDField=m("<input>",{type:"hidden",id:"approverIDField",name:"approverID"}).appendTo(this.form);this.approverAsUserOrGroupField=m("<input>",{type:"hidden",id:"approverAsUserOrGroupField",name:"approverAsUserOrGroup"}).appendTo(this.form);this.reasonsForRejectionField=m("<input>",{type:"hidden",id:"reasonsForRejectionField",
name:"reasonsForRejection"}).appendTo(this.form);return this.form};t.prototype._submitForm=function(a){this.commentField.val(a.comment);this.actionField.val(a.action);this.model.passwordValidation&&this.passwordField.val(a.password);this.approverIDField.val(a.approverID);this.approverAsUserOrGroupField.val(a.approverAsUserOrGroup);this.reasonsForRejectionField.val(a.reasonsForRejection);this._options.ajax?v.formSubmit(this.form,{dataType:"xml"}).then(function(a){var b=a.querySelector("error msg");
if(b)throw b.textContent;this.model.reset();this.model.readReturnXML(a);this._emit("didSubmit")}.bind(this)).catch(function(a){this._showErrorMessage(a)}.bind(this)).then(function(){this.model.submitDisabled=!1}.bind(this)):this.form.submit()};t.prototype._getStatusElement=function(){var b=m("<div />");b.addClass("approvalStatusLabelContainer");this._isSimplePage&&b.addClass("simple");var c=this._createHelpBalloon("CAppApprovalStatusHelp"),d=m("<span>",{text:h.t("CApp"+this.model.approvalStatus),
"class":a.statusLabels[this.model.approvalStatus]+" approvalStatusLabel"});b.append(d).append(c);return b};t.prototype._getGeneralSettingsPanel=function(){var b=m("<div>",{"class":"collapseSettingsPanel"}).append(m("<a>",{"class":"pull-left collapsed","data-toggle":"collapse","data-target":"#collapseSettings"}).append(m("<i>",{"class":"icon icon-normal"}))),c=m("<div/>",{"class":"panel panel-default"});m("<div/>",{"class":"panel-heading"}).append(m("<h3>",{"class":"panel-title",text:h.t("CAppSettings")})).appendTo(c);
var d=m("<div/>",{"class":"panel-body collapse",id:"collapseSettings"}).appendTo(c);this.model.approvalStatus===a.ApprovalStatus.NOT_STARTED&&!this.model.readOnly&&!this.model.isWorkflowDriven()?(d.append(this._getDueDateElement(!1)),this.model.isStagedApprovalAllowed()&&!this.model.isWorkflowDriven()&&d.append(this._getWhenNewVersionUploadedElement(!1)),d.append(this._getApprovalMasterElement(!1)),d.append(this._getNotificationElement(!1))):this.model.approvalStatus!==a.ApprovalStatus.NOT_DEFINED&&
!this.model.readOnly&&(d.append(this._getDueDateElement(!0)),this.model.isStagedApprovalAllowed()&&!this.model.isWorkflowDriven()&&d.append(this._getWhenNewVersionUploadedElement(!0)),d.append(this._getApprovalMasterElement(!0)),d.append(this._getNotificationElement(!0)));c=m("<div>",{"class":"settingsPanel"}).append(c);return m("<div>").append(b).append(c)};t.prototype._renderDueDateElement=function(){var b=this.displayElem.find(".approval-due-date-element"),c=this.displayElem.find(".final-due-date-element"),
d=null;!this.model.readOnly&&this.model.approvalStatus!==a.ApprovalStatus.NOT_DEFINED&&(d=this._getDueDateElement(this.model.approvalStatus!==a.ApprovalStatus.NOT_STARTED));d&&(b.after(d),b.remove(),c.remove())};t.prototype._getDueDateElement=function(b){var d=h.t("CAppDueDate"),e=this.model.dueDateType,f=h.t("CApp"+e);this.model.dueDateType===a.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&(f+=" "+c.getDateHourAttributeString(0!=this.model.dueDateData.time?new Date(this.model.dueDateData.time):null,this.model.dueDateData.item_name,
this.model.dueDateData.offset)+" ");if(b)return this._createFormEntryWithSelect(d,f,!1);var g=!0;(b=u.last(this.model.steps))&&b.approvalStatus!==a.ApprovalStatus.NOT_STARTED&&(g=!1);b=a.dueDateOptions;!this.model.milestoneAttributeAllowed&&!this.model.documentId&&!this.model.isMultiDocSetup&&(b=a.dueDateOptionsFolderProject);var i=null,j=null,k=function(){j&&(j.remove(),j=null);g&&(this.model.approvalStatus===a.ApprovalStatus.NOT_STARTED&&this.model.isStagedApprovalAllowed()&&this.model.dueDateType===
a.DueDateType.FIXED?(j=this._getDueDateRecalculateButton(),i.append(j)):this.model.dueDateType===a.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&(j=this._getFinalDueDateElement(),j.insertAfter(i)))}.bind(this);this.model.on("changed.duedatetype",k);var m=u.bind(function(a){this.model.changeDueDateType(a)},this),i=this._createFormEntryWithSelect(d,f,g,e,!1,b,m,null,k,"CAppDueDateHelp","approval_duedate_select");i.addClass("approval-due-date-element");return i};t.prototype._getWhenNewVersionUploadedElement=
function(a){var b=h.t("CAppWhenNewVersionUploaded"),c=["RestartApproval","RestartStage","InheritApproval"],d=this.model.uponNewVersion,e=u.bind(function(a){this.model.changeInheritApproval(a)},this);return a?this._createFormEntryWithSelect(b,h.t("CApp"+d),!1):this._createFormEntryWithSelect(b,h.t("CApp"+d),!0,d,!0,c,e,null,null,"CAppWhenNewVersionUploadedHelp","approval_new_version_select")};t.prototype._getApprovalMasterElement=function(b){var d=h.t("CAppApprovalMaster"),e="";this.model.approvalMasterType===
a.ApprovalMasterType.USER&&this.model.approvalMaster===this.currentUser.userId&&(e=h.t("CAppMe"));this.model.approvalMasterType===a.ApprovalMasterType.PROJECT_MANAGER&&(e=h.t("CAppProjectManager"));this.model.approvalMasterType===a.ApprovalMasterType.UPLOADER&&(e=h.t("CAppUploader"));var f;if(this.model.approvalMasterType===a.ApprovalMasterType.USER&&this.model.approvalMaster!==this.currentUser.userId){f=c.findMemberObj("User",this.model.approvalMaster,this.model.projectMembers);var g="";f||(f=c.findMemberObj("User",
this.model.approvalMaster,this.model.usersWithNoAccess),g=m("<div>").append(m("<i>",{"class":"icon icon-warning icon-WCR_Msg-Warning",title:h.t("CAppAppMasterUserNoMember")})).html());f&&(e=b?e+y.getUserNameStringActiveHTML(null,f.firstName,f.lastName,f.userName,f.isActive,h.t("CAppUserDeactivated"),!0):e+y.getUserNameStringActiveText(f.firstName,f.lastName,f.userName,f.isActive,h.t("CAppUserDeactivated")),e+=g)}this.model.approvalMasterType===a.ApprovalMasterType.GROUP&&(f=c.findMemberObj("Group",
this.model.approvalMaster,this.model.projectMembers),null===f?e="<i  class='icon icon-large icon-warning icon-WCR_Msg-Warning' ></i>"+z.xmlencode(h.t("CAppAppMasterGroupNoMember")):(e=h.t("CAppGroup"),f.isRole&&(e=h.t("CAppRole")),e=f.groupName+" ("+e+")"));if(b)return this._createFormEntryWithSelect(d,e,!1);b=this.model.approvalMasterType;this.model.approvalMasterType===a.ApprovalMasterType.USER&&this.model.approvalMaster===this.currentUser.userId?b="$Me$":this.model.approvalMasterType===a.ApprovalMasterType.PROJECT_MANAGER?
b="$PM$":this.model.approvalMasterType===a.ApprovalMasterType.UPLOADER?b="$Uploader$":this.model.approvalMasterType===a.ApprovalMasterType.GROUP?b="$Group$"+this.model.approvalMaster:this.model.approvalMasterType===a.ApprovalMasterType.USER&&(b=this.model.approvalMaster);g=f=!0;this.model.steps[0]&&this.model.steps[0].approvalStatus!==a.ApprovalStatus.NOT_STARTED&&(g=f=!1);var i=["$Me$","$PM$","$Uploader$"],j=[h.t("CAppMe"),h.t("CAppProjectManager"),h.t("CAppUploader")];this.createMemberOptionArrays(this.model.projectMembers,
0,!0,"",!0,i,j);var k=u.bind(function(a){this.model.changeApprovalMaster(a)},this);return this._createFormEntryWithSelect(d,e,f,b,g,i,k,j,null,"CAppApprovalMasterHelp","approval_master_select")};t.prototype._createFormEntryWithSelect=function(a,b,c,d,e,f,g,i,j,k,n){var l;if(c){l=m("<select>",{"class":"form-control","data-sahi-id":n});for(var p=0;p<f.length;p++){var q="",q=i?i[p]:h.t("CApp"+f[p]),q=m("<option>",{value:f[p]}).html(q);f[p]===d&&q.prop("selected",!0);l.append(q)}g&&l.change(function(){var a=
l.val();g(a)})}d=m("<div/>",{"class":"form-group"});m("<label>",{text:a}).appendTo(d);a=m("<div/>",{"class":"form-entry"}).appendTo(d);if(e)a.append(l);else{var s=m("<span>",{"class":"general-settings-form-entry-value"}).html(b).appendTo(a);c&&(a.append(l),l.hide(),s.append(m("<a>",{"class":"btn btn-no-border btn-no-padding-right","data-sahi-id":n+"_edit"}).append(m("<i>",{"class":"icon icon-WCR_Actions-Edit12"}))).on("click",function(){l.show();s.hide();j()}))}k&&(b=this._createHelpBalloon(k),c=
m("<div />").addClass("input-group"),c.append(a.children()),a.append(c),c.append(m("<div />").addClass("input-group-btn").append(b)));return d};t.prototype._getNotificationElement=function(a){this.notificationView=new q(this.model.notificationInfo,!a);a=m("<div />");this.notificationView.setElement(a);return a};t.prototype._getActionButtons=function(){var b=m('<div class="approval-action-buttons">');if(this.model.approvalStatus===a.ApprovalStatus.NOT_DEFINED){this.model.readOnly?this._showWarnMessage(h.t("CAppNotDefined"),
null,this.MSG_TAG):this._addSetupApprovalButton(b,this.model.approvalRuleChanged?!1:!0);if((this.model.documentId||!0===this.model.isMultiDocSetup)&&this.currentUser&&!0===this.currentUser.canStartApproval&&!this.model.nextVersion)(this.model.hasProjectApprovalSetup||this.model.hasFolderApprovalSetup)&&this._addStartDefaultApprovalButton(b);!this.model.readOnly&&this.model.approvalRuleChanged&&(b.prepend(this._getSaveButton()),b.append(this._getRevertButton(!0)))}else this.model.approvalStatus===
a.ApprovalStatus.PENDING?this._addApprovalActions(b):this.model.approvalStatus===a.ApprovalStatus.NOT_STARTED?this._addSaveCancelStartApprovalButtons(b,!0):this.model.approvalStatus===a.ApprovalStatus.WAITING_FOR_WORKFLOW&&!this.model.readOnly&&b.append(this._getFinishApprovalButton());this.model.approvalStatus===a.ApprovalStatus.NOT_DEFINED&&!this.model.readOnly&&this._addMoreActions(b);return b};t.prototype._addSetupApprovalButton=function(b,c){m("<button>",{"class":c?"btn btn-primary add-spacing-right":
"btn btn-default add-spacing-right",type:"button",on:{click:u.bind(function(){this.model.approvalStatus===a.ApprovalStatus.NOT_DEFINED&&this.model.setApprovalStatus(a.ApprovalStatus.NOT_STARTED);this.model.addNewStage(0)},this)}}).append(m("<i>",{"class":"icon icon-WCR_Actions-Appr-Setup12"})).append(" "+h.t("CAppSetupSimpleApproval")).appendTo(b)};t.prototype._addStartDefaultApprovalButton=function(a){m("<button>",{"class":"btn btn-default add-spacing-right",type:"button",on:{click:u.bind(function(){this.save(!0)},
this)}}).append(m("<i>",{"class":"icon icon-WCR_Actions-Appr-Start12"})).append(" "+h.t("CAppStartDefaultApprovalCycle")).appendTo(a)};t.prototype._addMoreActions=function(a){var b=m("<div>",{"class":"feedback-with-actions"}),c=m("<div>",{"class":"feedback-actions"}).append(m("<p>",{text:"More Actions"})),d=m("<ul>");this.model.isProjectSetupAvailable()&&d.append(m("<li>").append(this._getLoadProjectApprovalButton(!1)));this.model.isFolderSetupAvailable()&&d.append(m("<li>").append(this._getLoadFolderApprovalButton(!1)));
this.model.documentId&&this._options.showEditNextVersion&&d.append(m("<li>").append(m("<a>",{text:this.model.nextVersion?h.t("CAppGoBackToCurrentVersion"):h.t("CAppEditApprovalSetupForNextVersion"),on:{click:u.bind(function(){this.model.nextVersion?this.model.backToCurrentVersion():this.model.editSetupForNextVersion()},this)}})));0<d.children().length&&a.append(b.append(c.append(d)))};t.prototype._getLoadProjectApprovalButton=function(a){if(this.model.isProjectSetupAvailable()){var b={on:{click:u.bind(function(){var a=
!0;0<this.model.steps.length&&(a=this.confirmWithWarnings({question:"CAppConfirmLoadProject"}));a&&this.model.loadProjectFolderApproval(!1)},this)}};if(a)return b["class"]="btn btn-default",b.type="button",b.title=h.t("CAppLoadProjectApprovalSetup"),m("<button>",b).append(m("<i>",{"class":"icon icon-WCR_Actions-Project-Load12"}));b.text=h.t("CAppLoadProjectApprovalSetup");return m("<a>",b)}};t.prototype._getLoadFolderApprovalButton=function(a){if(this.model.isFolderSetupAvailable()){var b={on:{click:u.bind(function(){var a=
!0;0<this.model.steps.length&&(a=this.confirmWithWarnings({question:"CAppConfirmLoadProject"}));a&&this.model.loadProjectFolderApproval(!0)},this)}};if(a)return b["class"]="btn btn-default",b.title=h.t("CAppLoadFolderApprovalSetup"),b.type="button",m("<button>",b).append(m("<i>",{"class":"icon icon-WCR_Actions-Folder-Load12"}));b.text=h.t("CAppLoadFolderApprovalSetup");return m("<a>",b)}};t.prototype._addSaveCancelStartApprovalButtons=function(b){var c=!u.some(this.model.steps,function(b){return b.approvalStatus!==
a.ApprovalStatus.NOT_STARTED}),d=m("<div/>",{"class":"pull-left"}),e=m("<div/>",{"class":"pull-right btn-group"}),f=this._getSaveButton(),g=this._getRevertButton(!1),h=this._getStartApprovalButton(),i=this._getClearButton(),j=null,k=null;c&&(j=this._getLoadProjectApprovalButton(!0),k=this._getLoadFolderApprovalButton(!0));f&&d.append(f);h&&d.append(h);j&&e.append(j);k&&e.append(k);g&&e.append(g);i&&e.append(i);b.append(d).append(e);return b};t.prototype._getSaveButton=function(){return this._saveButton=
this.model.readOnly?null:m("<button>",{"class":"btn btn-primary add-spacing-right save-button",type:"button",on:{click:u.bind(function(){if(u.isEmpty(this.model.steps)&&!0===this.model.approvalRuleChanged&&!this.confirmWithWarnings({question:"CAppAreYouSureSaveEmpty"}))return!1;this.validateAndSave(!1)},this)}}).append(m("<i>",{"class":"icon icon-WCR_Save12"})).append(" "+h.t("CAppSave"))};t.prototype.validateAndSave=function(a){var b=this.model.validate();0<b.errors.length?this._showErrors(b):0<
b.warnings.length?this.confirmWithWarnings({question:"CAppContinueAnyway",warnings:b.warnings})&&this.save(a):this.save(a)};t.prototype.save=function(a){var b=null;if(this.model.readOnly){if(!a){this.model.setError({errorMsg:"CAppCannotSaveIfNothingChanged"});return}}else{b=this.model.writeToXML();if(!b)return this.model.setError({errorMsg:"CAppCouldNotSave"}),!1;this.xmlContentField&&this.xmlContentField.val(b)}if(this.actionField)this.model.nextVersion?this.actionField.val("saveNextDocVersion"):
a?this.actionField.val("startCycle"):this.actionField.val("save");else throw"actionField is null";if(this.model.submitDisabled)this.model.setError({errorMsg:"CAppApprovalActionOngoing"});else if(this.model.submitDisabled=!0,this.model.submitAllowed){this.model.confirmNeeded=!1;if(this._options.ajax)return v.formSubmit(this.form,{dataType:"xml"}).then(function(a){var b=a.querySelector("error msg");if(b)throw b.textContent;this.model.reset();this.model.readReturnXML(a);this._emit("didSubmit")}.bind(this)).catch(function(a){this._showErrorMessage(a)}.bind(this)).then(function(){this.model.submitDisabled=
!1}.bind(this));this.form.submit()}else return b&&document.getElementById(this.model.saveFieldId)&&(document.getElementById(this.model.saveFieldId).value=b),this.model.submitDisabled=!1};t.prototype._getRevertButton=function(a){if(!this.model.readOnly&&!this.model.isWorkflowDriven()){var b=m("<button>",{"class":"btn btn-default",type:"button",title:h.t("CAppRevert"),on:{click:u.bind(function(){this.model.cancel()},this)}}).append(m("<i>",{"class":"icon icon-WCR_Revert12"}));a&&(b.append(" "+h.t("CAppRevert")),
b.addClass("add-spacing-right"));return b}};t.prototype._getClearButton=function(){if(!this.model.readOnly&&0<this.model.steps.length&&this.model.steps[0].approvalStatus===a.ApprovalStatus.NOT_STARTED)return m("<button>",{"class":"btn btn-default",type:"button",title:h.t("CAppClear"),on:{click:u.bind(function(){this.model.clear()},this)}}).append(m("<i>",{"class":"icon icon-WCR_Actions-Clear12"}))};t.prototype._getStartApprovalButton=function(){if(this.model.approvalStatus===a.ApprovalStatus.NOT_STARTED&&
(this.model.documentId||!0===this.model.isMultiDocSetup)&&this.currentUser&&!0===this.currentUser.canStartApproval&&!this.model.nextVersion)return m("<button>",{"class":"btn btn-default add-spacing-right",type:"button",on:{click:u.bind(function(){this.validateAndSave(!0)},this)}}).append(m("<i>",{"class":"icon icon-WCR_Actions-Appr-Start12"})).append(" "+h.t("CAppStartApprovalCycle"))};t.prototype._getFinishApprovalButton=function(){if(!this.model.readOnly&&this.model.approvalStatus===a.ApprovalStatus.WAITING_FOR_WORKFLOW)return m("<button>",
{"class":"btn btn-default add-spacing-right",type:"button",on:{click:u.bind(function(){this.confirmWithWarnings({question:"CAppFinishApprovalCycleConfirm"})&&(this.model.submitDisabled?this.model.setError({errorMsg:"CAppApprovalActionOngoing"}):(this.model.submitDisabled=!0,this.model.confirmNeeded=!1,this.model.submit({action:"finishCycle"})))},this)}}).append(m("<i>",{"class":"icon icon-WCR_Actions-Appr-Finish12"})).append(" "+h.t("CAppFinishApprovalCycle"))};t.prototype._addApprovalActions=function(b){var c=
!1;this.model.approvalStatus===a.ApprovalStatus.PENDING&&this.model.documentId&&(this.currentUser&&this.currentUser.canStartApproval)&&(c=!0);this.approveButtonsToolbar.setElement(b);this.approveButtonsToolbar.render(3,c)};t.prototype._getSwitchToNextVersionBtn=function(){var a=!this.model.nextVersion?"icon icon-WCR_Actions-Edit12":"icon icon-WCR_Revert12",b=!this.model.nextVersion?h.t("CAppEditApprovalSetupForNextVersion"):h.t("CAppGoBackToCurrentVersion");return m("<button>",{"class":"btn btn-default",
type:"button",on:{click:u.bind(function(){var a=!0;this.model.approvalRuleChanged&&(a=this.confirmWithWarnings({question:this.model.newVersion?"CAppConfirmBackToCurrent":"CAppConfirmGoToNextVersion"}));if(!a)return!1;this.model.nextVersion?this.model.backToCurrentVersion():this.model.editSetupForNextVersion()},this)}}).append(m("<i>",{"class":a})).append(" "+b)};t.prototype._getDueDateRecalculateButton=function(){if(0===m("#dueDateRecalcDialog").length){var a=new b(h,g);a.d.defaultDueHour=34;this.displayElem.append(a.getRenderedHtml())}return m("<button>",
{"class":"btn btn-default add-spacing-top",type:"button",text:h.t("CAppDueDateCalculation"),on:{click:function(){this._createDueDateRecalcDialog();m("#dueDateRecalcDialog").dialog("open")}.bind(this)}})};t.prototype._createDueDateRecalcDialog=u.once(function(){var a={};a[h.t("CAppCancel")]=function(){m(this).dialog("close")};a[h.t("CAppOK")]=function(){this._doDueDateOperation()&&m("#dueDateRecalcDialog").dialog("close")}.bind(this);var b="auto";m.browser.msie&&(b="700px");m("#dueDateRecalcDialog").dialog({autoOpen:!1,
modal:!1,closeOnEscape:!0,draggable:!0,height:"auto",resizable:!0,width:b,maxWidth:500,buttons:a});this._createCalendar("#shiftLatestToDate","#shiftLatestToHour");this._createCalendar("#shiftFirstToDate","#shiftFirstToHour");this._createCalendar("#distributeFromDate","#distributeFromHour");this._createCalendar("#distributeToDate","#distributeToHour")});t.prototype._doDueDateOperation=function(){var b=!0;if(this.model.dueDateType!==a.DueDateType.FIXED)throw"You cannot change due dates when the due date type is not fixed due dates";
var c=document.getElementsByName("dueDateOperations"),c=u.find(c,function(a){return a.checked}),d;switch(null!=c?parseInt(c.value):null){case null:window.alert(h.t("CAppSelectOperation"));b=!1;break;case 0:c=parseInt(document.getElementById("giveDays").value,10);d=parseFloat(document.getElementById("giveHours").value);this.model.addTimeToStages(c,d)||(window.alert(h.t("CAppDaysAndHoursMustBePositive")),b=!1);break;case 1:c=parseInt(document.getElementById("shiftDays").value);d=parseFloat(document.getElementById("shiftHours").value);
this.model.shiftDueDatesOfStages(c,d)||(window.alert(h.t("CAppDaysAndHoursMustBeSameSign")),b=!1);break;case 2:if(!document.getElementById("shiftLatestToDate").value){window.alert(h.t("CAppPleaseGiveADate"));b=!1;break}b=w.getDateString(document.getElementById("shiftLatestToDate").value);c=document.getElementById("shiftLatestToHour").value;b=new Date(b);c&&b.setHours(Math.floor(c/2));2*Math.floor(c/2)==c?b.setMinutes(0):b.setMinutes(30);b=w.fixDateSummerWinterTime(b,!0);b=this.model.shiftDueDatesToLatest(b,
h);break;case 3:if(!this.model.steps||!this.model.steps[0]){window.alert(h.t("CAppFirstStepHasNoDueDate"));return}if(this.model.steps[0].approvalStatus!==a.ApprovalStatus.NOT_STARTED){window.alert(h.t("CAppCannotShiftIfStarted"));return}if(!document.getElementById("shiftFirstToDate").value){window.alert(h.t("CAppPleaseGiveADate"));b=!1;break}b=w.getDateString(document.getElementById("shiftFirstToDate").value);c=document.getElementById("shiftFirstToHour").value;b=new Date(b);c&&b.setHours(Math.floor(c/
2));2*Math.floor(c/2)==c?b.setMinutes(0):b.setMinutes(30);b=w.fixDateSummerWinterTime(b,!0);b=this.model.shiftDueDatesToFirst(b,h);break;case 4:if(!document.getElementById("distributeFromDate").value||!document.getElementById("distributeToDate").value){window.alert(h.t("CAppPleaseGiveADate"));b=!1;break}c=new Date(w.getDateString(document.getElementById("distributeFromDate").value));(d=document.getElementById("distributeFromHour").value)&&c.setHours(Math.floor(d/2));2*Math.floor(d/2)==d?c.setMinutes(0):
c.setMinutes(30);c=w.fixDateSummerWinterTime(c,!0);d=new Date(w.getDateString(document.getElementById("distributeToDate").value));var e=document.getElementById("distributeToHour").value;e&&d.setHours(Math.floor(e/2));2*Math.floor(e/2)==e?d.setMinutes(0):d.setMinutes(30);d=w.fixDateSummerWinterTime(d,!0);this.model.distributeDueDatesEvenly(c,d)||(window.alert(h.t("CAppFirstDayLater")),b=!1);break;default:window.alert("this operation is not implemented")}return b};t.prototype._getFinalDueDateElement=
function(){if(!this.model.finalDueDate||this.model.finalDueDate.constructor!==Date)this.model.finalDueDate=new Date;var a=new A({requireCategory:!0,categoryId:this.model.categoryId,supportOffset:this.model.milestoneAttributeAllowed,sahiId:"dueDateXDropFinal"});a.setValue(this.model.dueDateData);a.onChange(u.bind(function(){var b=a.getValue();b&&this.model.setDueDateData(b)},this));return m("<div/>",{"class":"form-group final-due-date-element"}).append(m("<label>",{text:h.t("CAppFinalDueDate")})).append(m("<div/>",
{"class":"form-entry"}).append(a.getElement()).append(m('<div class="clearfix final-due-date">')))};t.prototype._createCalendar=function(a,b){null!==m(a)&&m(a).datepicker({dateFormat:"M dd, yy",onClose:function(){var a=m(b)[0];a&&0===a.selectedIndex&&(a.selectedIndex=37)}})};t.prototype._toggleSaveButtonEnabled=function(){this._saveButton&&(this.model.approvalRuleChanged?this._saveButton.removeAttr("disabled"):this._saveButton.attr("disabled","disabled"))};t.prototype.getStagesContainer=function(){return this._stagesContainer};
t.prototype._addStage=function(a){var b=this.model.getStageNumber(a)-1;this._addViewsAtIndex(b,a)};t.prototype._addViewsAtIndex=function(a,b){var c=this.stageViews.length===a,d=new n(this.model,b,{inPopup:this._options.inPopup});this.stageViews.splice(a,0,d);0===a?this._stagesContainer.prepend(d.element):c?this._stagesContainer.append(d.element):this._getStageViewForStageAtIndex(a-1).element.after(d.element);d.render()};t.prototype._getStageViewForStageAtIndex=function(a){var b=this.model.getStageAtIndex(a);
return u.find(this.stageViews,function(a){return a.stageModel===b})};t.prototype._deleteStageView=function(){u.each(arguments,function(a){var b=u.findIndex(this.stageViews,function(b){return b.stageModel===a});-1<b&&this.stageViews.splice(b,1)}.bind(this))};t.prototype.createMemberOptionArrays=function(a,b,d,e,f,g,i){if(this.model.roleAssignments&&0<this.model.roleAssignments.length&&f)for(var f=h.t("CAppRole"),j=h.t("CAppGroup"),k=0;k<this.model.roleAssignments.length;k++){var l=this.model.roleAssignments[k],
m=l.roleID,n=l.roleName,p=c.findMemberObj("Group",m,this.model.projectMembers);if(!(null===p||"undefined"===p)){p=l.userRoleAssignments;l=l.groupRoleAssignments;g.push("$Group$"+m);i.push(n+"<"+f+">");if(p&&0<p.length&&!d)for(m=0;m<p.length;m++){var n=p[m],q=n.name;g.push(n.ID);i.push("&nbsp;&nbsp;&nbsp;&nbsp;"+q)}if(l&&0<l.length&&!d)for(p=0;p<l.length;p++){var s=l[p],m=s.ID,n=s.name,q=s.assigneeID,s=s.assigneeName,t=!1;q&&0<q.length&&(s&&0<s.length)&&(t=!0);t?i.push("&nbsp;&nbsp;&nbsp;&nbsp;"+s+
" @ "+n+"<"+j+">"):i.push("&nbsp;&nbsp;&nbsp;&nbsp;"+n+"<"+j+">");t?g.push(q):g.push("$Group$"+m)}}}for(f=0;f<a.length;f++)if((j=a[f])&&(!d||!0===j.canBeApprovalMaster)){k="";for(l=0;l<b;l++)k+="&nbsp;&nbsp;&nbsp;&nbsp;";l=j.isActive||this.model.approvalMaster===j.userId;if("User"===j.memberType&&l){if(k+=z.xmlencode(y.getUserNameStringActiveText(j.firstName,j.lastName,j.userName,j.isActive,h.t("CAppUserDeactivated"))),!e||-1!==k.toLowerCase().indexOf(e.toLowerCase()))g.push(j.userId),i.push(k)}else if("Group"===
j.memberType&&!j.isRole){j.groupName&&(l=h.t("CAppGroup"),j.isRole&&(l=h.t("CAppRole")),k+=j.groupName+"<"+l+">");if(!e||-1!==k.toLowerCase().indexOf(e.toLowerCase()))g.push("$Group$"+j.groupId),i.push(k);j.members&&0<j.members.length&&this.createMemberOptionArrays(j.members,b+1,d,e,!1,g,i)}}};t.prototype._showErrors=function(a){var b=a.errorMsg?h.t(a.errorMsg)+"\n":"";if(a.errors)for(var c=0;c<a.errors.length;c++){var d=a.errors[c];d.parameters||(d.parameters=[]);d.inline?b+="- "+d.tag:(0<c&&(b+=
"\n"),d.parameters.unshift(d.tag),b+="- "+h.t.apply(this,d.parameters))}this._showErrorMessage(b,null,this.MSG_TAG)};t.prototype.confirmWithWarnings=function(a){var b=a.warningMsg?h.t(a.warningMsg)+"\n":"";a.warnings&&u.each(u.sortBy(a.warnings,"tag"),function(c,d){c.parameters||(c.parameters=[]);0<d&&(b+="\n");1<a.warnings.length&&(b+="- ");c.inline?b+=c.tag:(c.parameters.unshift(c.tag),b+=h.t.apply(this,c.parameters))});a.question&&(b+="\n\n"+h.t(a.question));return window.confirm(b)};t.prototype._showSuccessMessage=
function(a,b,c,d){this._messageModel.markObsolete(d);a=new p.Message(p.MessageType.SUCCESS,a,b,c,d);this._messageModel.addToMessageQueue(a)};t.prototype._showErrorMessage=function(a,b,c){this._messageModel.markObsolete(c);a=new p.Message(p.MessageType.ERROR,a,b,!1,c);this._messageModel.addToMessageQueue(a)};t.prototype._showWarnMessage=function(a,b,c){this._messageModel.markObsolete(c);a=new p.Message(p.MessageType.WARN,a,b,!1,c);this._messageModel.addToMessageQueue(a)};t.prototype._showWorkflowManagedMessage=
function(){var a=h.t("CAppWarnApprovalManagedByWorkflow");this._stagesMessageModel.markObsolete(this.MSG_TAG);a=new p.Message(p.MessageType.INFO,a,null,!1,this.MSG_TAG);this._stagesMessageModel.addToMessageQueue(a)};t.prototype._createHelpBalloon=function(a){a=m("<a />").addClass("inline_help").attr("title",h.t("CAppHelp")).attr("help-info",a);a.append(m("<i />").addClass("icon icon-WCR_Info-Balloon"));a.on("click",u.bind(function(a){var b=a.currentTarget;a.preventDefault();a.stopPropagation();a=
m(b).attr("help-info");window.open(this._helpArr[a],a).focus()},this));return a};t.prototype.shouldShowSettingsPanel=function(){return this.model.approvalStatus!==a.ApprovalStatus.NOT_DEFINED&&!this.model.readOnly};return t});
define("approval/Approval","approval/ApprovalConstants approval/model/ApprovalModel approval/model/ApproveRejectViewModel approval/controller/SortableController approval/view/ApprovalView utils/webi18n!Approval jquery underscore wcr/hover wcr/date wcr/dateShift wcr/datetools wcr/webcenter_ajax".split(" "),function(b,a,c,q,n,k,d,p){function e(e){var g=(e||{}).displayId||null,k=(e||{}).readURL||null,i=(e||{}).actionURL||null,h=(e||{}).docVersionID||null,v=(e||{}).docName||null,f=(e||{}).currentUser||
null,s=(e||{}).stagedApprovalAllowed||null,w=(e||{}).isViewFile||null,m=(e||{}).isEncapsulated||null;this.afterInitializationCallback=(e||{}).afterInitializationCallback||function(){};var u=(e||{}).onUpdateCallback||null;this.model=new a(e);e=new c({actionURL:i,isEncapsulated:m,isViewable:w,onUpdateCallback:u,docVersionID:h,docName:v});this.view=new n(this.model,e,d("#"+g),f,-1!==k.indexOf("simplePage"));this._sortableController=new q(this.view,this.model);this._sortableController.disable();this.model.on("initialized",
function(){s&&(this.model.approvalStatus===b.ApprovalStatus.NOT_DEFINED||this.model.approvalStatus===b.ApprovalStatus.NOT_STARTED)?this._sortableController.enable():this._sortableController.disable()}.bind(this));this.model.once("initialized",p.partial(this.afterInitializationCallback,this));m||(window.onbeforeunload=p.bind(this.confirmExit,this),this.model.confirmNeeded=!0)}e.prototype.confirmExit=function(){if(this.model.confirmNeeded&&this.model.approvalRuleChanged)return k.t("CAppConfirmPageExit")};
e.prototype.setupSingleStageApproval=function(){this.model.approvalStatus===b.ApprovalStatus.NOT_DEFINED&&(this.model.setApprovalStatus(b.ApprovalStatus.NOT_STARTED),this.model.addNewStage(0))};return e});